Module accessibility

Module accessibility 

Modules

events

Structs

AxNode
A node in the accessibility tree.
AxNodeBuilder
Builder for AxNode.
AxProperty
AxPropertyBuilder
Builder for AxProperty.
AxRelatedNode
AxRelatedNodeBuilder
Builder for AxRelatedNode.
AxValue
A single computed AX property.
AxValueBuilder
Builder for AxValue.
AxValueSource
A single source for a computed AX property.
AxValueSourceBuilder
Builder for AxValueSource.
Disable
DisableReturnObject
Disables the accessibility domain.
Enable
EnableReturnObject
Enables the accessibility domain which causes AXNodeIds to remain consistent between method calls. This turns on accessibility for the page, which can impact performance until accessibility is disabled.
GetAXNodeAndAncestors
Fetches a node and all ancestors up to and including the root. Requires enable() to have been called previously.
GetAXNodeAndAncestorsBuilder
Builder for GetAXNodeAndAncestors.
GetAXNodeAndAncestorsReturnObject
Fetches a node and all ancestors up to and including the root. Requires enable() to have been called previously.
GetAXNodeAndAncestorsReturnObjectBuilder
Builder for GetAXNodeAndAncestorsReturnObject.
GetChildAXNodes
Fetches a particular accessibility node by AXNodeId. Requires enable() to have been called previously.
GetChildAXNodesBuilder
Builder for GetChildAXNodes.
GetChildAXNodesReturnObject
Fetches a particular accessibility node by AXNodeId. Requires enable() to have been called previously.
GetChildAXNodesReturnObjectBuilder
Builder for GetChildAXNodesReturnObject.
GetFullAXTree
Fetches the entire accessibility tree for the root Document
GetFullAXTreeBuilder
Builder for GetFullAXTree.
GetFullAXTreeReturnObject
Fetches the entire accessibility tree for the root Document
GetFullAXTreeReturnObjectBuilder
Builder for GetFullAXTreeReturnObject.
GetPartialAXTree
Fetches the accessibility node and partial accessibility tree for this DOM node, if it exists.
GetPartialAXTreeBuilder
Builder for GetPartialAXTree.
GetPartialAXTreeReturnObject
Fetches the accessibility node and partial accessibility tree for this DOM node, if it exists.
GetPartialAXTreeReturnObjectBuilder
Builder for GetPartialAXTreeReturnObject.
GetRootAXNode
Fetches the root node. Requires enable() to have been called previously.
GetRootAXNodeBuilder
Builder for GetRootAXNode.
GetRootAXNodeReturnObject
Fetches the root node. Requires enable() to have been called previously.
GetRootAXNodeReturnObjectBuilder
Builder for GetRootAXNodeReturnObject.
QueryAXTree
Query a DOM node’s accessibility subtree for accessible name and role. This command computes the name and role for all nodes in the subtree, including those that are ignored for accessibility, and returns those that match the specified name and role. If no DOM node is specified, or the DOM node does not exist, the command returns an error. If neither accessibleName or role is specified, it returns all the accessibility nodes in the subtree.
QueryAXTreeBuilder
Builder for QueryAXTree.
QueryAXTreeReturnObject
Query a DOM node’s accessibility subtree for accessible name and role. This command computes the name and role for all nodes in the subtree, including those that are ignored for accessibility, and returns those that match the specified name and role. If no DOM node is specified, or the DOM node does not exist, the command returns an error. If neither accessibleName or role is specified, it returns all the accessibility nodes in the subtree.
QueryAXTreeReturnObjectBuilder
Builder for QueryAXTreeReturnObject.

Enums

AxNodeBuilderError
Error type for AxNodeBuilder
AxPropertyBuilderError
Error type for AxPropertyBuilder
AxPropertyName
AxRelatedNodeBuilderError
Error type for AxRelatedNodeBuilder
AxValueBuilderError
Error type for AxValueBuilder
AxValueNativeSourceType
AxValueSourceBuilderError
Error type for AxValueSourceBuilder
AxValueSourceType
AxValueType
GetAXNodeAndAncestorsBuilderError
Error type for GetAXNodeAndAncestorsBuilder
GetAXNodeAndAncestorsReturnObjectBuilderError
Error type for GetAXNodeAndAncestorsReturnObjectBuilder
GetChildAXNodesBuilderError
Error type for GetChildAXNodesBuilder
GetChildAXNodesReturnObjectBuilderError
Error type for GetChildAXNodesReturnObjectBuilder
GetFullAXTreeBuilderError
Error type for GetFullAXTreeBuilder
GetFullAXTreeReturnObjectBuilderError
Error type for GetFullAXTreeReturnObjectBuilder
GetPartialAXTreeBuilderError
Error type for GetPartialAXTreeBuilder
GetPartialAXTreeReturnObjectBuilderError
Error type for GetPartialAXTreeReturnObjectBuilder
GetRootAXNodeBuilderError
Error type for GetRootAXNodeBuilder
GetRootAXNodeReturnObjectBuilderError
Error type for GetRootAXNodeReturnObjectBuilder
QueryAXTreeBuilderError
Error type for QueryAXTreeBuilder
QueryAXTreeReturnObjectBuilderError
Error type for QueryAXTreeReturnObjectBuilder

Type Aliases

AxNodeId