pub struct AxValueSourceBuilder { /* private fields */ }Expand description
Builder for AxValueSource.
Implementations
Sourceimpl AxValueSourceBuilder
impl AxValueSourceBuilder
Sourcepub fn type<VALUE: Into<AxValueSourceType>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn type<VALUE: Into<AxValueSourceType>>( &mut self, value: VALUE, ) -> &mut Self
What type of source this is.
Sourcepub fn value<VALUE: Into<AxValue>>(&mut self, value: VALUE) -> &mut Self
pub fn value<VALUE: Into<AxValue>>(&mut self, value: VALUE) -> &mut Self
The value of this property source.
Sourcepub fn attribute<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn attribute<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The name of the relevant attribute, if any.
Sourcepub fn attribute_value<VALUE: Into<AxValue>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn attribute_value<VALUE: Into<AxValue>>( &mut self, value: VALUE, ) -> &mut Self
The value of the relevant attribute, if any.
Sourcepub fn superseded<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn superseded<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether this source is superseded by a higher priority source.
Sourcepub fn native_source<VALUE: Into<AxValueNativeSourceType>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn native_source<VALUE: Into<AxValueNativeSourceType>>( &mut self, value: VALUE, ) -> &mut Self
The native markup source for this value, e.g. a \<label\> element.
Sourcepub fn native_source_value<VALUE: Into<AxValue>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn native_source_value<VALUE: Into<AxValue>>( &mut self, value: VALUE, ) -> &mut Self
The value, such as a node or node list, of the native source.
Sourcepub fn invalid<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn invalid<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether the value for this property is invalid.
Sourcepub fn invalid_reason<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn invalid_reason<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Reason for the value being invalid, if it is.
Sourcepub fn build(&self) -> Result<AxValueSource, AxValueSourceBuilderError>
pub fn build(&self) -> Result<AxValueSource, AxValueSourceBuilderError>