pub struct GetPartialAXTreeBuilder { /* private fields */ }Expand description
Builder for GetPartialAXTree.
Implementations
Sourceimpl GetPartialAXTreeBuilder
impl GetPartialAXTreeBuilder
Sourcepub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
pub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
Identifier of the node to get the partial accessibility tree for.
Sourcepub fn backend_node_id<VALUE: Into<BackendNodeId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn backend_node_id<VALUE: Into<BackendNodeId>>( &mut self, value: VALUE, ) -> &mut Self
Identifier of the backend node to get the partial accessibility tree for.
Sourcepub fn object_id<VALUE: Into<RemoteObjectId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn object_id<VALUE: Into<RemoteObjectId>>( &mut self, value: VALUE, ) -> &mut Self
JavaScript object id of the node wrapper to get the partial accessibility tree for.
Sourcepub fn fetch_relatives<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn fetch_relatives<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether to fetch this node’s ancestors, siblings and children. Defaults to true.
Sourcepub fn build(&self) -> Result<GetPartialAXTree, GetPartialAXTreeBuilderError>
pub fn build(&self) -> Result<GetPartialAXTree, GetPartialAXTreeBuilderError>