pub struct QueryAXTreeBuilder { /* private fields */ }Expand description
Builder for QueryAXTree.
Implementations
Sourceimpl QueryAXTreeBuilder
impl QueryAXTreeBuilder
Sourcepub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
pub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
Identifier of the node for the root to query.
Sourcepub fn backend_node_id<VALUE: Into<BackendNodeId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn backend_node_id<VALUE: Into<BackendNodeId>>( &mut self, value: VALUE, ) -> &mut Self
Identifier of the backend node for the root to query.
Sourcepub fn object_id<VALUE: Into<RemoteObjectId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn object_id<VALUE: Into<RemoteObjectId>>( &mut self, value: VALUE, ) -> &mut Self
JavaScript object id of the node wrapper for the root to query.
Sourcepub fn accessible_name<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn accessible_name<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
Find nodes with this computed name.
Sourcepub fn role<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn role<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Find nodes with this computed role.
Sourcepub fn build(&self) -> Result<QueryAXTree, QueryAXTreeBuilderError>
pub fn build(&self) -> Result<QueryAXTree, QueryAXTreeBuilderError>