pub struct ViewOrScrollTimelineBuilder { /* private fields */ }Expand description
Builder for ViewOrScrollTimeline.
Implementations
Sourceimpl ViewOrScrollTimelineBuilder
impl ViewOrScrollTimelineBuilder
Sourcepub fn source_node_id<VALUE: Into<BackendNodeId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn source_node_id<VALUE: Into<BackendNodeId>>( &mut self, value: VALUE, ) -> &mut Self
Scroll container node
Sourcepub fn start_offset<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn start_offset<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Represents the starting scroll position of the timeline as a length offset in pixels from scroll origin.
Sourcepub fn end_offset<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn end_offset<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Represents the ending scroll position of the timeline as a length offset in pixels from scroll origin.
Sourcepub fn subject_node_id<VALUE: Into<BackendNodeId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn subject_node_id<VALUE: Into<BackendNodeId>>( &mut self, value: VALUE, ) -> &mut Self
The element whose principal box’s visibility in the scrollport defined the progress of the timeline. Does not exist for animations with ScrollTimeline
Sourcepub fn axis<VALUE: Into<ScrollOrientation>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn axis<VALUE: Into<ScrollOrientation>>( &mut self, value: VALUE, ) -> &mut Self
Orientation of the scroll
Sourcepub fn build(
&self,
) -> Result<ViewOrScrollTimeline, ViewOrScrollTimelineBuilderError>
pub fn build( &self, ) -> Result<ViewOrScrollTimeline, ViewOrScrollTimelineBuilderError>