pub struct GetEncodedResponse {
pub request_id: RequestId,
pub encoding: GetEncodedResponseEncodingOption,
pub quality: Option<JsFloat>,
pub size_only: Option<bool>,
}Expand description
Returns the response body and size if it were re-encoded with the specified settings. Only applies to images.
Fields
request_id: RequestIdIdentifier of the network request to get content for.
encoding: GetEncodedResponseEncodingOptionThe encoding to use.
quality: Option<JsFloat>The quality of the encoding (0-1). (defaults to 1)
size_only: Option<bool>Whether to only return the size information (defaults to false).