pub struct ScanRecordBuilder { /* private fields */ }Expand description
Builder for ScanRecord.
Implementations
Sourceimpl ScanRecordBuilder
impl ScanRecordBuilder
pub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn uuids<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn appearance<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn appearance<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Stores the external appearance description of the device.
Sourcepub fn tx_power<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn tx_power<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Stores the transmission power of a broadcasting device.
Sourcepub fn manufacturer_data<VALUE: Into<Vec<ManufacturerData>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn manufacturer_data<VALUE: Into<Vec<ManufacturerData>>>( &mut self, value: VALUE, ) -> &mut Self
Key is the company identifier and the value is an array of bytes of manufacturer specific data.
Sourcepub fn build(&self) -> Result<ScanRecord, ScanRecordBuilderError>
pub fn build(&self) -> Result<ScanRecord, ScanRecordBuilderError>