pub struct SimulateDescriptorOperationResponseReturnObject(pub Option<Value>);Expand description
Simulates the response from the descriptor with |descriptorId| for a descriptor operation of |type|. The |code| value follows the Error Codes from Bluetooth Core Specification Vol 3 Part F 3.4.1.1 Error Response. The |data| is expected to exist when simulating a successful read operation response.
Tuple Fields
0: Option<Value>Trait Implementations
Sourceimpl Clone for SimulateDescriptorOperationResponseReturnObject
impl Clone for SimulateDescriptorOperationResponseReturnObject
Sourcefn clone(&self) -> SimulateDescriptorOperationResponseReturnObject
fn clone(&self) -> SimulateDescriptorOperationResponseReturnObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SimulateDescriptorOperationResponseReturnObject
impl<'de> Deserialize<'de> for SimulateDescriptorOperationResponseReturnObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SimulateDescriptorOperationResponseReturnObject
impl PartialEq for SimulateDescriptorOperationResponseReturnObject
Sourcefn eq(&self, other: &SimulateDescriptorOperationResponseReturnObject) -> bool
fn eq(&self, other: &SimulateDescriptorOperationResponseReturnObject) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SimulateDescriptorOperationResponseReturnObject