Module browser

Module browser 

Modules

events

Structs

AddPrivacySandboxCoordinatorKeyConfig
Configures encryption keys used with a given privacy sandbox API to talk to a trusted coordinator. Since this is intended for test automation only, coordinatorOrigin must be a .test domain. No existing coordinator configuration for the origin may exist.
AddPrivacySandboxCoordinatorKeyConfigBuilder
Builder for AddPrivacySandboxCoordinatorKeyConfig.
AddPrivacySandboxCoordinatorKeyConfigReturnObject
Configures encryption keys used with a given privacy sandbox API to talk to a trusted coordinator. Since this is intended for test automation only, coordinatorOrigin must be a .test domain. No existing coordinator configuration for the origin may exist.
AddPrivacySandboxEnrollmentOverride
Allows a site to use privacy sandbox features that require enrollment without the site actually being enrolled. Only supported on page targets.
AddPrivacySandboxEnrollmentOverrideBuilder
Builder for AddPrivacySandboxEnrollmentOverride.
AddPrivacySandboxEnrollmentOverrideReturnObject
Allows a site to use privacy sandbox features that require enrollment without the site actually being enrolled. Only supported on page targets.
Bounds
Browser window bounds information
BoundsBuilder
Builder for Bounds.
Bucket
Chrome histogram bucket.
BucketBuilder
Builder for Bucket.
CancelDownload
Cancel a download if in progress
CancelDownloadBuilder
Builder for CancelDownload.
CancelDownloadReturnObject
Cancel a download if in progress
Close
CloseReturnObject
Close browser gracefully.
Crash
CrashGpuProcess
CrashGpuProcessReturnObject
Crashes GPU process.
CrashReturnObject
Crashes browser on the main thread.
ExecuteBrowserCommand
Invoke custom browser commands used by telemetry.
ExecuteBrowserCommandBuilder
Builder for ExecuteBrowserCommand.
ExecuteBrowserCommandReturnObject
Invoke custom browser commands used by telemetry.
GetBrowserCommandLine
GetBrowserCommandLineReturnObject
Returns the command line switches for the browser process if, and only if –enable-automation is on the commandline.
GetBrowserCommandLineReturnObjectBuilder
Builder for GetBrowserCommandLineReturnObject.
GetHistogram
Get a Chrome histogram by name.
GetHistogramBuilder
Builder for GetHistogram.
GetHistogramReturnObject
Get a Chrome histogram by name.
GetHistogramReturnObjectBuilder
Builder for GetHistogramReturnObject.
GetHistograms
Get Chrome histograms.
GetHistogramsBuilder
Builder for GetHistograms.
GetHistogramsReturnObject
Get Chrome histograms.
GetHistogramsReturnObjectBuilder
Builder for GetHistogramsReturnObject.
GetVersion
GetVersionReturnObject
Returns version information.
GetVersionReturnObjectBuilder
Builder for GetVersionReturnObject.
GetWindowBounds
Get position and size of the browser window.
GetWindowBoundsBuilder
Builder for GetWindowBounds.
GetWindowBoundsReturnObject
Get position and size of the browser window.
GetWindowBoundsReturnObjectBuilder
Builder for GetWindowBoundsReturnObject.
GetWindowForTarget
Get the browser window that contains the devtools target.
GetWindowForTargetBuilder
Builder for GetWindowForTarget.
GetWindowForTargetReturnObject
Get the browser window that contains the devtools target.
GetWindowForTargetReturnObjectBuilder
Builder for GetWindowForTargetReturnObject.
GrantPermissionsDeprecated
Grant specific permissions to the given origin and reject all others. Deprecated. Use setPermission instead.
GrantPermissionsBuilder
Builder for GrantPermissions.
GrantPermissionsReturnObjectDeprecated
Grant specific permissions to the given origin and reject all others. Deprecated. Use setPermission instead.
Histogram
Chrome histogram.
HistogramBuilder
Builder for Histogram.
PermissionDescriptor
Definition of PermissionDescriptor defined in the Permissions API: https://w3c.github.io/permissions/#dom-permissiondescriptor.
PermissionDescriptorBuilder
Builder for PermissionDescriptor.
ResetPermissions
Reset all permission management for all origins.
ResetPermissionsBuilder
Builder for ResetPermissions.
ResetPermissionsReturnObject
Reset all permission management for all origins.
SetContentsSize
Set size of the browser contents resizing browser window as necessary.
SetContentsSizeBuilder
Builder for SetContentsSize.
SetContentsSizeReturnObject
Set size of the browser contents resizing browser window as necessary.
SetDockTile
Set dock tile details, platform-specific.
SetDockTileBuilder
Builder for SetDockTile.
SetDockTileReturnObject
Set dock tile details, platform-specific.
SetDownloadBehavior
Set the behavior when downloading a file.
SetDownloadBehaviorBuilder
Builder for SetDownloadBehavior.
SetDownloadBehaviorReturnObject
Set the behavior when downloading a file.
SetPermission
Set permission settings for given embedding and embedded origins.
SetPermissionBuilder
Builder for SetPermission.
SetPermissionReturnObject
Set permission settings for given embedding and embedded origins.
SetWindowBounds
Set position and/or size of the browser window.
SetWindowBoundsBuilder
Builder for SetWindowBounds.
SetWindowBoundsReturnObject
Set position and/or size of the browser window.

Enums

AddPrivacySandboxCoordinatorKeyConfigBuilderError
Error type for AddPrivacySandboxCoordinatorKeyConfigBuilder
AddPrivacySandboxEnrollmentOverrideBuilderError
Error type for AddPrivacySandboxEnrollmentOverrideBuilder
BoundsBuilderError
Error type for BoundsBuilder
BrowserCommandId
BucketBuilderError
Error type for BucketBuilder
CancelDownloadBuilderError
Error type for CancelDownloadBuilder
DownloadProgressStateOption
ExecuteBrowserCommandBuilderError
Error type for ExecuteBrowserCommandBuilder
GetBrowserCommandLineReturnObjectBuilderError
Error type for GetBrowserCommandLineReturnObjectBuilder
GetHistogramBuilderError
Error type for GetHistogramBuilder
GetHistogramReturnObjectBuilderError
Error type for GetHistogramReturnObjectBuilder
GetHistogramsBuilderError
Error type for GetHistogramsBuilder
GetHistogramsReturnObjectBuilderError
Error type for GetHistogramsReturnObjectBuilder
GetVersionReturnObjectBuilderError
Error type for GetVersionReturnObjectBuilder
GetWindowBoundsBuilderError
Error type for GetWindowBoundsBuilder
GetWindowBoundsReturnObjectBuilderError
Error type for GetWindowBoundsReturnObjectBuilder
GetWindowForTargetBuilderError
Error type for GetWindowForTargetBuilder
GetWindowForTargetReturnObjectBuilderError
Error type for GetWindowForTargetReturnObjectBuilder
GrantPermissionsBuilderError
Error type for GrantPermissionsBuilder
HistogramBuilderError
Error type for HistogramBuilder
PermissionDescriptorBuilderError
Error type for PermissionDescriptorBuilder
PermissionSetting
PermissionType
PrivacySandboxApi
ResetPermissionsBuilderError
Error type for ResetPermissionsBuilder
SetContentsSizeBuilderError
Error type for SetContentsSizeBuilder
SetDockTileBuilderError
Error type for SetDockTileBuilder
SetDownloadBehaviorBehaviorOption
SetDownloadBehaviorBuilderError
Error type for SetDownloadBehaviorBuilder
SetPermissionBuilderError
Error type for SetPermissionBuilder
SetWindowBoundsBuilderError
Error type for SetWindowBoundsBuilder
WindowState

Type Aliases

BrowserContextId
WindowId