pub struct DownloadProgressEventParams {
pub guid: String,
pub total_bytes: JsFloat,
pub received_bytes: JsFloat,
pub state: DownloadProgressStateOption,
pub file_path: Option<String>,
}Fields
guid: StringGlobal unique identifier of the download.
total_bytes: JsFloatTotal expected bytes to download.
received_bytes: JsFloatTotal bytes received.
state: DownloadProgressStateOptionDownload status.
file_path: Option<String>If download is “completed”, provides the path of the downloaded file. Depending on the platform, it is not guaranteed to be set, nor the file is guaranteed to exist.