DownloadProgressEventParamsBuilder

Struct DownloadProgressEventParamsBuilder 

pub struct DownloadProgressEventParamsBuilder { /* private fields */ }
Implementations

Source

impl DownloadProgressEventParamsBuilder

pub fn guid(&mut self, value: String) -> &mut Self

Global unique identifier of the download.

pub fn total_bytes(&mut self, value: JsFloat) -> &mut Self

Total expected bytes to download.

pub fn received_bytes(&mut self, value: JsFloat) -> &mut Self

Total bytes received.

pub fn state(&mut self, value: DownloadProgressStateOption) -> &mut Self

Download status.

pub fn file_path(&mut self, value: Option<String>) -> &mut Self

If download is “completed”, provides the path of the downloaded file. Depending on the platform, it is not guaranteed to be set, nor the file is guaranteed to exist.

pub fn build( &self, ) -> Result<DownloadProgressEventParams, DownloadProgressEventParamsBuilderError>

Builds a new DownloadProgressEventParams.

Errors

If a required field has not been initialized.