pub struct DownloadWillBeginEventParamsBuilder { /* private fields */ }Expand description
Builder for DownloadWillBeginEventParams.
Implementations
Sourceimpl DownloadWillBeginEventParamsBuilder
impl DownloadWillBeginEventParamsBuilder
Sourcepub fn frame_id(&mut self, value: FrameId) -> &mut Self
pub fn frame_id(&mut self, value: FrameId) -> &mut Self
Id of the frame that caused the download to begin.
Sourcepub fn suggested_filename(&mut self, value: String) -> &mut Self
pub fn suggested_filename(&mut self, value: String) -> &mut Self
Suggested file name of the resource (the actual name of the file saved on disk may differ).
Sourcepub fn build(
&self,
) -> Result<DownloadWillBeginEventParams, DownloadWillBeginEventParamsBuilderError>
pub fn build( &self, ) -> Result<DownloadWillBeginEventParams, DownloadWillBeginEventParamsBuilderError>