pub struct BoundsBuilder { /* private fields */ }Expand description
Builder for Bounds.
Implementations
Sourceimpl BoundsBuilder
impl BoundsBuilder
Sourcepub fn left<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn left<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The offset from the left edge of the screen to the window in pixels.
Sourcepub fn top<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn top<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The offset from the top edge of the screen to the window in pixels.
Sourcepub fn width<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn width<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The window width in pixels.
Sourcepub fn height<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn height<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The window height in pixels.
Sourcepub fn window_state<VALUE: Into<WindowState>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn window_state<VALUE: Into<WindowState>>( &mut self, value: VALUE, ) -> &mut Self
The window state. Default to normal.