pub struct SetDownloadBehavior {
pub behavior: SetDownloadBehaviorBehaviorOption,
pub browser_context_id: Option<BrowserContextId>,
pub download_path: Option<String>,
pub events_enabled: Option<bool>,
}Expand description
Set the behavior when downloading a file.
Fields
behavior: SetDownloadBehaviorBehaviorOptionWhether to allow all or deny all download requests, or use default Chrome behavior if available (otherwise deny). |allowAndName| allows download and names files according to their download guids.
browser_context_id: Option<BrowserContextId>BrowserContext to set download behavior. When omitted, default browser context is used.
download_path: Option<String>The default path to save downloaded files to. This is required if behavior is set to ‘allow’ or ‘allowAndName’.
events_enabled: Option<bool>Whether to emit download events (defaults to false).