SetPermissionBuilder

Struct SetPermissionBuilder 

pub struct SetPermissionBuilder { /* private fields */ }
Builder for SetPermission.

Implementations

Source

impl SetPermissionBuilder

pub fn permission<VALUE: Into<PermissionDescriptor>>( &mut self, value: VALUE, ) -> &mut Self

Descriptor of permission to override.

pub fn setting<VALUE: Into<PermissionSetting>>( &mut self, value: VALUE, ) -> &mut Self

Setting of the permission.

pub fn origin<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Embedding origin the permission applies to, all origins if not specified.

pub fn embedded_origin<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self

Embedded origin the permission applies to. It is ignored unless the embedding origin is present and valid. If the embedding origin is provided but the embedded origin isn’t, the embedding origin is used as the embedded origin.

pub fn browser_context_id<VALUE: Into<BrowserContextId>>( &mut self, value: VALUE, ) -> &mut Self

Context to override. When omitted, default browser context is used.

pub fn build(&self) -> Result<SetPermission, SetPermissionBuilderError>

Builds a new SetPermission.

Errors

If a required field has not been initialized.