Module cast

Module cast 

Modules

events

Structs

Disable
DisableReturnObject
Stops observing for sinks and issues.
Enable
Starts observing for sinks that can be used for tab mirroring, and if set, sinks compatible with |presentationUrl| as well. When sinks are found, a |sinksUpdated| event is fired. Also starts observing for issue messages. When an issue is added or removed, an |issueUpdated| event is fired.
EnableBuilder
Builder for Enable.
EnableReturnObject
Starts observing for sinks that can be used for tab mirroring, and if set, sinks compatible with |presentationUrl| as well. When sinks are found, a |sinksUpdated| event is fired. Also starts observing for issue messages. When an issue is added or removed, an |issueUpdated| event is fired.
SetSinkToUse
Sets a sink to be used when the web page requests the browser to choose a sink via Presentation API, Remote Playback API, or Cast SDK.
SetSinkToUseBuilder
Builder for SetSinkToUse.
SetSinkToUseReturnObject
Sets a sink to be used when the web page requests the browser to choose a sink via Presentation API, Remote Playback API, or Cast SDK.
Sink
SinkBuilder
Builder for Sink.
StartDesktopMirroring
Starts mirroring the desktop to the sink.
StartDesktopMirroringBuilder
Builder for StartDesktopMirroring.
StartDesktopMirroringReturnObject
Starts mirroring the desktop to the sink.
StartTabMirroring
Starts mirroring the tab to the sink.
StartTabMirroringBuilder
Builder for StartTabMirroring.
StartTabMirroringReturnObject
Starts mirroring the tab to the sink.
StopCasting
Stops the active Cast session on the sink.
StopCastingBuilder
Builder for StopCasting.
StopCastingReturnObject
Stops the active Cast session on the sink.

Enums

EnableBuilderError
Error type for EnableBuilder
SetSinkToUseBuilderError
Error type for SetSinkToUseBuilder
SinkBuilderError
Error type for SinkBuilder
StartDesktopMirroringBuilderError
Error type for StartDesktopMirroringBuilder
StartTabMirroringBuilderError
Error type for StartTabMirroringBuilder
StopCastingBuilderError
Error type for StopCastingBuilder