pub struct ConsoleMessageBuilder { /* private fields */ }Expand description
Builder for ConsoleMessage.
Implementations
Sourceimpl ConsoleMessageBuilder
impl ConsoleMessageBuilder
Sourcepub fn source<VALUE: Into<ConsoleMessageSource>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn source<VALUE: Into<ConsoleMessageSource>>( &mut self, value: VALUE, ) -> &mut Self
Message source.
Sourcepub fn level<VALUE: Into<ConsoleMessageLevel>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn level<VALUE: Into<ConsoleMessageLevel>>( &mut self, value: VALUE, ) -> &mut Self
Message severity.
Sourcepub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
URL of the message origin.
Sourcepub fn line<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn line<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Line number in the resource that generated this message (1-based).
Sourcepub fn column<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn column<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Column number in the resource that generated this message (1-based).
Sourcepub fn build(&self) -> Result<ConsoleMessage, ConsoleMessageBuilderError>
pub fn build(&self) -> Result<ConsoleMessage, ConsoleMessageBuilderError>