AddRule

Struct AddRule 

pub struct AddRule {
    pub style_sheet_id: StyleSheetId,
    pub rule_text: String,
    pub location: SourceRange,
    pub node_for_property_syntax_validation: Option<NodeId>,
}
Inserts a new rule with the given ruleText in a stylesheet with given styleSheetId, at the position specified by location.

Fields

style_sheet_id: StyleSheetId

The css style sheet identifier where a new rule should be inserted.

rule_text: String

The text of a new rule.

location: SourceRange

Text position of a new rule in the target style sheet.

node_for_property_syntax_validation: Option<NodeId>

NodeId for the DOM node in whose context custom property declarations for registered properties should be validated. If omitted, declarations in the new rule text can only be validated statically, which may produce incorrect results if the declaration contains a var() for example.