AddRuleBuilder

Struct AddRuleBuilder 

pub struct AddRuleBuilder { /* private fields */ }
Builder for AddRule.

Implementations

Source

impl AddRuleBuilder

pub fn style_sheet_id<VALUE: Into<StyleSheetId>>( &mut self, value: VALUE, ) -> &mut Self

The css style sheet identifier where a new rule should be inserted.

pub fn rule_text<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

The text of a new rule.

pub fn location<VALUE: Into<SourceRange>>(&mut self, value: VALUE) -> &mut Self

Text position of a new rule in the target style sheet.

pub fn node_for_property_syntax_validation<VALUE: Into<NodeId>>( &mut self, value: VALUE, ) -> &mut Self

NodeId for the DOM node in whose context custom property declarations for registered properties should be validated. If omitted, declarations in the new rule text can only be validated statically, which may produce incorrect results if the declaration contains a var() for example.

pub fn build(&self) -> Result<AddRule, AddRuleBuilderError>

Builds a new AddRule.

Errors

If a required field has not been initialized.