pub struct ComputedStyleExtraFieldsBuilder { /* private fields */ }Expand description
Builder for ComputedStyleExtraFields.
Implementations
Sourceimpl ComputedStyleExtraFieldsBuilder
impl ComputedStyleExtraFieldsBuilder
Sourcepub fn is_appearance_base<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn is_appearance_base<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Returns whether or not this node is being rendered with base appearance, which happens when it has its appearance property set to base/base-select or it is in the subtree of an element being rendered with base appearance.
Sourcepub fn build(
&self,
) -> Result<ComputedStyleExtraFields, ComputedStyleExtraFieldsBuilderError>
pub fn build( &self, ) -> Result<ComputedStyleExtraFields, ComputedStyleExtraFieldsBuilderError>