pub struct CreateStyleSheetBuilder { /* private fields */ }Expand description
Builder for CreateStyleSheet.
Implementations
Sourceimpl CreateStyleSheetBuilder
impl CreateStyleSheetBuilder
Sourcepub fn frame_id<VALUE: Into<FrameId>>(&mut self, value: VALUE) -> &mut Self
pub fn frame_id<VALUE: Into<FrameId>>(&mut self, value: VALUE) -> &mut Self
Identifier of the frame where “via-inspector” stylesheet should be created.
Sourcepub fn force<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn force<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If true, creates a new stylesheet for every call. If false, returns a stylesheet previously created by a call with force=false for the frame’s document if it exists or creates a new stylesheet (default: false).
Sourcepub fn build(&self) -> Result<CreateStyleSheet, CreateStyleSheetBuilderError>
pub fn build(&self) -> Result<CreateStyleSheet, CreateStyleSheetBuilderError>