pub struct CssLayerDataBuilder { /* private fields */ }Expand description
Builder for CssLayerData.
Implementations
Sourceimpl CssLayerDataBuilder
impl CssLayerDataBuilder
Sourcepub fn sub_layers<VALUE: Into<Vec<CssLayerData>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn sub_layers<VALUE: Into<Vec<CssLayerData>>>( &mut self, value: VALUE, ) -> &mut Self
Direct sub-layers
Sourcepub fn order<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn order<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Layer order. The order determines the order of the layer in the cascade order. A higher number has higher priority in the cascade order.
Sourcepub fn build(&self) -> Result<CssLayerData, CssLayerDataBuilderError>
pub fn build(&self) -> Result<CssLayerData, CssLayerDataBuilderError>