pub struct CssStyleSheetHeaderBuilder { /* private fields */ }Expand description
Builder for CssStyleSheetHeader.
Implementations
Sourceimpl CssStyleSheetHeaderBuilder
impl CssStyleSheetHeaderBuilder
Sourcepub fn style_sheet_id<VALUE: Into<StyleSheetId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn style_sheet_id<VALUE: Into<StyleSheetId>>( &mut self, value: VALUE, ) -> &mut Self
The stylesheet identifier.
Sourcepub fn frame_id<VALUE: Into<FrameId>>(&mut self, value: VALUE) -> &mut Self
pub fn frame_id<VALUE: Into<FrameId>>(&mut self, value: VALUE) -> &mut Self
Owner frame identifier.
Sourcepub fn source_url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn source_url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Stylesheet resource URL. Empty if this is a constructed stylesheet created using new CSSStyleSheet() (but non-empty if this is a constructed stylesheet imported as a CSS module script).
Sourcepub fn source_map_url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn source_map_url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
URL of source map associated with the stylesheet (if any).
Sourcepub fn origin<VALUE: Into<StyleSheetOrigin>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn origin<VALUE: Into<StyleSheetOrigin>>( &mut self, value: VALUE, ) -> &mut Self
Stylesheet origin.
Sourcepub fn owner_node<VALUE: Into<BackendNodeId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn owner_node<VALUE: Into<BackendNodeId>>( &mut self, value: VALUE, ) -> &mut Self
The backend id for the owner node of the stylesheet.
Sourcepub fn disabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn disabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Denotes whether the stylesheet is disabled.
Sourcepub fn has_source_url<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn has_source_url<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether the sourceURL field value comes from the sourceURL comment.
Sourcepub fn is_inline<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn is_inline<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether this stylesheet is created for STYLE tag by parser. This flag is not set for document.written STYLE tags.
Sourcepub fn is_mutable<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn is_mutable<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether this stylesheet is mutable. Inline stylesheets become mutable
after they have been modified via CSSOM API.
\<link\> element’s stylesheets become mutable only if DevTools modifies them.
Constructed stylesheets (new CSSStyleSheet()) are mutable immediately after creation.
Sourcepub fn is_constructed<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn is_constructed<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
True if this stylesheet is created through new CSSStyleSheet() or imported as a CSS module script.
Sourcepub fn start_line<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn start_line<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Line offset of the stylesheet within the resource (zero based).
Sourcepub fn start_column<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn start_column<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Column offset of the stylesheet within the resource (zero based).
Sourcepub fn length<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn length<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Size of the content (in characters).
Sourcepub fn end_line<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn end_line<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Line offset of the end of the stylesheet within the resource (zero based).
Sourcepub fn end_column<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn end_column<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Column offset of the end of the stylesheet within the resource (zero based).
Sourcepub fn loading_failed<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn loading_failed<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If the style sheet was loaded from a network resource, this indicates when the resource failed to load
Sourcepub fn build(
&self,
) -> Result<CssStyleSheetHeader, CssStyleSheetHeaderBuilderError>
pub fn build( &self, ) -> Result<CssStyleSheetHeader, CssStyleSheetHeaderBuilderError>