pub struct InheritedAnimatedStyleEntryBuilder { /* private fields */ }Expand description
Builder for InheritedAnimatedStyleEntry.
Implementations
Sourceimpl InheritedAnimatedStyleEntryBuilder
impl InheritedAnimatedStyleEntryBuilder
Sourcepub fn animation_styles<VALUE: Into<Vec<CssAnimationStyle>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn animation_styles<VALUE: Into<Vec<CssAnimationStyle>>>( &mut self, value: VALUE, ) -> &mut Self
Styles coming from the animations of the ancestor, if any, in the style inheritance chain.
Sourcepub fn transitions_style<VALUE: Into<CssStyle>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn transitions_style<VALUE: Into<CssStyle>>( &mut self, value: VALUE, ) -> &mut Self
The style coming from the transitions of the ancestor, if any, in the style inheritance chain.
Sourcepub fn build(
&self,
) -> Result<InheritedAnimatedStyleEntry, InheritedAnimatedStyleEntryBuilderError>
pub fn build( &self, ) -> Result<InheritedAnimatedStyleEntry, InheritedAnimatedStyleEntryBuilderError>