pub struct InheritedStyleEntryBuilder { /* private fields */ }Expand description
Builder for InheritedStyleEntry.
Implementations
Sourceimpl InheritedStyleEntryBuilder
impl InheritedStyleEntryBuilder
Sourcepub fn inline_style<VALUE: Into<CssStyle>>(&mut self, value: VALUE) -> &mut Self
pub fn inline_style<VALUE: Into<CssStyle>>(&mut self, value: VALUE) -> &mut Self
The ancestor node’s inline style, if any, in the style inheritance chain.
Sourcepub fn matched_css_rules<VALUE: Into<Vec<RuleMatch>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn matched_css_rules<VALUE: Into<Vec<RuleMatch>>>( &mut self, value: VALUE, ) -> &mut Self
Matches of CSS rules matching the ancestor node in the style inheritance chain.
Sourcepub fn build(
&self,
) -> Result<InheritedStyleEntry, InheritedStyleEntryBuilderError>
pub fn build( &self, ) -> Result<InheritedStyleEntry, InheritedStyleEntryBuilderError>