pub struct PlatformFontUsageBuilder { /* private fields */ }Expand description
Builder for PlatformFontUsage.
Implementations
Sourceimpl PlatformFontUsageBuilder
impl PlatformFontUsageBuilder
Sourcepub fn family_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn family_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Font’s family name reported by platform.
Sourcepub fn post_script_name<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn post_script_name<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
Font’s PostScript name reported by platform.
Sourcepub fn is_custom_font<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn is_custom_font<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Indicates if the font was downloaded or resolved locally.
Sourcepub fn glyph_count<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn glyph_count<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Amount of glyphs that were rendered with this font.
Sourcepub fn build(&self) -> Result<PlatformFontUsage, PlatformFontUsageBuilderError>
pub fn build(&self) -> Result<PlatformFontUsage, PlatformFontUsageBuilderError>