SetStyleTexts

Struct SetStyleTexts 

pub struct SetStyleTexts {
    pub edits: Vec<StyleDeclarationEdit>,
    pub node_for_property_syntax_validation: Option<NodeId>,
}
Applies specified style edits one after another in the given order.

Fields

edits: Vec<StyleDeclarationEdit>node_for_property_syntax_validation: Option<NodeId>

NodeId for the DOM node in whose context custom property declarations for registered properties should be validated. If omitted, declarations in the new rule text can only be validated statically, which may produce incorrect results if the declaration contains a var() for example.