pub struct SetStyleTextsBuilder { /* private fields */ }Expand description
Builder for SetStyleTexts.
Implementations
Sourceimpl SetStyleTextsBuilder
impl SetStyleTextsBuilder
pub fn edits<VALUE: Into<Vec<StyleDeclarationEdit>>>( &mut self, value: VALUE, ) -> &mut Self
Sourcepub fn node_for_property_syntax_validation<VALUE: Into<NodeId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn node_for_property_syntax_validation<VALUE: Into<NodeId>>( &mut self, value: VALUE, ) -> &mut Self
NodeId for the DOM node in whose context custom property declarations for registered properties should be validated. If omitted, declarations in the new rule text can only be validated statically, which may produce incorrect results if the declaration contains a var() for example.
Sourcepub fn build(&self) -> Result<SetStyleTexts, SetStyleTextsBuilderError>
pub fn build(&self) -> Result<SetStyleTexts, SetStyleTextsBuilderError>