SpecificityBuilder

Struct SpecificityBuilder 

pub struct SpecificityBuilder { /* private fields */ }
Builder for Specificity.

Implementations

Source

impl SpecificityBuilder

pub fn a<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self

The a component, which represents the number of ID selectors.

pub fn b<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self

The b component, which represents the number of class selectors, attributes selectors, and pseudo-classes.

pub fn c<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self

The c component, which represents the number of type selectors and pseudo-elements.

pub fn build(&self) -> Result<Specificity, SpecificityBuilderError>

Builds a new Specificity.

Errors

If a required field has not been initialized.