pub struct TrackComputedStyleUpdates {
pub properties_to_track: Vec<CssComputedStyleProperty>,
}Expand description
Starts tracking the given computed styles for updates. The specified array of properties replaces the one previously specified. Pass empty array to disable tracking. Use takeComputedStyleUpdates to retrieve the list of nodes that had properties modified. The changes to computed style properties are only tracked for nodes pushed to the front-end by the DOM agent. If no changes to the tracked properties occur after the node has been pushed to the front-end, no updates will be issued for the node.
Fields
properties_to_track: Vec<CssComputedStyleProperty>Trait Implementations
Sourceimpl Clone for TrackComputedStyleUpdates
impl Clone for TrackComputedStyleUpdates
Sourcefn clone(&self) -> TrackComputedStyleUpdates
fn clone(&self) -> TrackComputedStyleUpdates
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrackComputedStyleUpdates
impl Debug for TrackComputedStyleUpdates
Sourceimpl<'de> Deserialize<'de> for TrackComputedStyleUpdates
impl<'de> Deserialize<'de> for TrackComputedStyleUpdates
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Method for TrackComputedStyleUpdates
impl Method for TrackComputedStyleUpdates
const NAME: &'static str = "CSS.trackComputedStyleUpdates"
type ReturnObject = TrackComputedStyleUpdatesReturnObject
fn to_method_call(self, call_id: CallId) -> MethodCall<Self>where
Self: Sized,
impl StructuralPartialEq for TrackComputedStyleUpdates