pub struct TrackComputedStyleUpdatesForNodeReturnObject(pub Option<Value>);Expand description
Starts tracking the given node for the computed style updates
and whenever the computed style is updated for node, it queues
a computedStyleUpdated event with throttling.
There can only be 1 node tracked for computed style updates
so passing a new node id removes tracking from the previous node.
Pass undefined to disable tracking.
Tuple Fields
0: Option<Value>Trait Implementations
Sourceimpl Clone for TrackComputedStyleUpdatesForNodeReturnObject
impl Clone for TrackComputedStyleUpdatesForNodeReturnObject
Sourcefn clone(&self) -> TrackComputedStyleUpdatesForNodeReturnObject
fn clone(&self) -> TrackComputedStyleUpdatesForNodeReturnObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for TrackComputedStyleUpdatesForNodeReturnObject
impl<'de> Deserialize<'de> for TrackComputedStyleUpdatesForNodeReturnObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TrackComputedStyleUpdatesForNodeReturnObject
impl PartialEq for TrackComputedStyleUpdatesForNodeReturnObject
Sourcefn eq(&self, other: &TrackComputedStyleUpdatesForNodeReturnObject) -> bool
fn eq(&self, other: &TrackComputedStyleUpdatesForNodeReturnObject) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TrackComputedStyleUpdatesForNodeReturnObject