pub struct TrackComputedStyleUpdatesReturnObject(pub Option<Value>);Expand description
Starts tracking the given computed styles for updates. The specified array of properties replaces the one previously specified. Pass empty array to disable tracking. Use takeComputedStyleUpdates to retrieve the list of nodes that had properties modified. The changes to computed style properties are only tracked for nodes pushed to the front-end by the DOM agent. If no changes to the tracked properties occur after the node has been pushed to the front-end, no updates will be issued for the node.
Tuple Fields
0: Option<Value>Trait Implementations
Sourceimpl Clone for TrackComputedStyleUpdatesReturnObject
impl Clone for TrackComputedStyleUpdatesReturnObject
Sourcefn clone(&self) -> TrackComputedStyleUpdatesReturnObject
fn clone(&self) -> TrackComputedStyleUpdatesReturnObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for TrackComputedStyleUpdatesReturnObject
impl<'de> Deserialize<'de> for TrackComputedStyleUpdatesReturnObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TrackComputedStyleUpdatesReturnObject
impl PartialEq for TrackComputedStyleUpdatesReturnObject
Sourcefn eq(&self, other: &TrackComputedStyleUpdatesReturnObject) -> bool
fn eq(&self, other: &TrackComputedStyleUpdatesReturnObject) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TrackComputedStyleUpdatesReturnObject