Module debugger

Module debugger 

Modules

events

Structs

BreakLocation
BreakLocationBuilder
Builder for BreakLocation.
CallFrame
JavaScript call frame. Array of call frames form the call stack.
CallFrameBuilder
Builder for CallFrame.
ContinueToLocation
Continues execution until specific location is reached.
ContinueToLocationBuilder
Builder for ContinueToLocation.
ContinueToLocationReturnObject
Continues execution until specific location is reached.
DebugSymbols
Debug symbols available for a wasm script.
DebugSymbolsBuilder
Builder for DebugSymbols.
Disable
DisableReturnObject
Disables debugger for given page.
DisassembleWasmModule
DisassembleWasmModuleBuilder
Builder for DisassembleWasmModule.
DisassembleWasmModuleReturnObject
DisassembleWasmModuleReturnObjectBuilder
Builder for DisassembleWasmModuleReturnObject.
Enable
Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received.
EnableBuilder
Builder for Enable.
EnableReturnObject
Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received.
EnableReturnObjectBuilder
Builder for EnableReturnObject.
EvaluateOnCallFrame
Evaluates expression on a given call frame.
EvaluateOnCallFrameBuilder
Builder for EvaluateOnCallFrame.
EvaluateOnCallFrameReturnObject
Evaluates expression on a given call frame.
EvaluateOnCallFrameReturnObjectBuilder
Builder for EvaluateOnCallFrameReturnObject.
GetPossibleBreakpoints
Returns possible locations for breakpoint. scriptId in start and end range locations should be the same.
GetPossibleBreakpointsBuilder
Builder for GetPossibleBreakpoints.
GetPossibleBreakpointsReturnObject
Returns possible locations for breakpoint. scriptId in start and end range locations should be the same.
GetPossibleBreakpointsReturnObjectBuilder
Builder for GetPossibleBreakpointsReturnObject.
GetScriptSource
Returns source for the script with given id.
GetScriptSourceBuilder
Builder for GetScriptSource.
GetScriptSourceReturnObject
Returns source for the script with given id.
GetScriptSourceReturnObjectBuilder
Builder for GetScriptSourceReturnObject.
GetStackTrace
Returns stack trace with given stackTraceId.
GetStackTraceBuilder
Builder for GetStackTrace.
GetStackTraceReturnObject
Returns stack trace with given stackTraceId.
GetStackTraceReturnObjectBuilder
Builder for GetStackTraceReturnObject.
GetWasmBytecodeDeprecated
This command is deprecated. Use getScriptSource instead.
GetWasmBytecodeBuilder
Builder for GetWasmBytecode.
GetWasmBytecodeReturnObjectDeprecated
This command is deprecated. Use getScriptSource instead.
GetWasmBytecodeReturnObjectBuilder
Builder for GetWasmBytecodeReturnObject.
Location
Location in the source code.
LocationBuilder
Builder for Location.
LocationRange
Location range within one script.
LocationRangeBuilder
Builder for LocationRange.
NextWasmDisassemblyChunk
Disassemble the next chunk of lines for the module corresponding to the stream. If disassembly is complete, this API will invalidate the streamId and return an empty chunk. Any subsequent calls for the now invalid stream will return errors.
NextWasmDisassemblyChunkBuilder
Builder for NextWasmDisassemblyChunk.
NextWasmDisassemblyChunkReturnObject
Disassemble the next chunk of lines for the module corresponding to the stream. If disassembly is complete, this API will invalidate the streamId and return an empty chunk. Any subsequent calls for the now invalid stream will return errors.
NextWasmDisassemblyChunkReturnObjectBuilder
Builder for NextWasmDisassemblyChunkReturnObject.
Pause
PauseOnAsyncCallDeprecated
PauseOnAsyncCallBuilder
Builder for PauseOnAsyncCall.
PauseOnAsyncCallReturnObjectDeprecated
PauseReturnObject
Stops on the next JavaScript statement.
RemoveBreakpoint
Removes JavaScript breakpoint.
RemoveBreakpointBuilder
Builder for RemoveBreakpoint.
RemoveBreakpointReturnObject
Removes JavaScript breakpoint.
ResolvedBreakpoint
ResolvedBreakpointBuilder
Builder for ResolvedBreakpoint.
RestartFrame
Restarts particular call frame from the beginning. The old, deprecated behavior of restartFrame is to stay paused and allow further CDP commands after a restart was scheduled. This can cause problems with restarting, so we now continue execution immediatly after it has been scheduled until we reach the beginning of the restarted frame.
RestartFrameBuilder
Builder for RestartFrame.
RestartFrameReturnObject
Restarts particular call frame from the beginning. The old, deprecated behavior of restartFrame is to stay paused and allow further CDP commands after a restart was scheduled. This can cause problems with restarting, so we now continue execution immediatly after it has been scheduled until we reach the beginning of the restarted frame.
RestartFrameReturnObjectBuilder
Builder for RestartFrameReturnObject.
Resume
Resumes JavaScript execution.
ResumeBuilder
Builder for Resume.
ResumeReturnObject
Resumes JavaScript execution.
Scope
Scope description.
ScopeBuilder
Builder for Scope.
ScriptPosition
Location in the source code.
ScriptPositionBuilder
Builder for ScriptPosition.
SearchInContent
Searches for given string in script content.
SearchInContentBuilder
Builder for SearchInContent.
SearchInContentReturnObject
Searches for given string in script content.
SearchInContentReturnObjectBuilder
Builder for SearchInContentReturnObject.
SearchMatch
Search match for resource.
SearchMatchBuilder
Builder for SearchMatch.
SetAsyncCallStackDepth
Enables or disables async call stacks tracking.
SetAsyncCallStackDepthBuilder
Builder for SetAsyncCallStackDepth.
SetAsyncCallStackDepthReturnObject
Enables or disables async call stacks tracking.
SetBlackboxExecutionContexts
Replace previous blackbox execution contexts with passed ones. Forces backend to skip stepping/pausing in scripts in these execution contexts. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
SetBlackboxExecutionContextsBuilder
Builder for SetBlackboxExecutionContexts.
SetBlackboxExecutionContextsReturnObject
Replace previous blackbox execution contexts with passed ones. Forces backend to skip stepping/pausing in scripts in these execution contexts. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
SetBlackboxPatterns
Replace previous blackbox patterns with passed ones. Forces backend to skip stepping/pausing in scripts with url matching one of the patterns. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
SetBlackboxPatternsBuilder
Builder for SetBlackboxPatterns.
SetBlackboxPatternsReturnObject
Replace previous blackbox patterns with passed ones. Forces backend to skip stepping/pausing in scripts with url matching one of the patterns. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
SetBlackboxedRanges
Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. Positions array contains positions where blackbox state is changed. First interval isn’t blackboxed. Array should be sorted.
SetBlackboxedRangesBuilder
Builder for SetBlackboxedRanges.
SetBlackboxedRangesReturnObject
Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. Positions array contains positions where blackbox state is changed. First interval isn’t blackboxed. Array should be sorted.
SetBreakpoint
Sets JavaScript breakpoint at a given location.
SetBreakpointBuilder
Builder for SetBreakpoint.
SetBreakpointByUrl
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in locations property. Further matching script parsing will result in subsequent breakpointResolved events issued. This logical breakpoint will survive page reloads.
SetBreakpointByUrlBuilder
Builder for SetBreakpointByUrl.
SetBreakpointByUrlReturnObject
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in locations property. Further matching script parsing will result in subsequent breakpointResolved events issued. This logical breakpoint will survive page reloads.
SetBreakpointByUrlReturnObjectBuilder
Builder for SetBreakpointByUrlReturnObject.
SetBreakpointOnFunctionCall
Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint.
SetBreakpointOnFunctionCallBuilder
Builder for SetBreakpointOnFunctionCall.
SetBreakpointOnFunctionCallReturnObject
Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint.
SetBreakpointOnFunctionCallReturnObjectBuilder
Builder for SetBreakpointOnFunctionCallReturnObject.
SetBreakpointReturnObject
Sets JavaScript breakpoint at a given location.
SetBreakpointReturnObjectBuilder
Builder for SetBreakpointReturnObject.
SetBreakpointsActive
Activates / deactivates all breakpoints on the page.
SetBreakpointsActiveBuilder
Builder for SetBreakpointsActive.
SetBreakpointsActiveReturnObject
Activates / deactivates all breakpoints on the page.
SetInstrumentationBreakpoint
Sets instrumentation breakpoint.
SetInstrumentationBreakpointBuilder
Builder for SetInstrumentationBreakpoint.
SetInstrumentationBreakpointReturnObject
Sets instrumentation breakpoint.
SetInstrumentationBreakpointReturnObjectBuilder
Builder for SetInstrumentationBreakpointReturnObject.
SetPauseOnExceptions
Defines pause on exceptions state. Can be set to stop on all exceptions, uncaught exceptions, or caught exceptions, no exceptions. Initial pause on exceptions state is none.
SetPauseOnExceptionsBuilder
Builder for SetPauseOnExceptions.
SetPauseOnExceptionsReturnObject
Defines pause on exceptions state. Can be set to stop on all exceptions, uncaught exceptions, or caught exceptions, no exceptions. Initial pause on exceptions state is none.
SetReturnValue
Changes return value in top frame. Available only at return break position.
SetReturnValueBuilder
Builder for SetReturnValue.
SetReturnValueReturnObject
Changes return value in top frame. Available only at return break position.
SetScriptSource
Edits JavaScript source live.
SetScriptSourceBuilder
Builder for SetScriptSource.
SetScriptSourceReturnObject
Edits JavaScript source live.
SetScriptSourceReturnObjectBuilder
Builder for SetScriptSourceReturnObject.
SetSkipAllPauses
Makes page not interrupt on any pauses (breakpoint, exception, dom exception etc).
SetSkipAllPausesBuilder
Builder for SetSkipAllPauses.
SetSkipAllPausesReturnObject
Makes page not interrupt on any pauses (breakpoint, exception, dom exception etc).
SetVariableValue
Changes value of variable in a callframe. Object-based scopes are not supported and must be mutated manually.
SetVariableValueBuilder
Builder for SetVariableValue.
SetVariableValueReturnObject
Changes value of variable in a callframe. Object-based scopes are not supported and must be mutated manually.
StepInto
Steps into the function call.
StepIntoBuilder
Builder for StepInto.
StepIntoReturnObject
Steps into the function call.
StepOut
StepOutReturnObject
Steps out of the function call.
StepOver
Steps over the statement.
StepOverBuilder
Builder for StepOver.
StepOverReturnObject
Steps over the statement.
WasmDisassemblyChunk
WasmDisassemblyChunkBuilder
Builder for WasmDisassemblyChunk.

Enums

BreakLocationBuilderError
Error type for BreakLocationBuilder
BreakLocationType
CallFrameBuilderError
Error type for CallFrameBuilder
ContinueToLocationBuilderError
Error type for ContinueToLocationBuilder
ContinueToLocationTargetCallFramesOption
DebugSymbolsBuilderError
Error type for DebugSymbolsBuilder
DebugSymbolsType
DisassembleWasmModuleBuilderError
Error type for DisassembleWasmModuleBuilder
DisassembleWasmModuleReturnObjectBuilderError
Error type for DisassembleWasmModuleReturnObjectBuilder
EnableBuilderError
Error type for EnableBuilder
EnableReturnObjectBuilderError
Error type for EnableReturnObjectBuilder
EvaluateOnCallFrameBuilderError
Error type for EvaluateOnCallFrameBuilder
EvaluateOnCallFrameReturnObjectBuilderError
Error type for EvaluateOnCallFrameReturnObjectBuilder
GetPossibleBreakpointsBuilderError
Error type for GetPossibleBreakpointsBuilder
GetPossibleBreakpointsReturnObjectBuilderError
Error type for GetPossibleBreakpointsReturnObjectBuilder
GetScriptSourceBuilderError
Error type for GetScriptSourceBuilder
GetScriptSourceReturnObjectBuilderError
Error type for GetScriptSourceReturnObjectBuilder
GetStackTraceBuilderError
Error type for GetStackTraceBuilder
GetStackTraceReturnObjectBuilderError
Error type for GetStackTraceReturnObjectBuilder
GetWasmBytecodeBuilderError
Error type for GetWasmBytecodeBuilder
GetWasmBytecodeReturnObjectBuilderError
Error type for GetWasmBytecodeReturnObjectBuilder
LocationBuilderError
Error type for LocationBuilder
LocationRangeBuilderError
Error type for LocationRangeBuilder
NextWasmDisassemblyChunkBuilderError
Error type for NextWasmDisassemblyChunkBuilder
NextWasmDisassemblyChunkReturnObjectBuilderError
Error type for NextWasmDisassemblyChunkReturnObjectBuilder
PauseOnAsyncCallBuilderError
Error type for PauseOnAsyncCallBuilder
PausedReasonOption
RemoveBreakpointBuilderError
Error type for RemoveBreakpointBuilder
ResolvedBreakpointBuilderError
Error type for ResolvedBreakpointBuilder
RestartFrameBuilderError
Error type for RestartFrameBuilder
RestartFrameModeOption
RestartFrameReturnObjectBuilderError
Error type for RestartFrameReturnObjectBuilder
ResumeBuilderError
Error type for ResumeBuilder
ScopeBuilderError
Error type for ScopeBuilder
ScopeType
ScriptLanguage
ScriptPositionBuilderError
Error type for ScriptPositionBuilder
SearchInContentBuilderError
Error type for SearchInContentBuilder
SearchInContentReturnObjectBuilderError
Error type for SearchInContentReturnObjectBuilder
SearchMatchBuilderError
Error type for SearchMatchBuilder
SetAsyncCallStackDepthBuilderError
Error type for SetAsyncCallStackDepthBuilder
SetBlackboxExecutionContextsBuilderError
Error type for SetBlackboxExecutionContextsBuilder
SetBlackboxPatternsBuilderError
Error type for SetBlackboxPatternsBuilder
SetBlackboxedRangesBuilderError
Error type for SetBlackboxedRangesBuilder
SetBreakpointBuilderError
Error type for SetBreakpointBuilder
SetBreakpointByUrlBuilderError
Error type for SetBreakpointByUrlBuilder
SetBreakpointByUrlReturnObjectBuilderError
Error type for SetBreakpointByUrlReturnObjectBuilder
SetBreakpointOnFunctionCallBuilderError
Error type for SetBreakpointOnFunctionCallBuilder
SetBreakpointOnFunctionCallReturnObjectBuilderError
Error type for SetBreakpointOnFunctionCallReturnObjectBuilder
SetBreakpointReturnObjectBuilderError
Error type for SetBreakpointReturnObjectBuilder
SetBreakpointsActiveBuilderError
Error type for SetBreakpointsActiveBuilder
SetInstrumentationBreakpointBuilderError
Error type for SetInstrumentationBreakpointBuilder
SetInstrumentationBreakpointInstrumentationOption
SetInstrumentationBreakpointReturnObjectBuilderError
Error type for SetInstrumentationBreakpointReturnObjectBuilder
SetPauseOnExceptionsBuilderError
Error type for SetPauseOnExceptionsBuilder
SetPauseOnExceptionsStateOption
SetReturnValueBuilderError
Error type for SetReturnValueBuilder
SetScriptSourceBuilderError
Error type for SetScriptSourceBuilder
SetScriptSourceReturnObjectBuilderError
Error type for SetScriptSourceReturnObjectBuilder
SetSkipAllPausesBuilderError
Error type for SetSkipAllPausesBuilder
SetVariableValueBuilderError
Error type for SetVariableValueBuilder
StatusOption
StepIntoBuilderError
Error type for StepIntoBuilder
StepOverBuilderError
Error type for StepOverBuilder
WasmDisassemblyChunkBuilderError
Error type for WasmDisassemblyChunkBuilder

Type Aliases

BreakpointId
CallFrameId