ScriptParsedEventParams

Struct ScriptParsedEventParams 

pub struct ScriptParsedEventParams {
Show 21 fields pub script_id: ScriptId, pub url: String, pub start_line: JsUInt, pub start_column: JsUInt, pub end_line: JsUInt, pub end_column: JsUInt, pub execution_context_id: ExecutionContextId, pub hash: String, pub build_id: String, pub execution_context_aux_data: Option<Value>, pub is_live_edit: Option<bool>, pub source_map_url: Option<String>, pub has_source_url: Option<bool>, pub is_module: Option<bool>, pub length: Option<JsUInt>, pub stack_trace: Option<StackTrace>, pub code_offset: Option<JsUInt>, pub script_language: Option<ScriptLanguage>, pub debug_symbols: Option<DebugSymbols>, pub embedder_name: Option<String>, pub resolved_breakpoints: Option<Vec<ResolvedBreakpoint>>,
}

Fields

script_id: ScriptId

Identifier of the script parsed.

url: String

URL or name of the script parsed (if any).

start_line: JsUInt

Line offset of the script within the resource with given URL (for script tags).

start_column: JsUInt

Column offset of the script within the resource with given URL.

end_line: JsUInt

Last line of the script.

end_column: JsUInt

Length of the last line of the script.

execution_context_id: ExecutionContextId

Specifies script creation context.

hash: String

Content hash of the script, SHA-256.

build_id: String

For Wasm modules, the content of the build_id custom section. For JavaScript the debugId magic comment.

execution_context_aux_data: Option<Value>

Embedder-specific auxiliary data likely matching {isDefault: boolean, type: ‘default’|‘isolated’|‘worker’, frameId: string}

is_live_edit: Option<bool>

True, if this script is generated as a result of the live edit operation.

source_map_url: Option<String>

URL of source map associated with script (if any).

has_source_url: Option<bool>

True, if this script has sourceURL.

is_module: Option<bool>

True, if this script is ES6 module.

length: Option<JsUInt>

This script length.

stack_trace: Option<StackTrace>

JavaScript top stack frame of where the script parsed event was triggered if available.

code_offset: Option<JsUInt>

If the scriptLanguage is WebAssembly, the code section offset in the module.

script_language: Option<ScriptLanguage>

The language of the script.

debug_symbols: Option<DebugSymbols>

If the scriptLanguage is WebAssembly, the source of debug symbols for the module.

embedder_name: Option<String>

The name the embedder supplied for this script.

resolved_breakpoints: Option<Vec<ResolvedBreakpoint>>

The list of set breakpoints in this script if calls to setBreakpointByUrl matches this script’s URL or hash. Clients that use this list can ignore the breakpointResolved event. They are equivalent.