ScriptParsedEventParamsBuilder

Struct ScriptParsedEventParamsBuilder 

pub struct ScriptParsedEventParamsBuilder { /* private fields */ }
Implementations

Source

impl ScriptParsedEventParamsBuilder

pub fn script_id(&mut self, value: ScriptId) -> &mut Self

Identifier of the script parsed.

pub fn url(&mut self, value: String) -> &mut Self

URL or name of the script parsed (if any).

pub fn start_line(&mut self, value: JsUInt) -> &mut Self

Line offset of the script within the resource with given URL (for script tags).

pub fn start_column(&mut self, value: JsUInt) -> &mut Self

Column offset of the script within the resource with given URL.

pub fn end_line(&mut self, value: JsUInt) -> &mut Self

Last line of the script.

pub fn end_column(&mut self, value: JsUInt) -> &mut Self

Length of the last line of the script.

pub fn execution_context_id(&mut self, value: ExecutionContextId) -> &mut Self

Specifies script creation context.

pub fn hash(&mut self, value: String) -> &mut Self

Content hash of the script, SHA-256.

pub fn build_id(&mut self, value: String) -> &mut Self

For Wasm modules, the content of the build_id custom section. For JavaScript the debugId magic comment.

pub fn execution_context_aux_data(&mut self, value: Option<Json>) -> &mut Self

Embedder-specific auxiliary data likely matching {isDefault: boolean, type: ‘default’|‘isolated’|‘worker’, frameId: string}

pub fn is_live_edit(&mut self, value: Option<bool>) -> &mut Self

True, if this script is generated as a result of the live edit operation.

pub fn source_map_url(&mut self, value: Option<String>) -> &mut Self

URL of source map associated with script (if any).

pub fn has_source_url(&mut self, value: Option<bool>) -> &mut Self

True, if this script has sourceURL.

pub fn is_module(&mut self, value: Option<bool>) -> &mut Self

True, if this script is ES6 module.

pub fn length(&mut self, value: Option<JsUInt>) -> &mut Self

This script length.

pub fn stack_trace(&mut self, value: Option<StackTrace>) -> &mut Self

JavaScript top stack frame of where the script parsed event was triggered if available.

pub fn code_offset(&mut self, value: Option<JsUInt>) -> &mut Self

If the scriptLanguage is WebAssembly, the code section offset in the module.

pub fn script_language(&mut self, value: Option<ScriptLanguage>) -> &mut Self

The language of the script.

pub fn debug_symbols(&mut self, value: Option<DebugSymbols>) -> &mut Self

If the scriptLanguage is WebAssembly, the source of debug symbols for the module.

pub fn embedder_name(&mut self, value: Option<String>) -> &mut Self

The name the embedder supplied for this script.

pub fn resolved_breakpoints( &mut self, value: Option<Vec<ResolvedBreakpoint>>, ) -> &mut Self

The list of set breakpoints in this script if calls to setBreakpointByUrl matches this script’s URL or hash. Clients that use this list can ignore the breakpointResolved event. They are equivalent.

pub fn build( &self, ) -> Result<ScriptParsedEventParams, ScriptParsedEventParamsBuilderError>

Builds a new ScriptParsedEventParams.

Errors

If a required field has not been initialized.