pub struct CallFrame {
pub call_frame_id: CallFrameId,
pub function_name: String,
pub function_location: Option<Location>,
pub location: Location,
pub url: String,
pub scope_chain: Vec<Scope>,
pub this: RemoteObject,
pub return_value: Option<RemoteObject>,
pub can_be_restarted: Option<bool>,
}Expand description
JavaScript call frame. Array of call frames form the call stack.
Fields
call_frame_id: CallFrameIdCall frame identifier. This identifier is only valid while the virtual machine is paused.
function_name: StringName of the JavaScript function called on this call frame.
function_location: Option<Location>Location in the source code.
location: LocationLocation in the source code.
url: StringJavaScript script name or url.
Deprecated in favor of using the location.scriptId to resolve the URL via a previously
sent Debugger.scriptParsed event.
scope_chain: Vec<Scope>Scope chain for this call frame.
this: RemoteObjectthis object for this call frame.
return_value: Option<RemoteObject>The value being returned, if the function is at return point.
can_be_restarted: Option<bool>Valid only while the VM is paused and indicates whether this frame
can be restarted or not. Note that a true value here does not
guarantee that Debugger#restartFrame with this CallFrameId will be
successful, but it is very likely.