pub struct CallFrameBuilder { /* private fields */ }Expand description
Builder for CallFrame.
Implementations
Sourceimpl CallFrameBuilder
impl CallFrameBuilder
Sourcepub fn call_frame_id<VALUE: Into<CallFrameId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn call_frame_id<VALUE: Into<CallFrameId>>( &mut self, value: VALUE, ) -> &mut Self
Call frame identifier. This identifier is only valid while the virtual machine is paused.
Sourcepub fn function_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn function_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Name of the JavaScript function called on this call frame.
Sourcepub fn function_location<VALUE: Into<Location>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn function_location<VALUE: Into<Location>>( &mut self, value: VALUE, ) -> &mut Self
Location in the source code.
Sourcepub fn location<VALUE: Into<Location>>(&mut self, value: VALUE) -> &mut Self
pub fn location<VALUE: Into<Location>>(&mut self, value: VALUE) -> &mut Self
Location in the source code.
Sourcepub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
JavaScript script name or url.
Deprecated in favor of using the location.scriptId to resolve the URL via a previously
sent Debugger.scriptParsed event.
Sourcepub fn scope_chain<VALUE: Into<Vec<Scope>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn scope_chain<VALUE: Into<Vec<Scope>>>( &mut self, value: VALUE, ) -> &mut Self
Scope chain for this call frame.
Sourcepub fn this<VALUE: Into<RemoteObject>>(&mut self, value: VALUE) -> &mut Self
pub fn this<VALUE: Into<RemoteObject>>(&mut self, value: VALUE) -> &mut Self
this object for this call frame.
Sourcepub fn return_value<VALUE: Into<RemoteObject>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn return_value<VALUE: Into<RemoteObject>>( &mut self, value: VALUE, ) -> &mut Self
The value being returned, if the function is at return point.
Sourcepub fn can_be_restarted<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn can_be_restarted<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Valid only while the VM is paused and indicates whether this frame
can be restarted or not. Note that a true value here does not
guarantee that Debugger#restartFrame with this CallFrameId will be
successful, but it is very likely.