pub struct EvaluateOnCallFrameBuilder { /* private fields */ }Expand description
Builder for EvaluateOnCallFrame.
Implementations
Sourceimpl EvaluateOnCallFrameBuilder
impl EvaluateOnCallFrameBuilder
Sourcepub fn call_frame_id<VALUE: Into<CallFrameId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn call_frame_id<VALUE: Into<CallFrameId>>( &mut self, value: VALUE, ) -> &mut Self
Call frame identifier to evaluate on.
Sourcepub fn expression<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn expression<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Expression to evaluate.
Sourcepub fn object_group<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn object_group<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
String object group name to put result into (allows rapid releasing resulting object handles
using releaseObjectGroup).
Sourcepub fn include_command_line_api<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn include_command_line_api<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Specifies whether command line API should be available to the evaluated expression, defaults to false.
Sourcepub fn silent<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn silent<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
In silent mode exceptions thrown during evaluation are not reported and do not pause
execution. Overrides setPauseOnException state.
Sourcepub fn return_by_value<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn return_by_value<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether the result is expected to be a JSON object that should be sent by value.
Sourcepub fn generate_preview<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn generate_preview<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether preview should be generated for the result.
Sourcepub fn throw_on_side_effect<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn throw_on_side_effect<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Whether to throw an exception if side effect cannot be ruled out during evaluation.
Sourcepub fn timeout<VALUE: Into<TimeDelta>>(&mut self, value: VALUE) -> &mut Self
pub fn timeout<VALUE: Into<TimeDelta>>(&mut self, value: VALUE) -> &mut Self
Terminate execution after timing out (number of milliseconds).
Sourcepub fn build(
&self,
) -> Result<EvaluateOnCallFrame, EvaluateOnCallFrameBuilderError>
pub fn build( &self, ) -> Result<EvaluateOnCallFrame, EvaluateOnCallFrameBuilderError>