pub struct GetPossibleBreakpoints {
pub start: Location,
pub end: Option<Location>,
pub restrict_to_function: Option<bool>,
}Expand description
Returns possible locations for breakpoint. scriptId in start and end range locations should be the same.
Fields
start: LocationStart of range to search possible breakpoint locations in.
end: Option<Location>End of range to search possible breakpoint locations in (excluding). When not specified, end of scripts is used as end of range.
restrict_to_function: Option<bool>Only consider locations which are in the same (non-nested) function as start.