pub struct GetPossibleBreakpointsBuilder { /* private fields */ }Expand description
Builder for GetPossibleBreakpoints.
Implementations
Sourceimpl GetPossibleBreakpointsBuilder
impl GetPossibleBreakpointsBuilder
Sourcepub fn start<VALUE: Into<Location>>(&mut self, value: VALUE) -> &mut Self
pub fn start<VALUE: Into<Location>>(&mut self, value: VALUE) -> &mut Self
Start of range to search possible breakpoint locations in.
Sourcepub fn end<VALUE: Into<Location>>(&mut self, value: VALUE) -> &mut Self
pub fn end<VALUE: Into<Location>>(&mut self, value: VALUE) -> &mut Self
End of range to search possible breakpoint locations in (excluding). When not specified, end of scripts is used as end of range.
Sourcepub fn restrict_to_function<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn restrict_to_function<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Only consider locations which are in the same (non-nested) function as start.
Sourcepub fn build(
&self,
) -> Result<GetPossibleBreakpoints, GetPossibleBreakpointsBuilderError>
pub fn build( &self, ) -> Result<GetPossibleBreakpoints, GetPossibleBreakpointsBuilderError>