Resume

Struct Resume 

pub struct Resume {
    pub terminate_on_resume: Option<bool>,
}
Resumes JavaScript execution.

Fields

terminate_on_resume: Option<bool>

Set to true to terminate execution upon resuming execution. In contrast to Runtime.terminateExecution, this will allows to execute further JavaScript (i.e. via evaluation) until execution of the paused code is actually resumed, at which point termination is triggered. If execution is currently not paused, this parameter has no effect.