ResumeBuilder

Struct ResumeBuilder 

pub struct ResumeBuilder { /* private fields */ }
Builder for Resume.

Implementations

Source

impl ResumeBuilder

pub fn terminate_on_resume<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

Set to true to terminate execution upon resuming execution. In contrast to Runtime.terminateExecution, this will allows to execute further JavaScript (i.e. via evaluation) until execution of the paused code is actually resumed, at which point termination is triggered. If execution is currently not paused, this parameter has no effect.

pub fn build(&self) -> Result<Resume, ResumeBuilderError>

Builds a new Resume.

Errors

If a required field has not been initialized.