pub struct SetBlackboxPatternsBuilder { /* private fields */ }Expand description
Builder for SetBlackboxPatterns.
Implementations
Sourceimpl SetBlackboxPatternsBuilder
impl SetBlackboxPatternsBuilder
Sourcepub fn patterns<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
pub fn patterns<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
Array of regexps that will be used to check script url for blackbox state.
Sourcepub fn skip_anonymous<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn skip_anonymous<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If true, also ignore scripts with no source url.
Sourcepub fn build(
&self,
) -> Result<SetBlackboxPatterns, SetBlackboxPatternsBuilderError>
pub fn build( &self, ) -> Result<SetBlackboxPatterns, SetBlackboxPatternsBuilderError>