SetBlackboxedRangesReturnObject

Struct SetBlackboxedRangesReturnObject 

pub struct SetBlackboxedRangesReturnObject(pub Option<Value>);
Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. Positions array contains positions where blackbox state is changed. First interval isn’t blackboxed. Array should be sorted.

Tuple Fields

0: Option<Value>