pub struct SetBreakpointByUrl {
pub line_number: JsUInt,
pub url: Option<String>,
pub url_regex: Option<String>,
pub script_hash: Option<String>,
pub column_number: Option<JsUInt>,
pub condition: Option<String>,
}Expand description
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this
command is issued, all existing parsed scripts will have breakpoints resolved and returned in
locations property. Further matching script parsing will result in subsequent
breakpointResolved events issued. This logical breakpoint will survive page reloads.
Fields
line_number: JsUIntLine number to set breakpoint at.
url: Option<String>URL of the resources to set breakpoint on.
url_regex: Option<String>Regex pattern for the URLs of the resources to set breakpoints on. Either url or
urlRegex must be specified.
script_hash: Option<String>Script hash of the resources to set breakpoint on.
column_number: Option<JsUInt>Offset in the line to set breakpoint at.
condition: Option<String>Expression to use as a breakpoint condition. When specified, debugger will only stop on the breakpoint if this expression evaluates to true.