pub struct SetBreakpointByUrlBuilder { /* private fields */ }Expand description
Builder for SetBreakpointByUrl.
Implementations
Sourceimpl SetBreakpointByUrlBuilder
impl SetBreakpointByUrlBuilder
Sourcepub fn line_number<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn line_number<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Line number to set breakpoint at.
Sourcepub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
URL of the resources to set breakpoint on.
Sourcepub fn url_regex<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn url_regex<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Regex pattern for the URLs of the resources to set breakpoints on. Either url or
urlRegex must be specified.
Sourcepub fn script_hash<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn script_hash<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Script hash of the resources to set breakpoint on.
Sourcepub fn column_number<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn column_number<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Offset in the line to set breakpoint at.
Sourcepub fn condition<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn condition<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Expression to use as a breakpoint condition. When specified, debugger will only stop on the breakpoint if this expression evaluates to true.
Sourcepub fn build(
&self,
) -> Result<SetBreakpointByUrl, SetBreakpointByUrlBuilderError>
pub fn build( &self, ) -> Result<SetBreakpointByUrl, SetBreakpointByUrlBuilderError>