pub struct SetBreakpointOnFunctionCall {
pub object_id: RemoteObjectId,
pub condition: Option<String>,
}Expand description
Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint.
Fields
object_id: RemoteObjectIdFunction object id.
condition: Option<String>Expression to use as a breakpoint condition. When specified, debugger will stop on the breakpoint if this expression evaluates to true.