pub struct SetScriptSourceBuilder { /* private fields */ }Expand description
Builder for SetScriptSource.
Implementations
Sourceimpl SetScriptSourceBuilder
impl SetScriptSourceBuilder
Sourcepub fn script_id<VALUE: Into<ScriptId>>(&mut self, value: VALUE) -> &mut Self
pub fn script_id<VALUE: Into<ScriptId>>(&mut self, value: VALUE) -> &mut Self
Id of the script to edit.
Sourcepub fn script_source<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn script_source<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
New content of the script.
Sourcepub fn dry_run<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn dry_run<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If true the change will not actually be applied. Dry run may be used to get result description without actually modifying the code.
Sourcepub fn allow_top_frame_editing<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn allow_top_frame_editing<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
If true, then scriptSource is allowed to change the function on top of the stack
as long as the top-most stack frame is the only activation of that function.
Sourcepub fn build(&self) -> Result<SetScriptSource, SetScriptSourceBuilderError>
pub fn build(&self) -> Result<SetScriptSource, SetScriptSourceBuilderError>