pub struct SetScriptSourceReturnObject {
pub call_frames: Option<Vec<CallFrame>>,
pub stack_changed: Option<bool>,
pub async_stack_trace: Option<StackTrace>,
pub async_stack_trace_id: Option<StackTraceId>,
pub status: StatusOption,
pub exception_details: Option<ExceptionDetails>,
}Expand description
Edits JavaScript source live.
In general, functions that are currently on the stack can not be edited with
a single exception: If the edited function is the top-most stack frame and
that is the only activation of that function on the stack. In this case
the live edit will be successful and a Debugger.restartFrame for the
top-most function is automatically triggered.
Fields
call_frames: Option<Vec<CallFrame>>New stack trace in case editing has happened while VM was stopped.
stack_changed: Option<bool>Whether current call stack was modified after applying the changes.
async_stack_trace: Option<StackTrace>Async stack trace, if any.
async_stack_trace_id: Option<StackTraceId>Async stack trace, if any.
status: StatusOptionWhether the operation was successful or not. Only Ok denotes a
successful live edit while the other enum variants denote why
the live edit failed.
exception_details: Option<ExceptionDetails>Exception details if any. Only present when status is CompileError.