pub struct SetScriptSourceReturnObjectBuilder { /* private fields */ }Expand description
Builder for SetScriptSourceReturnObject.
Implementations
Sourceimpl SetScriptSourceReturnObjectBuilder
impl SetScriptSourceReturnObjectBuilder
Sourcepub fn call_frames(&mut self, value: Option<Vec<CallFrame>>) -> &mut Self
pub fn call_frames(&mut self, value: Option<Vec<CallFrame>>) -> &mut Self
New stack trace in case editing has happened while VM was stopped.
Sourcepub fn stack_changed(&mut self, value: Option<bool>) -> &mut Self
pub fn stack_changed(&mut self, value: Option<bool>) -> &mut Self
Whether current call stack was modified after applying the changes.
Sourcepub fn async_stack_trace(&mut self, value: Option<StackTrace>) -> &mut Self
pub fn async_stack_trace(&mut self, value: Option<StackTrace>) -> &mut Self
Async stack trace, if any.
Sourcepub fn async_stack_trace_id(&mut self, value: Option<StackTraceId>) -> &mut Self
pub fn async_stack_trace_id(&mut self, value: Option<StackTraceId>) -> &mut Self
Async stack trace, if any.
Sourcepub fn status(&mut self, value: StatusOption) -> &mut Self
pub fn status(&mut self, value: StatusOption) -> &mut Self
Whether the operation was successful or not. Only Ok denotes a
successful live edit while the other enum variants denote why
the live edit failed.
Sourcepub fn exception_details(
&mut self,
value: Option<ExceptionDetails>,
) -> &mut Self
pub fn exception_details( &mut self, value: Option<ExceptionDetails>, ) -> &mut Self
Exception details if any. Only present when status is CompileError.
Sourcepub fn build(
&self,
) -> Result<SetScriptSourceReturnObject, SetScriptSourceReturnObjectBuilderError>
pub fn build( &self, ) -> Result<SetScriptSourceReturnObject, SetScriptSourceReturnObjectBuilderError>