pub struct SetVariableValue {
pub scope_number: JsUInt,
pub variable_name: String,
pub new_value: CallArgument,
pub call_frame_id: CallFrameId,
}Expand description
Changes value of variable in a callframe. Object-based scopes are not supported and must be mutated manually.
Fields
scope_number: JsUInt0-based number of scope as was listed in scope chain. Only ‘local’, ‘closure’ and ‘catch’ scope types are allowed. Other scopes could be manipulated manually.
variable_name: StringVariable name.
new_value: CallArgumentNew variable value.
call_frame_id: CallFrameIdId of callframe that holds variable.