pub struct StepIntoBuilder { /* private fields */ }Expand description
Builder for StepInto.
Implementations
Sourceimpl StepIntoBuilder
impl StepIntoBuilder
Sourcepub fn break_on_async_call<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn break_on_async_call<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Debugger will pause on the execution of the first async task which was scheduled before next pause.
Sourcepub fn skip_list<VALUE: Into<Vec<LocationRange>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn skip_list<VALUE: Into<Vec<LocationRange>>>( &mut self, value: VALUE, ) -> &mut Self
The skipList specifies location ranges that should be skipped on step into.