pub struct CopyTo {
pub node_id: NodeId,
pub target_node_id: NodeId,
pub insert_before_node_id: Option<NodeId>,
}Expand description
Creates a deep copy of the specified node and places it into the target container before the given anchor.
Fields
node_id: NodeIdId of the node to copy.
target_node_id: NodeIdId of the element to drop the copy into.
insert_before_node_id: Option<NodeId>Drop the copy before this node (if absent, the copy becomes the last child of
targetNodeId).