pub struct CopyToBuilder { /* private fields */ }Expand description
Builder for CopyTo.
Implementations
Sourceimpl CopyToBuilder
impl CopyToBuilder
Sourcepub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
pub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
Id of the node to copy.
Sourcepub fn target_node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
pub fn target_node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
Id of the element to drop the copy into.
Sourcepub fn insert_before_node_id<VALUE: Into<NodeId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn insert_before_node_id<VALUE: Into<NodeId>>( &mut self, value: VALUE, ) -> &mut Self
Drop the copy before this node (if absent, the copy becomes the last child of
targetNodeId).