pub struct DescribeNode {
pub node_id: Option<NodeId>,
pub backend_node_id: Option<BackendNodeId>,
pub object_id: Option<RemoteObjectId>,
pub depth: Option<JsUInt>,
pub pierce: Option<bool>,
}Expand description
Describes node given its id, does not require domain to be enabled. Does not start tracking any objects, can be used for automation.
Fields
node_id: Option<NodeId>Identifier of the node.
backend_node_id: Option<BackendNodeId>Identifier of the backend node.
object_id: Option<RemoteObjectId>JavaScript object id of the node wrapper.
depth: Option<JsUInt>The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0.
pierce: Option<bool>Whether or not iframes and shadow roots should be traversed when returning the subtree (default is false).