pub struct DescribeNodeBuilder { /* private fields */ }Expand description
Builder for DescribeNode.
Implementations
Sourceimpl DescribeNodeBuilder
impl DescribeNodeBuilder
Sourcepub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
pub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
Identifier of the node.
Sourcepub fn backend_node_id<VALUE: Into<BackendNodeId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn backend_node_id<VALUE: Into<BackendNodeId>>( &mut self, value: VALUE, ) -> &mut Self
Identifier of the backend node.
Sourcepub fn object_id<VALUE: Into<RemoteObjectId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn object_id<VALUE: Into<RemoteObjectId>>( &mut self, value: VALUE, ) -> &mut Self
JavaScript object id of the node wrapper.
Sourcepub fn depth<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn depth<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0.
Sourcepub fn pierce<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn pierce<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether or not iframes and shadow roots should be traversed when returning the subtree (default is false).
Sourcepub fn build(&self) -> Result<DescribeNode, DescribeNodeBuilderError>
pub fn build(&self) -> Result<DescribeNode, DescribeNodeBuilderError>