pub struct ForceShowPopoverBuilder { /* private fields */ }Expand description
Builder for ForceShowPopover.
Implementations
Sourceimpl ForceShowPopoverBuilder
impl ForceShowPopoverBuilder
Sourcepub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
pub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
Id of the popover HTMLElement
Sourcepub fn enable<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn enable<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If true, opens the popover and keeps it open. If false, closes the popover if it was previously force-opened.
Sourcepub fn build(&self) -> Result<ForceShowPopover, ForceShowPopoverBuilderError>
pub fn build(&self) -> Result<ForceShowPopover, ForceShowPopoverBuilderError>