pub struct GetAnchorElementBuilder { /* private fields */ }Expand description
Builder for GetAnchorElement.
Implementations
Sourceimpl GetAnchorElementBuilder
impl GetAnchorElementBuilder
Sourcepub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
pub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
Id of the positioned element from which to find the anchor.
Sourcepub fn anchor_specifier<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn anchor_specifier<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
An optional anchor specifier, as defined in https://www.w3.org/TR/css-anchor-position-1/#anchor-specifier. If not provided, it will return the implicit anchor element for the given positioned element.
Sourcepub fn build(&self) -> Result<GetAnchorElement, GetAnchorElementBuilderError>
pub fn build(&self) -> Result<GetAnchorElement, GetAnchorElementBuilderError>