pub struct GetContainerForNodeReturnObject {
pub node_id: Option<NodeId>,
}Expand description
Returns the query container of the given node based on container query conditions: containerName, physical and logical axes, and whether it queries scroll-state or anchored elements. If no axes are provided and queriesScrollState is false, the style container is returned, which is the direct parent or the closest element with a matching container-name.
Fields
node_id: Option<NodeId>The container node for the given node, or null if not found.