pub struct GetDocument {
pub depth: Option<JsUInt>,
pub pierce: Option<bool>,
}Expand description
Returns the root DOM node (and optionally the subtree) to the caller. Implicitly enables the DOM domain events for the current target.
Fields
depth: Option<JsUInt>The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0.
pierce: Option<bool>Whether or not iframes and shadow roots should be traversed when returning the subtree (default is false).