pub struct GetDocumentBuilder { /* private fields */ }Expand description
Builder for GetDocument.
Implementations
Sourceimpl GetDocumentBuilder
impl GetDocumentBuilder
Sourcepub fn depth<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn depth<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0.
Sourcepub fn pierce<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn pierce<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether or not iframes and shadow roots should be traversed when returning the subtree (default is false).
Sourcepub fn build(&self) -> Result<GetDocument, GetDocumentBuilderError>
pub fn build(&self) -> Result<GetDocument, GetDocumentBuilderError>