pub struct GetNodesForSubtreeByStyleBuilder { /* private fields */ }Expand description
Builder for GetNodesForSubtreeByStyle.
Implementations
Sourceimpl GetNodesForSubtreeByStyleBuilder
impl GetNodesForSubtreeByStyleBuilder
Sourcepub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
pub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
Node ID pointing to the root of a subtree.
Sourcepub fn computed_styles<VALUE: Into<Vec<CssComputedStyleProperty>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn computed_styles<VALUE: Into<Vec<CssComputedStyleProperty>>>( &mut self, value: VALUE, ) -> &mut Self
The style to filter nodes by (includes nodes if any of properties matches).
Sourcepub fn pierce<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn pierce<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether or not iframes and shadow roots in the same target should be traversed when returning the results (default is false).
Sourcepub fn build(
&self,
) -> Result<GetNodesForSubtreeByStyle, GetNodesForSubtreeByStyleBuilderError>
pub fn build( &self, ) -> Result<GetNodesForSubtreeByStyle, GetNodesForSubtreeByStyleBuilderError>