pub struct GetSearchResultsBuilder { /* private fields */ }Expand description
Builder for GetSearchResults.
Implementations
Sourceimpl GetSearchResultsBuilder
impl GetSearchResultsBuilder
Sourcepub fn search_id<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn search_id<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Unique search session identifier.
Sourcepub fn from_index<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn from_index<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Start index of the search result to be returned.
Sourcepub fn to_index<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn to_index<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
End index of the search result to be returned.
Sourcepub fn build(&self) -> Result<GetSearchResults, GetSearchResultsBuilderError>
pub fn build(&self) -> Result<GetSearchResults, GetSearchResultsBuilderError>