pub struct MoveToBuilder { /* private fields */ }Expand description
Builder for MoveTo.
Implementations
Sourceimpl MoveToBuilder
impl MoveToBuilder
Sourcepub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
pub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
Id of the node to move.
Sourcepub fn target_node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
pub fn target_node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
Id of the element to drop the moved node into.
Sourcepub fn insert_before_node_id<VALUE: Into<NodeId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn insert_before_node_id<VALUE: Into<NodeId>>( &mut self, value: VALUE, ) -> &mut Self
Drop node before this one (if absent, the moved node becomes the last child of
targetNodeId).