pub struct NodeBuilder { /* private fields */ }Expand description
Builder for Node.
Implementations
Sourceimpl NodeBuilder
impl NodeBuilder
Sourcepub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
pub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
Node identifier that is passed into the rest of the DOM messages as the nodeId. Backend
will only push node with given id once. It is aware of all requested nodes and will only
fire DOM events for nodes known to the client.
Sourcepub fn parent_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
pub fn parent_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
The id of the parent node if any.
Sourcepub fn backend_node_id<VALUE: Into<BackendNodeId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn backend_node_id<VALUE: Into<BackendNodeId>>( &mut self, value: VALUE, ) -> &mut Self
The BackendNodeId for this node.
Sourcepub fn local_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn local_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Node’s localName.
Sourcepub fn node_value<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn node_value<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Node’s nodeValue.
Sourcepub fn child_node_count<VALUE: Into<JsUInt>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn child_node_count<VALUE: Into<JsUInt>>( &mut self, value: VALUE, ) -> &mut Self
Child count for Container nodes.
Sourcepub fn children<VALUE: Into<Vec<Node>>>(&mut self, value: VALUE) -> &mut Self
pub fn children<VALUE: Into<Vec<Node>>>(&mut self, value: VALUE) -> &mut Self
Child nodes of this node when requested with children.
Sourcepub fn attributes<VALUE: Into<Vec<String>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn attributes<VALUE: Into<Vec<String>>>( &mut self, value: VALUE, ) -> &mut Self
Attributes of the Element node in the form of flat array \[name1, value1, name2, value2\].
Sourcepub fn document_url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn document_url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Document URL that Document or FrameOwner node points to.
Sourcepub fn base_url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn base_url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Base URL that Document or FrameOwner node uses for URL completion.
Sourcepub fn public_id<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn public_id<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
DocumentType’s publicId.
Sourcepub fn system_id<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn system_id<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
DocumentType’s systemId.
Sourcepub fn internal_subset<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn internal_subset<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
DocumentType’s internalSubset.
Sourcepub fn xml_version<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn xml_version<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Document’s XML version in case of XML documents.
Sourcepub fn pseudo_type<VALUE: Into<PseudoType>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn pseudo_type<VALUE: Into<PseudoType>>( &mut self, value: VALUE, ) -> &mut Self
Pseudo element type for this node.
Sourcepub fn pseudo_identifier<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn pseudo_identifier<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
Pseudo element identifier for this node. Only present if there is a valid pseudoType.
Sourcepub fn shadow_root_type<VALUE: Into<ShadowRootType>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn shadow_root_type<VALUE: Into<ShadowRootType>>( &mut self, value: VALUE, ) -> &mut Self
Shadow root type.
Sourcepub fn frame_id<VALUE: Into<FrameId>>(&mut self, value: VALUE) -> &mut Self
pub fn frame_id<VALUE: Into<FrameId>>(&mut self, value: VALUE) -> &mut Self
Frame ID for frame owner elements.
Sourcepub fn content_document<VALUE: Into<Box<Node>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn content_document<VALUE: Into<Box<Node>>>( &mut self, value: VALUE, ) -> &mut Self
Content document for frame owner elements.
Sourcepub fn shadow_roots<VALUE: Into<Vec<Node>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn shadow_roots<VALUE: Into<Vec<Node>>>( &mut self, value: VALUE, ) -> &mut Self
Shadow root list for given element host.
Sourcepub fn template_content<VALUE: Into<Box<Node>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn template_content<VALUE: Into<Box<Node>>>( &mut self, value: VALUE, ) -> &mut Self
Content document fragment for template elements.
Sourcepub fn pseudo_elements<VALUE: Into<Vec<Node>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn pseudo_elements<VALUE: Into<Vec<Node>>>( &mut self, value: VALUE, ) -> &mut Self
Pseudo elements associated with this node.
Sourcepub fn imported_document<VALUE: Into<Box<Node>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn imported_document<VALUE: Into<Box<Node>>>( &mut self, value: VALUE, ) -> &mut Self
Deprecated, as the HTML Imports API has been removed (crbug.com/937746). This property used to return the imported document for the HTMLImport links. The property is always undefined now.
Sourcepub fn distributed_nodes<VALUE: Into<Vec<BackendNode>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn distributed_nodes<VALUE: Into<Vec<BackendNode>>>( &mut self, value: VALUE, ) -> &mut Self
Distributed nodes for given insertion point.
Sourcepub fn is_svg<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn is_svg<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether the node is SVG.
pub fn compatibility_mode<VALUE: Into<CompatibilityMode>>( &mut self, value: VALUE, ) -> &mut Self
pub fn assigned_slot<VALUE: Into<BackendNode>>( &mut self, value: VALUE, ) -> &mut Self
pub fn is_scrollable<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn affected_by_starting_styles<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
pub fn adopted_style_sheets<VALUE: Into<Vec<StyleSheetId>>>( &mut self, value: VALUE, ) -> &mut Self