pub struct RequestChildNodes {
pub node_id: NodeId,
pub depth: Option<JsUInt>,
pub pierce: Option<bool>,
}Expand description
Requests that children of the node with given id are returned to the caller in form of
setChildNodes events where not only immediate children are retrieved, but all children down to
the specified depth.
Fields
node_id: NodeIdId of the node to get children for.
depth: Option<JsUInt>The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0.
pierce: Option<bool>Whether or not iframes and shadow roots should be traversed when returning the sub-tree (default is false).