pub struct RequestChildNodesBuilder { /* private fields */ }Expand description
Builder for RequestChildNodes.
Implementations
Sourceimpl RequestChildNodesBuilder
impl RequestChildNodesBuilder
Sourcepub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
pub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
Id of the node to get children for.
Sourcepub fn depth<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn depth<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0.
Sourcepub fn pierce<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn pierce<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether or not iframes and shadow roots should be traversed when returning the sub-tree (default is false).
Sourcepub fn build(&self) -> Result<RequestChildNodes, RequestChildNodesBuilderError>
pub fn build(&self) -> Result<RequestChildNodes, RequestChildNodesBuilderError>