RequestNode

Struct RequestNode 

pub struct RequestNode {
    pub object_id: RemoteObjectId,
}
Requests that the node is sent to the caller given the JavaScript node object reference. All nodes that form the path from the node to the root are also sent to the client as a series of setChildNodes notifications.

Fields

object_id: RemoteObjectId

JavaScript object id to convert into node.