ScrollIntoViewIfNeededBuilder

Struct ScrollIntoViewIfNeededBuilder 

pub struct ScrollIntoViewIfNeededBuilder { /* private fields */ }
Implementations

Source

impl ScrollIntoViewIfNeededBuilder

pub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self

Identifier of the node.

pub fn backend_node_id<VALUE: Into<BackendNodeId>>( &mut self, value: VALUE, ) -> &mut Self

Identifier of the backend node.

pub fn object_id<VALUE: Into<RemoteObjectId>>( &mut self, value: VALUE, ) -> &mut Self

JavaScript object id of the node wrapper.

pub fn rect<VALUE: Into<Rect>>(&mut self, value: VALUE) -> &mut Self

The rect to be scrolled into view, relative to the node’s border box, in CSS pixels. When omitted, center of the node will be used, similar to Element.scrollIntoView.

pub fn build( &self, ) -> Result<ScrollIntoViewIfNeeded, ScrollIntoViewIfNeededBuilderError>

Builds a new ScrollIntoViewIfNeeded.

Errors

If a required field has not been initialized.