pub struct GetSnapshot {
pub computed_style_whitelist: Vec<String>,
pub include_event_listeners: Option<bool>,
pub include_paint_order: Option<bool>,
pub include_user_agent_shadow_tree: Option<bool>,
}👎Deprecated
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
Fields
computed_style_whitelist: Vec<String>👎Deprecated
Whitelist of computed styles to return.
include_event_listeners: Option<bool>👎Deprecated
Whether or not to retrieve details of DOM listeners (default false).
include_paint_order: Option<bool>👎Deprecated
Whether to determine and include the paint order index of LayoutTreeNodes (default false).
include_user_agent_shadow_tree: Option<bool>👎Deprecated
Whether to include UA shadow tree in the snapshot (default false).