pub struct GetSnapshotReturnObject {
pub dom_nodes: Vec<DomNode>,
pub layout_tree_nodes: Vec<LayoutTreeNode>,
pub computed_styles: Vec<ComputedStyle>,
}👎Deprecated
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
Fields
dom_nodes: Vec<DomNode>👎Deprecated
The nodes in the DOM tree. The DOMNode at index 0 corresponds to the root document.
layout_tree_nodes: Vec<LayoutTreeNode>👎Deprecated
The nodes in the layout tree.
computed_styles: Vec<ComputedStyle>👎Deprecated
Whitelisted ComputedStyle properties for each node in the layout tree.