pub struct InlineTextBox {
pub bounding_box: Rect,
pub start_character_index: JsUInt,
pub num_characters: JsUInt,
}Expand description
Details of post layout rendered text positions. The exact layout should not be regarded as stable and may change between versions.
Fields
bounding_box: RectThe bounding box in document coordinates. Note that scroll offset of the document is ignored.
start_character_index: JsUIntThe starting index in characters, for this post layout textbox substring. Characters that would be represented as a surrogate pair in UTF-16 have length 2.
num_characters: JsUIntThe number of characters in this post layout textbox substring. Characters that would be represented as a surrogate pair in UTF-16 have length 2.