pub struct InlineTextBoxBuilder { /* private fields */ }Expand description
Builder for InlineTextBox.
Implementations
Sourceimpl InlineTextBoxBuilder
impl InlineTextBoxBuilder
Sourcepub fn bounding_box<VALUE: Into<Rect>>(&mut self, value: VALUE) -> &mut Self
pub fn bounding_box<VALUE: Into<Rect>>(&mut self, value: VALUE) -> &mut Self
The bounding box in document coordinates. Note that scroll offset of the document is ignored.
Sourcepub fn start_character_index<VALUE: Into<JsUInt>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn start_character_index<VALUE: Into<JsUInt>>( &mut self, value: VALUE, ) -> &mut Self
The starting index in characters, for this post layout textbox substring. Characters that would be represented as a surrogate pair in UTF-16 have length 2.
Sourcepub fn num_characters<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn num_characters<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The number of characters in this post layout textbox substring. Characters that would be represented as a surrogate pair in UTF-16 have length 2.
Sourcepub fn build(&self) -> Result<InlineTextBox, InlineTextBoxBuilderError>
pub fn build(&self) -> Result<InlineTextBox, InlineTextBoxBuilderError>