pub struct LayoutTreeNode {
pub dom_node_index: JsUInt,
pub bounding_box: Rect,
pub layout_text: Option<String>,
pub inline_text_nodes: Option<Vec<InlineTextBox>>,
pub style_index: Option<JsUInt>,
pub paint_order: Option<JsUInt>,
pub is_stacking_context: Option<bool>,
}Expand description
Details of an element in the DOM tree with a LayoutObject.
Fields
dom_node_index: JsUIntThe index of the related DOM node in the domNodes array returned by getSnapshot.
bounding_box: RectThe bounding box in document coordinates. Note that scroll offset of the document is ignored.
layout_text: Option<String>Contents of the LayoutText, if any.
inline_text_nodes: Option<Vec<InlineTextBox>>The post-layout inline text nodes, if any.
style_index: Option<JsUInt>Index into the computedStyles array returned by getSnapshot.
paint_order: Option<JsUInt>Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in getSnapshot was true.
is_stacking_context: Option<bool>Set to true to indicate the element begins a new stacking context.