LayoutTreeSnapshotBuilder

Struct LayoutTreeSnapshotBuilder 

pub struct LayoutTreeSnapshotBuilder { /* private fields */ }
Builder for LayoutTreeSnapshot.

Implementations

Source

impl LayoutTreeSnapshotBuilder

pub fn node_index<VALUE: Into<Vec<JsUInt>>>( &mut self, value: VALUE, ) -> &mut Self

Index of the corresponding node in the NodeTreeSnapshot array returned by captureSnapshot.

pub fn styles<VALUE: Into<Vec<ArrayOfStrings>>>( &mut self, value: VALUE, ) -> &mut Self

Array of indexes specifying computed style strings, filtered according to the computedStyles parameter passed to captureSnapshot.

pub fn bounds<VALUE: Into<Vec<Rectangle>>>(&mut self, value: VALUE) -> &mut Self

The absolute position bounding box.

pub fn text<VALUE: Into<Vec<StringIndex>>>(&mut self, value: VALUE) -> &mut Self

Contents of the LayoutText, if any.

pub fn stacking_contexts<VALUE: Into<RareBooleanData>>( &mut self, value: VALUE, ) -> &mut Self

Stacking context information.

pub fn paint_orders<VALUE: Into<Vec<JsUInt>>>( &mut self, value: VALUE, ) -> &mut Self

Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in captureSnapshot was true.

pub fn offset_rects<VALUE: Into<Vec<Rectangle>>>( &mut self, value: VALUE, ) -> &mut Self

The offset rect of nodes. Only available when includeDOMRects is set to true

pub fn scroll_rects<VALUE: Into<Vec<Rectangle>>>( &mut self, value: VALUE, ) -> &mut Self

The scroll rect of nodes. Only available when includeDOMRects is set to true

pub fn client_rects<VALUE: Into<Vec<Rectangle>>>( &mut self, value: VALUE, ) -> &mut Self

The client rect of nodes. Only available when includeDOMRects is set to true

pub fn blended_background_colors<VALUE: Into<Vec<StringIndex>>>( &mut self, value: VALUE, ) -> &mut Self

The list of background colors that are blended with colors of overlapping elements.

pub fn text_color_opacities<VALUE: Into<Vec<JsFloat>>>( &mut self, value: VALUE, ) -> &mut Self

The list of computed text opacities.

pub fn build( &self, ) -> Result<LayoutTreeSnapshot, LayoutTreeSnapshotBuilderError>

Builds a new LayoutTreeSnapshot.

Errors

If a required field has not been initialized.