pub struct TextBoxSnapshotBuilder { /* private fields */ }Expand description
Builder for TextBoxSnapshot.
Implementations
Sourceimpl TextBoxSnapshotBuilder
impl TextBoxSnapshotBuilder
Sourcepub fn layout_index<VALUE: Into<Vec<JsUInt>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn layout_index<VALUE: Into<Vec<JsUInt>>>( &mut self, value: VALUE, ) -> &mut Self
Index of the layout tree node that owns this box collection.
Sourcepub fn bounds<VALUE: Into<Vec<Rectangle>>>(&mut self, value: VALUE) -> &mut Self
pub fn bounds<VALUE: Into<Vec<Rectangle>>>(&mut self, value: VALUE) -> &mut Self
The absolute position bounding box.
Sourcepub fn start<VALUE: Into<Vec<JsUInt>>>(&mut self, value: VALUE) -> &mut Self
pub fn start<VALUE: Into<Vec<JsUInt>>>(&mut self, value: VALUE) -> &mut Self
The starting index in characters, for this post layout textbox substring. Characters that would be represented as a surrogate pair in UTF-16 have length 2.
Sourcepub fn length<VALUE: Into<Vec<JsUInt>>>(&mut self, value: VALUE) -> &mut Self
pub fn length<VALUE: Into<Vec<JsUInt>>>(&mut self, value: VALUE) -> &mut Self
The number of characters in this post layout textbox substring. Characters that would be represented as a surrogate pair in UTF-16 have length 2.
Sourcepub fn build(&self) -> Result<TextBoxSnapshot, TextBoxSnapshotBuilderError>
pub fn build(&self) -> Result<TextBoxSnapshot, TextBoxSnapshotBuilderError>