pub struct AddScreen {
pub left: JsUInt,
pub top: JsUInt,
pub width: JsUInt,
pub height: JsUInt,
pub work_area_insets: Option<WorkAreaInsets>,
pub device_pixel_ratio: Option<JsFloat>,
pub rotation: Option<JsUInt>,
pub color_depth: Option<JsUInt>,
pub label: Option<String>,
pub is_internal: Option<bool>,
}Expand description
Add a new screen to the device. Only supported in headless mode.
Fields
left: JsUIntOffset of the left edge of the screen in pixels.
top: JsUIntOffset of the top edge of the screen in pixels.
width: JsUIntThe width of the screen in pixels.
height: JsUIntThe height of the screen in pixels.
work_area_insets: Option<WorkAreaInsets>Specifies the screen’s work area. Default is entire screen.
device_pixel_ratio: Option<JsFloat>Specifies the screen’s device pixel ratio. Default is 1.
rotation: Option<JsUInt>Specifies the screen’s rotation angle. Available values are 0, 90, 180 and 270. Default is 0.
color_depth: Option<JsUInt>Specifies the screen’s color depth in bits. Default is 24.
label: Option<String>Specifies the descriptive label for the screen. Default is none.
is_internal: Option<bool>Indicates whether the screen is internal to the device or external, attached to the device. Default is false.