pub struct AddScreenBuilder { /* private fields */ }Expand description
Builder for AddScreen.
Implementations
Sourceimpl AddScreenBuilder
impl AddScreenBuilder
Sourcepub fn left<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn left<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Offset of the left edge of the screen in pixels.
Sourcepub fn top<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn top<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Offset of the top edge of the screen in pixels.
Sourcepub fn width<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn width<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The width of the screen in pixels.
Sourcepub fn height<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn height<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The height of the screen in pixels.
Sourcepub fn work_area_insets<VALUE: Into<WorkAreaInsets>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn work_area_insets<VALUE: Into<WorkAreaInsets>>( &mut self, value: VALUE, ) -> &mut Self
Specifies the screen’s work area. Default is entire screen.
Sourcepub fn device_pixel_ratio<VALUE: Into<JsFloat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn device_pixel_ratio<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self
Specifies the screen’s device pixel ratio. Default is 1.
Sourcepub fn rotation<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn rotation<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Specifies the screen’s rotation angle. Available values are 0, 90, 180 and 270. Default is 0.
Sourcepub fn color_depth<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn color_depth<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Specifies the screen’s color depth in bits. Default is 24.
Sourcepub fn label<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn label<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Specifies the descriptive label for the screen. Default is none.
Sourcepub fn is_internal<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn is_internal<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Indicates whether the screen is internal to the device or external, attached to the device. Default is false.