pub struct ClearDevicePostureOverrideReturnObject(pub Option<Value>);Expand description
Clears a device posture override set with either setDeviceMetricsOverride() or setDevicePostureOverride() and starts using posture information from the platform again. Does nothing if no override is set.
Tuple Fields
0: Option<Value>Trait Implementations
Sourceimpl Clone for ClearDevicePostureOverrideReturnObject
impl Clone for ClearDevicePostureOverrideReturnObject
Sourcefn clone(&self) -> ClearDevicePostureOverrideReturnObject
fn clone(&self) -> ClearDevicePostureOverrideReturnObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ClearDevicePostureOverrideReturnObject
impl<'de> Deserialize<'de> for ClearDevicePostureOverrideReturnObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ClearDevicePostureOverrideReturnObject
impl PartialEq for ClearDevicePostureOverrideReturnObject
Sourcefn eq(&self, other: &ClearDevicePostureOverrideReturnObject) -> bool
fn eq(&self, other: &ClearDevicePostureOverrideReturnObject) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ClearDevicePostureOverrideReturnObject