pub struct DisplayFeatureBuilder { /* private fields */ }Expand description
Builder for DisplayFeature.
Implementations
Sourceimpl DisplayFeatureBuilder
impl DisplayFeatureBuilder
Sourcepub fn orientation<VALUE: Into<DisplayFeatureOrientation>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn orientation<VALUE: Into<DisplayFeatureOrientation>>( &mut self, value: VALUE, ) -> &mut Self
Orientation of a display feature in relation to screen
Sourcepub fn offset<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn offset<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The offset from the screen origin in either the x (for vertical orientation) or y (for horizontal orientation) direction.
Sourcepub fn mask_length<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn mask_length<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
A display feature may mask content such that it is not physically displayed - this length along with the offset describes this area. A display feature that only splits content will have a 0 mask_length.
Sourcepub fn build(&self) -> Result<DisplayFeature, DisplayFeatureBuilderError>
pub fn build(&self) -> Result<DisplayFeature, DisplayFeatureBuilderError>