pub struct ScreenInfo {Show 16 fields
pub left: JsUInt,
pub top: JsUInt,
pub width: JsUInt,
pub height: JsUInt,
pub avail_left: JsUInt,
pub avail_top: JsUInt,
pub avail_width: JsUInt,
pub avail_height: JsUInt,
pub device_pixel_ratio: JsFloat,
pub orientation: ScreenOrientation,
pub color_depth: JsUInt,
pub is_extended: bool,
pub is_internal: bool,
pub is_primary: bool,
pub label: String,
pub id: ScreenId,
}Expand description
Screen information similar to the one returned by window.getScreenDetails() method, see https://w3c.github.io/window-management/#screendetailed.
Fields
left: JsUIntOffset of the left edge of the screen.
top: JsUIntOffset of the top edge of the screen.
width: JsUIntWidth of the screen.
height: JsUIntHeight of the screen.
avail_left: JsUIntOffset of the left edge of the available screen area.
avail_top: JsUIntOffset of the top edge of the available screen area.
avail_width: JsUIntWidth of the available screen area.
avail_height: JsUIntHeight of the available screen area.
device_pixel_ratio: JsFloatSpecifies the screen’s device pixel ratio.
orientation: ScreenOrientationSpecifies the screen’s orientation.
color_depth: JsUIntSpecifies the screen’s color depth in bits.
is_extended: boolIndicates whether the device has multiple screens.
is_internal: boolIndicates whether the screen is internal to the device or external, attached to the device.
is_primary: boolIndicates whether the screen is set as the the operating system primary screen.
label: StringSpecifies the descriptive label for the screen.
id: ScreenIdSpecifies the unique identifier of the screen.