pub struct ScreenInfoBuilder { /* private fields */ }Expand description
Builder for ScreenInfo.
Implementations
Sourceimpl ScreenInfoBuilder
impl ScreenInfoBuilder
Sourcepub fn left<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn left<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Offset of the left edge of the screen.
Sourcepub fn top<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn top<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Offset of the top edge of the screen.
Sourcepub fn avail_left<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn avail_left<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Offset of the left edge of the available screen area.
Sourcepub fn avail_top<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn avail_top<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Offset of the top edge of the available screen area.
Sourcepub fn avail_width<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn avail_width<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Width of the available screen area.
Sourcepub fn avail_height<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn avail_height<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Height of the available screen area.
Sourcepub fn device_pixel_ratio<VALUE: Into<JsFloat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn device_pixel_ratio<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self
Specifies the screen’s device pixel ratio.
Sourcepub fn orientation<VALUE: Into<ScreenOrientation>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn orientation<VALUE: Into<ScreenOrientation>>( &mut self, value: VALUE, ) -> &mut Self
Specifies the screen’s orientation.
Sourcepub fn color_depth<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn color_depth<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Specifies the screen’s color depth in bits.
Sourcepub fn is_extended<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn is_extended<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Indicates whether the device has multiple screens.
Sourcepub fn is_internal<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn is_internal<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Indicates whether the screen is internal to the device or external, attached to the device.
Sourcepub fn is_primary<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn is_primary<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Indicates whether the screen is set as the the operating system primary screen.
Sourcepub fn label<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn label<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Specifies the descriptive label for the screen.
Sourcepub fn id<VALUE: Into<ScreenId>>(&mut self, value: VALUE) -> &mut Self
pub fn id<VALUE: Into<ScreenId>>(&mut self, value: VALUE) -> &mut Self
Specifies the unique identifier of the screen.
Sourcepub fn build(&self) -> Result<ScreenInfo, ScreenInfoBuilderError>
pub fn build(&self) -> Result<ScreenInfo, ScreenInfoBuilderError>