SetDeviceMetricsOverride

Struct SetDeviceMetricsOverride 

pub struct SetDeviceMetricsOverride {
Show 14 fields pub width: JsUInt, pub height: JsUInt, pub device_scale_factor: JsFloat, pub mobile: bool, pub scale: Option<JsFloat>, pub screen_width: Option<JsUInt>, pub screen_height: Option<JsUInt>, pub position_x: Option<JsUInt>, pub position_y: Option<JsUInt>, pub dont_set_visible_size: Option<bool>, pub screen_orientation: Option<ScreenOrientation>, pub viewport: Option<Viewport>, pub display_feature: Option<DisplayFeature>, pub device_posture: Option<DevicePosture>,
}
Overrides the values of device screen dimensions (window.screen.width, window.screen.height, window.innerWidth, window.innerHeight, and “device-width”/“device-height”-related CSS media query results).

Fields

width: JsUInt

Overriding width value in pixels (minimum 0, maximum 10000000). 0 disables the override.

height: JsUInt

Overriding height value in pixels (minimum 0, maximum 10000000). 0 disables the override.

device_scale_factor: JsFloat

Overriding device scale factor value. 0 disables the override.

mobile: bool

Whether to emulate mobile device. This includes viewport meta tag, overlay scrollbars, text autosizing and more.

scale: Option<JsFloat>

Scale to apply to resulting view image.

screen_width: Option<JsUInt>

Overriding screen width value in pixels (minimum 0, maximum 10000000).

screen_height: Option<JsUInt>

Overriding screen height value in pixels (minimum 0, maximum 10000000).

position_x: Option<JsUInt>

Overriding view X position on screen in pixels (minimum 0, maximum 10000000).

position_y: Option<JsUInt>

Overriding view Y position on screen in pixels (minimum 0, maximum 10000000).

dont_set_visible_size: Option<bool>

Do not set visible view size, rely upon explicit setVisibleSize call.

screen_orientation: Option<ScreenOrientation>

Screen orientation override.

viewport: Option<Viewport>

If set, the visible area of the page will be overridden to this viewport. This viewport change is not observed by the page, e.g. viewport-relative elements do not change positions.

display_feature: Option<DisplayFeature>
👎Deprecated

If set, the display feature of a multi-segment screen. If not set, multi-segment support is turned-off. Deprecated, use Emulation.setDisplayFeaturesOverride.

device_posture: Option<DevicePosture>
👎Deprecated

If set, the posture of a foldable device. If not set the posture is set to continuous. Deprecated, use Emulation.setDevicePostureOverride.