pub struct SetSmallViewportHeightDifferenceOverride {
pub difference: JsUInt,
}Expand description
Allows overriding the difference between the small and large viewport sizes, which determine the
value of the svh and lvh unit, respectively. Only supported for top-level frames.
Fields
difference: JsUIntThis will cause an element of size 100svh to be difference pixels smaller than an element
of size 100lvh.