Module extensions

Module extensions 

Modules

events

Structs

ClearStorageItems
Clears extension storage in the given storageArea.
ClearStorageItemsBuilder
Builder for ClearStorageItems.
ClearStorageItemsReturnObject
Clears extension storage in the given storageArea.
GetStorageItems
Gets data from extension storage in the given storageArea. If keys is specified, these are used to filter the result.
GetStorageItemsBuilder
Builder for GetStorageItems.
GetStorageItemsReturnObject
Gets data from extension storage in the given storageArea. If keys is specified, these are used to filter the result.
GetStorageItemsReturnObjectBuilder
Builder for GetStorageItemsReturnObject.
LoadUnpacked
Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set.
LoadUnpackedBuilder
Builder for LoadUnpacked.
LoadUnpackedReturnObject
Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set.
LoadUnpackedReturnObjectBuilder
Builder for LoadUnpackedReturnObject.
RemoveStorageItems
Removes keys from extension storage in the given storageArea.
RemoveStorageItemsBuilder
Builder for RemoveStorageItems.
RemoveStorageItemsReturnObject
Removes keys from extension storage in the given storageArea.
SetStorageItems
Sets values in extension storage in the given storageArea. The provided values will be merged with existing values in the storage area.
SetStorageItemsBuilder
Builder for SetStorageItems.
SetStorageItemsReturnObject
Sets values in extension storage in the given storageArea. The provided values will be merged with existing values in the storage area.
TriggerAction
Runs an extension default action. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set.
TriggerActionBuilder
Builder for TriggerAction.
TriggerActionReturnObject
Runs an extension default action. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set.
Uninstall
Uninstalls an unpacked extension (others not supported) from the profile. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging.
UninstallBuilder
Builder for Uninstall.
UninstallReturnObject
Uninstalls an unpacked extension (others not supported) from the profile. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging.

Enums

ClearStorageItemsBuilderError
Error type for ClearStorageItemsBuilder
GetStorageItemsBuilderError
Error type for GetStorageItemsBuilder
GetStorageItemsReturnObjectBuilderError
Error type for GetStorageItemsReturnObjectBuilder
LoadUnpackedBuilderError
Error type for LoadUnpackedBuilder
LoadUnpackedReturnObjectBuilderError
Error type for LoadUnpackedReturnObjectBuilder
RemoveStorageItemsBuilderError
Error type for RemoveStorageItemsBuilder
SetStorageItemsBuilderError
Error type for SetStorageItemsBuilder
StorageArea
TriggerActionBuilderError
Error type for TriggerActionBuilder
UninstallBuilderError
Error type for UninstallBuilder