pub struct LoadUnpackedReturnObject {
pub id: String,
}Expand description
Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set.
Fields
id: StringExtension id.