Module fetch

Module fetch 

Modules

events

Structs

AuthChallenge
Authorization challenge for HTTP status code 401 or 407.
AuthChallengeBuilder
Builder for AuthChallenge.
AuthChallengeResponse
Response to an AuthChallenge.
AuthChallengeResponseBuilder
Builder for AuthChallengeResponse.
ContinueRequest
Continues the request, optionally modifying some of its parameters.
ContinueRequestBuilder
Builder for ContinueRequest.
ContinueRequestReturnObject
Continues the request, optionally modifying some of its parameters.
ContinueResponse
Continues loading of the paused response, optionally modifying the response headers. If either responseCode or headers are modified, all of them must be present.
ContinueResponseBuilder
Builder for ContinueResponse.
ContinueResponseReturnObject
Continues loading of the paused response, optionally modifying the response headers. If either responseCode or headers are modified, all of them must be present.
ContinueWithAuth
Continues a request supplying authChallengeResponse following authRequired event.
ContinueWithAuthBuilder
Builder for ContinueWithAuth.
ContinueWithAuthReturnObject
Continues a request supplying authChallengeResponse following authRequired event.
Disable
DisableReturnObject
Disables the fetch domain.
Enable
Enables issuing of requestPaused events. A request will be paused until client calls one of failRequest, fulfillRequest or continueRequest/continueWithAuth.
EnableBuilder
Builder for Enable.
EnableReturnObject
Enables issuing of requestPaused events. A request will be paused until client calls one of failRequest, fulfillRequest or continueRequest/continueWithAuth.
FailRequest
Causes the request to fail with specified reason.
FailRequestBuilder
Builder for FailRequest.
FailRequestReturnObject
Causes the request to fail with specified reason.
FulfillRequest
Provides response to the request.
FulfillRequestBuilder
Builder for FulfillRequest.
FulfillRequestReturnObject
Provides response to the request.
GetResponseBody
Causes the body of the response to be received from the server and returned as a single string. May only be issued for a request that is paused in the Response stage and is mutually exclusive with takeResponseBodyForInterceptionAsStream. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior. Note that the response body is not available for redirects. Requests paused in the redirect received state may be differentiated by responseCode and presence of location response header, see comments to requestPaused for details.
GetResponseBodyBuilder
Builder for GetResponseBody.
GetResponseBodyReturnObject
Causes the body of the response to be received from the server and returned as a single string. May only be issued for a request that is paused in the Response stage and is mutually exclusive with takeResponseBodyForInterceptionAsStream. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior. Note that the response body is not available for redirects. Requests paused in the redirect received state may be differentiated by responseCode and presence of location response header, see comments to requestPaused for details.
GetResponseBodyReturnObjectBuilder
Builder for GetResponseBodyReturnObject.
HeaderEntry
Response HTTP header entry
HeaderEntryBuilder
Builder for HeaderEntry.
RequestPattern
RequestPatternBuilder
Builder for RequestPattern.
TakeResponseBodyAsStream
Returns a handle to the stream representing the response body. The request must be paused in the HeadersReceived stage. Note that after this command the request can’t be continued as is – client either needs to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified. This method is mutually exclusive with getResponseBody. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior.
TakeResponseBodyAsStreamBuilder
Builder for TakeResponseBodyAsStream.
TakeResponseBodyAsStreamReturnObject
Returns a handle to the stream representing the response body. The request must be paused in the HeadersReceived stage. Note that after this command the request can’t be continued as is – client either needs to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified. This method is mutually exclusive with getResponseBody. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior.
TakeResponseBodyAsStreamReturnObjectBuilder
Builder for TakeResponseBodyAsStreamReturnObject.

Enums

AuthChallengeBuilderError
Error type for AuthChallengeBuilder
AuthChallengeResponseBuilderError
Error type for AuthChallengeResponseBuilder
AuthChallengeResponseResponse
AuthChallengeSource
ContinueRequestBuilderError
Error type for ContinueRequestBuilder
ContinueResponseBuilderError
Error type for ContinueResponseBuilder
ContinueWithAuthBuilderError
Error type for ContinueWithAuthBuilder
EnableBuilderError
Error type for EnableBuilder
FailRequestBuilderError
Error type for FailRequestBuilder
FulfillRequestBuilderError
Error type for FulfillRequestBuilder
GetResponseBodyBuilderError
Error type for GetResponseBodyBuilder
GetResponseBodyReturnObjectBuilderError
Error type for GetResponseBodyReturnObjectBuilder
HeaderEntryBuilderError
Error type for HeaderEntryBuilder
RequestPatternBuilderError
Error type for RequestPatternBuilder
RequestStage
TakeResponseBodyAsStreamBuilderError
Error type for TakeResponseBodyAsStreamBuilder
TakeResponseBodyAsStreamReturnObjectBuilderError
Error type for TakeResponseBodyAsStreamReturnObjectBuilder

Type Aliases

RequestId