pub struct AuthRequiredEventParamsBuilder { /* private fields */ }Expand description
Builder for AuthRequiredEventParams.
Implementations
Sourceimpl AuthRequiredEventParamsBuilder
impl AuthRequiredEventParamsBuilder
Sourcepub fn request_id(&mut self, value: RequestId) -> &mut Self
pub fn request_id(&mut self, value: RequestId) -> &mut Self
Each request the page makes will have a unique id.
Sourcepub fn frame_id(&mut self, value: FrameId) -> &mut Self
pub fn frame_id(&mut self, value: FrameId) -> &mut Self
The id of the frame that initiated the request.
Sourcepub fn resource_type(&mut self, value: ResourceType) -> &mut Self
pub fn resource_type(&mut self, value: ResourceType) -> &mut Self
How the requested resource will be used.
Sourcepub fn auth_challenge(&mut self, value: AuthChallenge) -> &mut Self
pub fn auth_challenge(&mut self, value: AuthChallenge) -> &mut Self
Details of the Authorization Challenge encountered. If this is set, client should respond with continueRequest that contains AuthChallengeResponse.
Sourcepub fn build(
&self,
) -> Result<AuthRequiredEventParams, AuthRequiredEventParamsBuilderError>
pub fn build( &self, ) -> Result<AuthRequiredEventParams, AuthRequiredEventParamsBuilderError>