pub struct RequestPausedEventParams {
pub request_id: RequestId,
pub request: Request,
pub frame_id: FrameId,
pub resource_type: ResourceType,
pub response_error_reason: Option<ErrorReason>,
pub response_status_code: Option<JsUInt>,
pub response_status_text: Option<String>,
pub response_headers: Option<Vec<HeaderEntry>>,
pub network_id: Option<RequestId>,
pub redirected_request_id: Option<RequestId>,
}Fields
request_id: RequestIdEach request the page makes will have a unique id.
request: RequestThe details of the request.
frame_id: FrameIdThe id of the frame that initiated the request.
resource_type: ResourceTypeHow the requested resource will be used.
response_error_reason: Option<ErrorReason>Response error if intercepted at response stage.
response_status_code: Option<JsUInt>Response code if intercepted at response stage.
response_status_text: Option<String>Response status text if intercepted at response stage.
response_headers: Option<Vec<HeaderEntry>>Response headers if intercepted at the response stage.
network_id: Option<RequestId>If the intercepted request had a corresponding Network.requestWillBeSent event fired for it, then this networkId will be the same as the requestId present in the requestWillBeSent event.
redirected_request_id: Option<RequestId>If the request is due to a redirect response from the server, the id of the request that has caused the redirect.