pub struct AuthChallengeResponseBuilder { /* private fields */ }Expand description
Builder for AuthChallengeResponse.
Implementations
Sourceimpl AuthChallengeResponseBuilder
impl AuthChallengeResponseBuilder
Sourcepub fn response<VALUE: Into<AuthChallengeResponseResponse>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn response<VALUE: Into<AuthChallengeResponseResponse>>( &mut self, value: VALUE, ) -> &mut Self
The decision on what to do in response to the authorization challenge. Default means deferring to the default behavior of the net stack, which will likely either the Cancel authentication or display a popup dialog box.
Sourcepub fn username<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn username<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The username to provide, possibly empty. Should only be set if response is ProvideCredentials.
Sourcepub fn password<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn password<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The password to provide, possibly empty. Should only be set if response is ProvideCredentials.
Sourcepub fn build(
&self,
) -> Result<AuthChallengeResponse, AuthChallengeResponseBuilderError>
pub fn build( &self, ) -> Result<AuthChallengeResponse, AuthChallengeResponseBuilderError>