pub struct ContinueRequestBuilder { /* private fields */ }Expand description
Builder for ContinueRequest.
Implementations
Sourceimpl ContinueRequestBuilder
impl ContinueRequestBuilder
Sourcepub fn request_id<VALUE: Into<RequestId>>(&mut self, value: VALUE) -> &mut Self
pub fn request_id<VALUE: Into<RequestId>>(&mut self, value: VALUE) -> &mut Self
An id the client received in requestPaused event.
Sourcepub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
If set, the request url will be modified in a way that’s not observable by page.
Sourcepub fn method<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn method<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
If set, the request method is overridden.
Sourcepub fn post_data<VALUE: Into<Vec<u8>>>(&mut self, value: VALUE) -> &mut Self
pub fn post_data<VALUE: Into<Vec<u8>>>(&mut self, value: VALUE) -> &mut Self
If set, overrides the post data in the request.
Sourcepub fn headers<VALUE: Into<Vec<HeaderEntry>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn headers<VALUE: Into<Vec<HeaderEntry>>>( &mut self, value: VALUE, ) -> &mut Self
If set, overrides the request headers. Note that the overrides do not extend to subsequent redirect hops, if a redirect happens. Another override may be applied to a different request produced by a redirect.
Sourcepub fn intercept_response<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn intercept_response<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
If set, overrides response interception behavior for this request.
Sourcepub fn build(&self) -> Result<ContinueRequest, ContinueRequestBuilderError>
pub fn build(&self) -> Result<ContinueRequest, ContinueRequestBuilderError>