pub struct ContinueResponse {
pub request_id: RequestId,
pub response_code: Option<JsUInt>,
pub response_phrase: Option<String>,
pub response_headers: Option<Vec<HeaderEntry>>,
pub binary_response_headers: Option<Vec<u8>>,
}Expand description
Continues loading of the paused response, optionally modifying the response headers. If either responseCode or headers are modified, all of them must be present.
Fields
request_id: RequestIdAn id the client received in requestPaused event.
response_code: Option<JsUInt>An HTTP response code. If absent, original response code will be used.
response_phrase: Option<String>A textual representation of responseCode. If absent, a standard phrase matching responseCode is used.
response_headers: Option<Vec<HeaderEntry>>Response headers. If absent, original response headers will be used.
binary_response_headers: Option<Vec<u8>>Alternative way of specifying response headers as a \0-separated series of name: value pairs. Prefer the above method unless you need to represent some non-UTF8 values that can’t be transmitted over the protocol as text.