pub struct ContinueResponseBuilder { /* private fields */ }Expand description
Builder for ContinueResponse.
Implementations
Sourceimpl ContinueResponseBuilder
impl ContinueResponseBuilder
Sourcepub fn request_id<VALUE: Into<RequestId>>(&mut self, value: VALUE) -> &mut Self
pub fn request_id<VALUE: Into<RequestId>>(&mut self, value: VALUE) -> &mut Self
An id the client received in requestPaused event.
Sourcepub fn response_code<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn response_code<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
An HTTP response code. If absent, original response code will be used.
Sourcepub fn response_phrase<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn response_phrase<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
A textual representation of responseCode. If absent, a standard phrase matching responseCode is used.
Sourcepub fn response_headers<VALUE: Into<Vec<HeaderEntry>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn response_headers<VALUE: Into<Vec<HeaderEntry>>>( &mut self, value: VALUE, ) -> &mut Self
Response headers. If absent, original response headers will be used.
Sourcepub fn binary_response_headers<VALUE: Into<Vec<u8>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn binary_response_headers<VALUE: Into<Vec<u8>>>( &mut self, value: VALUE, ) -> &mut Self
Alternative way of specifying response headers as a \0-separated series of name: value pairs. Prefer the above method unless you need to represent some non-UTF8 values that can’t be transmitted over the protocol as text.
Sourcepub fn build(&self) -> Result<ContinueResponse, ContinueResponseBuilderError>
pub fn build(&self) -> Result<ContinueResponse, ContinueResponseBuilderError>