pub struct ContinueResponseReturnObject(pub Option<Value>);Expand description
Continues loading of the paused response, optionally modifying the response headers. If either responseCode or headers are modified, all of them must be present.
Tuple Fields
0: Option<Value>Trait Implementations
Sourceimpl Clone for ContinueResponseReturnObject
impl Clone for ContinueResponseReturnObject
Sourcefn clone(&self) -> ContinueResponseReturnObject
fn clone(&self) -> ContinueResponseReturnObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContinueResponseReturnObject
impl Debug for ContinueResponseReturnObject
Sourceimpl<'de> Deserialize<'de> for ContinueResponseReturnObject
impl<'de> Deserialize<'de> for ContinueResponseReturnObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ContinueResponseReturnObject
impl PartialEq for ContinueResponseReturnObject
Sourcefn eq(&self, other: &ContinueResponseReturnObject) -> bool
fn eq(&self, other: &ContinueResponseReturnObject) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ContinueResponseReturnObject