pub struct Enable {
pub patterns: Option<Vec<RequestPattern>>,
pub handle_auth_requests: Option<bool>,
}Expand description
Enables issuing of requestPaused events. A request will be paused until client calls one of failRequest, fulfillRequest or continueRequest/continueWithAuth.
Fields
patterns: Option<Vec<RequestPattern>>If specified, only requests matching any of these patterns will produce fetchRequested event and will be paused until clients response. If not set, all requests will be affected.
handle_auth_requests: Option<bool>If true, authRequired events will be issued and requests will be paused expecting a call to continueWithAuth.