EnableBuilder

Struct EnableBuilder 

pub struct EnableBuilder { /* private fields */ }
Builder for Enable.

Implementations

Source

impl EnableBuilder

pub fn patterns<VALUE: Into<Vec<RequestPattern>>>( &mut self, value: VALUE, ) -> &mut Self

If specified, only requests matching any of these patterns will produce fetchRequested event and will be paused until clients response. If not set, all requests will be affected.

pub fn handle_auth_requests<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

If true, authRequired events will be issued and requests will be paused expecting a call to continueWithAuth.

pub fn build(&self) -> Result<Enable, EnableBuilderError>

Builds a new Enable.

Errors

If a required field has not been initialized.