pub struct FulfillRequest {
pub request_id: RequestId,
pub response_code: JsUInt,
pub response_headers: Option<Vec<HeaderEntry>>,
pub binary_response_headers: Option<Vec<u8>>,
pub body: Option<Vec<u8>>,
pub response_phrase: Option<String>,
}Expand description
Provides response to the request.
Fields
request_id: RequestIdAn id the client received in requestPaused event.
response_code: JsUIntAn HTTP response code.
response_headers: Option<Vec<HeaderEntry>>Response headers.
binary_response_headers: Option<Vec<u8>>Alternative way of specifying response headers as a \0-separated series of name: value pairs. Prefer the above method unless you need to represent some non-UTF8 values that can’t be transmitted over the protocol as text.
body: Option<Vec<u8>>A response body. If absent, original response body will be used if the request is intercepted at the response stage and empty body will be used if the request is intercepted at the request stage.
response_phrase: Option<String>A textual representation of responseCode. If absent, a standard phrase matching responseCode is used.