FulfillRequestBuilder

Struct FulfillRequestBuilder 

pub struct FulfillRequestBuilder { /* private fields */ }
Builder for FulfillRequest.

Implementations

Source

impl FulfillRequestBuilder

pub fn request_id<VALUE: Into<RequestId>>(&mut self, value: VALUE) -> &mut Self

An id the client received in requestPaused event.

pub fn response_code<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self

An HTTP response code.

pub fn response_headers<VALUE: Into<Vec<HeaderEntry>>>( &mut self, value: VALUE, ) -> &mut Self

Response headers.

pub fn binary_response_headers<VALUE: Into<Vec<u8>>>( &mut self, value: VALUE, ) -> &mut Self

Alternative way of specifying response headers as a \0-separated series of name: value pairs. Prefer the above method unless you need to represent some non-UTF8 values that can’t be transmitted over the protocol as text.

pub fn body<VALUE: Into<Vec<u8>>>(&mut self, value: VALUE) -> &mut Self

A response body. If absent, original response body will be used if the request is intercepted at the response stage and empty body will be used if the request is intercepted at the request stage.

pub fn response_phrase<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self

A textual representation of responseCode. If absent, a standard phrase matching responseCode is used.

pub fn build(&self) -> Result<FulfillRequest, FulfillRequestBuilderError>

Builds a new FulfillRequest.

Errors

If a required field has not been initialized.