pub struct TakeResponseBodyAsStream {
pub request_id: RequestId,
}Expand description
Returns a handle to the stream representing the response body. The request must be paused in the HeadersReceived stage. Note that after this command the request can’t be continued as is – client either needs to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified. This method is mutually exclusive with getResponseBody. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior.
Fields
request_id: RequestIdTrait Implementations
Sourceimpl Clone for TakeResponseBodyAsStream
impl Clone for TakeResponseBodyAsStream
Sourcefn clone(&self) -> TakeResponseBodyAsStream
fn clone(&self) -> TakeResponseBodyAsStream
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TakeResponseBodyAsStream
impl Debug for TakeResponseBodyAsStream
Sourceimpl<'de> Deserialize<'de> for TakeResponseBodyAsStream
impl<'de> Deserialize<'de> for TakeResponseBodyAsStream
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Method for TakeResponseBodyAsStream
impl Method for TakeResponseBodyAsStream
const NAME: &'static str = "Fetch.takeResponseBodyAsStream"
type ReturnObject = TakeResponseBodyAsStreamReturnObject
fn to_method_call(self, call_id: CallId) -> MethodCall<Self>where
Self: Sized,
Sourceimpl PartialEq for TakeResponseBodyAsStream
impl PartialEq for TakeResponseBodyAsStream
Sourceimpl Serialize for TakeResponseBodyAsStream
impl Serialize for TakeResponseBodyAsStream
impl StructuralPartialEq for TakeResponseBodyAsStream