pub struct TakeResponseBodyAsStreamReturnObject {
pub stream: StreamHandle,
}Expand description
Returns a handle to the stream representing the response body. The request must be paused in the HeadersReceived stage. Note that after this command the request can’t be continued as is – client either needs to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified. This method is mutually exclusive with getResponseBody. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior.
Fields
stream: StreamHandleTrait Implementations
Sourceimpl Clone for TakeResponseBodyAsStreamReturnObject
impl Clone for TakeResponseBodyAsStreamReturnObject
Sourcefn clone(&self) -> TakeResponseBodyAsStreamReturnObject
fn clone(&self) -> TakeResponseBodyAsStreamReturnObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for TakeResponseBodyAsStreamReturnObject
impl<'de> Deserialize<'de> for TakeResponseBodyAsStreamReturnObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TakeResponseBodyAsStreamReturnObject
impl PartialEq for TakeResponseBodyAsStreamReturnObject
Sourcefn eq(&self, other: &TakeResponseBodyAsStreamReturnObject) -> bool
fn eq(&self, other: &TakeResponseBodyAsStreamReturnObject) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TakeResponseBodyAsStreamReturnObject