BeginFrameBuilder

Struct BeginFrameBuilder 

pub struct BeginFrameBuilder { /* private fields */ }
Builder for BeginFrame.

Implementations

Source

impl BeginFrameBuilder

pub fn frame_time_ticks<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self

Timestamp of this BeginFrame in Renderer TimeTicks (milliseconds of uptime). If not set, the current time will be used.

pub fn interval<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

The interval between BeginFrames that is reported to the compositor, in milliseconds. Defaults to a 60 frames/second interval, i.e. about 16.666 milliseconds.

pub fn no_display_updates<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

Whether updates should not be committed and drawn onto the display. False by default. If true, only side effects of the BeginFrame will be run, such as layout and animations, but any visual updates may not be visible on the display or in screenshots.

pub fn screenshot<VALUE: Into<ScreenshotParams>>( &mut self, value: VALUE, ) -> &mut Self

If set, a screenshot of the frame will be captured and returned in the response. Otherwise, no screenshot will be captured. Note that capturing a screenshot can fail, for example, during renderer initialization. In such a case, no screenshot data will be returned.

pub fn build(&self) -> Result<BeginFrame, BeginFrameBuilderError>

Builds a new BeginFrame.

Errors

If a required field has not been initialized.