pub struct BeginFrameReturnObject {
pub has_damage: bool,
pub screenshot_data: Option<String>,
}Expand description
Sends a BeginFrame to the target and returns when the frame was completed. Optionally captures a screenshot from the resulting frame. Requires that the target was created with enabled BeginFrameControl. Designed for use with –run-all-compositor-stages-before-draw, see also https://goo.gle/chrome-headless-rendering for more background.
Fields
has_damage: boolWhether the BeginFrame resulted in damage and, thus, a new frame was committed to the display. Reported for diagnostic uses, may be removed in the future.
screenshot_data: Option<String>Base64-encoded image data of the screenshot, if one was requested and successfully taken.