pub struct BeginFrameReturnObjectBuilder { /* private fields */ }Expand description
Builder for BeginFrameReturnObject.
Implementations
Sourceimpl BeginFrameReturnObjectBuilder
impl BeginFrameReturnObjectBuilder
Sourcepub fn has_damage(&mut self, value: bool) -> &mut Self
pub fn has_damage(&mut self, value: bool) -> &mut Self
Whether the BeginFrame resulted in damage and, thus, a new frame was committed to the display. Reported for diagnostic uses, may be removed in the future.
Sourcepub fn screenshot_data(&mut self, value: Option<String>) -> &mut Self
pub fn screenshot_data(&mut self, value: Option<String>) -> &mut Self
Base64-encoded image data of the screenshot, if one was requested and successfully taken.
Sourcepub fn build(
&self,
) -> Result<BeginFrameReturnObject, BeginFrameReturnObjectBuilderError>
pub fn build( &self, ) -> Result<BeginFrameReturnObject, BeginFrameReturnObjectBuilderError>