pub struct HeapStatsUpdateEventParamsBuilder { /* private fields */ }Expand description
Builder for HeapStatsUpdateEventParams.
Implementations
Sourceimpl HeapStatsUpdateEventParamsBuilder
impl HeapStatsUpdateEventParamsBuilder
Sourcepub fn stats_update(&mut self, value: Vec<JsUInt>) -> &mut Self
pub fn stats_update(&mut self, value: Vec<JsUInt>) -> &mut Self
An array of triplets. Each triplet describes a fragment. The first integer is the fragment index, the second integer is a total count of objects for the fragment, the third integer is a total size of the objects for the fragment.
Sourcepub fn build(
&self,
) -> Result<HeapStatsUpdateEventParams, HeapStatsUpdateEventParamsBuilderError>
pub fn build( &self, ) -> Result<HeapStatsUpdateEventParams, HeapStatsUpdateEventParamsBuilderError>