StartSamplingBuilder

Struct StartSamplingBuilder 

pub struct StartSamplingBuilder { /* private fields */ }
Builder for StartSampling.

Implementations

Source

impl StartSamplingBuilder

pub fn sampling_interval<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self

Average sample interval in bytes. Poisson distribution is used for the intervals. The default value is 32768 bytes.

pub fn stack_depth<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

Maximum stack depth. The default value is 128.

pub fn include_objects_collected_by_major_gc<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

By default, the sampling heap profiler reports only objects which are still alive when the profile is returned via getSamplingProfile or stopSampling, which is useful for determining what functions contribute the most to steady-state memory usage. This flag instructs the sampling heap profiler to also include information about objects discarded by major GC, which will show which functions cause large temporary memory usage or long GC pauses.

pub fn include_objects_collected_by_minor_gc<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

By default, the sampling heap profiler reports only objects which are still alive when the profile is returned via getSamplingProfile or stopSampling, which is useful for determining what functions contribute the most to steady-state memory usage. This flag instructs the sampling heap profiler to also include information about objects discarded by minor GC, which is useful when tuning a latency-sensitive application for minimal GC activity.

pub fn build(&self) -> Result<StartSampling, StartSamplingBuilderError>

Builds a new StartSampling.

Errors

If a required field has not been initialized.