pub struct TakeHeapSnapshotBuilder { /* private fields */ }Expand description
Builder for TakeHeapSnapshot.
Implementations
Sourceimpl TakeHeapSnapshotBuilder
impl TakeHeapSnapshotBuilder
Sourcepub fn report_progress<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn report_progress<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If true ‘reportHeapSnapshotProgress’ events will be generated while snapshot is being taken.
Sourcepub fn treat_global_objects_as_roots<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn treat_global_objects_as_roots<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
If true, a raw snapshot without artificial roots will be generated.
Deprecated in favor of exposeInternals.
Sourcepub fn capture_numeric_value<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn capture_numeric_value<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
If true, numerical values are included in the snapshot
Sourcepub fn expose_internals<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn expose_internals<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If true, exposes internals of the snapshot.
Sourcepub fn build(&self) -> Result<TakeHeapSnapshot, TakeHeapSnapshotBuilderError>
pub fn build(&self) -> Result<TakeHeapSnapshot, TakeHeapSnapshotBuilderError>