Module input

Module input 

Modules

events

Structs

CancelDragging
CancelDraggingReturnObject
Cancels any active dragging in the page.
DispatchDragEvent
Dispatches a drag event into the page.
DispatchDragEventBuilder
Builder for DispatchDragEvent.
DispatchDragEventReturnObject
Dispatches a drag event into the page.
DispatchKeyEvent
Dispatches a key event to the page.
DispatchKeyEventBuilder
Builder for DispatchKeyEvent.
DispatchKeyEventReturnObject
Dispatches a key event to the page.
DispatchMouseEvent
Dispatches a mouse event to the page.
DispatchMouseEventBuilder
Builder for DispatchMouseEvent.
DispatchMouseEventReturnObject
Dispatches a mouse event to the page.
DispatchTouchEvent
Dispatches a touch event to the page.
DispatchTouchEventBuilder
Builder for DispatchTouchEvent.
DispatchTouchEventReturnObject
Dispatches a touch event to the page.
DragData
DragDataBuilder
Builder for DragData.
DragDataItem
DragDataItemBuilder
Builder for DragDataItem.
EmulateTouchFromMouseEvent
Emulates touch event from the mouse event parameters.
EmulateTouchFromMouseEventBuilder
Builder for EmulateTouchFromMouseEvent.
EmulateTouchFromMouseEventReturnObject
Emulates touch event from the mouse event parameters.
ImeSetComposition
This method sets the current candidate text for IME. Use imeCommitComposition to commit the final text. Use imeSetComposition with empty string as text to cancel composition.
ImeSetCompositionBuilder
Builder for ImeSetComposition.
ImeSetCompositionReturnObject
This method sets the current candidate text for IME. Use imeCommitComposition to commit the final text. Use imeSetComposition with empty string as text to cancel composition.
InsertText
This method emulates inserting text that doesn’t come from a key press, for example an emoji keyboard or an IME.
InsertTextBuilder
Builder for InsertText.
InsertTextReturnObject
This method emulates inserting text that doesn’t come from a key press, for example an emoji keyboard or an IME.
SetIgnoreInputEvents
Ignores input events (useful while auditing page).
SetIgnoreInputEventsBuilder
Builder for SetIgnoreInputEvents.
SetIgnoreInputEventsReturnObject
Ignores input events (useful while auditing page).
SetInterceptDrags
Prevents default drag and drop behavior and instead emits Input.dragIntercepted events. Drag and drop behavior can be directly controlled via Input.dispatchDragEvent.
SetInterceptDragsBuilder
Builder for SetInterceptDrags.
SetInterceptDragsReturnObject
Prevents default drag and drop behavior and instead emits Input.dragIntercepted events. Drag and drop behavior can be directly controlled via Input.dispatchDragEvent.
SynthesizePinchGesture
Synthesizes a pinch gesture over a time period by issuing appropriate touch events.
SynthesizePinchGestureBuilder
Builder for SynthesizePinchGesture.
SynthesizePinchGestureReturnObject
Synthesizes a pinch gesture over a time period by issuing appropriate touch events.
SynthesizeScrollGesture
Synthesizes a scroll gesture over a time period by issuing appropriate touch events.
SynthesizeScrollGestureBuilder
Builder for SynthesizeScrollGesture.
SynthesizeScrollGestureReturnObject
Synthesizes a scroll gesture over a time period by issuing appropriate touch events.
SynthesizeTapGesture
Synthesizes a tap gesture over a time period by issuing appropriate touch events.
SynthesizeTapGestureBuilder
Builder for SynthesizeTapGesture.
SynthesizeTapGestureReturnObject
Synthesizes a tap gesture over a time period by issuing appropriate touch events.
TouchPoint
TouchPointBuilder
Builder for TouchPoint.

Enums

DispatchDragEventBuilderError
Error type for DispatchDragEventBuilder
DispatchDragEventTypeOption
DispatchKeyEventBuilderError
Error type for DispatchKeyEventBuilder
DispatchKeyEventTypeOption
DispatchMouseEventBuilderError
Error type for DispatchMouseEventBuilder
DispatchMouseEventPointerTypeOption
DispatchMouseEventTypeOption
DispatchTouchEventBuilderError
Error type for DispatchTouchEventBuilder
DispatchTouchEventTypeOption
DragDataBuilderError
Error type for DragDataBuilder
DragDataItemBuilderError
Error type for DragDataItemBuilder
EmulateTouchFromMouseEventBuilderError
Error type for EmulateTouchFromMouseEventBuilder
EmulateTouchFromMouseEventTypeOption
GestureSourceType
ImeSetCompositionBuilderError
Error type for ImeSetCompositionBuilder
InsertTextBuilderError
Error type for InsertTextBuilder
MouseButton
SetIgnoreInputEventsBuilderError
Error type for SetIgnoreInputEventsBuilder
SetInterceptDragsBuilderError
Error type for SetInterceptDragsBuilder
SynthesizePinchGestureBuilderError
Error type for SynthesizePinchGestureBuilder
SynthesizeScrollGestureBuilderError
Error type for SynthesizeScrollGestureBuilder
SynthesizeTapGestureBuilderError
Error type for SynthesizeTapGestureBuilder
TouchPointBuilderError
Error type for TouchPointBuilder

Type Aliases

TimeSinceEpoch