pub struct DispatchMouseEventBuilder { /* private fields */ }Expand description
Builder for DispatchMouseEvent.
Implementations
Sourceimpl DispatchMouseEventBuilder
impl DispatchMouseEventBuilder
Sourcepub fn type<VALUE: Into<DispatchMouseEventTypeOption>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn type<VALUE: Into<DispatchMouseEventTypeOption>>( &mut self, value: VALUE, ) -> &mut Self
Type of the mouse event.
Sourcepub fn x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
X coordinate of the event relative to the main frame’s viewport in CSS pixels.
Sourcepub fn y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.
Sourcepub fn modifiers<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn modifiers<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0).
Sourcepub fn timestamp<VALUE: Into<TimeSinceEpoch>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn timestamp<VALUE: Into<TimeSinceEpoch>>( &mut self, value: VALUE, ) -> &mut Self
Time at which the event occurred.
Mouse button (default: “none”).
A number indicating which buttons are pressed on the mouse when a mouse event is triggered. Left=1, Right=2, Middle=4, Back=8, Forward=16, None=0.
Sourcepub fn click_count<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn click_count<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Number of times the mouse button was clicked (default: 0).
Sourcepub fn force<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn force<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
The normalized pressure, which has a range of [0,1] (default: 0).
Sourcepub fn tangential_pressure<VALUE: Into<JsFloat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn tangential_pressure<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self
The normalized tangential pressure, which has a range of [-1,1] (default: 0).
Sourcepub fn tilt_x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn tilt_x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
The plane angle between the Y-Z plane and the plane containing both the stylus axis and the Y axis, in degrees of the range [-90,90], a positive tiltX is to the right (default: 0).
Sourcepub fn tilt_y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn tilt_y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
The plane angle between the X-Z plane and the plane containing both the stylus axis and the X axis, in degrees of the range [-90,90], a positive tiltY is towards the user (default: 0).
Sourcepub fn twist<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn twist<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The clockwise rotation of a pen stylus around its own major axis, in degrees in the range [0,359] (default: 0).
Sourcepub fn delta_x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn delta_x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
X delta in CSS pixels for mouse wheel event (default: 0).
Sourcepub fn delta_y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn delta_y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Y delta in CSS pixels for mouse wheel event (default: 0).
Sourcepub fn pointer_type<VALUE: Into<DispatchMouseEventPointerTypeOption>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn pointer_type<VALUE: Into<DispatchMouseEventPointerTypeOption>>( &mut self, value: VALUE, ) -> &mut Self
Pointer type (default: “mouse”).
Sourcepub fn build(
&self,
) -> Result<DispatchMouseEvent, DispatchMouseEventBuilderError>
pub fn build( &self, ) -> Result<DispatchMouseEvent, DispatchMouseEventBuilderError>