pub struct ImeSetComposition {
pub text: String,
pub selection_start: JsUInt,
pub selection_end: JsUInt,
pub replacement_start: Option<JsUInt>,
pub replacement_end: Option<JsUInt>,
}Expand description
This method sets the current candidate text for IME. Use imeCommitComposition to commit the final text. Use imeSetComposition with empty string as text to cancel composition.
Fields
text: StringThe text to insert
selection_start: JsUIntselection start
selection_end: JsUIntselection end
replacement_start: Option<JsUInt>replacement start
replacement_end: Option<JsUInt>replacement end