ImeSetCompositionReturnObject

Struct ImeSetCompositionReturnObject 

pub struct ImeSetCompositionReturnObject(pub Option<Value>);
This method sets the current candidate text for IME. Use imeCommitComposition to commit the final text. Use imeSetComposition with empty string as text to cancel composition.

Tuple Fields

0: Option<Value>