pub struct SynthesizePinchGesture {
pub x: JsFloat,
pub y: JsFloat,
pub scale_factor: JsFloat,
pub relative_speed: Option<JsUInt>,
pub gesture_source_type: Option<GestureSourceType>,
}Expand description
Synthesizes a pinch gesture over a time period by issuing appropriate touch events.
Fields
x: JsFloatX coordinate of the start of the gesture in CSS pixels.
y: JsFloatY coordinate of the start of the gesture in CSS pixels.
scale_factor: JsFloatRelative scale factor after zooming (>1.0 zooms in, <1.0 zooms out).
relative_speed: Option<JsUInt>Relative pointer speed in pixels per second (default: 800).
gesture_source_type: Option<GestureSourceType>Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).