pub struct SynthesizePinchGestureBuilder { /* private fields */ }Expand description
Builder for SynthesizePinchGesture.
Implementations
Sourceimpl SynthesizePinchGestureBuilder
impl SynthesizePinchGestureBuilder
Sourcepub fn x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
X coordinate of the start of the gesture in CSS pixels.
Sourcepub fn y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Y coordinate of the start of the gesture in CSS pixels.
Sourcepub fn scale_factor<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn scale_factor<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Relative scale factor after zooming (>1.0 zooms in, <1.0 zooms out).
Sourcepub fn relative_speed<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn relative_speed<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Relative pointer speed in pixels per second (default: 800).
Sourcepub fn gesture_source_type<VALUE: Into<GestureSourceType>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn gesture_source_type<VALUE: Into<GestureSourceType>>( &mut self, value: VALUE, ) -> &mut Self
Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).
Sourcepub fn build(
&self,
) -> Result<SynthesizePinchGesture, SynthesizePinchGestureBuilderError>
pub fn build( &self, ) -> Result<SynthesizePinchGesture, SynthesizePinchGestureBuilderError>