pub struct SynthesizeScrollGesture {
pub x: JsFloat,
pub y: JsFloat,
pub x_distance: Option<JsFloat>,
pub y_distance: Option<JsFloat>,
pub x_overscroll: Option<JsFloat>,
pub y_overscroll: Option<JsFloat>,
pub prevent_fling: Option<bool>,
pub speed: Option<JsUInt>,
pub gesture_source_type: Option<GestureSourceType>,
pub repeat_count: Option<JsUInt>,
pub repeat_delay_ms: Option<JsUInt>,
pub interaction_marker_name: Option<String>,
}Expand description
Synthesizes a scroll gesture over a time period by issuing appropriate touch events.
Fields
x: JsFloatX coordinate of the start of the gesture in CSS pixels.
y: JsFloatY coordinate of the start of the gesture in CSS pixels.
x_distance: Option<JsFloat>The distance to scroll along the X axis (positive to scroll left).
y_distance: Option<JsFloat>The distance to scroll along the Y axis (positive to scroll up).
x_overscroll: Option<JsFloat>The number of additional pixels to scroll back along the X axis, in addition to the given distance.
y_overscroll: Option<JsFloat>The number of additional pixels to scroll back along the Y axis, in addition to the given distance.
prevent_fling: Option<bool>Prevent fling (default: true).
speed: Option<JsUInt>Swipe speed in pixels per second (default: 800).
gesture_source_type: Option<GestureSourceType>Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).
repeat_count: Option<JsUInt>The number of times to repeat the gesture (default: 0).
repeat_delay_ms: Option<JsUInt>The number of milliseconds delay between each repeat. (default: 250).
interaction_marker_name: Option<String>The name of the interaction markers to generate, if not empty (default: “”).