SynthesizeScrollGestureBuilder

Struct SynthesizeScrollGestureBuilder 

pub struct SynthesizeScrollGestureBuilder { /* private fields */ }
Implementations

Source

impl SynthesizeScrollGestureBuilder

pub fn x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

X coordinate of the start of the gesture in CSS pixels.

pub fn y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

Y coordinate of the start of the gesture in CSS pixels.

pub fn x_distance<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

The distance to scroll along the X axis (positive to scroll left).

pub fn y_distance<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

The distance to scroll along the Y axis (positive to scroll up).

pub fn x_overscroll<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

The number of additional pixels to scroll back along the X axis, in addition to the given distance.

pub fn y_overscroll<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

The number of additional pixels to scroll back along the Y axis, in addition to the given distance.

pub fn prevent_fling<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

Prevent fling (default: true).

pub fn speed<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self

Swipe speed in pixels per second (default: 800).

pub fn gesture_source_type<VALUE: Into<GestureSourceType>>( &mut self, value: VALUE, ) -> &mut Self

Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).

pub fn repeat_count<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self

The number of times to repeat the gesture (default: 0).

pub fn repeat_delay_ms<VALUE: Into<JsUInt>>( &mut self, value: VALUE, ) -> &mut Self

The number of milliseconds delay between each repeat. (default: 250).

pub fn interaction_marker_name<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self

The name of the interaction markers to generate, if not empty (default: “”).

pub fn build( &self, ) -> Result<SynthesizeScrollGesture, SynthesizeScrollGestureBuilderError>

Builds a new SynthesizeScrollGesture.

Errors

If a required field has not been initialized.