pub struct SynthesizeTapGesture {
pub x: JsFloat,
pub y: JsFloat,
pub duration: Option<JsUInt>,
pub tap_count: Option<JsUInt>,
pub gesture_source_type: Option<GestureSourceType>,
}Expand description
Synthesizes a tap gesture over a time period by issuing appropriate touch events.
Fields
x: JsFloatX coordinate of the start of the gesture in CSS pixels.
y: JsFloatY coordinate of the start of the gesture in CSS pixels.
duration: Option<JsUInt>Duration between touchdown and touchup events in ms (default: 50).
tap_count: Option<JsUInt>Number of times to perform the tap (e.g. 2 for double tap, default: 1).
gesture_source_type: Option<GestureSourceType>Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).