pub struct SynthesizeTapGestureBuilder { /* private fields */ }Expand description
Builder for SynthesizeTapGesture.
Implementations
Sourceimpl SynthesizeTapGestureBuilder
impl SynthesizeTapGestureBuilder
Sourcepub fn x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
X coordinate of the start of the gesture in CSS pixels.
Sourcepub fn y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Y coordinate of the start of the gesture in CSS pixels.
Sourcepub fn duration<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn duration<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Duration between touchdown and touchup events in ms (default: 50).
Sourcepub fn tap_count<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn tap_count<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Number of times to perform the tap (e.g. 2 for double tap, default: 1).
Sourcepub fn gesture_source_type<VALUE: Into<GestureSourceType>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn gesture_source_type<VALUE: Into<GestureSourceType>>( &mut self, value: VALUE, ) -> &mut Self
Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).
Sourcepub fn build(
&self,
) -> Result<SynthesizeTapGesture, SynthesizeTapGestureBuilderError>
pub fn build( &self, ) -> Result<SynthesizeTapGesture, SynthesizeTapGestureBuilderError>