pub struct TouchPointBuilder { /* private fields */ }Expand description
Builder for TouchPoint.
Implementations
Sourceimpl TouchPointBuilder
impl TouchPointBuilder
Sourcepub fn x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
X coordinate of the event relative to the main frame’s viewport in CSS pixels.
Sourcepub fn y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.
Sourcepub fn radius_x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn radius_x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
X radius of the touch area (default: 1.0).
Sourcepub fn radius_y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn radius_y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Y radius of the touch area (default: 1.0).
Sourcepub fn rotation_angle<VALUE: Into<JsFloat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn rotation_angle<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self
Rotation angle (default: 0.0).
Sourcepub fn tangential_pressure<VALUE: Into<JsFloat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn tangential_pressure<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self
The normalized tangential pressure, which has a range of [-1,1] (default: 0).
Sourcepub fn tilt_x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn tilt_x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
The plane angle between the Y-Z plane and the plane containing both the stylus axis and the Y axis, in degrees of the range [-90,90], a positive tiltX is to the right (default: 0)
Sourcepub fn tilt_y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn tilt_y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
The plane angle between the X-Z plane and the plane containing both the stylus axis and the X axis, in degrees of the range [-90,90], a positive tiltY is towards the user (default: 0).
Sourcepub fn twist<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn twist<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The clockwise rotation of a pen stylus around its own major axis, in degrees in the range [0,359] (default: 0).
Sourcepub fn id<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn id<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Identifier used to track touch sources between events, must be unique within an event.
Sourcepub fn build(&self) -> Result<TouchPoint, TouchPointBuilderError>
pub fn build(&self) -> Result<TouchPoint, TouchPointBuilderError>