ReadBuilder

Struct ReadBuilder 

pub struct ReadBuilder { /* private fields */ }
Builder for Read.

Implementations

Source

impl ReadBuilder

pub fn handle<VALUE: Into<StreamHandle>>(&mut self, value: VALUE) -> &mut Self

Handle of the stream to read.

pub fn offset<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self

Seek to the specified offset before reading (if not specified, proceed with offset following the last read). Some types of streams may only support sequential reads.

pub fn size<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self

Maximum number of bytes to read (left upon the agent discretion if not specified).

pub fn build(&self) -> Result<Read, ReadBuilderError>

Builds a new Read.

Errors

If a required field has not been initialized.