LayerBuilder

Struct LayerBuilder 

pub struct LayerBuilder { /* private fields */ }
Builder for Layer.

Implementations

Source

impl LayerBuilder

pub fn layer_id<VALUE: Into<LayerId>>(&mut self, value: VALUE) -> &mut Self

The unique id for this layer.

pub fn parent_layer_id<VALUE: Into<LayerId>>( &mut self, value: VALUE, ) -> &mut Self

The id of parent (not present for root).

pub fn backend_node_id<VALUE: Into<BackendNodeId>>( &mut self, value: VALUE, ) -> &mut Self

The backend id for the node associated with this layer.

pub fn offset_x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

Offset from parent layer, X coordinate.

pub fn offset_y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

Offset from parent layer, Y coordinate.

pub fn width<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

Layer width.

pub fn height<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

Layer height.

pub fn transform<VALUE: Into<Vec<JsFloat>>>( &mut self, value: VALUE, ) -> &mut Self

Transformation matrix for layer, default is identity matrix

pub fn anchor_x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

Transform anchor point X, absent if no transform specified

pub fn anchor_y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

Transform anchor point Y, absent if no transform specified

pub fn anchor_z<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

Transform anchor point Z, absent if no transform specified

pub fn paint_count<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self

Indicates how many time this layer has painted.

pub fn draws_content<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

Indicates whether this layer hosts any content, rather than being used for transform/scrolling purposes only.

pub fn invisible<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

Set if layer is not visible.

pub fn scroll_rects<VALUE: Into<Vec<ScrollRect>>>( &mut self, value: VALUE, ) -> &mut Self

Rectangles scrolling on main thread only.

pub fn sticky_position_constraint<VALUE: Into<StickyPositionConstraint>>( &mut self, value: VALUE, ) -> &mut Self

Sticky position constraint information

pub fn build(&self) -> Result<Layer, LayerBuilderError>

Builds a new Layer.

Errors

If a required field has not been initialized.