pub struct ProfileSnapshotBuilder { /* private fields */ }Expand description
Builder for ProfileSnapshot.
Implementations
Sourceimpl ProfileSnapshotBuilder
impl ProfileSnapshotBuilder
Sourcepub fn snapshot_id<VALUE: Into<SnapshotId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn snapshot_id<VALUE: Into<SnapshotId>>( &mut self, value: VALUE, ) -> &mut Self
The id of the layer snapshot.
Sourcepub fn min_repeat_count<VALUE: Into<JsUInt>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn min_repeat_count<VALUE: Into<JsUInt>>( &mut self, value: VALUE, ) -> &mut Self
The maximum number of times to replay the snapshot (1, if not specified).
Sourcepub fn min_duration<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn min_duration<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
The minimum duration (in seconds) to replay the snapshot.
Sourcepub fn clip_rect<VALUE: Into<Rect>>(&mut self, value: VALUE) -> &mut Self
pub fn clip_rect<VALUE: Into<Rect>>(&mut self, value: VALUE) -> &mut Self
The clip rectangle to apply when replaying the snapshot.
Sourcepub fn build(&self) -> Result<ProfileSnapshot, ProfileSnapshotBuilderError>
pub fn build(&self) -> Result<ProfileSnapshot, ProfileSnapshotBuilderError>