pub struct StickyPositionConstraintBuilder { /* private fields */ }Expand description
Builder for StickyPositionConstraint.
Implementations
Sourceimpl StickyPositionConstraintBuilder
impl StickyPositionConstraintBuilder
Sourcepub fn sticky_box_rect<VALUE: Into<Rect>>(&mut self, value: VALUE) -> &mut Self
pub fn sticky_box_rect<VALUE: Into<Rect>>(&mut self, value: VALUE) -> &mut Self
Layout rectangle of the sticky element before being shifted
Sourcepub fn containing_block_rect<VALUE: Into<Rect>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn containing_block_rect<VALUE: Into<Rect>>( &mut self, value: VALUE, ) -> &mut Self
Layout rectangle of the containing block of the sticky element
Sourcepub fn nearest_layer_shifting_sticky_box<VALUE: Into<LayerId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn nearest_layer_shifting_sticky_box<VALUE: Into<LayerId>>( &mut self, value: VALUE, ) -> &mut Self
The nearest sticky layer that shifts the sticky box
Sourcepub fn nearest_layer_shifting_containing_block<VALUE: Into<LayerId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn nearest_layer_shifting_containing_block<VALUE: Into<LayerId>>( &mut self, value: VALUE, ) -> &mut Self
The nearest sticky layer that shifts the containing block
Sourcepub fn build(
&self,
) -> Result<StickyPositionConstraint, StickyPositionConstraintBuilderError>
pub fn build( &self, ) -> Result<StickyPositionConstraint, StickyPositionConstraintBuilderError>