Module log

Module log 

Modules

events

Structs

Clear
ClearReturnObject
Clears the log.
Disable
DisableReturnObject
Disables log domain, prevents further log entries from being reported to the client.
Enable
EnableReturnObject
Enables log domain, sends the entries collected so far to the client by means of the entryAdded notification.
LogEntry
Log entry.
LogEntryBuilder
Builder for LogEntry.
StartViolationsReport
start violation reporting.
StartViolationsReportBuilder
Builder for StartViolationsReport.
StartViolationsReportReturnObject
start violation reporting.
StopViolationsReport
StopViolationsReportReturnObject
Stop violation reporting.
ViolationSetting
Violation configuration setting.
ViolationSettingBuilder
Builder for ViolationSetting.

Enums

LogEntryBuilderError
Error type for LogEntryBuilder
LogEntryCategory
LogEntryLevel
LogEntrySource
StartViolationsReportBuilderError
Error type for StartViolationsReportBuilder
ViolationSettingBuilderError
Error type for ViolationSettingBuilder
ViolationSettingName