pub struct PlayerErrorBuilder { /* private fields */ }Expand description
Builder for PlayerError.
Implementations
Sourceimpl PlayerErrorBuilder
impl PlayerErrorBuilder
pub fn error_type<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn code<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn code<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Code is the numeric enum entry for a specific set of error codes, such as PipelineStatusCodes in media/base/pipeline_status.h
Sourcepub fn stack<VALUE: Into<Vec<PlayerErrorSourceLocation>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn stack<VALUE: Into<Vec<PlayerErrorSourceLocation>>>( &mut self, value: VALUE, ) -> &mut Self
A trace of where this error was caused / where it passed through.
Sourcepub fn cause<VALUE: Into<Vec<PlayerError>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn cause<VALUE: Into<Vec<PlayerError>>>( &mut self, value: VALUE, ) -> &mut Self
Errors potentially have a root cause error, ie, a DecoderError might be caused by an WindowsError
Sourcepub fn data<VALUE: Into<Json>>(&mut self, value: VALUE) -> &mut Self
pub fn data<VALUE: Into<Json>>(&mut self, value: VALUE) -> &mut Self
Extra data attached to an error, such as an HRESULT, Video Codec, etc.
Sourcepub fn build(&self) -> Result<PlayerError, PlayerErrorBuilderError>
pub fn build(&self) -> Result<PlayerError, PlayerErrorBuilderError>