pub struct PlayerMessageBuilder { /* private fields */ }Expand description
Builder for PlayerMessage.
Implementations
Sourceimpl PlayerMessageBuilder
impl PlayerMessageBuilder
Sourcepub fn level<VALUE: Into<PlayerMessageLevel>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn level<VALUE: Into<PlayerMessageLevel>>( &mut self, value: VALUE, ) -> &mut Self
Keep in sync with MediaLogMessageLevel We are currently keeping the message level ‘error’ separate from the PlayerError type because right now they represent different things, this one being a DVLOG(ERROR) style log message that gets printed based on what log level is selected in the UI, and the other is a representation of a media::PipelineStatus object. Soon however we’re going to be moving away from using PipelineStatus for errors and introducing a new error type which should hopefully let us integrate the error log level into the PlayerError type.
pub fn message<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn build(&self) -> Result<PlayerMessage, PlayerMessageBuilderError>
pub fn build(&self) -> Result<PlayerMessage, PlayerMessageBuilderError>