Module memory

Module memory 

Modules

events

Structs

DomCounter
DOM object counter data.
DomCounterBuilder
Builder for DomCounter.
ForciblyPurgeJavaScriptMemory
ForciblyPurgeJavaScriptMemoryReturnObject
Simulate OomIntervention by purging V8 memory.
GetAllTimeSamplingProfile
GetAllTimeSamplingProfileReturnObject
Retrieve native memory allocations profile collected since renderer process startup.
GetAllTimeSamplingProfileReturnObjectBuilder
Builder for GetAllTimeSamplingProfileReturnObject.
GetBrowserSamplingProfile
GetBrowserSamplingProfileReturnObject
Retrieve native memory allocations profile collected since browser process startup.
GetBrowserSamplingProfileReturnObjectBuilder
Builder for GetBrowserSamplingProfileReturnObject.
GetDOMCounters
GetDOMCountersForLeakDetection
GetDOMCountersForLeakDetectionReturnObject
Retruns DOM object counters after preparing renderer for leak detection.
GetDOMCountersForLeakDetectionReturnObjectBuilder
Builder for GetDOMCountersForLeakDetectionReturnObject.
GetDOMCountersReturnObject
Retruns current DOM object counters.
GetDOMCountersReturnObjectBuilder
Builder for GetDOMCountersReturnObject.
GetSamplingProfile
GetSamplingProfileReturnObject
Retrieve native memory allocations profile collected since last startSampling call.
GetSamplingProfileReturnObjectBuilder
Builder for GetSamplingProfileReturnObject.
Module
Executable module information
ModuleBuilder
Builder for Module.
PrepareForLeakDetection
PrepareForLeakDetectionReturnObject
Prepares for leak detection by terminating workers, stopping spellcheckers, dropping non-essential internal caches, running garbage collections, etc.
SamplingProfile
Array of heap profile samples.
SamplingProfileBuilder
Builder for SamplingProfile.
SamplingProfileNode
Heap profile sample.
SamplingProfileNodeBuilder
Builder for SamplingProfileNode.
SetPressureNotificationsSuppressed
Enable/disable suppressing memory pressure notifications in all processes.
SetPressureNotificationsSuppressedBuilder
Builder for SetPressureNotificationsSuppressed.
SetPressureNotificationsSuppressedReturnObject
Enable/disable suppressing memory pressure notifications in all processes.
SimulatePressureNotification
Simulate a memory pressure notification in all processes.
SimulatePressureNotificationBuilder
Builder for SimulatePressureNotification.
SimulatePressureNotificationReturnObject
Simulate a memory pressure notification in all processes.
StartSampling
Start collecting native memory profile.
StartSamplingBuilder
Builder for StartSampling.
StartSamplingReturnObject
Start collecting native memory profile.
StopSampling
StopSamplingReturnObject
Stop collecting native memory profile.

Enums

DomCounterBuilderError
Error type for DomCounterBuilder
GetAllTimeSamplingProfileReturnObjectBuilderError
Error type for GetAllTimeSamplingProfileReturnObjectBuilder
GetBrowserSamplingProfileReturnObjectBuilderError
Error type for GetBrowserSamplingProfileReturnObjectBuilder
GetDOMCountersForLeakDetectionReturnObjectBuilderError
Error type for GetDOMCountersForLeakDetectionReturnObjectBuilder
GetDOMCountersReturnObjectBuilderError
Error type for GetDOMCountersReturnObjectBuilder
GetSamplingProfileReturnObjectBuilderError
Error type for GetSamplingProfileReturnObjectBuilder
ModuleBuilderError
Error type for ModuleBuilder
PressureLevel
SamplingProfileBuilderError
Error type for SamplingProfileBuilder
SamplingProfileNodeBuilderError
Error type for SamplingProfileNodeBuilder
SetPressureNotificationsSuppressedBuilderError
Error type for SetPressureNotificationsSuppressedBuilder
SimulatePressureNotificationBuilderError
Error type for SimulatePressureNotificationBuilder
StartSamplingBuilderError
Error type for StartSamplingBuilder