Module network

Module network 

Modules

events

Structs

AssociatedCookie
A cookie associated with the request which may or may not be sent with it. Includes the cookies itself and reasons for blocking or exemption.
AssociatedCookieBuilder
Builder for AssociatedCookie.
AuthChallenge
Authorization challenge for HTTP status code 401 or 407.
AuthChallengeBuilder
Builder for AuthChallenge.
AuthChallengeResponse
Response to an AuthChallenge.
AuthChallengeResponseBuilder
Builder for AuthChallengeResponse.
BlockPattern
BlockPatternBuilder
Builder for BlockPattern.
BlockedSetCookieWithReason
A cookie which was not stored from a response with the corresponding reason.
BlockedSetCookieWithReasonBuilder
Builder for BlockedSetCookieWithReason.
CachedResource
Information about the cached resource.
CachedResourceBuilder
Builder for CachedResource.
CanClearBrowserCache
CanClearBrowserCacheReturnObjectDeprecated
Tells whether clearing browser cache is supported.
CanClearBrowserCacheReturnObjectBuilder
Builder for CanClearBrowserCacheReturnObject.
CanClearBrowserCookies
CanClearBrowserCookiesReturnObjectDeprecated
Tells whether clearing browser cookies is supported.
CanClearBrowserCookiesReturnObjectBuilder
Builder for CanClearBrowserCookiesReturnObject.
CanEmulateNetworkConditions
CanEmulateNetworkConditionsReturnObjectDeprecated
Tells whether emulation of network conditions is supported.
CanEmulateNetworkConditionsReturnObjectBuilder
Builder for CanEmulateNetworkConditionsReturnObject.
ChallengeEventDetails
Session event details specific to challenges.
ChallengeEventDetailsBuilder
Builder for ChallengeEventDetails.
ClearAcceptedEncodingsOverride
ClearAcceptedEncodingsOverrideReturnObject
Clears accepted encodings set by setAcceptedEncodings
ClearBrowserCache
ClearBrowserCacheReturnObject
Clears browser cache.
ClearBrowserCookies
ClearBrowserCookiesReturnObject
Clears browser cookies.
ClientSecurityState
ClientSecurityStateBuilder
Builder for ClientSecurityState.
ConfigureDurableMessages
Configures storing response bodies outside of renderer, so that these survive a cross-process navigation. If maxTotalBufferSize is not set, durable messages are disabled.
ConfigureDurableMessagesBuilder
Builder for ConfigureDurableMessages.
ConfigureDurableMessagesReturnObject
Configures storing response bodies outside of renderer, so that these survive a cross-process navigation. If maxTotalBufferSize is not set, durable messages are disabled.
ConnectTiming
ConnectTimingBuilder
Builder for ConnectTiming.
ContentSecurityPolicyStatus
ContentSecurityPolicyStatusBuilder
Builder for ContentSecurityPolicyStatus.
ContinueInterceptedRequestDeprecated
Response to Network.requestIntercepted which either modifies the request to continue with any modifications, or blocks it, or completes it with the provided response bytes. If a network fetch occurs as a result which encounters a redirect an additional Network.requestIntercepted event will be sent with the same InterceptionId. Deprecated, use Fetch.continueRequest, Fetch.fulfillRequest and Fetch.failRequest instead.
ContinueInterceptedRequestBuilder
Builder for ContinueInterceptedRequest.
ContinueInterceptedRequestReturnObjectDeprecated
Response to Network.requestIntercepted which either modifies the request to continue with any modifications, or blocks it, or completes it with the provided response bytes. If a network fetch occurs as a result which encounters a redirect an additional Network.requestIntercepted event will be sent with the same InterceptionId. Deprecated, use Fetch.continueRequest, Fetch.fulfillRequest and Fetch.failRequest instead.
Cookie
Cookie object
CookieBuilder
Builder for Cookie.
CookieParam
Cookie parameter object
CookieParamBuilder
Builder for CookieParam.
CookiePartitionKey
cookiePartitionKey object The representation of the components of the key that are created by the cookiePartitionKey class contained in net/cookies/cookie_partition_key.h.
CookiePartitionKeyBuilder
Builder for CookiePartitionKey.
CorsErrorStatus
CorsErrorStatusBuilder
Builder for CorsErrorStatus.
CreationEventDetails
Session event details specific to creation.
CreationEventDetailsBuilder
Builder for CreationEventDetails.
CrossOriginEmbedderPolicyStatus
CrossOriginEmbedderPolicyStatusBuilder
Builder for CrossOriginEmbedderPolicyStatus.
CrossOriginOpenerPolicyStatus
CrossOriginOpenerPolicyStatusBuilder
Builder for CrossOriginOpenerPolicyStatus.
DeleteCookies
Deletes browser cookies with matching name and url or domain/path/partitionKey pair.
DeleteCookiesBuilder
Builder for DeleteCookies.
DeleteCookiesReturnObject
Deletes browser cookies with matching name and url or domain/path/partitionKey pair.
DeviceBoundSession
A device bound session.
DeviceBoundSessionBuilder
Builder for DeviceBoundSession.
DeviceBoundSessionCookieCraving
A device bound session’s cookie craving.
DeviceBoundSessionCookieCravingBuilder
Builder for DeviceBoundSessionCookieCraving.
DeviceBoundSessionInclusionRules
A device bound session’s inclusion rules.
DeviceBoundSessionInclusionRulesBuilder
Builder for DeviceBoundSessionInclusionRules.
DeviceBoundSessionKey
Unique identifier for a device bound session.
DeviceBoundSessionKeyBuilder
Builder for DeviceBoundSessionKey.
DeviceBoundSessionUrlRule
A device bound session’s inclusion URL rule.
DeviceBoundSessionUrlRuleBuilder
Builder for DeviceBoundSessionUrlRule.
DeviceBoundSessionWithUsage
How a device bound session was used during a request.
DeviceBoundSessionWithUsageBuilder
Builder for DeviceBoundSessionWithUsage.
DirectTcpSocketOptions
DirectTcpSocketOptionsBuilder
Builder for DirectTcpSocketOptions.
DirectUdpMessage
DirectUdpMessageBuilder
Builder for DirectUdpMessage.
DirectUdpSocketOptions
DirectUdpSocketOptionsBuilder
Builder for DirectUdpSocketOptions.
Disable
DisableReturnObject
Disables network tracking, prevents network events from being sent to the client.
EmulateNetworkConditionsDeprecated
Activates emulation of network conditions. This command is deprecated in favor of the emulateNetworkConditionsByRule and overrideNetworkState commands, which can be used together to the same effect.
EmulateNetworkConditionsBuilder
Builder for EmulateNetworkConditions.
EmulateNetworkConditionsByRule
Activates emulation of network conditions for individual requests using URL match patterns. Unlike the deprecated Network.emulateNetworkConditions this method does not affect navigator state. Use Network.overrideNetworkState to explicitly modify navigator behavior.
EmulateNetworkConditionsByRuleBuilder
Builder for EmulateNetworkConditionsByRule.
EmulateNetworkConditionsByRuleReturnObject
Activates emulation of network conditions for individual requests using URL match patterns. Unlike the deprecated Network.emulateNetworkConditions this method does not affect navigator state. Use Network.overrideNetworkState to explicitly modify navigator behavior.
EmulateNetworkConditionsByRuleReturnObjectBuilder
Builder for EmulateNetworkConditionsByRuleReturnObject.
EmulateNetworkConditionsReturnObjectDeprecated
Activates emulation of network conditions. This command is deprecated in favor of the emulateNetworkConditionsByRule and overrideNetworkState commands, which can be used together to the same effect.
Enable
Enables network tracking, network events will now be delivered to the client.
EnableBuilder
Builder for Enable.
EnableDeviceBoundSessions
Sets up tracking device bound sessions and fetching of initial set of sessions.
EnableDeviceBoundSessionsBuilder
Builder for EnableDeviceBoundSessions.
EnableDeviceBoundSessionsReturnObject
Sets up tracking device bound sessions and fetching of initial set of sessions.
EnableReportingApi
Enables tracking for the Reporting API, events generated by the Reporting API will now be delivered to the client. Enabling triggers ‘reportingApiReportAdded’ for all existing reports.
EnableReportingApiBuilder
Builder for EnableReportingApi.
EnableReportingApiReturnObject
Enables tracking for the Reporting API, events generated by the Reporting API will now be delivered to the client. Enabling triggers ‘reportingApiReportAdded’ for all existing reports.
EnableReturnObject
Enables network tracking, network events will now be delivered to the client.
ExemptedSetCookieWithReason
A cookie should have been blocked by 3PCD but is exempted and stored from a response with the corresponding reason. A cookie could only have at most one exemption reason.
ExemptedSetCookieWithReasonBuilder
Builder for ExemptedSetCookieWithReason.
FetchSchemefulSite
Fetches the schemeful site for a specific origin.
FetchSchemefulSiteBuilder
Builder for FetchSchemefulSite.
FetchSchemefulSiteReturnObject
Fetches the schemeful site for a specific origin.
FetchSchemefulSiteReturnObjectBuilder
Builder for FetchSchemefulSiteReturnObject.
GetAllCookies
GetAllCookiesReturnObjectDeprecated
Returns all browser cookies. Depending on the backend support, will return detailed cookie information in the cookies field. Deprecated. Use Storage.getCookies instead.
GetAllCookiesReturnObjectBuilder
Builder for GetAllCookiesReturnObject.
GetCertificate
Returns the DER-encoded certificate.
GetCertificateBuilder
Builder for GetCertificate.
GetCertificateReturnObject
Returns the DER-encoded certificate.
GetCertificateReturnObjectBuilder
Builder for GetCertificateReturnObject.
GetCookies
Returns all browser cookies for the current URL. Depending on the backend support, will return detailed cookie information in the cookies field.
GetCookiesBuilder
Builder for GetCookies.
GetCookiesReturnObject
Returns all browser cookies for the current URL. Depending on the backend support, will return detailed cookie information in the cookies field.
GetCookiesReturnObjectBuilder
Builder for GetCookiesReturnObject.
GetRequestPostData
Returns post data sent with the request. Returns an error when no data was sent with the request.
GetRequestPostDataBuilder
Builder for GetRequestPostData.
GetRequestPostDataReturnObject
Returns post data sent with the request. Returns an error when no data was sent with the request.
GetRequestPostDataReturnObjectBuilder
Builder for GetRequestPostDataReturnObject.
GetResponseBody
Returns content served for the given request.
GetResponseBodyBuilder
Builder for GetResponseBody.
GetResponseBodyForInterception
Returns content served for the given currently intercepted request.
GetResponseBodyForInterceptionBuilder
Builder for GetResponseBodyForInterception.
GetResponseBodyForInterceptionReturnObject
Returns content served for the given currently intercepted request.
GetResponseBodyForInterceptionReturnObjectBuilder
Builder for GetResponseBodyForInterceptionReturnObject.
GetResponseBodyReturnObject
Returns content served for the given request.
GetResponseBodyReturnObjectBuilder
Builder for GetResponseBodyReturnObject.
GetSecurityIsolationStatus
Returns information about the COEP/COOP isolation status.
GetSecurityIsolationStatusBuilder
Builder for GetSecurityIsolationStatus.
GetSecurityIsolationStatusReturnObject
Returns information about the COEP/COOP isolation status.
GetSecurityIsolationStatusReturnObjectBuilder
Builder for GetSecurityIsolationStatusReturnObject.
Headers
Initiator
Information about the request initiator.
InitiatorBuilder
Builder for Initiator.
LoadNetworkResource
Fetches the resource and returns the content.
LoadNetworkResourceBuilder
Builder for LoadNetworkResource.
LoadNetworkResourceOptions
An options object that may be extended later to better support CORS, CORB and streaming.
LoadNetworkResourceOptionsBuilder
Builder for LoadNetworkResourceOptions.
LoadNetworkResourcePageResult
An object providing the result of a network resource load.
LoadNetworkResourcePageResultBuilder
Builder for LoadNetworkResourcePageResult.
LoadNetworkResourceReturnObject
Fetches the resource and returns the content.
LoadNetworkResourceReturnObjectBuilder
Builder for LoadNetworkResourceReturnObject.
NetworkConditions
NetworkConditionsBuilder
Builder for NetworkConditions.
OverrideNetworkState
Override the state of navigator.onLine and navigator.connection.
OverrideNetworkStateBuilder
Builder for OverrideNetworkState.
OverrideNetworkStateReturnObject
Override the state of navigator.onLine and navigator.connection.
PostDataEntry
Post data entry for HTTP request
PostDataEntryBuilder
Builder for PostDataEntry.
RefreshEventDetails
Session event details specific to refresh.
RefreshEventDetailsBuilder
Builder for RefreshEventDetails.
ReplayXHR
This method sends a new XMLHttpRequest which is identical to the original one. The following parameters should be identical: method, url, async, request body, extra headers, withCredentials attribute, user, password.
ReplayXHRBuilder
Builder for ReplayXHR.
ReplayXHRReturnObject
This method sends a new XMLHttpRequest which is identical to the original one. The following parameters should be identical: method, url, async, request body, extra headers, withCredentials attribute, user, password.
ReportingApiEndpoint
ReportingApiEndpointBuilder
Builder for ReportingApiEndpoint.
ReportingApiReport
An object representing a report generated by the Reporting API.
ReportingApiReportBuilder
Builder for ReportingApiReport.
Request
HTTP request data.
RequestBuilder
Builder for Request.
RequestPattern
Request pattern for interception.
RequestPatternBuilder
Builder for RequestPattern.
ResourceTiming
Timing information for the request.
ResourceTimingBuilder
Builder for ResourceTiming.
Response
HTTP response data.
ResponseBuilder
Builder for Response.
SearchInResponseBody
Searches for given string in response content.
SearchInResponseBodyBuilder
Builder for SearchInResponseBody.
SearchInResponseBodyReturnObject
Searches for given string in response content.
SearchInResponseBodyReturnObjectBuilder
Builder for SearchInResponseBodyReturnObject.
SecurityDetails
Security details about a request.
SecurityDetailsBuilder
Builder for SecurityDetails.
SecurityIsolationStatus
SecurityIsolationStatusBuilder
Builder for SecurityIsolationStatus.
ServiceWorkerRouterInfo
ServiceWorkerRouterInfoBuilder
Builder for ServiceWorkerRouterInfo.
SetAcceptedEncodings
Sets a list of content encodings that will be accepted. Empty list means no encoding is accepted.
SetAcceptedEncodingsBuilder
Builder for SetAcceptedEncodings.
SetAcceptedEncodingsReturnObject
Sets a list of content encodings that will be accepted. Empty list means no encoding is accepted.
SetAttachDebugStack
Specifies whether to attach a page script stack id in requests
SetAttachDebugStackBuilder
Builder for SetAttachDebugStack.
SetAttachDebugStackReturnObject
Specifies whether to attach a page script stack id in requests
SetBlockedURLs
Blocks URLs from loading.
SetBlockedURLsBuilder
Builder for SetBlockedURLs.
SetBlockedURLsReturnObject
Blocks URLs from loading.
SetBypassServiceWorker
Toggles ignoring of service worker for each request.
SetBypassServiceWorkerBuilder
Builder for SetBypassServiceWorker.
SetBypassServiceWorkerReturnObject
Toggles ignoring of service worker for each request.
SetCacheDisabled
Toggles ignoring cache for each request. If true, cache will not be used.
SetCacheDisabledBuilder
Builder for SetCacheDisabled.
SetCacheDisabledReturnObject
Toggles ignoring cache for each request. If true, cache will not be used.
SetCookie
Sets a cookie with the given cookie data; may overwrite equivalent cookies if they exist.
SetCookieBuilder
Builder for SetCookie.
SetCookieControls
Sets Controls for third-party cookie access Page reload is required before the new cookie behavior will be observed
SetCookieControlsBuilder
Builder for SetCookieControls.
SetCookieControlsReturnObject
Sets Controls for third-party cookie access Page reload is required before the new cookie behavior will be observed
SetCookieReturnObject
Sets a cookie with the given cookie data; may overwrite equivalent cookies if they exist.
SetCookieReturnObjectBuilder
Builder for SetCookieReturnObject.
SetCookies
Sets given cookies.
SetCookiesBuilder
Builder for SetCookies.
SetCookiesReturnObject
Sets given cookies.
SetExtraHTTPHeaders
Specifies whether to always send extra HTTP headers with the requests from this page.
SetExtraHTTPHeadersBuilder
Builder for SetExtraHTTPHeaders.
SetExtraHTTPHeadersReturnObject
Specifies whether to always send extra HTTP headers with the requests from this page.
SetRequestInterceptionDeprecated
Sets the requests to intercept that match the provided patterns and optionally resource types. Deprecated, please use Fetch.enable instead.
SetRequestInterceptionBuilder
Builder for SetRequestInterception.
SetRequestInterceptionReturnObjectDeprecated
Sets the requests to intercept that match the provided patterns and optionally resource types. Deprecated, please use Fetch.enable instead.
SetUserAgentOverride
Allows overriding user agent with the given string.
SetUserAgentOverrideBuilder
Builder for SetUserAgentOverride.
SetUserAgentOverrideReturnObject
Allows overriding user agent with the given string.
SignedCertificateTimestamp
Details of a signed certificate timestamp (SCT).
SignedCertificateTimestampBuilder
Builder for SignedCertificateTimestamp.
SignedExchangeError
Information about a signed exchange response.
SignedExchangeErrorBuilder
Builder for SignedExchangeError.
SignedExchangeHeader
Information about a signed exchange header. https://wicg.github.io/webpackage/draft-yasskin-httpbis-origin-signed-exchanges-impl.html#cbor-representation
SignedExchangeHeaderBuilder
Builder for SignedExchangeHeader.
SignedExchangeInfo
Information about a signed exchange response.
SignedExchangeInfoBuilder
Builder for SignedExchangeInfo.
SignedExchangeSignature
Information about a signed exchange signature. https://wicg.github.io/webpackage/draft-yasskin-httpbis-origin-signed-exchanges-impl.html#rfc.section.3.1
SignedExchangeSignatureBuilder
Builder for SignedExchangeSignature.
StreamResourceContent
Enables streaming of the response for the given requestId. If enabled, the dataReceived event contains the data that was received during streaming.
StreamResourceContentBuilder
Builder for StreamResourceContent.
StreamResourceContentReturnObject
Enables streaming of the response for the given requestId. If enabled, the dataReceived event contains the data that was received during streaming.
StreamResourceContentReturnObjectBuilder
Builder for StreamResourceContentReturnObject.
TakeResponseBodyForInterceptionAsStream
Returns a handle to the stream representing the response body. Note that after this command, the intercepted request can’t be continued as is – you either need to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified.
TakeResponseBodyForInterceptionAsStreamBuilder
Builder for TakeResponseBodyForInterceptionAsStream.
TakeResponseBodyForInterceptionAsStreamReturnObject
Returns a handle to the stream representing the response body. Note that after this command, the intercepted request can’t be continued as is – you either need to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified.
TakeResponseBodyForInterceptionAsStreamReturnObjectBuilder
Builder for TakeResponseBodyForInterceptionAsStreamReturnObject.
TerminationEventDetails
Session event details specific to termination.
TerminationEventDetailsBuilder
Builder for TerminationEventDetails.
TrustTokenParams
Determines what type of Trust Token operation is executed and depending on the type, some additional parameters. The values are specified in third_party/blink/renderer/core/fetch/trust_token.idl.
TrustTokenParamsBuilder
Builder for TrustTokenParams.
WebSocketFrame
WebSocket message data. This represents an entire WebSocket message, not just a fragmented frame as the name suggests.
WebSocketFrameBuilder
Builder for WebSocketFrame.
WebSocketRequest
WebSocket request data.
WebSocketRequestBuilder
Builder for WebSocketRequest.
WebSocketResponse
WebSocket response data.
WebSocketResponseBuilder
Builder for WebSocketResponse.

Enums

AlternateProtocolUsage
AssociatedCookieBuilderError
Error type for AssociatedCookieBuilder
AuthChallengeBuilderError
Error type for AuthChallengeBuilder
AuthChallengeResponseBuilderError
Error type for AuthChallengeResponseBuilder
AuthChallengeResponseResponse
AuthChallengeSource
BlockPatternBuilderError
Error type for BlockPatternBuilder
BlockedReason
BlockedSetCookieWithReasonBuilderError
Error type for BlockedSetCookieWithReasonBuilder
CachedResourceBuilderError
Error type for CachedResourceBuilder
CanClearBrowserCacheReturnObjectBuilderError
Error type for CanClearBrowserCacheReturnObjectBuilder
CanClearBrowserCookiesReturnObjectBuilderError
Error type for CanClearBrowserCookiesReturnObjectBuilder
CanEmulateNetworkConditionsReturnObjectBuilderError
Error type for CanEmulateNetworkConditionsReturnObjectBuilder
CertificateTransparencyCompliance
ChallengeEventDetailsBuilderError
Error type for ChallengeEventDetailsBuilder
ChallengeEventDetailsChallengeResult
ClientSecurityStateBuilderError
Error type for ClientSecurityStateBuilder
ConfigureDurableMessagesBuilderError
Error type for ConfigureDurableMessagesBuilder
ConnectTimingBuilderError
Error type for ConnectTimingBuilder
ConnectionType
ContentEncoding
ContentSecurityPolicySource
ContentSecurityPolicyStatusBuilderError
Error type for ContentSecurityPolicyStatusBuilder
ContinueInterceptedRequestBuilderError
Error type for ContinueInterceptedRequestBuilder
CookieBlockedReason
CookieBuilderError
Error type for CookieBuilder
CookieExemptionReason
CookieParamBuilderError
Error type for CookieParamBuilder
CookiePartitionKeyBuilderError
Error type for CookiePartitionKeyBuilder
CookiePriority
CookieSameSite
CookieSourceScheme
CorsError
CorsErrorStatusBuilderError
Error type for CorsErrorStatusBuilder
CreationEventDetailsBuilderError
Error type for CreationEventDetailsBuilder
CrossOriginEmbedderPolicyStatusBuilderError
Error type for CrossOriginEmbedderPolicyStatusBuilder
CrossOriginEmbedderPolicyValue
CrossOriginOpenerPolicyStatusBuilderError
Error type for CrossOriginOpenerPolicyStatusBuilder
CrossOriginOpenerPolicyValue
DeleteCookiesBuilderError
Error type for DeleteCookiesBuilder
DeviceBoundSessionBuilderError
Error type for DeviceBoundSessionBuilder
DeviceBoundSessionCookieCravingBuilderError
Error type for DeviceBoundSessionCookieCravingBuilder
DeviceBoundSessionFetchResult
DeviceBoundSessionInclusionRulesBuilderError
Error type for DeviceBoundSessionInclusionRulesBuilder
DeviceBoundSessionKeyBuilderError
Error type for DeviceBoundSessionKeyBuilder
DeviceBoundSessionUrlRuleBuilderError
Error type for DeviceBoundSessionUrlRuleBuilder
DeviceBoundSessionUrlRuleRuleType
DeviceBoundSessionWithUsageBuilderError
Error type for DeviceBoundSessionWithUsageBuilder
DeviceBoundSessionWithUsageUsage
DirectSocketDnsQueryType
DirectTcpSocketOptionsBuilderError
Error type for DirectTcpSocketOptionsBuilder
DirectUdpMessageBuilderError
Error type for DirectUdpMessageBuilder
DirectUdpSocketOptionsBuilderError
Error type for DirectUdpSocketOptionsBuilder
EmulateNetworkConditionsBuilderError
Error type for EmulateNetworkConditionsBuilder
EmulateNetworkConditionsByRuleBuilderError
Error type for EmulateNetworkConditionsByRuleBuilder
EmulateNetworkConditionsByRuleReturnObjectBuilderError
Error type for EmulateNetworkConditionsByRuleReturnObjectBuilder
EnableBuilderError
Error type for EnableBuilder
EnableDeviceBoundSessionsBuilderError
Error type for EnableDeviceBoundSessionsBuilder
EnableReportingApiBuilderError
Error type for EnableReportingApiBuilder
ErrorReason
ExemptedSetCookieWithReasonBuilderError
Error type for ExemptedSetCookieWithReasonBuilder
FetchSchemefulSiteBuilderError
Error type for FetchSchemefulSiteBuilder
FetchSchemefulSiteReturnObjectBuilderError
Error type for FetchSchemefulSiteReturnObjectBuilder
GetAllCookiesReturnObjectBuilderError
Error type for GetAllCookiesReturnObjectBuilder
GetCertificateBuilderError
Error type for GetCertificateBuilder
GetCertificateReturnObjectBuilderError
Error type for GetCertificateReturnObjectBuilder
GetCookiesBuilderError
Error type for GetCookiesBuilder
GetCookiesReturnObjectBuilderError
Error type for GetCookiesReturnObjectBuilder
GetRequestPostDataBuilderError
Error type for GetRequestPostDataBuilder
GetRequestPostDataReturnObjectBuilderError
Error type for GetRequestPostDataReturnObjectBuilder
GetResponseBodyBuilderError
Error type for GetResponseBodyBuilder
GetResponseBodyForInterceptionBuilderError
Error type for GetResponseBodyForInterceptionBuilder
GetResponseBodyForInterceptionReturnObjectBuilderError
Error type for GetResponseBodyForInterceptionReturnObjectBuilder
GetResponseBodyReturnObjectBuilderError
Error type for GetResponseBodyReturnObjectBuilder
GetSecurityIsolationStatusBuilderError
Error type for GetSecurityIsolationStatusBuilder
GetSecurityIsolationStatusReturnObjectBuilderError
Error type for GetSecurityIsolationStatusReturnObjectBuilder
InitiatorBuilderError
Error type for InitiatorBuilder
InitiatorType
InterceptionStage
IpAddressSpace
LoadNetworkResourceBuilderError
Error type for LoadNetworkResourceBuilder
LoadNetworkResourceOptionsBuilderError
Error type for LoadNetworkResourceOptionsBuilder
LoadNetworkResourcePageResultBuilderError
Error type for LoadNetworkResourcePageResultBuilder
LoadNetworkResourceReturnObjectBuilderError
Error type for LoadNetworkResourceReturnObjectBuilder
LocalNetworkAccessRequestPolicy
NetworkConditionsBuilderError
Error type for NetworkConditionsBuilder
OverrideNetworkStateBuilderError
Error type for OverrideNetworkStateBuilder
PostDataEntryBuilderError
Error type for PostDataEntryBuilder
RefreshEventDetailsBuilderError
Error type for RefreshEventDetailsBuilder
RefreshEventDetailsRefreshResult
RenderBlockingBehavior
ReplayXHRBuilderError
Error type for ReplayXHRBuilder
ReportStatus
ReportingApiEndpointBuilderError
Error type for ReportingApiEndpointBuilder
ReportingApiReportBuilderError
Error type for ReportingApiReportBuilder
RequestBuilderError
Error type for RequestBuilder
RequestPatternBuilderError
Error type for RequestPatternBuilder
RequestReferrerPolicy
ResourcePriority
ResourceTimingBuilderError
Error type for ResourceTimingBuilder
ResourceType
ResponseBuilderError
Error type for ResponseBuilder
SearchInResponseBodyBuilderError
Error type for SearchInResponseBodyBuilder
SearchInResponseBodyReturnObjectBuilderError
Error type for SearchInResponseBodyReturnObjectBuilder
SecurityDetailsBuilderError
Error type for SecurityDetailsBuilder
SecurityIsolationStatusBuilderError
Error type for SecurityIsolationStatusBuilder
ServiceWorkerResponseSource
ServiceWorkerRouterInfoBuilderError
Error type for ServiceWorkerRouterInfoBuilder
ServiceWorkerRouterSource
SetAcceptedEncodingsBuilderError
Error type for SetAcceptedEncodingsBuilder
SetAttachDebugStackBuilderError
Error type for SetAttachDebugStackBuilder
SetBlockedURLsBuilderError
Error type for SetBlockedURLsBuilder
SetBypassServiceWorkerBuilderError
Error type for SetBypassServiceWorkerBuilder
SetCacheDisabledBuilderError
Error type for SetCacheDisabledBuilder
SetCookieBlockedReason
SetCookieBuilderError
Error type for SetCookieBuilder
SetCookieControlsBuilderError
Error type for SetCookieControlsBuilder
SetCookieReturnObjectBuilderError
Error type for SetCookieReturnObjectBuilder
SetCookiesBuilderError
Error type for SetCookiesBuilder
SetExtraHTTPHeadersBuilderError
Error type for SetExtraHTTPHeadersBuilder
SetRequestInterceptionBuilderError
Error type for SetRequestInterceptionBuilder
SetUserAgentOverrideBuilderError
Error type for SetUserAgentOverrideBuilder
SignedCertificateTimestampBuilderError
Error type for SignedCertificateTimestampBuilder
SignedExchangeErrorBuilderError
Error type for SignedExchangeErrorBuilder
SignedExchangeErrorField
SignedExchangeHeaderBuilderError
Error type for SignedExchangeHeaderBuilder
SignedExchangeInfoBuilderError
Error type for SignedExchangeInfoBuilder
SignedExchangeSignatureBuilderError
Error type for SignedExchangeSignatureBuilder
StreamResourceContentBuilderError
Error type for StreamResourceContentBuilder
StreamResourceContentReturnObjectBuilderError
Error type for StreamResourceContentReturnObjectBuilder
TakeResponseBodyForInterceptionAsStreamBuilderError
Error type for TakeResponseBodyForInterceptionAsStreamBuilder
TakeResponseBodyForInterceptionAsStreamReturnObjectBuilderError
Error type for TakeResponseBodyForInterceptionAsStreamReturnObjectBuilder
TerminationEventDetailsBuilderError
Error type for TerminationEventDetailsBuilder
TerminationEventDetailsDeletionReason
TrustTokenOperationDoneStatusOption
TrustTokenOperationType
TrustTokenParamsBuilderError
Error type for TrustTokenParamsBuilder
TrustTokenParamsRefreshPolicy
WebSocketFrameBuilderError
Error type for WebSocketFrameBuilder
WebSocketRequestBuilderError
Error type for WebSocketRequestBuilder
WebSocketResponseBuilderError
Error type for WebSocketResponseBuilder

Type Aliases

DeviceBoundSessionEventId
InterceptionId
LoaderId
MonotonicTime
ReportId
RequestId
TimeSinceEpoch