pub struct DeviceBoundSessionEventOccurredEventParams {
pub event_id: DeviceBoundSessionEventId,
pub site: String,
pub succeeded: bool,
pub session_id: Option<String>,
pub creation_event_details: Option<CreationEventDetails>,
pub refresh_event_details: Option<RefreshEventDetails>,
pub termination_event_details: Option<TerminationEventDetails>,
pub challenge_event_details: Option<ChallengeEventDetails>,
}Fields
event_id: DeviceBoundSessionEventIdA unique identifier for this session event.
site: StringThe site this session event is associated with.
succeeded: boolWhether this event was considered successful.
session_id: Option<String>The session ID this event is associated with. May not be populated for failed events.
creation_event_details: Option<CreationEventDetails>The below are the different session event type details. Exactly one is populated.
refresh_event_details: Option<RefreshEventDetails>termination_event_details: Option<TerminationEventDetails>challenge_event_details: Option<ChallengeEventDetails>Trait Implementations
Sourceimpl Clone for DeviceBoundSessionEventOccurredEventParams
impl Clone for DeviceBoundSessionEventOccurredEventParams
Sourcefn clone(&self) -> DeviceBoundSessionEventOccurredEventParams
fn clone(&self) -> DeviceBoundSessionEventOccurredEventParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for DeviceBoundSessionEventOccurredEventParams
impl<'de> Deserialize<'de> for DeviceBoundSessionEventOccurredEventParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DeviceBoundSessionEventOccurredEventParams
impl PartialEq for DeviceBoundSessionEventOccurredEventParams
Sourcefn eq(&self, other: &DeviceBoundSessionEventOccurredEventParams) -> bool
fn eq(&self, other: &DeviceBoundSessionEventOccurredEventParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceBoundSessionEventOccurredEventParams