RequestInterceptedEventParams

Struct RequestInterceptedEventParams 

pub struct RequestInterceptedEventParams {
    pub interception_id: InterceptionId,
    pub request: Request,
    pub frame_id: FrameId,
    pub resource_type: ResourceType,
    pub is_navigation_request: bool,
    pub is_download: Option<bool>,
    pub redirect_url: Option<String>,
    pub auth_challenge: Option<AuthChallenge>,
    pub response_error_reason: Option<ErrorReason>,
    pub response_status_code: Option<JsUInt>,
    pub response_headers: Option<Headers>,
    pub request_id: Option<RequestId>,
}

Fields

interception_id: InterceptionId

Each request the page makes will have a unique id, however if any redirects are encountered while processing that fetch, they will be reported with the same id as the original fetch. Likewise if HTTP authentication is needed then the same fetch id will be used.

request: Requestframe_id: FrameId

The id of the frame that initiated the request.

resource_type: ResourceType

How the requested resource will be used.

is_navigation_request: bool

Whether this is a navigation request, which can abort the navigation completely.

is_download: Option<bool>

Set if the request is a navigation that will result in a download. Only present after response is received from the server (i.e. HeadersReceived stage).

redirect_url: Option<String>

Redirect location, only sent if a redirect was intercepted.

auth_challenge: Option<AuthChallenge>

Details of the Authorization Challenge encountered. If this is set then continueInterceptedRequest must contain an authChallengeResponse.

response_error_reason: Option<ErrorReason>

Response error if intercepted at response stage or if redirect occurred while intercepting request.

response_status_code: Option<JsUInt>

Response code if intercepted at response stage or if redirect occurred while intercepting request or auth retry occurred.

response_headers: Option<Headers>

Response headers if intercepted at the response stage or if redirect occurred while intercepting request or auth retry occurred.

request_id: Option<RequestId>

If the intercepted request had a corresponding requestWillBeSent event fired for it, then this requestId will be the same as the requestId present in the requestWillBeSent event.