RequestWillBeSentEventParamsBuilder

Struct RequestWillBeSentEventParamsBuilder 

pub struct RequestWillBeSentEventParamsBuilder { /* private fields */ }
Implementations

Source

impl RequestWillBeSentEventParamsBuilder

pub fn request_id(&mut self, value: RequestId) -> &mut Self

Request identifier.

pub fn loader_id(&mut self, value: LoaderId) -> &mut Self

Loader identifier. Empty string if the request is fetched from worker.

pub fn document_url(&mut self, value: String) -> &mut Self

URL of the document this request is loaded for.

pub fn request(&mut self, value: Request) -> &mut Self

Request data.

pub fn timestamp(&mut self, value: MonotonicTime) -> &mut Self

Timestamp.

pub fn wall_time(&mut self, value: TimeSinceEpoch) -> &mut Self

Timestamp.

pub fn initiator(&mut self, value: Initiator) -> &mut Self

Request initiator.

pub fn redirect_has_extra_info(&mut self, value: bool) -> &mut Self

In the case that redirectResponse is populated, this flag indicates whether requestWillBeSentExtraInfo and responseReceivedExtraInfo events will be or were emitted for the request which was just redirected.

pub fn redirect_response(&mut self, value: Option<Response>) -> &mut Self

Redirect response data.

pub fn type(&mut self, value: Option<ResourceType>) -> &mut Self

Type of this resource.

pub fn frame_id(&mut self, value: Option<FrameId>) -> &mut Self

Frame identifier.

pub fn has_user_gesture(&mut self, value: Option<bool>) -> &mut Self

Whether the request is initiated by a user gesture. Defaults to false.

pub fn render_blocking_behavior( &mut self, value: Option<RenderBlockingBehavior>, ) -> &mut Self

The render blocking behavior of the request.

pub fn build( &self, ) -> Result<RequestWillBeSentEventParams, RequestWillBeSentEventParamsBuilderError>

Builds a new RequestWillBeSentEventParams.

Errors

If a required field has not been initialized.