pub struct RequestWillBeSentExtraInfoEventParamsBuilder { /* private fields */ }Expand description
Builder for RequestWillBeSentExtraInfoEventParams.
Implementations
Sourceimpl RequestWillBeSentExtraInfoEventParamsBuilder
impl RequestWillBeSentExtraInfoEventParamsBuilder
Sourcepub fn request_id(&mut self, value: RequestId) -> &mut Self
pub fn request_id(&mut self, value: RequestId) -> &mut Self
Request identifier. Used to match this information to an existing requestWillBeSent event.
A list of cookies potentially associated to the requested URL. This includes both cookies sent with the request and the ones not sent; the latter are distinguished by having blockedReasons field set.
Sourcepub fn headers(&mut self, value: Headers) -> &mut Self
pub fn headers(&mut self, value: Headers) -> &mut Self
Raw request headers as they will be sent over the wire.
Sourcepub fn connect_timing(&mut self, value: ConnectTiming) -> &mut Self
pub fn connect_timing(&mut self, value: ConnectTiming) -> &mut Self
Connection timing information for the request.
Sourcepub fn device_bound_session_usages(
&mut self,
value: Option<Vec<DeviceBoundSessionWithUsage>>,
) -> &mut Self
pub fn device_bound_session_usages( &mut self, value: Option<Vec<DeviceBoundSessionWithUsage>>, ) -> &mut Self
How the request site’s device bound sessions were used during this request.
Sourcepub fn client_security_state(
&mut self,
value: Option<ClientSecurityState>,
) -> &mut Self
pub fn client_security_state( &mut self, value: Option<ClientSecurityState>, ) -> &mut Self
The client security state set for the request.
Whether the site has partitioned cookies stored in a partition different than the current one.
Sourcepub fn applied_network_conditions_id(
&mut self,
value: Option<String>,
) -> &mut Self
pub fn applied_network_conditions_id( &mut self, value: Option<String>, ) -> &mut Self
The network conditions id if this request was affected by network conditions configured via emulateNetworkConditionsByRule.
Sourcepub fn build(
&self,
) -> Result<RequestWillBeSentExtraInfoEventParams, RequestWillBeSentExtraInfoEventParamsBuilderError>
pub fn build( &self, ) -> Result<RequestWillBeSentExtraInfoEventParams, RequestWillBeSentExtraInfoEventParamsBuilderError>
Builds a new RequestWillBeSentExtraInfoEventParams.
Errors
If a required field has not been initialized.