pub struct ResponseReceivedEarlyHintsEventParamsBuilder { /* private fields */ }Expand description
Builder for ResponseReceivedEarlyHintsEventParams.
Implementations
Sourceimpl ResponseReceivedEarlyHintsEventParamsBuilder
impl ResponseReceivedEarlyHintsEventParamsBuilder
Sourcepub fn request_id(&mut self, value: RequestId) -> &mut Self
pub fn request_id(&mut self, value: RequestId) -> &mut Self
Request identifier. Used to match this information to another responseReceived event.
Sourcepub fn headers(&mut self, value: Headers) -> &mut Self
pub fn headers(&mut self, value: Headers) -> &mut Self
Raw response headers as they were received over the wire.
Duplicate headers in the response are represented as a single key with their values
concatentated using \n as the separator.
See also headersText that contains verbatim text for HTTP/1.*.
Sourcepub fn build(
&self,
) -> Result<ResponseReceivedEarlyHintsEventParams, ResponseReceivedEarlyHintsEventParamsBuilderError>
pub fn build( &self, ) -> Result<ResponseReceivedEarlyHintsEventParams, ResponseReceivedEarlyHintsEventParamsBuilderError>
Builds a new ResponseReceivedEarlyHintsEventParams.
Errors
If a required field has not been initialized.