pub struct ResponseReceivedEventParamsBuilder { /* private fields */ }Expand description
Builder for ResponseReceivedEventParams.
Implementations
Sourceimpl ResponseReceivedEventParamsBuilder
impl ResponseReceivedEventParamsBuilder
Sourcepub fn request_id(&mut self, value: RequestId) -> &mut Self
pub fn request_id(&mut self, value: RequestId) -> &mut Self
Request identifier.
Sourcepub fn loader_id(&mut self, value: LoaderId) -> &mut Self
pub fn loader_id(&mut self, value: LoaderId) -> &mut Self
Loader identifier. Empty string if the request is fetched from worker.
Sourcepub fn timestamp(&mut self, value: MonotonicTime) -> &mut Self
pub fn timestamp(&mut self, value: MonotonicTime) -> &mut Self
Timestamp.
Sourcepub fn type(&mut self, value: ResourceType) -> &mut Self
pub fn type(&mut self, value: ResourceType) -> &mut Self
Resource type.
Sourcepub fn has_extra_info(&mut self, value: bool) -> &mut Self
pub fn has_extra_info(&mut self, value: bool) -> &mut Self
Indicates whether requestWillBeSentExtraInfo and responseReceivedExtraInfo events will be or were emitted for this request.
Sourcepub fn build(
&self,
) -> Result<ResponseReceivedEventParams, ResponseReceivedEventParamsBuilderError>
pub fn build( &self, ) -> Result<ResponseReceivedEventParams, ResponseReceivedEventParamsBuilderError>