pub struct TrustTokenOperationDoneEventParamsBuilder { /* private fields */ }Expand description
Builder for TrustTokenOperationDoneEventParams.
Implementations
Sourceimpl TrustTokenOperationDoneEventParamsBuilder
impl TrustTokenOperationDoneEventParamsBuilder
Sourcepub fn status(
&mut self,
value: TrustTokenOperationDoneStatusOption,
) -> &mut Self
pub fn status( &mut self, value: TrustTokenOperationDoneStatusOption, ) -> &mut Self
Detailed success or error status of the operation. ‘AlreadyExists’ also signifies a successful operation, as the result of the operation already exists und thus, the operation was abort preemptively (e.g. a cache hit).
pub fn type(&mut self, value: TrustTokenOperationType) -> &mut Self
pub fn request_id(&mut self, value: RequestId) -> &mut Self
Sourcepub fn top_level_origin(&mut self, value: Option<String>) -> &mut Self
pub fn top_level_origin(&mut self, value: Option<String>) -> &mut Self
Top level origin. The context in which the operation was attempted.
Sourcepub fn issuer_origin(&mut self, value: Option<String>) -> &mut Self
pub fn issuer_origin(&mut self, value: Option<String>) -> &mut Self
Origin of the issuer in case of a “Issuance” or “Redemption” operation.
Sourcepub fn issued_token_count(&mut self, value: Option<JsUInt>) -> &mut Self
pub fn issued_token_count(&mut self, value: Option<JsUInt>) -> &mut Self
The number of obtained Trust Tokens on a successful “Issuance” operation.
Sourcepub fn build(
&self,
) -> Result<TrustTokenOperationDoneEventParams, TrustTokenOperationDoneEventParamsBuilderError>
pub fn build( &self, ) -> Result<TrustTokenOperationDoneEventParams, TrustTokenOperationDoneEventParamsBuilderError>
Builds a new TrustTokenOperationDoneEventParams.
Errors
If a required field has not been initialized.