AssociatedCookieBuilder

Struct AssociatedCookieBuilder 

pub struct AssociatedCookieBuilder { /* private fields */ }
Builder for AssociatedCookie.

Implementations

Source

impl AssociatedCookieBuilder

pub fn cookie<VALUE: Into<Cookie>>(&mut self, value: VALUE) -> &mut Self

The cookie object representing the cookie which was not sent.

pub fn blocked_reasons<VALUE: Into<Vec<CookieBlockedReason>>>( &mut self, value: VALUE, ) -> &mut Self

The reason(s) the cookie was blocked. If empty means the cookie is included.

pub fn exemption_reason<VALUE: Into<CookieExemptionReason>>( &mut self, value: VALUE, ) -> &mut Self

The reason the cookie should have been blocked by 3PCD but is exempted. A cookie could only have at most one exemption reason.

pub fn build(&self) -> Result<AssociatedCookie, AssociatedCookieBuilderError>

Builds a new AssociatedCookie.

Errors

If a required field has not been initialized.