AuthChallengeResponseBuilder

Struct AuthChallengeResponseBuilder 

pub struct AuthChallengeResponseBuilder { /* private fields */ }
Builder for AuthChallengeResponse.

Implementations

Source

impl AuthChallengeResponseBuilder

pub fn response<VALUE: Into<AuthChallengeResponseResponse>>( &mut self, value: VALUE, ) -> &mut Self

The decision on what to do in response to the authorization challenge. Default means deferring to the default behavior of the net stack, which will likely either the Cancel authentication or display a popup dialog box.

pub fn username<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

The username to provide, possibly empty. Should only be set if response is ProvideCredentials.

pub fn password<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

The password to provide, possibly empty. Should only be set if response is ProvideCredentials.

pub fn build( &self, ) -> Result<AuthChallengeResponse, AuthChallengeResponseBuilderError>

Builds a new AuthChallengeResponse.

Errors

If a required field has not been initialized.