ContinueInterceptedRequest

Struct ContinueInterceptedRequest 

pub struct ContinueInterceptedRequest {
    pub interception_id: InterceptionId,
    pub error_reason: Option<ErrorReason>,
    pub raw_response: Option<Vec<u8>>,
    pub url: Option<String>,
    pub method: Option<String>,
    pub post_data: Option<String>,
    pub headers: Option<Headers>,
    pub auth_challenge_response: Option<AuthChallengeResponse>,
}
👎Deprecated
Response to Network.requestIntercepted which either modifies the request to continue with any modifications, or blocks it, or completes it with the provided response bytes. If a network fetch occurs as a result which encounters a redirect an additional Network.requestIntercepted event will be sent with the same InterceptionId. Deprecated, use Fetch.continueRequest, Fetch.fulfillRequest and Fetch.failRequest instead.

Fields

interception_id: InterceptionId
👎Deprecated
error_reason: Option<ErrorReason>
👎Deprecated

If set this causes the request to fail with the given reason. Passing Aborted for requests marked with isNavigationRequest also cancels the navigation. Must not be set in response to an authChallenge.

raw_response: Option<Vec<u8>>
👎Deprecated

If set the requests completes using with the provided base64 encoded raw response, including HTTP status line and headers etc… Must not be set in response to an authChallenge.

url: Option<String>
👎Deprecated

If set the request url will be modified in a way that’s not observable by page. Must not be set in response to an authChallenge.

method: Option<String>
👎Deprecated

If set this allows the request method to be overridden. Must not be set in response to an authChallenge.

post_data: Option<String>
👎Deprecated

If set this allows postData to be set. Must not be set in response to an authChallenge.

headers: Option<Headers>
👎Deprecated

If set this allows the request headers to be changed. Must not be set in response to an authChallenge.

auth_challenge_response: Option<AuthChallengeResponse>
👎Deprecated

Response to a requestIntercepted with an authChallenge. Must not be set otherwise.