pub struct Cookie {Show 15 fields
pub name: String,
pub value: String,
pub domain: String,
pub path: String,
pub expires: JsFloat,
pub size: JsUInt,
pub http_only: bool,
pub secure: bool,
pub session: bool,
pub same_site: Option<CookieSameSite>,
pub priority: CookiePriority,
pub source_scheme: CookieSourceScheme,
pub source_port: JsUInt,
pub partition_key: Option<CookiePartitionKey>,
pub partition_key_opaque: Option<bool>,
}Expand description
Cookie object
Fields
name: StringCookie name.
value: StringCookie value.
domain: StringCookie domain.
path: StringCookie path.
expires: JsFloatCookie expiration date as the number of seconds since the UNIX epoch. The value is set to -1 if the expiry date is not set. The value can be null for values that cannot be represented in JSON (±Inf).
size: JsUIntCookie size.
http_only: boolTrue if cookie is http-only.
secure: boolTrue if cookie is secure.
session: boolTrue in case of session cookie.
same_site: Option<CookieSameSite>Cookie SameSite type.
priority: CookiePriorityCookie Priority
source_scheme: CookieSourceSchemeCookie source scheme type.
source_port: JsUIntCookie source port. Valid values are {-1, [1, 65535]}, -1 indicates an unspecified port. An unspecified port value allows protocol clients to emulate legacy cookie scope for the port. This is a temporary ability and it will be removed in the future.
partition_key: Option<CookiePartitionKey>Cookie partition key.
partition_key_opaque: Option<bool>True if cookie partition key is opaque.