CookieBuilder

Struct CookieBuilder 

pub struct CookieBuilder { /* private fields */ }
Builder for Cookie.

Implementations

Source

impl CookieBuilder

pub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Cookie name.

pub fn value<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Cookie value.

pub fn domain<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Cookie domain.

pub fn path<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Cookie path.

pub fn expires<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

Cookie expiration date as the number of seconds since the UNIX epoch. The value is set to -1 if the expiry date is not set. The value can be null for values that cannot be represented in JSON (±Inf).

pub fn size<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self

Cookie size.

pub fn http_only<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

True if cookie is http-only.

pub fn secure<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

True if cookie is secure.

pub fn session<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

True in case of session cookie.

pub fn same_site<VALUE: Into<CookieSameSite>>( &mut self, value: VALUE, ) -> &mut Self

Cookie SameSite type.

pub fn priority<VALUE: Into<CookiePriority>>( &mut self, value: VALUE, ) -> &mut Self

Cookie Priority

pub fn source_scheme<VALUE: Into<CookieSourceScheme>>( &mut self, value: VALUE, ) -> &mut Self

Cookie source scheme type.

pub fn source_port<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self

Cookie source port. Valid values are {-1, [1, 65535]}, -1 indicates an unspecified port. An unspecified port value allows protocol clients to emulate legacy cookie scope for the port. This is a temporary ability and it will be removed in the future.

pub fn partition_key<VALUE: Into<CookiePartitionKey>>( &mut self, value: VALUE, ) -> &mut Self

Cookie partition key.

pub fn partition_key_opaque<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

True if cookie partition key is opaque.

pub fn build(&self) -> Result<Cookie, CookieBuilderError>

Builds a new Cookie.

Errors

If a required field has not been initialized.