pub struct CookiePartitionKeyBuilder { /* private fields */ }Expand description
Builder for CookiePartitionKey.
Implementations
Sourceimpl CookiePartitionKeyBuilder
impl CookiePartitionKeyBuilder
Sourcepub fn top_level_site<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn top_level_site<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The site of the top-level URL the browser was visiting at the start of the request to the endpoint that set the cookie.
Sourcepub fn has_cross_site_ancestor<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn has_cross_site_ancestor<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Indicates if the cookie has any ancestors that are cross-site to the topLevelSite.
Sourcepub fn build(
&self,
) -> Result<CookiePartitionKey, CookiePartitionKeyBuilderError>
pub fn build( &self, ) -> Result<CookiePartitionKey, CookiePartitionKeyBuilderError>