DeleteCookies

Struct DeleteCookies 

pub struct DeleteCookies {
    pub name: String,
    pub url: Option<String>,
    pub domain: Option<String>,
    pub path: Option<String>,
    pub partition_key: Option<CookiePartitionKey>,
}
Deletes browser cookies with matching name and url or domain/path/partitionKey pair.

Fields

name: String

Name of the cookies to remove.

url: Option<String>

If specified, deletes all the cookies with the given name where domain and path match provided URL.

domain: Option<String>

If specified, deletes only cookies with the exact domain.

path: Option<String>

If specified, deletes only cookies with the exact path.

partition_key: Option<CookiePartitionKey>

If specified, deletes only cookies with the the given name and partitionKey where all partition key attributes match the cookie partition key attribute.