pub struct DeleteCookiesBuilder { /* private fields */ }Expand description
Builder for DeleteCookies.
Implementations
Sourceimpl DeleteCookiesBuilder
impl DeleteCookiesBuilder
Sourcepub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Name of the cookies to remove.
Sourcepub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
If specified, deletes all the cookies with the given name where domain and path match provided URL.
Sourcepub fn domain<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn domain<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
If specified, deletes only cookies with the exact domain.
Sourcepub fn path<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn path<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
If specified, deletes only cookies with the exact path.
Sourcepub fn partition_key<VALUE: Into<CookiePartitionKey>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn partition_key<VALUE: Into<CookiePartitionKey>>( &mut self, value: VALUE, ) -> &mut Self
If specified, deletes only cookies with the the given name and partitionKey where all partition key attributes match the cookie partition key attribute.
Sourcepub fn build(&self) -> Result<DeleteCookies, DeleteCookiesBuilderError>
pub fn build(&self) -> Result<DeleteCookies, DeleteCookiesBuilderError>