EmulateNetworkConditionsByRuleBuilder

Struct EmulateNetworkConditionsByRuleBuilder 

pub struct EmulateNetworkConditionsByRuleBuilder { /* private fields */ }
Implementations

Source

impl EmulateNetworkConditionsByRuleBuilder

pub fn offline<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

True to emulate internet disconnection.

pub fn matched_network_conditions<VALUE: Into<Vec<NetworkConditions>>>( &mut self, value: VALUE, ) -> &mut Self

Configure conditions for matching requests. If multiple entries match a request, the first entry wins. Global conditions can be configured by leaving the urlPattern for the conditions empty. These global conditions are also applied for throttling of p2p connections.

pub fn build( &self, ) -> Result<EmulateNetworkConditionsByRule, EmulateNetworkConditionsByRuleBuilderError>

Builds a new EmulateNetworkConditionsByRule.

Errors

If a required field has not been initialized.