pub struct Enable {
pub max_total_buffer_size: Option<JsUInt>,
pub max_resource_buffer_size: Option<JsUInt>,
pub max_post_data_size: Option<JsUInt>,
pub report_direct_socket_traffic: Option<bool>,
pub enable_durable_messages: Option<bool>,
}Expand description
Enables network tracking, network events will now be delivered to the client.
Fields
max_total_buffer_size: Option<JsUInt>Buffer size in bytes to use when preserving network payloads (XHRs, etc).
max_resource_buffer_size: Option<JsUInt>Per-resource buffer size in bytes to use when preserving network payloads (XHRs, etc).
max_post_data_size: Option<JsUInt>Longest post body size (in bytes) that would be included in requestWillBeSent notification
report_direct_socket_traffic: Option<bool>Whether DirectSocket chunk send/receive events should be reported.
enable_durable_messages: Option<bool>Enable storing response bodies outside of renderer, so that these survive a cross-process navigation. Requires maxTotalBufferSize to be set. Currently defaults to false. This field is being deprecated in favor of the dedicated configureDurableMessages command, due to the possibility of deadlocks when awaiting Network.enable before issuing Runtime.runIfWaitingForDebugger.