EnableBuilder

Struct EnableBuilder 

pub struct EnableBuilder { /* private fields */ }
Builder for Enable.

Implementations

Source

impl EnableBuilder

pub fn max_total_buffer_size<VALUE: Into<JsUInt>>( &mut self, value: VALUE, ) -> &mut Self

Buffer size in bytes to use when preserving network payloads (XHRs, etc).

pub fn max_resource_buffer_size<VALUE: Into<JsUInt>>( &mut self, value: VALUE, ) -> &mut Self

Per-resource buffer size in bytes to use when preserving network payloads (XHRs, etc).

pub fn max_post_data_size<VALUE: Into<JsUInt>>( &mut self, value: VALUE, ) -> &mut Self

Longest post body size (in bytes) that would be included in requestWillBeSent notification

pub fn report_direct_socket_traffic<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

Whether DirectSocket chunk send/receive events should be reported.

pub fn enable_durable_messages<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

Enable storing response bodies outside of renderer, so that these survive a cross-process navigation. Requires maxTotalBufferSize to be set. Currently defaults to false. This field is being deprecated in favor of the dedicated configureDurableMessages command, due to the possibility of deadlocks when awaiting Network.enable before issuing Runtime.runIfWaitingForDebugger.

pub fn build(&self) -> Result<Enable, EnableBuilderError>

Builds a new Enable.

Errors

If a required field has not been initialized.