pub struct EnableDeviceBoundSessionsReturnObject(pub Option<Value>);Expand description
Sets up tracking device bound sessions and fetching of initial set of sessions.
Tuple Fields
0: Option<Value>Trait Implementations
Sourceimpl Clone for EnableDeviceBoundSessionsReturnObject
impl Clone for EnableDeviceBoundSessionsReturnObject
Sourcefn clone(&self) -> EnableDeviceBoundSessionsReturnObject
fn clone(&self) -> EnableDeviceBoundSessionsReturnObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for EnableDeviceBoundSessionsReturnObject
impl<'de> Deserialize<'de> for EnableDeviceBoundSessionsReturnObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for EnableDeviceBoundSessionsReturnObject
impl PartialEq for EnableDeviceBoundSessionsReturnObject
Sourcefn eq(&self, other: &EnableDeviceBoundSessionsReturnObject) -> bool
fn eq(&self, other: &EnableDeviceBoundSessionsReturnObject) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EnableDeviceBoundSessionsReturnObject