GetCookies

Struct GetCookies 

pub struct GetCookies {
    pub urls: Option<Vec<String>>,
}
Returns all browser cookies for the current URL. Depending on the backend support, will return detailed cookie information in the cookies field.

Fields

urls: Option<Vec<String>>

The list of URLs for which applicable cookies will be fetched. If not specified, it’s assumed to be set to the list containing the URLs of the page and all of its subframes.