GetCookiesBuilder

Struct GetCookiesBuilder 

pub struct GetCookiesBuilder { /* private fields */ }
Builder for GetCookies.

Implementations

Source

impl GetCookiesBuilder

pub fn urls<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self

The list of URLs for which applicable cookies will be fetched. If not specified, it’s assumed to be set to the list containing the URLs of the page and all of its subframes.

pub fn build(&self) -> Result<GetCookies, GetCookiesBuilderError>

Builds a new GetCookies.

Errors

If a required field has not been initialized.