pub struct InitiatorBuilder { /* private fields */ }Expand description
Builder for Initiator.
Implementations
Sourceimpl InitiatorBuilder
impl InitiatorBuilder
Sourcepub fn type<VALUE: Into<InitiatorType>>(&mut self, value: VALUE) -> &mut Self
pub fn type<VALUE: Into<InitiatorType>>(&mut self, value: VALUE) -> &mut Self
Type of this initiator.
Sourcepub fn stack<VALUE: Into<StackTrace>>(&mut self, value: VALUE) -> &mut Self
pub fn stack<VALUE: Into<StackTrace>>(&mut self, value: VALUE) -> &mut Self
Initiator JavaScript stack trace, set for Script only. Requires the Debugger domain to be enabled.
Sourcepub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Initiator URL, set for Parser type or for Script type (when script is importing module) or for SignedExchange type.
Sourcepub fn line_number<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn line_number<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Initiator line number, set for Parser type or for Script type (when script is importing module) (0-based).
Sourcepub fn column_number<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn column_number<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Initiator column number, set for Parser type or for Script type (when script is importing module) (0-based).
Sourcepub fn request_id<VALUE: Into<RequestId>>(&mut self, value: VALUE) -> &mut Self
pub fn request_id<VALUE: Into<RequestId>>(&mut self, value: VALUE) -> &mut Self
Set if another request triggered this request (e.g. preflight).