pub struct NetworkConditions {
pub url_pattern: String,
pub latency: JsFloat,
pub download_throughput: JsFloat,
pub upload_throughput: JsFloat,
pub connection_type: Option<ConnectionType>,
pub packet_loss: Option<JsFloat>,
pub packet_queue_length: Option<JsUInt>,
pub packet_reordering: Option<bool>,
}Fields
url_pattern: StringOnly matching requests will be affected by these conditions. Patterns use the URLPattern constructor string syntax (https://urlpattern.spec.whatwg.org/) and must be absolute. If the pattern is empty, all requests are matched (including p2p connections).
latency: JsFloatMinimum latency from request sent to response headers received (ms).
download_throughput: JsFloatMaximal aggregated download throughput (bytes/sec). -1 disables download throttling.
upload_throughput: JsFloatMaximal aggregated upload throughput (bytes/sec). -1 disables upload throttling.
connection_type: Option<ConnectionType>Connection type if known.
packet_loss: Option<JsFloat>WebRTC packet loss (percent, 0-100). 0 disables packet loss emulation, 100 drops all the packets.
packet_queue_length: Option<JsUInt>WebRTC packet queue length (packet). 0 removes any queue length limitations.
packet_reordering: Option<bool>WebRTC packetReordering feature.