pub struct RefreshEventDetailsBuilder { /* private fields */ }Expand description
Builder for RefreshEventDetails.
Implementations
Sourceimpl RefreshEventDetailsBuilder
impl RefreshEventDetailsBuilder
Sourcepub fn refresh_result<VALUE: Into<RefreshEventDetailsRefreshResult>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn refresh_result<VALUE: Into<RefreshEventDetailsRefreshResult>>( &mut self, value: VALUE, ) -> &mut Self
The result of a refresh.
Sourcepub fn fetch_result<VALUE: Into<DeviceBoundSessionFetchResult>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn fetch_result<VALUE: Into<DeviceBoundSessionFetchResult>>( &mut self, value: VALUE, ) -> &mut Self
If there was a fetch attempt, the result of that.
Sourcepub fn new_session<VALUE: Into<DeviceBoundSession>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn new_session<VALUE: Into<DeviceBoundSession>>( &mut self, value: VALUE, ) -> &mut Self
The session display if there was a newly created session. This is populated for any refresh event that modifies the session config.
Sourcepub fn was_fully_proactive_refresh<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn was_fully_proactive_refresh<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
See comments on net::device_bound_sessions::RefreshEventResult::was_fully_proactive_refresh.
Sourcepub fn build(
&self,
) -> Result<RefreshEventDetails, RefreshEventDetailsBuilderError>
pub fn build( &self, ) -> Result<RefreshEventDetails, RefreshEventDetailsBuilderError>