ReportingApiReportBuilder

Struct ReportingApiReportBuilder 

pub struct ReportingApiReportBuilder { /* private fields */ }
Builder for ReportingApiReport.

Implementations

Source

impl ReportingApiReportBuilder

pub fn id<VALUE: Into<ReportId>>(&mut self, value: VALUE) -> &mut Self

pub fn initiator_url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

The URL of the document that triggered the report.

pub fn destination<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

The name of the endpoint group that should be used to deliver the report.

pub fn type<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

The type of the report (specifies the set of data that is contained in the report body).

pub fn timestamp<VALUE: Into<TimeSinceEpoch>>( &mut self, value: VALUE, ) -> &mut Self

When the report was generated.

pub fn depth<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self

How many uploads deep the related request was.

pub fn completed_attempts<VALUE: Into<JsUInt>>( &mut self, value: VALUE, ) -> &mut Self

The number of delivery attempts made so far, not including an active attempt.

pub fn body<VALUE: Into<Json>>(&mut self, value: VALUE) -> &mut Self

pub fn status<VALUE: Into<ReportStatus>>(&mut self, value: VALUE) -> &mut Self

pub fn build( &self, ) -> Result<ReportingApiReport, ReportingApiReportBuilderError>

Builds a new ReportingApiReport.

Errors

If a required field has not been initialized.