pub struct ResourceTiming {Show 21 fields
pub request_time: JsFloat,
pub proxy_start: JsFloat,
pub proxy_end: JsFloat,
pub dns_start: JsFloat,
pub dns_end: JsFloat,
pub connect_start: JsFloat,
pub connect_end: JsFloat,
pub ssl_start: JsFloat,
pub ssl_end: JsFloat,
pub worker_start: JsFloat,
pub worker_ready: JsFloat,
pub worker_fetch_start: JsFloat,
pub worker_respond_with_settled: JsFloat,
pub worker_router_evaluation_start: Option<JsFloat>,
pub worker_cache_lookup_start: Option<JsFloat>,
pub send_start: JsFloat,
pub send_end: JsFloat,
pub push_start: JsFloat,
pub push_end: JsFloat,
pub receive_headers_start: JsFloat,
pub receive_headers_end: JsFloat,
}Expand description
Timing information for the request.
Fields
request_time: JsFloatTiming’s requestTime is a baseline in seconds, while the other numbers are ticks in milliseconds relatively to this requestTime.
proxy_start: JsFloatStarted resolving proxy.
proxy_end: JsFloatFinished resolving proxy.
dns_start: JsFloatStarted DNS address resolve.
dns_end: JsFloatFinished DNS address resolve.
connect_start: JsFloatStarted connecting to the remote host.
connect_end: JsFloatConnected to the remote host.
ssl_start: JsFloatStarted SSL handshake.
ssl_end: JsFloatFinished SSL handshake.
worker_start: JsFloatStarted running ServiceWorker.
worker_ready: JsFloatFinished Starting ServiceWorker.
worker_fetch_start: JsFloatStarted fetch event.
worker_respond_with_settled: JsFloatSettled fetch event respondWith promise.
worker_router_evaluation_start: Option<JsFloat>Started ServiceWorker static routing source evaluation.
worker_cache_lookup_start: Option<JsFloat>Started cache lookup when the source was evaluated to cache.
send_start: JsFloatStarted sending request.
send_end: JsFloatFinished sending request.
push_start: JsFloatTime the server started pushing request.
push_end: JsFloatTime the server finished pushing request.
receive_headers_start: JsFloatStarted receiving response headers.
receive_headers_end: JsFloatFinished receiving response headers.