pub struct ResourceTimingBuilder { /* private fields */ }Expand description
Builder for ResourceTiming.
Implementations
Sourceimpl ResourceTimingBuilder
impl ResourceTimingBuilder
Sourcepub fn request_time<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn request_time<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Timing’s requestTime is a baseline in seconds, while the other numbers are ticks in milliseconds relatively to this requestTime.
Sourcepub fn proxy_start<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn proxy_start<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Started resolving proxy.
Sourcepub fn proxy_end<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn proxy_end<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Finished resolving proxy.
Sourcepub fn dns_start<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn dns_start<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Started DNS address resolve.
Sourcepub fn dns_end<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn dns_end<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Finished DNS address resolve.
Sourcepub fn connect_start<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn connect_start<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Started connecting to the remote host.
Sourcepub fn connect_end<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn connect_end<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Connected to the remote host.
Sourcepub fn ssl_start<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn ssl_start<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Started SSL handshake.
Sourcepub fn ssl_end<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn ssl_end<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Finished SSL handshake.
Sourcepub fn worker_start<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn worker_start<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Started running ServiceWorker.
Sourcepub fn worker_ready<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn worker_ready<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Finished Starting ServiceWorker.
Sourcepub fn worker_fetch_start<VALUE: Into<JsFloat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn worker_fetch_start<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self
Started fetch event.
Sourcepub fn worker_respond_with_settled<VALUE: Into<JsFloat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn worker_respond_with_settled<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self
Settled fetch event respondWith promise.
Sourcepub fn worker_router_evaluation_start<VALUE: Into<JsFloat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn worker_router_evaluation_start<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self
Started ServiceWorker static routing source evaluation.
Sourcepub fn worker_cache_lookup_start<VALUE: Into<JsFloat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn worker_cache_lookup_start<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self
Started cache lookup when the source was evaluated to cache.
Sourcepub fn send_start<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn send_start<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Started sending request.
Sourcepub fn send_end<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn send_end<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Finished sending request.
Sourcepub fn push_start<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn push_start<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Time the server started pushing request.
Sourcepub fn push_end<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn push_end<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Time the server finished pushing request.
Sourcepub fn receive_headers_start<VALUE: Into<JsFloat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn receive_headers_start<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self
Started receiving response headers.
Sourcepub fn receive_headers_end<VALUE: Into<JsFloat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn receive_headers_end<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self
Finished receiving response headers.
Sourcepub fn build(&self) -> Result<ResourceTiming, ResourceTimingBuilderError>
pub fn build(&self) -> Result<ResourceTiming, ResourceTimingBuilderError>