pub struct SecurityDetailsBuilder { /* private fields */ }Expand description
Builder for SecurityDetails.
Implementations
Sourceimpl SecurityDetailsBuilder
impl SecurityDetailsBuilder
Sourcepub fn protocol<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn protocol<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Protocol name (e.g. “TLS 1.2” or “QUIC”).
Sourcepub fn key_exchange<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn key_exchange<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Key Exchange used by the connection, or the empty string if not applicable.
Sourcepub fn key_exchange_group<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn key_exchange_group<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
(EC)DH group used by the connection, if applicable.
Sourcepub fn mac<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn mac<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
TLS MAC. Note that AEAD ciphers do not have separate MACs.
Sourcepub fn certificate_id<VALUE: Into<CertificateId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn certificate_id<VALUE: Into<CertificateId>>( &mut self, value: VALUE, ) -> &mut Self
Certificate ID value.
Sourcepub fn subject_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn subject_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Certificate subject name.
Sourcepub fn san_list<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
pub fn san_list<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
Subject Alternative Name (SAN) DNS names and IP addresses.
Sourcepub fn issuer<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn issuer<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Name of the issuing CA.
Sourcepub fn valid_from<VALUE: Into<TimeSinceEpoch>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn valid_from<VALUE: Into<TimeSinceEpoch>>( &mut self, value: VALUE, ) -> &mut Self
Certificate valid from date.
Sourcepub fn valid_to<VALUE: Into<TimeSinceEpoch>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn valid_to<VALUE: Into<TimeSinceEpoch>>( &mut self, value: VALUE, ) -> &mut Self
Certificate valid to (expiration) date
Sourcepub fn signed_certificate_timestamp_list<VALUE: Into<Vec<SignedCertificateTimestamp>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn signed_certificate_timestamp_list<VALUE: Into<Vec<SignedCertificateTimestamp>>>( &mut self, value: VALUE, ) -> &mut Self
List of signed certificate timestamps (SCTs).
Sourcepub fn certificate_transparency_compliance<VALUE: Into<CertificateTransparencyCompliance>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn certificate_transparency_compliance<VALUE: Into<CertificateTransparencyCompliance>>( &mut self, value: VALUE, ) -> &mut Self
Whether the request complied with Certificate Transparency policy
Sourcepub fn server_signature_algorithm<VALUE: Into<JsUInt>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn server_signature_algorithm<VALUE: Into<JsUInt>>( &mut self, value: VALUE, ) -> &mut Self
The signature algorithm used by the server in the TLS server signature, represented as a TLS SignatureScheme code point. Omitted if not applicable or not known.
Sourcepub fn encrypted_client_hello<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn encrypted_client_hello<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Whether the connection used Encrypted ClientHello
Sourcepub fn build(&self) -> Result<SecurityDetails, SecurityDetailsBuilderError>
pub fn build(&self) -> Result<SecurityDetails, SecurityDetailsBuilderError>