pub struct ServiceWorkerRouterInfoBuilder { /* private fields */ }Expand description
Builder for ServiceWorkerRouterInfo.
Implementations
Sourceimpl ServiceWorkerRouterInfoBuilder
impl ServiceWorkerRouterInfoBuilder
Sourcepub fn rule_id_matched<VALUE: Into<JsUInt>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn rule_id_matched<VALUE: Into<JsUInt>>( &mut self, value: VALUE, ) -> &mut Self
ID of the rule matched. If there is a matched rule, this field will be set, otherwiser no value will be set.
Sourcepub fn matched_source_type<VALUE: Into<ServiceWorkerRouterSource>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn matched_source_type<VALUE: Into<ServiceWorkerRouterSource>>( &mut self, value: VALUE, ) -> &mut Self
The router source of the matched rule. If there is a matched rule, this field will be set, otherwise no value will be set.
Sourcepub fn actual_source_type<VALUE: Into<ServiceWorkerRouterSource>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn actual_source_type<VALUE: Into<ServiceWorkerRouterSource>>( &mut self, value: VALUE, ) -> &mut Self
The actual router source used.
Sourcepub fn build(
&self,
) -> Result<ServiceWorkerRouterInfo, ServiceWorkerRouterInfoBuilderError>
pub fn build( &self, ) -> Result<ServiceWorkerRouterInfo, ServiceWorkerRouterInfoBuilderError>