pub struct SetBlockedURLsBuilder { /* private fields */ }Expand description
Builder for SetBlockedURLs.
Implementations
Sourceimpl SetBlockedURLsBuilder
impl SetBlockedURLsBuilder
Sourcepub fn url_patterns<VALUE: Into<Vec<BlockPattern>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn url_patterns<VALUE: Into<Vec<BlockPattern>>>( &mut self, value: VALUE, ) -> &mut Self
Patterns to match in the order in which they are given. These patterns
also take precedence over any wildcard patterns defined in urls.
Sourcepub fn urls<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
pub fn urls<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
URL patterns to block. Wildcards (‘*’) are allowed.
Sourcepub fn build(&self) -> Result<SetBlockedURLs, SetBlockedURLsBuilderError>
pub fn build(&self) -> Result<SetBlockedURLs, SetBlockedURLsBuilderError>