pub struct SetRequestInterception {
pub patterns: Vec<RequestPattern>,
}๐Deprecated
Sets the requests to intercept that match the provided patterns and optionally resource types. Deprecated, please use Fetch.enable instead.
Fields
patterns: Vec<RequestPattern>๐Deprecated
Requests matching any of these patterns will be forwarded and wait for the corresponding continueInterceptedRequest call.