pub struct TrustTokenParamsBuilder { /* private fields */ }Expand description
Builder for TrustTokenParams.
Implementations
Sourceimpl TrustTokenParamsBuilder
impl TrustTokenParamsBuilder
pub fn operation<VALUE: Into<TrustTokenOperationType>>( &mut self, value: VALUE, ) -> &mut Self
Sourcepub fn refresh_policy<VALUE: Into<TrustTokenParamsRefreshPolicy>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn refresh_policy<VALUE: Into<TrustTokenParamsRefreshPolicy>>( &mut self, value: VALUE, ) -> &mut Self
Only set for “token-redemption” operation and determine whether to request a fresh SRR or use a still valid cached SRR.
Sourcepub fn issuers<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
pub fn issuers<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
Origins of issuers from whom to request tokens or redemption records.
Sourcepub fn build(&self) -> Result<TrustTokenParams, TrustTokenParamsBuilderError>
pub fn build(&self) -> Result<TrustTokenParams, TrustTokenParamsBuilderError>