pub struct FlexItemHighlightConfig {
pub base_size_box: Option<BoxStyle>,
pub base_size_border: Option<LineStyle>,
pub flexibility_arrow: Option<LineStyle>,
}Expand description
Configuration data for the highlighting of Flex item elements.
Fields
base_size_box: Option<BoxStyle>Style of the box representing the item’s base size
base_size_border: Option<LineStyle>Style of the border around the box representing the item’s base size
flexibility_arrow: Option<LineStyle>Style of the arrow representing if the item grew or shrank