pub struct FlexItemHighlightConfigBuilder { /* private fields */ }Expand description
Builder for FlexItemHighlightConfig.
Implementations
Sourceimpl FlexItemHighlightConfigBuilder
impl FlexItemHighlightConfigBuilder
Sourcepub fn base_size_box<VALUE: Into<BoxStyle>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn base_size_box<VALUE: Into<BoxStyle>>( &mut self, value: VALUE, ) -> &mut Self
Style of the box representing the item’s base size
Sourcepub fn base_size_border<VALUE: Into<LineStyle>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn base_size_border<VALUE: Into<LineStyle>>( &mut self, value: VALUE, ) -> &mut Self
Style of the border around the box representing the item’s base size
Sourcepub fn flexibility_arrow<VALUE: Into<LineStyle>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn flexibility_arrow<VALUE: Into<LineStyle>>( &mut self, value: VALUE, ) -> &mut Self
Style of the arrow representing if the item grew or shrank
Sourcepub fn build(
&self,
) -> Result<FlexItemHighlightConfig, FlexItemHighlightConfigBuilderError>
pub fn build( &self, ) -> Result<FlexItemHighlightConfig, FlexItemHighlightConfigBuilderError>