pub struct HighlightConfigBuilder { /* private fields */ }Expand description
Builder for HighlightConfig.
Implementations
Sourceimpl HighlightConfigBuilder
impl HighlightConfigBuilder
Sourcepub fn show_info<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn show_info<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether the node info tooltip should be shown (default: false).
Sourcepub fn show_styles<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn show_styles<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether the node styles in the tooltip (default: false).
Sourcepub fn show_rulers<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn show_rulers<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether the rulers should be shown (default: false).
Sourcepub fn show_accessibility_info<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn show_accessibility_info<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Whether the a11y info should be shown (default: true).
Sourcepub fn show_extension_lines<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn show_extension_lines<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Whether the extension lines from node to the rulers should be shown (default: false).
Sourcepub fn content_color<VALUE: Into<Rgba>>(&mut self, value: VALUE) -> &mut Self
pub fn content_color<VALUE: Into<Rgba>>(&mut self, value: VALUE) -> &mut Self
The content box highlight fill color (default: transparent).
Sourcepub fn padding_color<VALUE: Into<Rgba>>(&mut self, value: VALUE) -> &mut Self
pub fn padding_color<VALUE: Into<Rgba>>(&mut self, value: VALUE) -> &mut Self
The padding highlight fill color (default: transparent).
Sourcepub fn border_color<VALUE: Into<Rgba>>(&mut self, value: VALUE) -> &mut Self
pub fn border_color<VALUE: Into<Rgba>>(&mut self, value: VALUE) -> &mut Self
The border highlight fill color (default: transparent).
Sourcepub fn margin_color<VALUE: Into<Rgba>>(&mut self, value: VALUE) -> &mut Self
pub fn margin_color<VALUE: Into<Rgba>>(&mut self, value: VALUE) -> &mut Self
The margin highlight fill color (default: transparent).
Sourcepub fn event_target_color<VALUE: Into<Rgba>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn event_target_color<VALUE: Into<Rgba>>( &mut self, value: VALUE, ) -> &mut Self
The event target element highlight fill color (default: transparent).
Sourcepub fn shape_color<VALUE: Into<Rgba>>(&mut self, value: VALUE) -> &mut Self
pub fn shape_color<VALUE: Into<Rgba>>(&mut self, value: VALUE) -> &mut Self
The shape outside fill color (default: transparent).
Sourcepub fn shape_margin_color<VALUE: Into<Rgba>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn shape_margin_color<VALUE: Into<Rgba>>( &mut self, value: VALUE, ) -> &mut Self
The shape margin fill color (default: transparent).
Sourcepub fn css_grid_color<VALUE: Into<Rgba>>(&mut self, value: VALUE) -> &mut Self
pub fn css_grid_color<VALUE: Into<Rgba>>(&mut self, value: VALUE) -> &mut Self
The grid layout color (default: transparent).
Sourcepub fn color_format<VALUE: Into<ColorFormat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn color_format<VALUE: Into<ColorFormat>>( &mut self, value: VALUE, ) -> &mut Self
The color format used to format color styles (default: hex).
Sourcepub fn grid_highlight_config<VALUE: Into<GridHighlightConfig>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn grid_highlight_config<VALUE: Into<GridHighlightConfig>>( &mut self, value: VALUE, ) -> &mut Self
The grid layout highlight configuration (default: all transparent).
Sourcepub fn flex_container_highlight_config<VALUE: Into<FlexContainerHighlightConfig>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn flex_container_highlight_config<VALUE: Into<FlexContainerHighlightConfig>>( &mut self, value: VALUE, ) -> &mut Self
The flex container highlight configuration (default: all transparent).
Sourcepub fn flex_item_highlight_config<VALUE: Into<FlexItemHighlightConfig>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn flex_item_highlight_config<VALUE: Into<FlexItemHighlightConfig>>( &mut self, value: VALUE, ) -> &mut Self
The flex item highlight configuration (default: all transparent).
Sourcepub fn contrast_algorithm<VALUE: Into<ContrastAlgorithm>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn contrast_algorithm<VALUE: Into<ContrastAlgorithm>>( &mut self, value: VALUE, ) -> &mut Self
The contrast algorithm to use for the contrast ratio (default: aa).
Sourcepub fn container_query_container_highlight_config<VALUE: Into<ContainerQueryContainerHighlightConfig>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn container_query_container_highlight_config<VALUE: Into<ContainerQueryContainerHighlightConfig>>( &mut self, value: VALUE, ) -> &mut Self
The container query container highlight configuration (default: all transparent).
Sourcepub fn build(&self) -> Result<HighlightConfig, HighlightConfigBuilderError>
pub fn build(&self) -> Result<HighlightConfig, HighlightConfigBuilderError>