pub struct HighlightSourceOrder {
pub source_order_config: SourceOrderConfig,
pub node_id: Option<NodeId>,
pub backend_node_id: Option<BackendNodeId>,
pub object_id: Option<RemoteObjectId>,
}Expand description
Highlights the source order of the children of the DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified.
Fields
source_order_config: SourceOrderConfigA descriptor for the appearance of the overlay drawing.
node_id: Option<NodeId>Identifier of the node to highlight.
backend_node_id: Option<BackendNodeId>Identifier of the backend node to highlight.
object_id: Option<RemoteObjectId>JavaScript object id of the node to be highlighted.