pub struct HighlightSourceOrderBuilder { /* private fields */ }Expand description
Builder for HighlightSourceOrder.
Implementations
Sourceimpl HighlightSourceOrderBuilder
impl HighlightSourceOrderBuilder
Sourcepub fn source_order_config<VALUE: Into<SourceOrderConfig>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn source_order_config<VALUE: Into<SourceOrderConfig>>( &mut self, value: VALUE, ) -> &mut Self
A descriptor for the appearance of the overlay drawing.
Sourcepub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
pub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
Identifier of the node to highlight.
Sourcepub fn backend_node_id<VALUE: Into<BackendNodeId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn backend_node_id<VALUE: Into<BackendNodeId>>( &mut self, value: VALUE, ) -> &mut Self
Identifier of the backend node to highlight.
Sourcepub fn object_id<VALUE: Into<RemoteObjectId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn object_id<VALUE: Into<RemoteObjectId>>( &mut self, value: VALUE, ) -> &mut Self
JavaScript object id of the node to be highlighted.
Sourcepub fn build(
&self,
) -> Result<HighlightSourceOrder, HighlightSourceOrderBuilderError>
pub fn build( &self, ) -> Result<HighlightSourceOrder, HighlightSourceOrderBuilderError>