pub struct BackForwardCacheNotUsedEventParamsBuilder { /* private fields */ }Expand description
Builder for BackForwardCacheNotUsedEventParams.
Implementations
Sourceimpl BackForwardCacheNotUsedEventParamsBuilder
impl BackForwardCacheNotUsedEventParamsBuilder
Sourcepub fn loader_id(&mut self, value: LoaderId) -> &mut Self
pub fn loader_id(&mut self, value: LoaderId) -> &mut Self
The loader id for the associated navigation.
Sourcepub fn not_restored_explanations(
&mut self,
value: Vec<BackForwardCacheNotRestoredExplanation>,
) -> &mut Self
pub fn not_restored_explanations( &mut self, value: Vec<BackForwardCacheNotRestoredExplanation>, ) -> &mut Self
Array of reasons why the page could not be cached. This must not be empty.
Sourcepub fn not_restored_explanations_tree(
&mut self,
value: Option<BackForwardCacheNotRestoredExplanationTree>,
) -> &mut Self
pub fn not_restored_explanations_tree( &mut self, value: Option<BackForwardCacheNotRestoredExplanationTree>, ) -> &mut Self
Tree structure of reasons why the page could not be cached for each frame.
Sourcepub fn build(
&self,
) -> Result<BackForwardCacheNotUsedEventParams, BackForwardCacheNotUsedEventParamsBuilderError>
pub fn build( &self, ) -> Result<BackForwardCacheNotUsedEventParams, BackForwardCacheNotUsedEventParamsBuilderError>
Builds a new BackForwardCacheNotUsedEventParams.
Errors
If a required field has not been initialized.