pub struct FrameStartedNavigatingEventParamsBuilder { /* private fields */ }Expand description
Builder for FrameStartedNavigatingEventParams.
Implementations
Sourcepub fn frame_id(&mut self, value: FrameId) -> &mut Self
pub fn frame_id(&mut self, value: FrameId) -> &mut Self
ID of the frame that is being navigated.
Sourcepub fn url(&mut self, value: String) -> &mut Self
pub fn url(&mut self, value: String) -> &mut Self
The URL the navigation started with. The final URL can be different.
Sourcepub fn loader_id(&mut self, value: LoaderId) -> &mut Self
pub fn loader_id(&mut self, value: LoaderId) -> &mut Self
Loader identifier. Even though it is present in case of same-document navigation, the previously committed loaderId would not change unless the navigation changes from a same-document to a cross-document navigation.
Sourcepub fn build(
&self,
) -> Result<FrameStartedNavigatingEventParams, FrameStartedNavigatingEventParamsBuilderError>
pub fn build( &self, ) -> Result<FrameStartedNavigatingEventParams, FrameStartedNavigatingEventParamsBuilderError>
Builds a new FrameStartedNavigatingEventParams.
Errors
If a required field has not been initialized.