JavascriptDialogOpeningEventParamsBuilder

Struct JavascriptDialogOpeningEventParamsBuilder 

pub struct JavascriptDialogOpeningEventParamsBuilder { /* private fields */ }
Implementations

Source

impl JavascriptDialogOpeningEventParamsBuilder

pub fn url(&mut self, value: String) -> &mut Self

Frame url.

pub fn frame_id(&mut self, value: FrameId) -> &mut Self

Frame id.

pub fn message(&mut self, value: String) -> &mut Self

Message that will be displayed by the dialog.

pub fn type(&mut self, value: DialogType) -> &mut Self

Dialog type.

pub fn has_browser_handler(&mut self, value: bool) -> &mut Self

True iff browser is capable showing or acting on the given dialog. When browser has no dialog handler for given target, calling alert while Page domain is engaged will stall the page execution. Execution can be resumed via calling Page.handleJavaScriptDialog.

pub fn default_prompt(&mut self, value: Option<String>) -> &mut Self

Default dialog prompt.

pub fn build( &self, ) -> Result<JavascriptDialogOpeningEventParams, JavascriptDialogOpeningEventParamsBuilderError>

Builds a new JavascriptDialogOpeningEventParams.

Errors

If a required field has not been initialized.