pub struct AdScriptAncestryBuilder { /* private fields */ }Expand description
Builder for AdScriptAncestry.
Implementations
Sourceimpl AdScriptAncestryBuilder
impl AdScriptAncestryBuilder
Sourcepub fn ancestry_chain<VALUE: Into<Vec<AdScriptId>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn ancestry_chain<VALUE: Into<Vec<AdScriptId>>>( &mut self, value: VALUE, ) -> &mut Self
A chain of AdScriptIds representing the ancestry of an ad script that
led to the creation of a frame. The chain is ordered from the script
itself (lower level) up to its root ancestor that was flagged by
filterlist.
Sourcepub fn root_script_filterlist_rule<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn root_script_filterlist_rule<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
The filterlist rule that caused the root (last) script in
ancestryChain to be ad-tagged. Only populated if the rule is
available.
Sourcepub fn build(&self) -> Result<AdScriptAncestry, AdScriptAncestryBuilderError>
pub fn build(&self) -> Result<AdScriptAncestry, AdScriptAncestryBuilderError>