pub struct AddScriptToEvaluateOnNewDocumentBuilder { /* private fields */ }Expand description
Builder for AddScriptToEvaluateOnNewDocument.
Implementations
Sourceimpl AddScriptToEvaluateOnNewDocumentBuilder
impl AddScriptToEvaluateOnNewDocumentBuilder
pub fn source<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn world_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn world_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
If specified, creates an isolated world with the given name and evaluates given script in it. This world name will be used as the ExecutionContextDescription::name when the corresponding event is emitted.
Sourcepub fn include_command_line_api<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn include_command_line_api<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Specifies whether command line API should be available to the script, defaults to false.
Sourcepub fn run_immediately<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn run_immediately<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If true, runs the script immediately on existing execution contexts or worlds. Default: false.
Sourcepub fn build(
&self,
) -> Result<AddScriptToEvaluateOnNewDocument, AddScriptToEvaluateOnNewDocumentBuilderError>
pub fn build( &self, ) -> Result<AddScriptToEvaluateOnNewDocument, AddScriptToEvaluateOnNewDocumentBuilderError>
Builds a new AddScriptToEvaluateOnNewDocument.
Errors
If a required field has not been initialized.