pub struct CaptureScreenshotBuilder { /* private fields */ }Expand description
Builder for CaptureScreenshot.
Implementations
Sourceimpl CaptureScreenshotBuilder
impl CaptureScreenshotBuilder
Sourcepub fn format<VALUE: Into<CaptureScreenshotFormatOption>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn format<VALUE: Into<CaptureScreenshotFormatOption>>( &mut self, value: VALUE, ) -> &mut Self
Image compression format (defaults to png).
Sourcepub fn quality<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn quality<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Compression quality from range [0..100] (jpeg only).
Sourcepub fn clip<VALUE: Into<Viewport>>(&mut self, value: VALUE) -> &mut Self
pub fn clip<VALUE: Into<Viewport>>(&mut self, value: VALUE) -> &mut Self
Capture the screenshot of a given region only.
Sourcepub fn from_surface<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn from_surface<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Capture the screenshot from the surface, rather than the view. Defaults to true.
Sourcepub fn capture_beyond_viewport<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn capture_beyond_viewport<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Capture the screenshot beyond the viewport. Defaults to false.
Sourcepub fn optimize_for_speed<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn optimize_for_speed<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Optimize image encoding for speed, not for resulting size (defaults to false)
Sourcepub fn build(&self) -> Result<CaptureScreenshot, CaptureScreenshotBuilderError>
pub fn build(&self) -> Result<CaptureScreenshot, CaptureScreenshotBuilderError>