pub struct CompilationCacheParamsBuilder { /* private fields */ }Expand description
Builder for CompilationCacheParams.
Implementations
Sourceimpl CompilationCacheParamsBuilder
impl CompilationCacheParamsBuilder
Sourcepub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The URL of the script to produce a compilation cache entry for.
Sourcepub fn eager<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn eager<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
A hint to the backend whether eager compilation is recommended. (the actual compilation mode used is upon backend discretion).
Sourcepub fn build(
&self,
) -> Result<CompilationCacheParams, CompilationCacheParamsBuilderError>
pub fn build( &self, ) -> Result<CompilationCacheParams, CompilationCacheParamsBuilderError>