pub struct CreateIsolatedWorldBuilder { /* private fields */ }Expand description
Builder for CreateIsolatedWorld.
Implementations
Sourceimpl CreateIsolatedWorldBuilder
impl CreateIsolatedWorldBuilder
Sourcepub fn frame_id<VALUE: Into<FrameId>>(&mut self, value: VALUE) -> &mut Self
pub fn frame_id<VALUE: Into<FrameId>>(&mut self, value: VALUE) -> &mut Self
Id of the frame in which the isolated world should be created.
Sourcepub fn world_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn world_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
An optional name which is reported in the Execution Context.
Sourcepub fn grant_univeral_access<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn grant_univeral_access<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Whether or not universal access should be granted to the isolated world. This is a powerful option, use with caution.
Sourcepub fn build(
&self,
) -> Result<CreateIsolatedWorld, CreateIsolatedWorldBuilderError>
pub fn build( &self, ) -> Result<CreateIsolatedWorld, CreateIsolatedWorldBuilderError>