pub struct FileHandlerBuilder { /* private fields */ }Expand description
Builder for FileHandler.
Implementations
Sourceimpl FileHandlerBuilder
impl FileHandlerBuilder
pub fn action<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn icons<VALUE: Into<Vec<ImageResource>>>( &mut self, value: VALUE, ) -> &mut Self
Sourcepub fn accepts<VALUE: Into<Vec<FileFilter>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn accepts<VALUE: Into<Vec<FileFilter>>>( &mut self, value: VALUE, ) -> &mut Self
Mimic a map, name is the key, accepts is the value.
Sourcepub fn launch_type<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn launch_type<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Won’t repeat the enums, using string for easy comparison. Same as the other enums below.
Sourcepub fn build(&self) -> Result<FileHandler, FileHandlerBuilderError>
pub fn build(&self) -> Result<FileHandler, FileHandlerBuilderError>