FrameBuilder

Struct FrameBuilder 

pub struct FrameBuilder { /* private fields */ }
Builder for Frame.

Implementations

Source

impl FrameBuilder

pub fn id<VALUE: Into<FrameId>>(&mut self, value: VALUE) -> &mut Self

Frame unique identifier.

pub fn parent_id<VALUE: Into<FrameId>>(&mut self, value: VALUE) -> &mut Self

Parent frame identifier.

pub fn loader_id<VALUE: Into<LoaderId>>(&mut self, value: VALUE) -> &mut Self

Identifier of the loader associated with this frame.

pub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Frame’s name as specified in the tag.

pub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Frame document’s URL without fragment.

pub fn url_fragment<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Frame document’s URL fragment including the ‘#’.

pub fn domain_and_registry<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self

Frame document’s registered domain, taking the public suffixes list into account. Extracted from the Frame’s url. Example URLs: http://www.google.com/file.html -> “google.com” http://a.b.co.uk/file.html -> “b.co.uk”

pub fn security_origin<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self

Frame document’s security origin.

pub fn security_origin_details<VALUE: Into<SecurityOriginDetails>>( &mut self, value: VALUE, ) -> &mut Self

Additional details about the frame document’s security origin.

pub fn mime_type<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Frame document’s mimeType as determined by the browser.

pub fn unreachable_url<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self

If the frame failed to load, this contains the URL that could not be loaded. Note that unlike url above, this URL may contain a fragment.

pub fn ad_frame_status<VALUE: Into<AdFrameStatus>>( &mut self, value: VALUE, ) -> &mut Self

Indicates whether this frame was tagged as an ad and why.

pub fn secure_context_type<VALUE: Into<SecureContextType>>( &mut self, value: VALUE, ) -> &mut Self

Indicates whether the main document is a secure context and explains why that is the case.

pub fn cross_origin_isolated_context_type<VALUE: Into<CrossOriginIsolatedContextType>>( &mut self, value: VALUE, ) -> &mut Self

Indicates whether this is a cross origin isolated context.

pub fn gated_api_features<VALUE: Into<Vec<GatedApiFeatures>>>( &mut self, value: VALUE, ) -> &mut Self

Indicated which gated APIs / features are available.

pub fn build(&self) -> Result<Frame, FrameBuilderError>

Builds a new Frame.

Errors

If a required field has not been initialized.