pub struct GetAnnotatedPageContent {
pub include_actionable_information: Option<bool>,
}Expand description
Get the annotated page content for the main frame. This is an experimental command that is subject to change.
Fields
include_actionable_information: Option<bool>Whether to include actionable information. Defaults to true.