GetAppManifestReturnObject

Struct GetAppManifestReturnObject 

pub struct GetAppManifestReturnObject {
    pub url: String,
    pub errors: Vec<AppManifestError>,
    pub data: Option<String>,
    pub parsed: Option<AppManifestParsedProperties>,
    pub manifest: WebAppManifest,
}
Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.

Fields

url: String

Manifest location.

errors: Vec<AppManifestError>data: Option<String>

Manifest content.

parsed: Option<AppManifestParsedProperties>
👎Deprecated

Parsed manifest properties. Deprecated, use manifest instead.

manifest: WebAppManifest