pub struct ProduceCompilationCache {
pub scripts: Vec<CompilationCacheParams>,
}Expand description
Requests backend to produce compilation cache for the specified scripts.
scripts are appended to the list of scripts for which the cache
would be produced. The list may be reset during page navigation.
When script with a matching URL is encountered, the cache is optionally
produced upon backend discretion, based on internal heuristics.
See also: Page.compilationCacheProduced.
Fields
scripts: Vec<CompilationCacheParams>Trait Implementations
Sourceimpl Clone for ProduceCompilationCache
impl Clone for ProduceCompilationCache
Sourcefn clone(&self) -> ProduceCompilationCache
fn clone(&self) -> ProduceCompilationCache
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProduceCompilationCache
impl Debug for ProduceCompilationCache
Sourceimpl<'de> Deserialize<'de> for ProduceCompilationCache
impl<'de> Deserialize<'de> for ProduceCompilationCache
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Method for ProduceCompilationCache
impl Method for ProduceCompilationCache
const NAME: &'static str = "Page.produceCompilationCache"
type ReturnObject = ProduceCompilationCacheReturnObject
fn to_method_call(self, call_id: CallId) -> MethodCall<Self>where
Self: Sized,
Sourceimpl PartialEq for ProduceCompilationCache
impl PartialEq for ProduceCompilationCache
Sourceimpl Serialize for ProduceCompilationCache
impl Serialize for ProduceCompilationCache
impl StructuralPartialEq for ProduceCompilationCache