pub struct ProduceCompilationCacheReturnObject(pub Option<Value>);Expand description
Requests backend to produce compilation cache for the specified scripts.
scripts are appended to the list of scripts for which the cache
would be produced. The list may be reset during page navigation.
When script with a matching URL is encountered, the cache is optionally
produced upon backend discretion, based on internal heuristics.
See also: Page.compilationCacheProduced.
Tuple Fields
0: Option<Value>Trait Implementations
Sourceimpl Clone for ProduceCompilationCacheReturnObject
impl Clone for ProduceCompilationCacheReturnObject
Sourcefn clone(&self) -> ProduceCompilationCacheReturnObject
fn clone(&self) -> ProduceCompilationCacheReturnObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ProduceCompilationCacheReturnObject
impl<'de> Deserialize<'de> for ProduceCompilationCacheReturnObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ProduceCompilationCacheReturnObject
impl PartialEq for ProduceCompilationCacheReturnObject
Sourcefn eq(&self, other: &ProduceCompilationCacheReturnObject) -> bool
fn eq(&self, other: &ProduceCompilationCacheReturnObject) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ProduceCompilationCacheReturnObject