pub struct Reload {
pub ignore_cache: Option<bool>,
pub script_to_evaluate_on_load: Option<String>,
pub loader_id: Option<LoaderId>,
}Expand description
Reloads given page optionally ignoring the cache.
Fields
ignore_cache: Option<bool>If true, browser cache is ignored (as if the user pressed Shift+refresh).
script_to_evaluate_on_load: Option<String>If set, the script will be injected into all frames of the inspected page after reload. Argument will be ignored if reloading dataURL origin.
loader_id: Option<LoaderId>If set, an error will be thrown if the target page’s main frame’s loader id does not match the provided id. This prevents accidentally reloading an unintended target in case there’s a racing navigation.