ReloadBuilder

Struct ReloadBuilder 

pub struct ReloadBuilder { /* private fields */ }
Builder for Reload.

Implementations

Source

impl ReloadBuilder

pub fn ignore_cache<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

If true, browser cache is ignored (as if the user pressed Shift+refresh).

pub fn script_to_evaluate_on_load<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self

If set, the script will be injected into all frames of the inspected page after reload. Argument will be ignored if reloading dataURL origin.

pub fn loader_id<VALUE: Into<LoaderId>>(&mut self, value: VALUE) -> &mut Self

If set, an error will be thrown if the target page’s main frame’s loader id does not match the provided id. This prevents accidentally reloading an unintended target in case there’s a racing navigation.

pub fn build(&self) -> Result<Reload, ReloadBuilderError>

Builds a new Reload.

Errors

If a required field has not been initialized.