pub struct SetDownloadBehaviorBuilder { /* private fields */ }Expand description
Builder for SetDownloadBehavior.
Implementations
Sourceimpl SetDownloadBehaviorBuilder
impl SetDownloadBehaviorBuilder
Sourcepub fn behavior<VALUE: Into<SetDownloadBehaviorBehaviorOption>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn behavior<VALUE: Into<SetDownloadBehaviorBehaviorOption>>( &mut self, value: VALUE, ) -> &mut Self
Whether to allow all or deny all download requests, or use default Chrome behavior if available (otherwise deny).
Sourcepub fn download_path<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn download_path<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The default path to save downloaded files to. This is required if behavior is set to ‘allow’
Sourcepub fn build(
&self,
) -> Result<SetDownloadBehavior, SetDownloadBehaviorBuilderError>
pub fn build( &self, ) -> Result<SetDownloadBehavior, SetDownloadBehaviorBuilderError>