pub struct SetInterceptFileChooserDialogBuilder { /* private fields */ }Expand description
Builder for SetInterceptFileChooserDialog.
Implementations
Sourceimpl SetInterceptFileChooserDialogBuilder
impl SetInterceptFileChooserDialogBuilder
pub fn enabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn cancel<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn cancel<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If true, cancels the dialog by emitting relevant events (if any) in addition to not showing it if the interception is enabled (default: false).
Sourcepub fn build(
&self,
) -> Result<SetInterceptFileChooserDialog, SetInterceptFileChooserDialogBuilderError>
pub fn build( &self, ) -> Result<SetInterceptFileChooserDialog, SetInterceptFileChooserDialogBuilderError>