Module performance

Module performance 

Modules

events

Structs

Disable
DisableReturnObject
Disable collecting and reporting metrics.
Enable
Enable collecting and reporting metrics.
EnableBuilder
Builder for Enable.
EnableReturnObject
Enable collecting and reporting metrics.
GetMetrics
GetMetricsReturnObject
Retrieve current values of run-time metrics.
GetMetricsReturnObjectBuilder
Builder for GetMetricsReturnObject.
Metric
Run-time execution metric.
MetricBuilder
Builder for Metric.
SetTimeDomainDeprecated
Sets time domain to use for collecting and reporting duration metrics. Note that this must be called before enabling metrics collection. Calling this method while metrics collection is enabled returns an error.
SetTimeDomainBuilder
Builder for SetTimeDomain.
SetTimeDomainReturnObjectDeprecated
Sets time domain to use for collecting and reporting duration metrics. Note that this must be called before enabling metrics collection. Calling this method while metrics collection is enabled returns an error.

Enums

EnableBuilderError
Error type for EnableBuilder
EnableTimeDomainOption
GetMetricsReturnObjectBuilderError
Error type for GetMetricsReturnObjectBuilder
MetricBuilderError
Error type for MetricBuilder
SetTimeDomainBuilderError
Error type for SetTimeDomainBuilder
SetTimeDomainTimeDomainOption