pub struct SetTimeDomain {
pub time_domain: SetTimeDomainTimeDomainOption,
}๐Deprecated
Sets time domain to use for collecting and reporting duration metrics. Note that this must be called before enabling metrics collection. Calling this method while metrics collection is enabled returns an error.
Fields
time_domain: SetTimeDomainTimeDomainOption๐Deprecated
Time domain