pub struct SetTimeDomainReturnObject(pub Option<Value>);๐Deprecated
Sets time domain to use for collecting and reporting duration metrics. Note that this must be called before enabling metrics collection. Calling this method while metrics collection is enabled returns an error.
Tuple Fields
0: Option<Value>๐Deprecated