Module preload

Module preload 

Modules

events

Structs

Disable
DisableReturnObject
Enable
EnableReturnObject
PreloadingAttemptKey
A key that identifies a preloading attempt.
PreloadingAttemptKeyBuilder
Builder for PreloadingAttemptKey.
PreloadingAttemptSource
Lists sources for a preloading attempt, specifically the ids of rule sets that had a speculation rule that triggered the attempt, and the BackendNodeIds of <a href> or <area href> elements that triggered the attempt (in the case of attempts triggered by a document rule). It is possible for multiple rule sets and links to trigger a single attempt.
PreloadingAttemptSourceBuilder
Builder for PreloadingAttemptSource.
PrerenderMismatchedHeaders
Information of headers to be displayed when the header mismatch occurred.
PrerenderMismatchedHeadersBuilder
Builder for PrerenderMismatchedHeaders.
RuleSet
Corresponds to SpeculationRuleSet
RuleSetBuilder
Builder for RuleSet.

Enums

PrefetchStatus
PreloadingAttemptKeyBuilderError
Error type for PreloadingAttemptKeyBuilder
PreloadingAttemptSourceBuilderError
Error type for PreloadingAttemptSourceBuilder
PreloadingStatus
PrerenderFinalStatus
PrerenderMismatchedHeadersBuilderError
Error type for PrerenderMismatchedHeadersBuilder
RuleSetBuilderError
Error type for RuleSetBuilder
RuleSetErrorType
SpeculationAction
SpeculationTargetHint

Type Aliases

PreloadPipelineId
RuleSetId