PrerenderStatusUpdatedEventParamsBuilder

Struct PrerenderStatusUpdatedEventParamsBuilder 

pub struct PrerenderStatusUpdatedEventParamsBuilder { /* private fields */ }
Implementations

Source

impl PrerenderStatusUpdatedEventParamsBuilder

pub fn key(&mut self, value: PreloadingAttemptKey) -> &mut Self

pub fn pipeline_id(&mut self, value: PreloadPipelineId) -> &mut Self

pub fn status(&mut self, value: PreloadingStatus) -> &mut Self

pub fn prerender_status( &mut self, value: Option<PrerenderFinalStatus>, ) -> &mut Self

pub fn disallowed_mojo_interface(&mut self, value: Option<String>) -> &mut Self

This is used to give users more information about the name of Mojo interface that is incompatible with prerender and has caused the cancellation of the attempt.

pub fn mismatched_headers( &mut self, value: Option<Vec<PrerenderMismatchedHeaders>>, ) -> &mut Self

pub fn build( &self, ) -> Result<PrerenderStatusUpdatedEventParams, PrerenderStatusUpdatedEventParamsBuilderError>

Builds a new PrerenderStatusUpdatedEventParams.

Errors

If a required field has not been initialized.