pub struct ProfileNode {
pub id: JsUInt,
pub call_frame: CallFrame,
pub hit_count: Option<JsUInt>,
pub children: Option<Vec<JsUInt>>,
pub deopt_reason: Option<String>,
pub position_ticks: Option<Vec<PositionTickInfo>>,
}Expand description
Profile node. Holds callsite information, execution statistics and child nodes.
Fields
id: JsUIntUnique id of the node.
call_frame: CallFrameFunction location.
hit_count: Option<JsUInt>Number of samples where this node was on top of the call stack.
children: Option<Vec<JsUInt>>Child node ids.
deopt_reason: Option<String>The reason of being not optimized. The function may be deoptimized or marked as don’t optimize.
position_ticks: Option<Vec<PositionTickInfo>>An array of source position ticks.