pub struct ProfileNodeBuilder { /* private fields */ }Expand description
Builder for ProfileNode.
Implementations
Sourceimpl ProfileNodeBuilder
impl ProfileNodeBuilder
Sourcepub fn call_frame<VALUE: Into<CallFrame>>(&mut self, value: VALUE) -> &mut Self
pub fn call_frame<VALUE: Into<CallFrame>>(&mut self, value: VALUE) -> &mut Self
Function location.
Sourcepub fn hit_count<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn hit_count<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Number of samples where this node was on top of the call stack.
Sourcepub fn children<VALUE: Into<Vec<JsUInt>>>(&mut self, value: VALUE) -> &mut Self
pub fn children<VALUE: Into<Vec<JsUInt>>>(&mut self, value: VALUE) -> &mut Self
Child node ids.
Sourcepub fn deopt_reason<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn deopt_reason<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The reason of being not optimized. The function may be deoptimized or marked as don’t optimize.
Sourcepub fn position_ticks<VALUE: Into<Vec<PositionTickInfo>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn position_ticks<VALUE: Into<Vec<PositionTickInfo>>>( &mut self, value: VALUE, ) -> &mut Self
An array of source position ticks.
Sourcepub fn build(&self) -> Result<ProfileNode, ProfileNodeBuilderError>
pub fn build(&self) -> Result<ProfileNode, ProfileNodeBuilderError>