pub struct StartPreciseCoverageReturnObject {
pub timestamp: JsFloat,
}Expand description
Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters.
Fields
timestamp: JsFloatMonotonically increasing time (in seconds) when the coverage update was taken in the backend.