pub struct TakePreciseCoverageReturnObject {
pub result: Vec<ScriptCoverage>,
pub timestamp: JsFloat,
}Expand description
Collect coverage data for the current isolate, and resets execution counters. Precise code coverage needs to have started.
Fields
result: Vec<ScriptCoverage>Coverage data for the current isolate.
timestamp: JsFloatMonotonically increasing time (in seconds) when the coverage update was taken in the backend.