pub struct ChangeAppUserSettings {
pub manifest_id: String,
pub link_capturing: Option<bool>,
pub display_mode: Option<DisplayMode>,
}Expand description
Changes user settings of the web app identified by its manifestId. If the app was not installed, this command returns an error. Unset parameters will be ignored; unrecognized values will cause an error.
Unlike the ones defined in the manifest files of the web apps, these settings are provided by the browser and controlled by the users, they impact the way the browser handling the web apps.
See the comment of each parameter.
Fields
manifest_id: Stringlink_capturing: Option<bool>If user allows the links clicked on by the user in the app’s scope, or
extended scope if the manifest has scope extensions and the flags
DesktopPWAsLinkCapturingWithScopeExtensions and
WebAppEnableScopeExtensions are enabled.
Note, the API does not support resetting the linkCapturing to the initial value, uninstalling and installing the web app again will reset it.
TODO(crbug.com/339453269): Setting this value on ChromeOS is not supported yet.
display_mode: Option<DisplayMode>Trait Implementations
Sourceimpl Clone for ChangeAppUserSettings
impl Clone for ChangeAppUserSettings
Sourcefn clone(&self) -> ChangeAppUserSettings
fn clone(&self) -> ChangeAppUserSettings
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more