pub struct Launch {
pub manifest_id: String,
pub url: Option<String>,
}Expand description
Launches the installed web app, or an url in the same web app instead of the default start url if it is provided. Returns a page Target.TargetID which can be used to attach to via Target.attachToTarget or similar APIs.
Fields
manifest_id: Stringurl: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Launch
impl<'de> Deserialize<'de> for Launch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Method for Launch
impl Method for Launch
const NAME: &'static str = "PWA.launch"
type ReturnObject = LaunchReturnObject
fn to_method_call(self, call_id: CallId) -> MethodCall<Self>where
Self: Sized,
impl StructuralPartialEq for Launch