Module runtime

Module runtime 

Modules

events

Structs

AddBinding
If executionContextId is empty, adds binding with the given name on the global objects of all inspected contexts, including those created later, bindings survive reloads. Binding function takes exactly one argument, this argument should be string, in case of any other input, function throws an exception. Each binding function call produces Runtime.bindingCalled notification.
AddBindingBuilder
Builder for AddBinding.
AddBindingReturnObject
If executionContextId is empty, adds binding with the given name on the global objects of all inspected contexts, including those created later, bindings survive reloads. Binding function takes exactly one argument, this argument should be string, in case of any other input, function throws an exception. Each binding function call produces Runtime.bindingCalled notification.
AwaitPromise
Add handler to promise with given promise object id.
AwaitPromiseBuilder
Builder for AwaitPromise.
AwaitPromiseReturnObject
Add handler to promise with given promise object id.
AwaitPromiseReturnObjectBuilder
Builder for AwaitPromiseReturnObject.
CallArgument
Represents function call argument. Either remote object id objectId, primitive value, unserializable primitive value or neither of (for undefined) them should be specified.
CallArgumentBuilder
Builder for CallArgument.
CallFrame
Stack entry for runtime errors and assertions.
CallFrameBuilder
Builder for CallFrame.
CallFunctionOn
Calls function with given declaration on the given object. Object group of the result is inherited from the target object.
CallFunctionOnBuilder
Builder for CallFunctionOn.
CallFunctionOnReturnObject
Calls function with given declaration on the given object. Object group of the result is inherited from the target object.
CallFunctionOnReturnObjectBuilder
Builder for CallFunctionOnReturnObject.
CompileScript
Compiles expression.
CompileScriptBuilder
Builder for CompileScript.
CompileScriptReturnObject
Compiles expression.
CompileScriptReturnObjectBuilder
Builder for CompileScriptReturnObject.
CustomPreview
CustomPreviewBuilder
Builder for CustomPreview.
DeepSerializedValue
Represents deep serialized value.
DeepSerializedValueBuilder
Builder for DeepSerializedValue.
Disable
DisableReturnObject
Disables reporting of execution contexts creation.
DiscardConsoleEntries
DiscardConsoleEntriesReturnObject
Discards collected exceptions and console API calls.
Enable
EnableReturnObject
Enables reporting of execution contexts creation by means of executionContextCreated event. When the reporting gets enabled the event will be sent immediately for each existing execution context.
EntryPreview
EntryPreviewBuilder
Builder for EntryPreview.
Evaluate
Evaluates expression on global object.
EvaluateBuilder
Builder for Evaluate.
EvaluateReturnObject
Evaluates expression on global object.
EvaluateReturnObjectBuilder
Builder for EvaluateReturnObject.
ExceptionDetails
Detailed information about exception (or error) that was thrown during script compilation or execution.
ExceptionDetailsBuilder
Builder for ExceptionDetails.
ExecutionContextDescription
Description of an isolated world.
ExecutionContextDescriptionBuilder
Builder for ExecutionContextDescription.
GetExceptionDetails
This method tries to lookup and populate exception details for a JavaScript Error object. Note that the stackTrace portion of the resulting exceptionDetails will only be populated if the Runtime domain was enabled at the time when the Error was thrown.
GetExceptionDetailsBuilder
Builder for GetExceptionDetails.
GetExceptionDetailsReturnObject
This method tries to lookup and populate exception details for a JavaScript Error object. Note that the stackTrace portion of the resulting exceptionDetails will only be populated if the Runtime domain was enabled at the time when the Error was thrown.
GetExceptionDetailsReturnObjectBuilder
Builder for GetExceptionDetailsReturnObject.
GetHeapUsage
GetHeapUsageReturnObject
Returns the JavaScript heap usage. It is the total usage of the corresponding isolate not scoped to a particular Runtime.
GetHeapUsageReturnObjectBuilder
Builder for GetHeapUsageReturnObject.
GetIsolateId
GetIsolateIdReturnObject
Returns the isolate id.
GetIsolateIdReturnObjectBuilder
Builder for GetIsolateIdReturnObject.
GetProperties
Returns properties of a given object. Object group of the result is inherited from the target object.
GetPropertiesBuilder
Builder for GetProperties.
GetPropertiesReturnObject
Returns properties of a given object. Object group of the result is inherited from the target object.
GetPropertiesReturnObjectBuilder
Builder for GetPropertiesReturnObject.
GlobalLexicalScopeNames
Returns all let, const and class variables from global scope.
GlobalLexicalScopeNamesBuilder
Builder for GlobalLexicalScopeNames.
GlobalLexicalScopeNamesReturnObject
Returns all let, const and class variables from global scope.
GlobalLexicalScopeNamesReturnObjectBuilder
Builder for GlobalLexicalScopeNamesReturnObject.
InternalPropertyDescriptor
Object internal property descriptor. This property isn’t normally visible in JavaScript code.
InternalPropertyDescriptorBuilder
Builder for InternalPropertyDescriptor.
ObjectPreview
Object containing abbreviated remote object value.
ObjectPreviewBuilder
Builder for ObjectPreview.
PrivatePropertyDescriptor
Object private field descriptor.
PrivatePropertyDescriptorBuilder
Builder for PrivatePropertyDescriptor.
PropertyDescriptor
Object property descriptor.
PropertyDescriptorBuilder
Builder for PropertyDescriptor.
PropertyPreview
PropertyPreviewBuilder
Builder for PropertyPreview.
QueryObjects
QueryObjectsBuilder
Builder for QueryObjects.
QueryObjectsReturnObject
QueryObjectsReturnObjectBuilder
Builder for QueryObjectsReturnObject.
ReleaseObject
Releases remote object with given id.
ReleaseObjectBuilder
Builder for ReleaseObject.
ReleaseObjectGroup
Releases all remote objects that belong to a given group.
ReleaseObjectGroupBuilder
Builder for ReleaseObjectGroup.
ReleaseObjectGroupReturnObject
Releases all remote objects that belong to a given group.
ReleaseObjectReturnObject
Releases remote object with given id.
RemoteObject
Mirror object referencing original JavaScript object.
RemoteObjectBuilder
Builder for RemoteObject.
RemoveBinding
This method does not remove binding function from global object but unsubscribes current runtime agent from Runtime.bindingCalled notifications.
RemoveBindingBuilder
Builder for RemoveBinding.
RemoveBindingReturnObject
This method does not remove binding function from global object but unsubscribes current runtime agent from Runtime.bindingCalled notifications.
RunIfWaitingForDebugger
RunIfWaitingForDebuggerReturnObject
Tells inspected instance to run if it was waiting for debugger to attach.
RunScript
Runs script with given id in a given context.
RunScriptBuilder
Builder for RunScript.
RunScriptReturnObject
Runs script with given id in a given context.
RunScriptReturnObjectBuilder
Builder for RunScriptReturnObject.
SerializationOptions
Represents options for serialization. Overrides generatePreview and returnByValue.
SerializationOptionsBuilder
Builder for SerializationOptions.
SetAsyncCallStackDepth
Enables or disables async call stacks tracking.
SetAsyncCallStackDepthBuilder
Builder for SetAsyncCallStackDepth.
SetAsyncCallStackDepthReturnObject
Enables or disables async call stacks tracking.
SetCustomObjectFormatterEnabled
SetCustomObjectFormatterEnabledBuilder
Builder for SetCustomObjectFormatterEnabled.
SetCustomObjectFormatterEnabledReturnObject
SetMaxCallStackSizeToCapture
SetMaxCallStackSizeToCaptureBuilder
Builder for SetMaxCallStackSizeToCapture.
SetMaxCallStackSizeToCaptureReturnObject
StackTrace
Call frames for assertions or error messages.
StackTraceBuilder
Builder for StackTrace.
StackTraceId
If debuggerId is set stack trace comes from another debugger and can be resolved there. This allows to track cross-debugger calls. See Runtime.StackTrace and Debugger.paused for usages.
StackTraceIdBuilder
Builder for StackTraceId.
TerminateExecution
TerminateExecutionReturnObject
Terminate current or next JavaScript execution. Will cancel the termination when the outer-most script execution ends.

Enums

AddBindingBuilderError
Error type for AddBindingBuilder
AwaitPromiseBuilderError
Error type for AwaitPromiseBuilder
AwaitPromiseReturnObjectBuilderError
Error type for AwaitPromiseReturnObjectBuilder
CallArgumentBuilderError
Error type for CallArgumentBuilder
CallFrameBuilderError
Error type for CallFrameBuilder
CallFunctionOnBuilderError
Error type for CallFunctionOnBuilder
CallFunctionOnReturnObjectBuilderError
Error type for CallFunctionOnReturnObjectBuilder
CompileScriptBuilderError
Error type for CompileScriptBuilder
CompileScriptReturnObjectBuilderError
Error type for CompileScriptReturnObjectBuilder
ConsoleApiCalledTypeOption
CustomPreviewBuilderError
Error type for CustomPreviewBuilder
DeepSerializedValueBuilderError
Error type for DeepSerializedValueBuilder
DeepSerializedValueType
EntryPreviewBuilderError
Error type for EntryPreviewBuilder
EvaluateBuilderError
Error type for EvaluateBuilder
EvaluateReturnObjectBuilderError
Error type for EvaluateReturnObjectBuilder
ExceptionDetailsBuilderError
Error type for ExceptionDetailsBuilder
ExecutionContextDescriptionBuilderError
Error type for ExecutionContextDescriptionBuilder
GetExceptionDetailsBuilderError
Error type for GetExceptionDetailsBuilder
GetExceptionDetailsReturnObjectBuilderError
Error type for GetExceptionDetailsReturnObjectBuilder
GetHeapUsageReturnObjectBuilderError
Error type for GetHeapUsageReturnObjectBuilder
GetIsolateIdReturnObjectBuilderError
Error type for GetIsolateIdReturnObjectBuilder
GetPropertiesBuilderError
Error type for GetPropertiesBuilder
GetPropertiesReturnObjectBuilderError
Error type for GetPropertiesReturnObjectBuilder
GlobalLexicalScopeNamesBuilderError
Error type for GlobalLexicalScopeNamesBuilder
GlobalLexicalScopeNamesReturnObjectBuilderError
Error type for GlobalLexicalScopeNamesReturnObjectBuilder
InternalPropertyDescriptorBuilderError
Error type for InternalPropertyDescriptorBuilder
ObjectPreviewBuilderError
Error type for ObjectPreviewBuilder
ObjectPreviewSubtype
ObjectPreviewType
PrivatePropertyDescriptorBuilderError
Error type for PrivatePropertyDescriptorBuilder
PropertyDescriptorBuilderError
Error type for PropertyDescriptorBuilder
PropertyPreviewBuilderError
Error type for PropertyPreviewBuilder
PropertyPreviewSubtype
PropertyPreviewType
QueryObjectsBuilderError
Error type for QueryObjectsBuilder
QueryObjectsReturnObjectBuilderError
Error type for QueryObjectsReturnObjectBuilder
ReleaseObjectBuilderError
Error type for ReleaseObjectBuilder
ReleaseObjectGroupBuilderError
Error type for ReleaseObjectGroupBuilder
RemoteObjectBuilderError
Error type for RemoteObjectBuilder
RemoteObjectSubtype
RemoteObjectType
RemoveBindingBuilderError
Error type for RemoveBindingBuilder
RunScriptBuilderError
Error type for RunScriptBuilder
RunScriptReturnObjectBuilderError
Error type for RunScriptReturnObjectBuilder
SerializationOptionsBuilderError
Error type for SerializationOptionsBuilder
SerializationOptionsSerialization
SetAsyncCallStackDepthBuilderError
Error type for SetAsyncCallStackDepthBuilder
SetCustomObjectFormatterEnabledBuilderError
Error type for SetCustomObjectFormatterEnabledBuilder
SetMaxCallStackSizeToCaptureBuilderError
Error type for SetMaxCallStackSizeToCaptureBuilder
StackTraceBuilderError
Error type for StackTraceBuilder
StackTraceIdBuilderError
Error type for StackTraceIdBuilder

Type Aliases

ExecutionContextId
RemoteObjectId
ScriptId
TimeDelta
Timestamp
UniqueDebuggerId
UnserializableValue