CompileScript

Struct CompileScript 

pub struct CompileScript {
    pub expression: String,
    pub source_url: String,
    pub persist_script: bool,
    pub execution_context_id: Option<ExecutionContextId>,
}
Compiles expression.

Fields

expression: String

Expression to compile.

source_url: String

Source url to be set for the script.

persist_script: bool

Specifies whether the compiled script should be persisted.

execution_context_id: Option<ExecutionContextId>

Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page.