pub struct CompileScriptBuilder { /* private fields */ }Expand description
Builder for CompileScript.
Implementations
Sourceimpl CompileScriptBuilder
impl CompileScriptBuilder
Sourcepub fn expression<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn expression<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Expression to compile.
Sourcepub fn source_url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn source_url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Source url to be set for the script.
Sourcepub fn persist_script<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn persist_script<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Specifies whether the compiled script should be persisted.
Sourcepub fn execution_context_id<VALUE: Into<ExecutionContextId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn execution_context_id<VALUE: Into<ExecutionContextId>>( &mut self, value: VALUE, ) -> &mut Self
Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page.
Sourcepub fn build(&self) -> Result<CompileScript, CompileScriptBuilderError>
pub fn build(&self) -> Result<CompileScript, CompileScriptBuilderError>