pub struct CustomPreviewBuilder { /* private fields */ }Expand description
Builder for CustomPreview.
Implementations
Sourceimpl CustomPreviewBuilder
impl CustomPreviewBuilder
Sourcepub fn header<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn header<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The JSON-stringified result of formatter.header(object, config) call. It contains json ML array that represents RemoteObject.
Sourcepub fn body_getter_id<VALUE: Into<RemoteObjectId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn body_getter_id<VALUE: Into<RemoteObjectId>>( &mut self, value: VALUE, ) -> &mut Self
If formatter returns true as a result of formatter.hasBody call then bodyGetterId will contain RemoteObjectId for the function that returns result of formatter.body(object, config) call. The result value is json ML array.
Sourcepub fn build(&self) -> Result<CustomPreview, CustomPreviewBuilderError>
pub fn build(&self) -> Result<CustomPreview, CustomPreviewBuilderError>