DeepSerializedValueBuilder

Struct DeepSerializedValueBuilder 

pub struct DeepSerializedValueBuilder { /* private fields */ }
Builder for DeepSerializedValue.

Implementations

Source

impl DeepSerializedValueBuilder

pub fn type<VALUE: Into<DeepSerializedValueType>>( &mut self, value: VALUE, ) -> &mut Self

pub fn value<VALUE: Into<Json>>(&mut self, value: VALUE) -> &mut Self

pub fn object_id<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

pub fn weak_local_object_reference<VALUE: Into<JsUInt>>( &mut self, value: VALUE, ) -> &mut Self

Set if value reference met more then once during serialization. In such case, value is provided only to one of the serialized values. Unique per value in the scope of one CDP call.

pub fn build( &self, ) -> Result<DeepSerializedValue, DeepSerializedValueBuilderError>

Builds a new DeepSerializedValue.

Errors

If a required field has not been initialized.