pub struct EnableReturnObject(pub Option<Value>);Expand description
Enables reporting of execution contexts creation by means of executionContextCreated event.
When the reporting gets enabled the event will be sent immediately for each existing execution
context.
Tuple Fields
0: Option<Value>Trait Implementations
Sourceimpl Clone for EnableReturnObject
impl Clone for EnableReturnObject
Sourcefn clone(&self) -> EnableReturnObject
fn clone(&self) -> EnableReturnObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EnableReturnObject
impl Debug for EnableReturnObject
Sourceimpl<'de> Deserialize<'de> for EnableReturnObject
impl<'de> Deserialize<'de> for EnableReturnObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for EnableReturnObject
impl PartialEq for EnableReturnObject
Sourceimpl Serialize for EnableReturnObject
impl Serialize for EnableReturnObject
impl StructuralPartialEq for EnableReturnObject