ExceptionDetails

Struct ExceptionDetails 

pub struct ExceptionDetails {
    pub exception_id: JsUInt,
    pub text: String,
    pub line_number: JsUInt,
    pub column_number: JsUInt,
    pub script_id: Option<ScriptId>,
    pub url: Option<String>,
    pub stack_trace: Option<StackTrace>,
    pub exception: Option<RemoteObject>,
    pub execution_context_id: Option<ExecutionContextId>,
    pub exception_meta_data: Option<Value>,
}
Detailed information about exception (or error) that was thrown during script compilation or execution.

Fields

exception_id: JsUInt

Exception id.

text: String

Exception text, which should be used together with exception object when available.

line_number: JsUInt

Line number of the exception location (0-based).

column_number: JsUInt

Column number of the exception location (0-based).

script_id: Option<ScriptId>

Script ID of the exception location.

url: Option<String>

URL of the exception location, to be used when the script was not reported.

stack_trace: Option<StackTrace>

JavaScript stack trace if available.

exception: Option<RemoteObject>

Exception object if available.

execution_context_id: Option<ExecutionContextId>

Identifier of the context where exception happened.

exception_meta_data: Option<Value>

Dictionary with entries of meta data that the client associated with this exception, such as information about associated network requests, etc.