pub struct ExceptionDetailsBuilder { /* private fields */ }Expand description
Builder for ExceptionDetails.
Implementations
Sourceimpl ExceptionDetailsBuilder
impl ExceptionDetailsBuilder
Sourcepub fn exception_id<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn exception_id<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Exception id.
Sourcepub fn text<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn text<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Exception text, which should be used together with exception object when available.
Sourcepub fn line_number<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn line_number<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Line number of the exception location (0-based).
Sourcepub fn column_number<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn column_number<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Column number of the exception location (0-based).
Sourcepub fn script_id<VALUE: Into<ScriptId>>(&mut self, value: VALUE) -> &mut Self
pub fn script_id<VALUE: Into<ScriptId>>(&mut self, value: VALUE) -> &mut Self
Script ID of the exception location.
Sourcepub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
URL of the exception location, to be used when the script was not reported.
Sourcepub fn stack_trace<VALUE: Into<StackTrace>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn stack_trace<VALUE: Into<StackTrace>>( &mut self, value: VALUE, ) -> &mut Self
JavaScript stack trace if available.
Sourcepub fn exception<VALUE: Into<RemoteObject>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn exception<VALUE: Into<RemoteObject>>( &mut self, value: VALUE, ) -> &mut Self
Exception object if available.
Sourcepub fn execution_context_id<VALUE: Into<ExecutionContextId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn execution_context_id<VALUE: Into<ExecutionContextId>>( &mut self, value: VALUE, ) -> &mut Self
Identifier of the context where exception happened.
Sourcepub fn exception_meta_data<VALUE: Into<Json>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn exception_meta_data<VALUE: Into<Json>>( &mut self, value: VALUE, ) -> &mut Self
Dictionary with entries of meta data that the client associated with this exception, such as information about associated network requests, etc.
Sourcepub fn build(&self) -> Result<ExceptionDetails, ExceptionDetailsBuilderError>
pub fn build(&self) -> Result<ExceptionDetails, ExceptionDetailsBuilderError>