pub struct PropertyDescriptorBuilder { /* private fields */ }Expand description
Builder for PropertyDescriptor.
Implementations
Sourceimpl PropertyDescriptorBuilder
impl PropertyDescriptorBuilder
Sourcepub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Property name or symbol description.
Sourcepub fn value<VALUE: Into<RemoteObject>>(&mut self, value: VALUE) -> &mut Self
pub fn value<VALUE: Into<RemoteObject>>(&mut self, value: VALUE) -> &mut Self
The value associated with the property.
Sourcepub fn writable<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn writable<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
True if the value associated with the property may be changed (data descriptors only).
Sourcepub fn get<VALUE: Into<RemoteObject>>(&mut self, value: VALUE) -> &mut Self
pub fn get<VALUE: Into<RemoteObject>>(&mut self, value: VALUE) -> &mut Self
A function which serves as a getter for the property, or undefined if there is no getter
(accessor descriptors only).
Sourcepub fn set<VALUE: Into<RemoteObject>>(&mut self, value: VALUE) -> &mut Self
pub fn set<VALUE: Into<RemoteObject>>(&mut self, value: VALUE) -> &mut Self
A function which serves as a setter for the property, or undefined if there is no setter
(accessor descriptors only).
Sourcepub fn configurable<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn configurable<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
True if the type of this property descriptor may be changed and if the property may be deleted from the corresponding object.
Sourcepub fn enumerable<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn enumerable<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
True if this property shows up during enumeration of the properties on the corresponding object.
Sourcepub fn was_thrown<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn was_thrown<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
True if the result was thrown during the evaluation.
Sourcepub fn is_own<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn is_own<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
True if the property is owned for the object.
Sourcepub fn symbol<VALUE: Into<RemoteObject>>(&mut self, value: VALUE) -> &mut Self
pub fn symbol<VALUE: Into<RemoteObject>>(&mut self, value: VALUE) -> &mut Self
Property symbol object, if the property is of the symbol type.
Sourcepub fn build(
&self,
) -> Result<PropertyDescriptor, PropertyDescriptorBuilderError>
pub fn build( &self, ) -> Result<PropertyDescriptor, PropertyDescriptorBuilderError>