pub struct RemoteObjectBuilder { /* private fields */ }Expand description
Builder for RemoteObject.
Implementations
Sourceimpl RemoteObjectBuilder
impl RemoteObjectBuilder
Sourcepub fn type<VALUE: Into<RemoteObjectType>>(&mut self, value: VALUE) -> &mut Self
pub fn type<VALUE: Into<RemoteObjectType>>(&mut self, value: VALUE) -> &mut Self
Object type.
Sourcepub fn subtype<VALUE: Into<RemoteObjectSubtype>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn subtype<VALUE: Into<RemoteObjectSubtype>>( &mut self, value: VALUE, ) -> &mut Self
Object subtype hint. Specified for object type values only.
NOTE: If you change anything here, make sure to also update
subtype in ObjectPreview and PropertyPreview below.
Sourcepub fn class_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn class_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Object class (constructor) name. Specified for object type values only.
Sourcepub fn value<VALUE: Into<Json>>(&mut self, value: VALUE) -> &mut Self
pub fn value<VALUE: Into<Json>>(&mut self, value: VALUE) -> &mut Self
Remote object value in case of primitive values or JSON values (if it was requested).
Sourcepub fn unserializable_value<VALUE: Into<UnserializableValue>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn unserializable_value<VALUE: Into<UnserializableValue>>( &mut self, value: VALUE, ) -> &mut Self
Primitive value which can not be JSON-stringified does not have value, but gets this
property.
Sourcepub fn description<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn description<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
String representation of the object.
Sourcepub fn deep_serialized_value<VALUE: Into<DeepSerializedValue>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn deep_serialized_value<VALUE: Into<DeepSerializedValue>>( &mut self, value: VALUE, ) -> &mut Self
Deep serialized value.
Sourcepub fn object_id<VALUE: Into<RemoteObjectId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn object_id<VALUE: Into<RemoteObjectId>>( &mut self, value: VALUE, ) -> &mut Self
Unique object identifier (for non-primitive values).
Sourcepub fn preview<VALUE: Into<ObjectPreview>>(&mut self, value: VALUE) -> &mut Self
pub fn preview<VALUE: Into<ObjectPreview>>(&mut self, value: VALUE) -> &mut Self
Preview containing abbreviated property values. Specified for object type values only.
pub fn custom_preview<VALUE: Into<CustomPreview>>( &mut self, value: VALUE, ) -> &mut Self
Sourcepub fn build(&self) -> Result<RemoteObject, RemoteObjectBuilderError>
pub fn build(&self) -> Result<RemoteObject, RemoteObjectBuilderError>