pub struct RunScript {
pub script_id: ScriptId,
pub execution_context_id: Option<ExecutionContextId>,
pub object_group: Option<String>,
pub silent: Option<bool>,
pub include_command_line_api: Option<bool>,
pub return_by_value: Option<bool>,
pub generate_preview: Option<bool>,
pub await_promise: Option<bool>,
}Expand description
Runs script with given id in a given context.
Fields
script_id: ScriptIdId of the script to run.
execution_context_id: Option<ExecutionContextId>Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page.
object_group: Option<String>Symbolic group name that can be used to release multiple objects.
silent: Option<bool>In silent mode exceptions thrown during evaluation are not reported and do not pause
execution. Overrides setPauseOnException state.
include_command_line_api: Option<bool>Determines whether Command Line API should be available during the evaluation.
return_by_value: Option<bool>Whether the result is expected to be a JSON object which should be sent by value.
generate_preview: Option<bool>Whether preview should be generated for the result.
await_promise: Option<bool>Whether execution should await for resulting value and return once awaited promise is
resolved.