RunScriptBuilder

Struct RunScriptBuilder 

pub struct RunScriptBuilder { /* private fields */ }
Builder for RunScript.

Implementations

Source

impl RunScriptBuilder

pub fn script_id<VALUE: Into<ScriptId>>(&mut self, value: VALUE) -> &mut Self

Id of the script to run.

pub fn execution_context_id<VALUE: Into<ExecutionContextId>>( &mut self, value: VALUE, ) -> &mut Self

Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page.

pub fn object_group<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Symbolic group name that can be used to release multiple objects.

pub fn silent<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides setPauseOnException state.

pub fn include_command_line_api<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

Determines whether Command Line API should be available during the evaluation.

pub fn return_by_value<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

Whether the result is expected to be a JSON object which should be sent by value.

pub fn generate_preview<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

Whether preview should be generated for the result.

pub fn await_promise<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

Whether execution should await for resulting value and return once awaited promise is resolved.

pub fn build(&self) -> Result<RunScript, RunScriptBuilderError>

Builds a new RunScript.

Errors

If a required field has not been initialized.