pub struct StackTraceBuilder { /* private fields */ }Expand description
Builder for StackTrace.
Implementations
Sourceimpl StackTraceBuilder
impl StackTraceBuilder
Sourcepub fn description<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn description<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
String label of this stack trace. For async traces this may be a name of the function that initiated the async call.
Sourcepub fn call_frames<VALUE: Into<Vec<CallFrame>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn call_frames<VALUE: Into<Vec<CallFrame>>>( &mut self, value: VALUE, ) -> &mut Self
JavaScript function name.
Sourcepub fn parent<VALUE: Into<Box<StackTrace>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn parent<VALUE: Into<Box<StackTrace>>>( &mut self, value: VALUE, ) -> &mut Self
Asynchronous JavaScript stack trace that preceded this stack, if available.
Sourcepub fn parent_id<VALUE: Into<StackTraceId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn parent_id<VALUE: Into<StackTraceId>>( &mut self, value: VALUE, ) -> &mut Self
Asynchronous JavaScript stack trace that preceded this stack, if available.
Sourcepub fn build(&self) -> Result<StackTrace, StackTraceBuilderError>
pub fn build(&self) -> Result<StackTrace, StackTraceBuilderError>