pub struct SecurityStateChangedEventParamsBuilder { /* private fields */ }Expand description
Builder for SecurityStateChangedEventParams.
Implementations
Sourceimpl SecurityStateChangedEventParamsBuilder
impl SecurityStateChangedEventParamsBuilder
Sourcepub fn security_state(&mut self, value: SecurityState) -> &mut Self
pub fn security_state(&mut self, value: SecurityState) -> &mut Self
Security state.
Sourcepub fn scheme_is_cryptographic(&mut self, value: bool) -> &mut Self
pub fn scheme_is_cryptographic(&mut self, value: bool) -> &mut Self
True if the page was loaded over cryptographic transport such as HTTPS.
Sourcepub fn explanations(
&mut self,
value: Vec<SecurityStateExplanation>,
) -> &mut Self
pub fn explanations( &mut self, value: Vec<SecurityStateExplanation>, ) -> &mut Self
Previously a list of explanations for the security state. Now always empty.
Sourcepub fn insecure_content_status(
&mut self,
value: InsecureContentStatus,
) -> &mut Self
pub fn insecure_content_status( &mut self, value: InsecureContentStatus, ) -> &mut Self
Information about insecure content on the page.
Sourcepub fn summary(&mut self, value: Option<String>) -> &mut Self
pub fn summary(&mut self, value: Option<String>) -> &mut Self
Overrides user-visible description of the state. Always omitted.
Sourcepub fn build(
&self,
) -> Result<SecurityStateChangedEventParams, SecurityStateChangedEventParamsBuilderError>
pub fn build( &self, ) -> Result<SecurityStateChangedEventParams, SecurityStateChangedEventParamsBuilderError>