CertificateSecurityStateBuilder

Struct CertificateSecurityStateBuilder 

pub struct CertificateSecurityStateBuilder { /* private fields */ }
Implementations

Source

impl CertificateSecurityStateBuilder

pub fn protocol<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Protocol name (e.g. “TLS 1.2” or “QUIC”).

pub fn key_exchange<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Key Exchange used by the connection, or the empty string if not applicable.

pub fn key_exchange_group<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self

(EC)DH group used by the connection, if applicable.

pub fn cipher<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Cipher name.

pub fn mac<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

TLS MAC. Note that AEAD ciphers do not have separate MACs.

pub fn certificate<VALUE: Into<Vec<String>>>( &mut self, value: VALUE, ) -> &mut Self

Page certificate.

pub fn subject_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Certificate subject name.

pub fn issuer<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Name of the issuing CA.

pub fn valid_from<VALUE: Into<TimeSinceEpoch>>( &mut self, value: VALUE, ) -> &mut Self

Certificate valid from date.

pub fn valid_to<VALUE: Into<TimeSinceEpoch>>( &mut self, value: VALUE, ) -> &mut Self

Certificate valid to (expiration) date

pub fn certificate_network_error<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self

The highest priority network error code, if the certificate has an error.

pub fn certificate_has_weak_signature<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

True if the certificate uses a weak signature algorithm.

pub fn certificate_has_sha_1_signature<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

True if the certificate has a SHA1 signature in the chain.

pub fn modern_ssl<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

True if modern SSL

pub fn obsolete_ssl_protocol<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

True if the connection is using an obsolete SSL protocol.

pub fn obsolete_ssl_key_exchange<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

True if the connection is using an obsolete SSL key exchange.

pub fn obsolete_ssl_cipher<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

True if the connection is using an obsolete SSL cipher.

pub fn obsolete_ssl_signature<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

True if the connection is using an obsolete SSL signature.

pub fn build( &self, ) -> Result<CertificateSecurityState, CertificateSecurityStateBuilderError>

Builds a new CertificateSecurityState.

Errors

If a required field has not been initialized.