pub struct SecurityStateExplanationBuilder { /* private fields */ }Expand description
Builder for SecurityStateExplanation.
Implementations
Sourceimpl SecurityStateExplanationBuilder
impl SecurityStateExplanationBuilder
Sourcepub fn security_state<VALUE: Into<SecurityState>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn security_state<VALUE: Into<SecurityState>>( &mut self, value: VALUE, ) -> &mut Self
Security state representing the severity of the factor being explained.
Sourcepub fn title<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn title<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Title describing the type of factor.
Sourcepub fn summary<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn summary<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Short phrase describing the type of factor.
Sourcepub fn description<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn description<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Full text explanation of the factor.
Sourcepub fn mixed_content_type<VALUE: Into<MixedContentType>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn mixed_content_type<VALUE: Into<MixedContentType>>( &mut self, value: VALUE, ) -> &mut Self
The type of mixed content described by the explanation.
Sourcepub fn certificate<VALUE: Into<Vec<String>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn certificate<VALUE: Into<Vec<String>>>( &mut self, value: VALUE, ) -> &mut Self
Page certificate.
Sourcepub fn recommendations<VALUE: Into<Vec<String>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn recommendations<VALUE: Into<Vec<String>>>( &mut self, value: VALUE, ) -> &mut Self
Recommendations to fix any issues.
Sourcepub fn build(
&self,
) -> Result<SecurityStateExplanation, SecurityStateExplanationBuilderError>
pub fn build( &self, ) -> Result<SecurityStateExplanation, SecurityStateExplanationBuilderError>