pub struct ServiceWorkerVersion {
pub version_id: String,
pub registration_id: RegistrationId,
pub script_url: String,
pub running_status: ServiceWorkerVersionRunningStatus,
pub status: ServiceWorkerVersionStatus,
pub script_last_modified: Option<JsFloat>,
pub script_response_time: Option<JsFloat>,
pub controlled_clients: Option<Vec<TargetId>>,
pub target_id: Option<TargetId>,
pub router_rules: Option<String>,
}Expand description
ServiceWorker version.
Fields
version_id: Stringregistration_id: RegistrationIdscript_url: Stringrunning_status: ServiceWorkerVersionRunningStatusstatus: ServiceWorkerVersionStatusscript_last_modified: Option<JsFloat>The Last-Modified header value of the main script.
script_response_time: Option<JsFloat>The time at which the response headers of the main script were received from the server. For cached script it is the last time the cache entry was validated.
controlled_clients: Option<Vec<TargetId>>target_id: Option<TargetId>router_rules: Option<String>Trait Implementations
Sourceimpl Clone for ServiceWorkerVersion
impl Clone for ServiceWorkerVersion
Sourcefn clone(&self) -> ServiceWorkerVersion
fn clone(&self) -> ServiceWorkerVersion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServiceWorkerVersion
impl Debug for ServiceWorkerVersion
Sourceimpl<'de> Deserialize<'de> for ServiceWorkerVersion
impl<'de> Deserialize<'de> for ServiceWorkerVersion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ServiceWorkerVersion
impl PartialEq for ServiceWorkerVersion
Sourceimpl Serialize for ServiceWorkerVersion
impl Serialize for ServiceWorkerVersion
impl StructuralPartialEq for ServiceWorkerVersion