ServiceWorkerVersionBuilder

Struct ServiceWorkerVersionBuilder 

pub struct ServiceWorkerVersionBuilder { /* private fields */ }
Builder for ServiceWorkerVersion.

Implementations

Source

impl ServiceWorkerVersionBuilder

pub fn version_id<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

pub fn registration_id<VALUE: Into<RegistrationId>>( &mut self, value: VALUE, ) -> &mut Self

pub fn script_url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

pub fn running_status<VALUE: Into<ServiceWorkerVersionRunningStatus>>( &mut self, value: VALUE, ) -> &mut Self

pub fn status<VALUE: Into<ServiceWorkerVersionStatus>>( &mut self, value: VALUE, ) -> &mut Self

pub fn script_last_modified<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self

The Last-Modified header value of the main script.

pub fn script_response_time<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self

The time at which the response headers of the main script were received from the server. For cached script it is the last time the cache entry was validated.

pub fn controlled_clients<VALUE: Into<Vec<TargetId>>>( &mut self, value: VALUE, ) -> &mut Self

pub fn target_id<VALUE: Into<TargetId>>(&mut self, value: VALUE) -> &mut Self

pub fn router_rules<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

pub fn build( &self, ) -> Result<ServiceWorkerVersion, ServiceWorkerVersionBuilderError>

Builds a new ServiceWorkerVersion.

Errors

If a required field has not been initialized.