Skip to main content Module smart_card_emulation Copy item path Source events Disable DisableReturnObject Disables the |SmartCardEmulation| domain. Enable EnableReturnObject Enables the |SmartCardEmulation| domain. ProtocolSet Maps to the |SCARD_PROTOCOL_*| flags. ProtocolSetBuilder Builder for ProtocolSet . ReaderStateFlags Maps to the |SCARD_STATE_*| flags. ReaderStateFlagsBuilder Builder for ReaderStateFlags . ReaderStateIn ReaderStateInBuilder Builder for ReaderStateIn . ReaderStateOut ReaderStateOutBuilder Builder for ReaderStateOut . ReportBeginTransactionResult Reports the result of a |SCardBeginTransaction| call.
On success, this creates a new transaction object. ReportBeginTransactionResultBuilder Builder for ReportBeginTransactionResult . ReportBeginTransactionResultReturnObject Reports the result of a |SCardBeginTransaction| call.
On success, this creates a new transaction object. ReportConnectResult Reports the successful result of a |SCardConnect| call. ReportConnectResultBuilder Builder for ReportConnectResult . ReportConnectResultReturnObject Reports the successful result of a |SCardConnect| call. ReportDataResult Reports the successful result of a call that sends back data on success.
Used for |SCardTransmit|, |SCardControl|, and |SCardGetAttrib|. ReportDataResultBuilder Builder for ReportDataResult . ReportDataResultReturnObject Reports the successful result of a call that sends back data on success.
Used for |SCardTransmit|, |SCardControl|, and |SCardGetAttrib|. ReportError Reports an error result for the given request. ReportErrorBuilder Builder for ReportError . ReportErrorReturnObject Reports an error result for the given request. ReportEstablishContextResult Reports the successful result of a |SCardEstablishContext| call. ReportEstablishContextResultBuilder Builder for ReportEstablishContextResult . ReportEstablishContextResultReturnObject Reports the successful result of a |SCardEstablishContext| call. ReportGetStatusChangeResult Reports the successful result of a |SCardGetStatusChange| call. ReportGetStatusChangeResultBuilder Builder for ReportGetStatusChangeResult . ReportGetStatusChangeResultReturnObject Reports the successful result of a |SCardGetStatusChange| call. ReportListReadersResult Reports the successful result of a |SCardListReaders| call. ReportListReadersResultBuilder Builder for ReportListReadersResult . ReportListReadersResultReturnObject Reports the successful result of a |SCardListReaders| call. ReportPlainResult Reports the successful result of a call that returns only a result code.
Used for: |SCardCancel|, |SCardDisconnect|, |SCardSetAttrib|, |SCardEndTransaction|. ReportPlainResultBuilder Builder for ReportPlainResult . ReportPlainResultReturnObject Reports the successful result of a call that returns only a result code.
Used for: |SCardCancel|, |SCardDisconnect|, |SCardSetAttrib|, |SCardEndTransaction|. ReportReleaseContextResult Reports the successful result of a |SCardReleaseContext| call. ReportReleaseContextResultBuilder Builder for ReportReleaseContextResult . ReportReleaseContextResultReturnObject Reports the successful result of a |SCardReleaseContext| call. ReportStatusResult Reports the successful result of a |SCardStatus| call. ReportStatusResultBuilder Builder for ReportStatusResult . ReportStatusResultReturnObject Reports the successful result of a |SCardStatus| call. ConnectionState Disposition Protocol ProtocolSetBuilderError Error type for ProtocolSetBuilder ReaderStateFlagsBuilderError Error type for ReaderStateFlagsBuilder ReaderStateInBuilderError Error type for ReaderStateInBuilder ReaderStateOutBuilderError Error type for ReaderStateOutBuilder ReportBeginTransactionResultBuilderError Error type for ReportBeginTransactionResultBuilder ReportConnectResultBuilderError Error type for ReportConnectResultBuilder ReportDataResultBuilderError Error type for ReportDataResultBuilder ReportErrorBuilderError Error type for ReportErrorBuilder ReportEstablishContextResultBuilderError Error type for ReportEstablishContextResultBuilder ReportGetStatusChangeResultBuilderError Error type for ReportGetStatusChangeResultBuilder ReportListReadersResultBuilderError Error type for ReportListReadersResultBuilder ReportPlainResultBuilderError Error type for ReportPlainResultBuilder ReportReleaseContextResultBuilderError Error type for ReportReleaseContextResultBuilder ReportStatusResultBuilderError Error type for ReportStatusResultBuilder ResultCode ShareMode