pub struct ReportDataResultReturnObject(pub Option<Value>);Expand description
Reports the successful result of a call that sends back data on success. Used for |SCardTransmit|, |SCardControl|, and |SCardGetAttrib|.
This maps to:
-
SCardTransmit PC/SC Lite: https://pcsclite.apdu.fr/api/group__API.html#ga9a2d77242a271310269065e64633ab99 Microsoft: https://learn.microsoft.com/en-us/windows/win32/api/winscard/nf-winscard-scardtransmit
-
SCardControl PC/SC Lite: https://pcsclite.apdu.fr/api/group__API.html#gac3454d4657110fd7f753b2d3d8f4e32f Microsoft: https://learn.microsoft.com/en-us/windows/win32/api/winscard/nf-winscard-scardcontrol
-
SCardGetAttrib PC/SC Lite: https://pcsclite.apdu.fr/api/group__API.html#gaacfec51917255b7a25b94c5104961602 Microsoft: https://learn.microsoft.com/en-us/windows/win32/api/winscard/nf-winscard-scardgetattrib
Tuple Fields
0: Option<Value>Trait Implementations
Sourceimpl Clone for ReportDataResultReturnObject
impl Clone for ReportDataResultReturnObject
Sourcefn clone(&self) -> ReportDataResultReturnObject
fn clone(&self) -> ReportDataResultReturnObject
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ReportDataResultReturnObject
impl Debug for ReportDataResultReturnObject
Sourceimpl<'de> Deserialize<'de> for ReportDataResultReturnObject
impl<'de> Deserialize<'de> for ReportDataResultReturnObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for ReportDataResultReturnObject
impl PartialEq for ReportDataResultReturnObject
Sourcefn eq(&self, other: &ReportDataResultReturnObject) -> bool
fn eq(&self, other: &ReportDataResultReturnObject) -> bool
self and other values to be equal, and is used by ==.