pub struct InterestGroupAuctionNetworkRequestCreatedEventParams {
pub type: InterestGroupAuctionFetchType,
pub request_id: RequestId,
pub auctions: Vec<InterestGroupAuctionId>,
}Fields
type: InterestGroupAuctionFetchTyperequest_id: RequestIdauctions: Vec<InterestGroupAuctionId>This is the set of the auctions using the worklet that issued this request. In the case of trusted signals, it’s possible that only some of them actually care about the keys being queried.