InterestGroupAuctionNetworkRequestCreatedEventParamsBuilder

Struct InterestGroupAuctionNetworkRequestCreatedEventParamsBuilder 

pub struct InterestGroupAuctionNetworkRequestCreatedEventParamsBuilder { /* private fields */ }
Implementations

Source

impl InterestGroupAuctionNetworkRequestCreatedEventParamsBuilder

pub fn type(&mut self, value: InterestGroupAuctionFetchType) -> &mut Self

pub fn request_id(&mut self, value: RequestId) -> &mut Self

pub fn auctions(&mut self, value: Vec<InterestGroupAuctionId>) -> &mut Self

This is the set of the auctions using the worklet that issued this request. In the case of trusted signals, it’s possible that only some of them actually care about the keys being queried.

pub fn build( &self, ) -> Result<InterestGroupAuctionNetworkRequestCreatedEventParams, InterestGroupAuctionNetworkRequestCreatedEventParamsBuilderError>

Builds a new InterestGroupAuctionNetworkRequestCreatedEventParams.

Errors

If a required field has not been initialized.