pub struct SharedStorageAccessedEventParamsBuilder { /* private fields */ }Expand description
Builder for SharedStorageAccessedEventParams.
Implementations
Sourcepub fn access_time(&mut self, value: TimeSinceEpoch) -> &mut Self
pub fn access_time(&mut self, value: TimeSinceEpoch) -> &mut Self
Time of the access.
Sourcepub fn scope(&mut self, value: SharedStorageAccessScope) -> &mut Self
pub fn scope(&mut self, value: SharedStorageAccessScope) -> &mut Self
Enum value indicating the access scope.
Sourcepub fn method(&mut self, value: SharedStorageAccessMethod) -> &mut Self
pub fn method(&mut self, value: SharedStorageAccessMethod) -> &mut Self
Enum value indicating the Shared Storage API method invoked.
Sourcepub fn main_frame_id(&mut self, value: FrameId) -> &mut Self
pub fn main_frame_id(&mut self, value: FrameId) -> &mut Self
DevTools Frame Token for the primary frame tree’s root.
Sourcepub fn owner_origin(&mut self, value: String) -> &mut Self
pub fn owner_origin(&mut self, value: String) -> &mut Self
Serialization of the origin owning the Shared Storage data.
Sourcepub fn owner_site(&mut self, value: String) -> &mut Self
pub fn owner_site(&mut self, value: String) -> &mut Self
Serialization of the site owning the Shared Storage data.
Sourcepub fn params(&mut self, value: SharedStorageAccessParams) -> &mut Self
pub fn params(&mut self, value: SharedStorageAccessParams) -> &mut Self
The sub-parameters wrapped by params are all optional and their
presence/absence depends on type.
Sourcepub fn build(
&self,
) -> Result<SharedStorageAccessedEventParams, SharedStorageAccessedEventParamsBuilderError>
pub fn build( &self, ) -> Result<SharedStorageAccessedEventParams, SharedStorageAccessedEventParamsBuilderError>
Builds a new SharedStorageAccessedEventParams.
Errors
If a required field has not been initialized.