pub struct SharedStorageWorkletOperationExecutionFinishedEventParamsBuilder { /* private fields */ }Expand description
Implementations
Sourcepub fn finished_time(&mut self, value: TimeSinceEpoch) -> &mut Self
pub fn finished_time(&mut self, value: TimeSinceEpoch) -> &mut Self
Time that the operation finished.
Sourcepub fn execution_time(&mut self, value: JsUInt) -> &mut Self
pub fn execution_time(&mut self, value: JsUInt) -> &mut Self
Time, in microseconds, from start of shared storage JS API call until end of operation execution in the worklet.
Sourcepub fn method(&mut self, value: SharedStorageAccessMethod) -> &mut Self
pub fn method(&mut self, value: SharedStorageAccessMethod) -> &mut Self
Enum value indicating the Shared Storage API method invoked.
Sourcepub fn operation_id(&mut self, value: String) -> &mut Self
pub fn operation_id(&mut self, value: String) -> &mut Self
ID of the operation call.
Sourcepub fn worklet_target_id(&mut self, value: TargetId) -> &mut Self
pub fn worklet_target_id(&mut self, value: TargetId) -> &mut Self
Hex representation of the DevTools token used as the TargetID for the associated shared storage worklet.
Sourcepub fn main_frame_id(&mut self, value: FrameId) -> &mut Self
pub fn main_frame_id(&mut self, value: FrameId) -> &mut Self
DevTools Frame Token for the primary frame tree’s root.
Sourcepub fn owner_origin(&mut self, value: String) -> &mut Self
pub fn owner_origin(&mut self, value: String) -> &mut Self
Serialization of the origin owning the Shared Storage data.
Sourcepub fn build(
&self,
) -> Result<SharedStorageWorkletOperationExecutionFinishedEventParams, SharedStorageWorkletOperationExecutionFinishedEventParamsBuilderError>
pub fn build( &self, ) -> Result<SharedStorageWorkletOperationExecutionFinishedEventParams, SharedStorageWorkletOperationExecutionFinishedEventParamsBuilderError>
Builds a new SharedStorageWorkletOperationExecutionFinishedEventParams.
Errors
If a required field has not been initialized.