pub struct GetRelatedWebsiteSetsReturnObject {
pub sets: Vec<RelatedWebsiteSet>,
}Expand description
Returns the effective Related Website Sets in use by this profile for the browser session. The effective Related Website Sets will not change during a browser session.
Fields
sets: Vec<RelatedWebsiteSet>Trait Implementations
Sourceimpl Clone for GetRelatedWebsiteSetsReturnObject
impl Clone for GetRelatedWebsiteSetsReturnObject
Sourcefn clone(&self) -> GetRelatedWebsiteSetsReturnObject
fn clone(&self) -> GetRelatedWebsiteSetsReturnObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for GetRelatedWebsiteSetsReturnObject
impl<'de> Deserialize<'de> for GetRelatedWebsiteSetsReturnObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for GetRelatedWebsiteSetsReturnObject
impl PartialEq for GetRelatedWebsiteSetsReturnObject
Sourcefn eq(&self, other: &GetRelatedWebsiteSetsReturnObject) -> bool
fn eq(&self, other: &GetRelatedWebsiteSetsReturnObject) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GetRelatedWebsiteSetsReturnObject