pub struct OverrideQuotaForOrigin {
pub origin: String,
pub quota_size: Option<JsFloat>,
}Expand description
Override quota for the specified origin
Fields
origin: StringSecurity origin.
quota_size: Option<JsFloat>The quota size (in bytes) to override the original quota with. If this is called multiple times, the overridden quota will be equal to the quotaSize provided in the final call. If this is called without specifying a quotaSize, the quota will be reset to the default value for the specified origin. If this is called multiple times with different origins, the override will be maintained for each origin until it is disabled (called without a quotaSize).