OverrideQuotaForOriginBuilder

Struct OverrideQuotaForOriginBuilder 

pub struct OverrideQuotaForOriginBuilder { /* private fields */ }
Implementations

Source

impl OverrideQuotaForOriginBuilder

pub fn origin<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Security origin.

pub fn quota_size<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self

The quota size (in bytes) to override the original quota with. If this is called multiple times, the overridden quota will be equal to the quotaSize provided in the final call. If this is called without specifying a quotaSize, the quota will be reset to the default value for the specified origin. If this is called multiple times with different origins, the override will be maintained for each origin until it is disabled (called without a quotaSize).

pub fn build( &self, ) -> Result<OverrideQuotaForOrigin, OverrideQuotaForOriginBuilderError>

Builds a new OverrideQuotaForOrigin.

Errors

If a required field has not been initialized.