pub struct RelatedWebsiteSet {
pub primary_sites: Vec<String>,
pub associated_sites: Vec<String>,
pub service_sites: Vec<String>,
}Expand description
A single Related Website Set object.
Fields
primary_sites: Vec<String>The primary site of this set, along with the ccTLDs if there is any.
associated_sites: Vec<String>The associated sites of this set, along with the ccTLDs if there is any.
service_sites: Vec<String>The service sites of this set, along with the ccTLDs if there is any.