pub struct RelatedWebsiteSetBuilder { /* private fields */ }Expand description
Builder for RelatedWebsiteSet.
Implementations
Sourceimpl RelatedWebsiteSetBuilder
impl RelatedWebsiteSetBuilder
Sourcepub fn primary_sites<VALUE: Into<Vec<String>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn primary_sites<VALUE: Into<Vec<String>>>( &mut self, value: VALUE, ) -> &mut Self
The primary site of this set, along with the ccTLDs if there is any.
Sourcepub fn associated_sites<VALUE: Into<Vec<String>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn associated_sites<VALUE: Into<Vec<String>>>( &mut self, value: VALUE, ) -> &mut Self
The associated sites of this set, along with the ccTLDs if there is any.
Sourcepub fn service_sites<VALUE: Into<Vec<String>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn service_sites<VALUE: Into<Vec<String>>>( &mut self, value: VALUE, ) -> &mut Self
The service sites of this set, along with the ccTLDs if there is any.
Sourcepub fn build(&self) -> Result<RelatedWebsiteSet, RelatedWebsiteSetBuilderError>
pub fn build(&self) -> Result<RelatedWebsiteSet, RelatedWebsiteSetBuilderError>