Module target

Module target 

Modules

events

Structs

ActivateTarget
Activates (focuses) the target.
ActivateTargetBuilder
Builder for ActivateTarget.
ActivateTargetReturnObject
Activates (focuses) the target.
AttachToBrowserTarget
AttachToBrowserTargetReturnObject
Attaches to the browser target, only uses flat sessionId mode.
AttachToBrowserTargetReturnObjectBuilder
Builder for AttachToBrowserTargetReturnObject.
AttachToTarget
Attaches to the target with given id.
AttachToTargetBuilder
Builder for AttachToTarget.
AttachToTargetReturnObject
Attaches to the target with given id.
AttachToTargetReturnObjectBuilder
Builder for AttachToTargetReturnObject.
AutoAttachRelated
Adds the specified target to the list of targets that will be monitored for any related target creation (such as child frames, child workers and new versions of service worker) and reported through attachedToTarget. The specified target is also auto-attached. This cancels the effect of any previous setAutoAttach and is also cancelled by subsequent setAutoAttach. Only available at the Browser target.
AutoAttachRelatedBuilder
Builder for AutoAttachRelated.
AutoAttachRelatedReturnObject
Adds the specified target to the list of targets that will be monitored for any related target creation (such as child frames, child workers and new versions of service worker) and reported through attachedToTarget. The specified target is also auto-attached. This cancels the effect of any previous setAutoAttach and is also cancelled by subsequent setAutoAttach. Only available at the Browser target.
CloseTarget
Closes the target. If the target is a page that gets closed too.
CloseTargetBuilder
Builder for CloseTarget.
CloseTargetReturnObject
Closes the target. If the target is a page that gets closed too.
CloseTargetReturnObjectBuilder
Builder for CloseTargetReturnObject.
CreateBrowserContext
Creates a new empty BrowserContext. Similar to an incognito profile but you can have more than one.
CreateBrowserContextBuilder
Builder for CreateBrowserContext.
CreateBrowserContextReturnObject
Creates a new empty BrowserContext. Similar to an incognito profile but you can have more than one.
CreateBrowserContextReturnObjectBuilder
Builder for CreateBrowserContextReturnObject.
CreateTarget
Creates a new page.
CreateTargetBuilder
Builder for CreateTarget.
CreateTargetReturnObject
Creates a new page.
CreateTargetReturnObjectBuilder
Builder for CreateTargetReturnObject.
DetachFromTarget
Detaches session with given id.
DetachFromTargetBuilder
Builder for DetachFromTarget.
DetachFromTargetReturnObject
Detaches session with given id.
DisposeBrowserContext
Deletes a BrowserContext. All the belonging pages will be closed without calling their beforeunload hooks.
DisposeBrowserContextBuilder
Builder for DisposeBrowserContext.
DisposeBrowserContextReturnObject
Deletes a BrowserContext. All the belonging pages will be closed without calling their beforeunload hooks.
ExposeDevToolsProtocol
Inject object to the target’s main frame that provides a communication channel with browser target.
ExposeDevToolsProtocolBuilder
Builder for ExposeDevToolsProtocol.
ExposeDevToolsProtocolReturnObject
Inject object to the target’s main frame that provides a communication channel with browser target.
FilterEntry
A filter used by target query/discovery/auto-attach operations.
FilterEntryBuilder
Builder for FilterEntry.
GetBrowserContexts
GetBrowserContextsReturnObject
Returns all browser contexts created with Target.createBrowserContext method.
GetBrowserContextsReturnObjectBuilder
Builder for GetBrowserContextsReturnObject.
GetDevToolsTarget
Gets the targetId of the DevTools page target opened for the given target (if any).
GetDevToolsTargetBuilder
Builder for GetDevToolsTarget.
GetDevToolsTargetReturnObject
Gets the targetId of the DevTools page target opened for the given target (if any).
GetDevToolsTargetReturnObjectBuilder
Builder for GetDevToolsTargetReturnObject.
GetTargetInfo
Returns information about a target.
GetTargetInfoBuilder
Builder for GetTargetInfo.
GetTargetInfoReturnObject
Returns information about a target.
GetTargetInfoReturnObjectBuilder
Builder for GetTargetInfoReturnObject.
GetTargets
Retrieves a list of available targets.
GetTargetsBuilder
Builder for GetTargets.
GetTargetsReturnObject
Retrieves a list of available targets.
GetTargetsReturnObjectBuilder
Builder for GetTargetsReturnObject.
OpenDevTools
Opens a DevTools window for the target.
OpenDevToolsBuilder
Builder for OpenDevTools.
OpenDevToolsReturnObject
Opens a DevTools window for the target.
OpenDevToolsReturnObjectBuilder
Builder for OpenDevToolsReturnObject.
RemoteLocation
RemoteLocationBuilder
Builder for RemoteLocation.
SendMessageToTargetDeprecated
Sends protocol message over session with given id. Consider using flat mode instead; see commands attachToTarget, setAutoAttach, and crbug.com/991325.
SendMessageToTargetBuilder
Builder for SendMessageToTarget.
SendMessageToTargetReturnObjectDeprecated
Sends protocol message over session with given id. Consider using flat mode instead; see commands attachToTarget, setAutoAttach, and crbug.com/991325.
SetAutoAttach
Controls whether to automatically attach to new targets which are considered to be directly related to this one (for example, iframes or workers). When turned on, attaches to all existing related targets as well. When turned off, automatically detaches from all currently attached targets. This also clears all targets added by autoAttachRelated from the list of targets to watch for creation of related targets. You might want to call this recursively for auto-attached targets to attach to all available targets.
SetAutoAttachBuilder
Builder for SetAutoAttach.
SetAutoAttachReturnObject
Controls whether to automatically attach to new targets which are considered to be directly related to this one (for example, iframes or workers). When turned on, attaches to all existing related targets as well. When turned off, automatically detaches from all currently attached targets. This also clears all targets added by autoAttachRelated from the list of targets to watch for creation of related targets. You might want to call this recursively for auto-attached targets to attach to all available targets.
SetDiscoverTargets
Controls whether to discover available targets and notify via targetCreated/targetInfoChanged/targetDestroyed events.
SetDiscoverTargetsBuilder
Builder for SetDiscoverTargets.
SetDiscoverTargetsReturnObject
Controls whether to discover available targets and notify via targetCreated/targetInfoChanged/targetDestroyed events.
SetRemoteLocations
Enables target discovery for the specified locations, when setDiscoverTargets was set to true.
SetRemoteLocationsBuilder
Builder for SetRemoteLocations.
SetRemoteLocationsReturnObject
Enables target discovery for the specified locations, when setDiscoverTargets was set to true.
TargetInfo
TargetInfoBuilder
Builder for TargetInfo.

Enums

ActivateTargetBuilderError
Error type for ActivateTargetBuilder
AttachToBrowserTargetReturnObjectBuilderError
Error type for AttachToBrowserTargetReturnObjectBuilder
AttachToTargetBuilderError
Error type for AttachToTargetBuilder
AttachToTargetReturnObjectBuilderError
Error type for AttachToTargetReturnObjectBuilder
AutoAttachRelatedBuilderError
Error type for AutoAttachRelatedBuilder
CloseTargetBuilderError
Error type for CloseTargetBuilder
CloseTargetReturnObjectBuilderError
Error type for CloseTargetReturnObjectBuilder
CreateBrowserContextBuilderError
Error type for CreateBrowserContextBuilder
CreateBrowserContextReturnObjectBuilderError
Error type for CreateBrowserContextReturnObjectBuilder
CreateTargetBuilderError
Error type for CreateTargetBuilder
CreateTargetReturnObjectBuilderError
Error type for CreateTargetReturnObjectBuilder
DetachFromTargetBuilderError
Error type for DetachFromTargetBuilder
DisposeBrowserContextBuilderError
Error type for DisposeBrowserContextBuilder
ExposeDevToolsProtocolBuilderError
Error type for ExposeDevToolsProtocolBuilder
FilterEntryBuilderError
Error type for FilterEntryBuilder
GetBrowserContextsReturnObjectBuilderError
Error type for GetBrowserContextsReturnObjectBuilder
GetDevToolsTargetBuilderError
Error type for GetDevToolsTargetBuilder
GetDevToolsTargetReturnObjectBuilderError
Error type for GetDevToolsTargetReturnObjectBuilder
GetTargetInfoBuilderError
Error type for GetTargetInfoBuilder
GetTargetInfoReturnObjectBuilderError
Error type for GetTargetInfoReturnObjectBuilder
GetTargetsBuilderError
Error type for GetTargetsBuilder
GetTargetsReturnObjectBuilderError
Error type for GetTargetsReturnObjectBuilder
OpenDevToolsBuilderError
Error type for OpenDevToolsBuilder
OpenDevToolsReturnObjectBuilderError
Error type for OpenDevToolsReturnObjectBuilder
RemoteLocationBuilderError
Error type for RemoteLocationBuilder
SendMessageToTargetBuilderError
Error type for SendMessageToTargetBuilder
SetAutoAttachBuilderError
Error type for SetAutoAttachBuilder
SetDiscoverTargetsBuilderError
Error type for SetDiscoverTargetsBuilder
SetRemoteLocationsBuilderError
Error type for SetRemoteLocationsBuilder
TargetInfoBuilderError
Error type for TargetInfoBuilder
WindowState

Type Aliases

SessionId
TargetFilter
TargetId