pub struct CreateBrowserContext {
pub dispose_on_detach: Option<bool>,
pub proxy_server: Option<String>,
pub proxy_bypass_list: Option<String>,
pub origins_with_universal_network_access: Option<Vec<String>>,
}Expand description
Creates a new empty BrowserContext. Similar to an incognito profile but you can have more than one.
Fields
dispose_on_detach: Option<bool>If specified, disposes this context when debugging session disconnects.
proxy_server: Option<String>Proxy server, similar to the one passed to –proxy-server
proxy_bypass_list: Option<String>Proxy bypass list, similar to the one passed to –proxy-bypass-list
origins_with_universal_network_access: Option<Vec<String>>An optional list of origins to grant unlimited cross-origin access to. Parts of the URL other than those constituting origin are ignored.