pub struct CreateBrowserContextBuilder { /* private fields */ }Expand description
Builder for CreateBrowserContext.
Implementations
Sourceimpl CreateBrowserContextBuilder
impl CreateBrowserContextBuilder
Sourcepub fn dispose_on_detach<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn dispose_on_detach<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
If specified, disposes this context when debugging session disconnects.
Sourcepub fn proxy_server<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn proxy_server<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Proxy server, similar to the one passed to –proxy-server
Sourcepub fn proxy_bypass_list<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn proxy_bypass_list<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
Proxy bypass list, similar to the one passed to –proxy-bypass-list
Sourcepub fn origins_with_universal_network_access<VALUE: Into<Vec<String>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn origins_with_universal_network_access<VALUE: Into<Vec<String>>>( &mut self, value: VALUE, ) -> &mut Self
An optional list of origins to grant unlimited cross-origin access to. Parts of the URL other than those constituting origin are ignored.
Sourcepub fn build(
&self,
) -> Result<CreateBrowserContext, CreateBrowserContextBuilderError>
pub fn build( &self, ) -> Result<CreateBrowserContext, CreateBrowserContextBuilderError>