pub struct GetTargetsBuilder { /* private fields */ }Expand description
Builder for GetTargets.
Implementations
Sourceimpl GetTargetsBuilder
impl GetTargetsBuilder
Sourcepub fn filter<VALUE: Into<TargetFilter>>(&mut self, value: VALUE) -> &mut Self
pub fn filter<VALUE: Into<TargetFilter>>(&mut self, value: VALUE) -> &mut Self
Only targets matching filter will be reported. If filter is not specified and target discovery is currently enabled, a filter used for target discovery is used for consistency.
Sourcepub fn build(&self) -> Result<GetTargets, GetTargetsBuilderError>
pub fn build(&self) -> Result<GetTargets, GetTargetsBuilderError>