pub struct SetAutoAttachBuilder { /* private fields */ }Expand description
Builder for SetAutoAttach.
Implementations
Sourceimpl SetAutoAttachBuilder
impl SetAutoAttachBuilder
Sourcepub fn auto_attach<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn auto_attach<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether to auto-attach to related targets.
Sourcepub fn wait_for_debugger_on_start<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn wait_for_debugger_on_start<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Whether to pause new targets when attaching to them. Use Runtime.runIfWaitingForDebugger
to run paused targets.
Sourcepub fn flatten<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn flatten<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Enables “flat” access to the session via specifying sessionId attribute in the commands. We plan to make this the default, deprecate non-flattened mode, and eventually retire it. See crbug.com/991325.
Sourcepub fn filter<VALUE: Into<TargetFilter>>(&mut self, value: VALUE) -> &mut Self
pub fn filter<VALUE: Into<TargetFilter>>(&mut self, value: VALUE) -> &mut Self
Only targets matching filter will be attached.
Sourcepub fn build(&self) -> Result<SetAutoAttach, SetAutoAttachBuilderError>
pub fn build(&self) -> Result<SetAutoAttach, SetAutoAttachBuilderError>