pub struct SetAutoAttachReturnObject(pub Option<Value>);Expand description
Controls whether to automatically attach to new targets which are considered
to be directly related to this one (for example, iframes or workers).
When turned on, attaches to all existing related targets as well. When turned off,
automatically detaches from all currently attached targets.
This also clears all targets added by autoAttachRelated from the list of targets to watch
for creation of related targets.
You might want to call this recursively for auto-attached targets to attach
to all available targets.
Tuple Fields
0: Option<Value>Trait Implementations
Sourceimpl Clone for SetAutoAttachReturnObject
impl Clone for SetAutoAttachReturnObject
Sourcefn clone(&self) -> SetAutoAttachReturnObject
fn clone(&self) -> SetAutoAttachReturnObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetAutoAttachReturnObject
impl Debug for SetAutoAttachReturnObject
Sourceimpl<'de> Deserialize<'de> for SetAutoAttachReturnObject
impl<'de> Deserialize<'de> for SetAutoAttachReturnObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for SetAutoAttachReturnObject