pub struct TargetInfo {
pub target_id: TargetId,
pub type: String,
pub title: String,
pub url: String,
pub attached: bool,
pub opener_id: Option<TargetId>,
pub can_access_opener: bool,
pub opener_frame_id: Option<FrameId>,
pub parent_frame_id: Option<FrameId>,
pub browser_context_id: Option<BrowserContextId>,
pub subtype: Option<String>,
}Fields
target_id: TargetIdtype: Stringtitle: Stringurl: Stringattached: boolWhether the target has an attached client.
opener_id: Option<TargetId>Opener target Id
can_access_opener: boolWhether the target has access to the originating window.
opener_frame_id: Option<FrameId>Frame id of originating window (is only set if target has an opener).
parent_frame_id: Option<FrameId>Id of the parent frame, only present for the “iframe” targets.
browser_context_id: Option<BrowserContextId>subtype: Option<String>Provides additional details for specific target types. For example, for the type of “page”, this may be set to “prerender”.