pub struct TargetInfoBuilder { /* private fields */ }Expand description
Builder for TargetInfo.
Implementations
Sourceimpl TargetInfoBuilder
impl TargetInfoBuilder
pub fn target_id<VALUE: Into<TargetId>>(&mut self, value: VALUE) -> &mut Self
pub fn title<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn attached<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn attached<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether the target has an attached client.
Sourcepub fn can_access_opener<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn can_access_opener<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Whether the target has access to the originating window.
Sourcepub fn opener_frame_id<VALUE: Into<FrameId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn opener_frame_id<VALUE: Into<FrameId>>( &mut self, value: VALUE, ) -> &mut Self
Frame id of originating window (is only set if target has an opener).
Sourcepub fn parent_frame_id<VALUE: Into<FrameId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn parent_frame_id<VALUE: Into<FrameId>>( &mut self, value: VALUE, ) -> &mut Self
Id of the parent frame, only present for the “iframe” targets.
pub fn browser_context_id<VALUE: Into<BrowserContextId>>( &mut self, value: VALUE, ) -> &mut Self
Sourcepub fn subtype<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn subtype<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Provides additional details for specific target types. For example, for the type of “page”, this may be set to “prerender”.
Sourcepub fn build(&self) -> Result<TargetInfo, TargetInfoBuilderError>
pub fn build(&self) -> Result<TargetInfo, TargetInfoBuilderError>