pub struct BufferUsageEventParamsBuilder { /* private fields */ }Expand description
Builder for BufferUsageEventParams.
Implementations
Sourceimpl BufferUsageEventParamsBuilder
impl BufferUsageEventParamsBuilder
Sourcepub fn percent_full(&mut self, value: Option<JsFloat>) -> &mut Self
pub fn percent_full(&mut self, value: Option<JsFloat>) -> &mut Self
A number in range [0..1] that indicates the used size of event buffer as a fraction of its total size.
Sourcepub fn event_count(&mut self, value: Option<JsFloat>) -> &mut Self
pub fn event_count(&mut self, value: Option<JsFloat>) -> &mut Self
An approximate number of events in the trace log.
Sourcepub fn value(&mut self, value: Option<JsFloat>) -> &mut Self
pub fn value(&mut self, value: Option<JsFloat>) -> &mut Self
A number in range [0..1] that indicates the used size of event buffer as a fraction of its total size.
Sourcepub fn build(
&self,
) -> Result<BufferUsageEventParams, BufferUsageEventParamsBuilderError>
pub fn build( &self, ) -> Result<BufferUsageEventParams, BufferUsageEventParamsBuilderError>