StartBuilder

Struct StartBuilder 

pub struct StartBuilder { /* private fields */ }
Builder for Start.

Implementations

Source

impl StartBuilder

pub fn categories<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Category/tag filter

pub fn options<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Tracing options

pub fn buffer_usage_reporting_interval<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self

If set, the agent will issue bufferUsage events at this interval, specified in milliseconds

pub fn transfer_mode<VALUE: Into<StartTransferModeOption>>( &mut self, value: VALUE, ) -> &mut Self

Whether to report trace events as series of dataCollected events or to save trace to a stream (defaults to ReportEvents).

pub fn stream_format<VALUE: Into<StreamFormat>>( &mut self, value: VALUE, ) -> &mut Self

Trace data format to use. This only applies when using ReturnAsStream transfer mode (defaults to json).

pub fn stream_compression<VALUE: Into<StreamCompression>>( &mut self, value: VALUE, ) -> &mut Self

Compression format to use. This only applies when using ReturnAsStream transfer mode (defaults to none)

pub fn trace_config<VALUE: Into<TraceConfig>>( &mut self, value: VALUE, ) -> &mut Self

pub fn perfetto_config<VALUE: Into<Vec<u8>>>( &mut self, value: VALUE, ) -> &mut Self

Base64-encoded serialized perfetto.protos.TraceConfig protobuf message When specified, the parameters categories, options, traceConfig are ignored.

pub fn tracing_backend<VALUE: Into<TracingBackend>>( &mut self, value: VALUE, ) -> &mut Self

Backend type (defaults to auto)

pub fn build(&self) -> Result<Start, StartBuilderError>

Builds a new Start.

Errors

If a required field has not been initialized.