pub struct SetResponseOverrideBitsBuilder { /* private fields */ }Expand description
Builder for SetResponseOverrideBits.
Implementations
Sourceimpl SetResponseOverrideBitsBuilder
impl SetResponseOverrideBitsBuilder
pub fn authenticator_id<VALUE: Into<AuthenticatorId>>( &mut self, value: VALUE, ) -> &mut Self
Sourcepub fn is_bogus_signature<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn is_bogus_signature<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
If isBogusSignature is set, overrides the signature in the authenticator response to be zero. Defaults to false.
Sourcepub fn is_bad_uv<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn is_bad_uv<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If isBadUV is set, overrides the UV bit in the flags in the authenticator response to be zero. Defaults to false.
Sourcepub fn is_bad_up<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn is_bad_up<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If isBadUP is set, overrides the UP bit in the flags in the authenticator response to be zero. Defaults to false.
Sourcepub fn build(
&self,
) -> Result<SetResponseOverrideBits, SetResponseOverrideBitsBuilderError>
pub fn build( &self, ) -> Result<SetResponseOverrideBits, SetResponseOverrideBitsBuilderError>