pub struct PermissionElementIssueDetails {
pub issue_type: PermissionElementIssueType,
pub type: Option<String>,
pub node_id: Option<BackendNodeId>,
pub is_warning: Option<bool>,
pub permission_name: Option<String>,
pub occluder_node_info: Option<String>,
pub occluder_parent_node_info: Option<String>,
pub disable_reason: Option<String>,
}Expand description
This issue warns about improper usage of the <permission> element.
Fields
issue_type: PermissionElementIssueTypetype: Option<String>The value of the type attribute.
node_id: Option<BackendNodeId>The node ID of the <permission> element.
is_warning: Option<bool>True if the issue is a warning, false if it is an error.
permission_name: Option<String>Fields for message construction: Used for messages that reference a specific permission name
occluder_node_info: Option<String>Used for messages about occlusion
occluder_parent_node_info: Option<String>Used for messages about occluder’s parent
disable_reason: Option<String>Used for messages about activation disabled reason