Modules
Structs
- AddPrivacy
Sandbox Coordinator KeyConfig - Configures encryption keys used with a given privacy sandbox API to talk to a trusted coordinator. Since this is intended for test automation only, coordinatorOrigin must be a .test domain. No existing coordinator configuration for the origin may exist.
- AddPrivacy
Sandbox Coordinator KeyConfig Builder - Builder for
AddPrivacySandboxCoordinatorKeyConfig. - AddPrivacy
Sandbox Coordinator KeyConfig Return Object - Configures encryption keys used with a given privacy sandbox API to talk to a trusted coordinator. Since this is intended for test automation only, coordinatorOrigin must be a .test domain. No existing coordinator configuration for the origin may exist.
- AddPrivacy
Sandbox Enrollment Override - Allows a site to use privacy sandbox features that require enrollment without the site actually being enrolled. Only supported on page targets.
- AddPrivacy
Sandbox Enrollment Override Builder - Builder for
AddPrivacySandboxEnrollmentOverride. - AddPrivacy
Sandbox Enrollment Override Return Object - Allows a site to use privacy sandbox features that require enrollment without the site actually being enrolled. Only supported on page targets.
- Bounds
- Browser window bounds information
- Bounds
Builder - Builder for
Bounds. - Bucket
- Chrome histogram bucket.
- Bucket
Builder - Builder for
Bucket. - Cancel
Download - Cancel a download if in progress
- Cancel
Download Builder - Builder for
CancelDownload. - Cancel
Download Return Object - Cancel a download if in progress
- Close
- Close
Return Object - Close browser gracefully.
- Crash
- Crash
GpuProcess - Crash
GpuProcess Return Object - Crashes GPU process.
- Crash
Return Object - Crashes browser on the main thread.
- Execute
Browser Command - Invoke custom browser commands used by telemetry.
- Execute
Browser Command Builder - Builder for
ExecuteBrowserCommand. - Execute
Browser Command Return Object - Invoke custom browser commands used by telemetry.
- GetBrowser
Command Line - GetBrowser
Command Line Return Object - Returns the command line switches for the browser process if, and only if –enable-automation is on the commandline.
- GetBrowser
Command Line Return Object Builder - Builder for
GetBrowserCommandLineReturnObject. - GetHistogram
- Get a Chrome histogram by name.
- GetHistogram
Builder - Builder for
GetHistogram. - GetHistogram
Return Object - Get a Chrome histogram by name.
- GetHistogram
Return Object Builder - Builder for
GetHistogramReturnObject. - GetHistograms
- Get Chrome histograms.
- GetHistograms
Builder - Builder for
GetHistograms. - GetHistograms
Return Object - Get Chrome histograms.
- GetHistograms
Return Object Builder - Builder for
GetHistogramsReturnObject. - GetVersion
- GetVersion
Return Object - Returns version information.
- GetVersion
Return Object Builder - Builder for
GetVersionReturnObject. - GetWindow
Bounds - Get position and size of the browser window.
- GetWindow
Bounds Builder - Builder for
GetWindowBounds. - GetWindow
Bounds Return Object - Get position and size of the browser window.
- GetWindow
Bounds Return Object Builder - Builder for
GetWindowBoundsReturnObject. - GetWindow
ForTarget - Get the browser window that contains the devtools target.
- GetWindow
ForTarget Builder - Builder for
GetWindowForTarget. - GetWindow
ForTarget Return Object - Get the browser window that contains the devtools target.
- GetWindow
ForTarget Return Object Builder - Builder for
GetWindowForTargetReturnObject. - Grant
Permissions Deprecated - Grant specific permissions to the given origin and reject all others. Deprecated. Use setPermission instead.
- Grant
Permissions Builder - Builder for
GrantPermissions. - Grant
Permissions Return Object Deprecated - Grant specific permissions to the given origin and reject all others. Deprecated. Use setPermission instead.
- Histogram
- Chrome histogram.
- Histogram
Builder - Builder for
Histogram. - Permission
Descriptor - Definition of PermissionDescriptor defined in the Permissions API: https://w3c.github.io/permissions/#dom-permissiondescriptor.
- Permission
Descriptor Builder - Builder for
PermissionDescriptor. - Reset
Permissions - Reset all permission management for all origins.
- Reset
Permissions Builder - Builder for
ResetPermissions. - Reset
Permissions Return Object - Reset all permission management for all origins.
- SetContents
Size - Set size of the browser contents resizing browser window as necessary.
- SetContents
Size Builder - Builder for
SetContentsSize. - SetContents
Size Return Object - Set size of the browser contents resizing browser window as necessary.
- SetDock
Tile - Set dock tile details, platform-specific.
- SetDock
Tile Builder - Builder for
SetDockTile. - SetDock
Tile Return Object - Set dock tile details, platform-specific.
- SetDownload
Behavior - Set the behavior when downloading a file.
- SetDownload
Behavior Builder - Builder for
SetDownloadBehavior. - SetDownload
Behavior Return Object - Set the behavior when downloading a file.
- SetPermission
- Set permission settings for given embedding and embedded origins.
- SetPermission
Builder - Builder for
SetPermission. - SetPermission
Return Object - Set permission settings for given embedding and embedded origins.
- SetWindow
Bounds - Set position and/or size of the browser window.
- SetWindow
Bounds Builder - Builder for
SetWindowBounds. - SetWindow
Bounds Return Object - Set position and/or size of the browser window.
Enums
- AddPrivacy
Sandbox Coordinator KeyConfig Builder Error - Error type for AddPrivacySandboxCoordinatorKeyConfigBuilder
- AddPrivacy
Sandbox Enrollment Override Builder Error - Error type for AddPrivacySandboxEnrollmentOverrideBuilder
- Bounds
Builder Error - Error type for BoundsBuilder
- Browser
Command Id - Bucket
Builder Error - Error type for BucketBuilder
- Cancel
Download Builder Error - Error type for CancelDownloadBuilder
- Download
Progress State Option - Execute
Browser Command Builder Error - Error type for ExecuteBrowserCommandBuilder
- GetBrowser
Command Line Return Object Builder Error - Error type for GetBrowserCommandLineReturnObjectBuilder
- GetHistogram
Builder Error - Error type for GetHistogramBuilder
- GetHistogram
Return Object Builder Error - Error type for GetHistogramReturnObjectBuilder
- GetHistograms
Builder Error - Error type for GetHistogramsBuilder
- GetHistograms
Return Object Builder Error - Error type for GetHistogramsReturnObjectBuilder
- GetVersion
Return Object Builder Error - Error type for GetVersionReturnObjectBuilder
- GetWindow
Bounds Builder Error - Error type for GetWindowBoundsBuilder
- GetWindow
Bounds Return Object Builder Error - Error type for GetWindowBoundsReturnObjectBuilder
- GetWindow
ForTarget Builder Error - Error type for GetWindowForTargetBuilder
- GetWindow
ForTarget Return Object Builder Error - Error type for GetWindowForTargetReturnObjectBuilder
- Grant
Permissions Builder Error - Error type for GrantPermissionsBuilder
- Histogram
Builder Error - Error type for HistogramBuilder
- Permission
Descriptor Builder Error - Error type for PermissionDescriptorBuilder
- Permission
Setting - Permission
Type - Privacy
Sandbox Api - Reset
Permissions Builder Error - Error type for ResetPermissionsBuilder
- SetContents
Size Builder Error - Error type for SetContentsSizeBuilder
- SetDock
Tile Builder Error - Error type for SetDockTileBuilder
- SetDownload
Behavior Behavior Option - SetDownload
Behavior Builder Error - Error type for SetDownloadBehaviorBuilder
- SetPermission
Builder Error - Error type for SetPermissionBuilder
- SetWindow
Bounds Builder Error - Error type for SetWindowBoundsBuilder
- Window
State