pub struct DownloadProgressEventParamsBuilder { /* private fields */ }Expand description
Builder for DownloadProgressEventParams.
Implementations
Sourceimpl DownloadProgressEventParamsBuilder
impl DownloadProgressEventParamsBuilder
Sourcepub fn total_bytes(&mut self, value: JsFloat) -> &mut Self
pub fn total_bytes(&mut self, value: JsFloat) -> &mut Self
Total expected bytes to download.
Sourcepub fn received_bytes(&mut self, value: JsFloat) -> &mut Self
pub fn received_bytes(&mut self, value: JsFloat) -> &mut Self
Total bytes received.
Sourcepub fn state(&mut self, value: DownloadProgressStateOption) -> &mut Self
pub fn state(&mut self, value: DownloadProgressStateOption) -> &mut Self
Download status.
Sourcepub fn file_path(&mut self, value: Option<String>) -> &mut Self
pub fn file_path(&mut self, value: Option<String>) -> &mut Self
If download is “completed”, provides the path of the downloaded file. Depending on the platform, it is not guaranteed to be set, nor the file is guaranteed to exist.
Sourcepub fn build(
&self,
) -> Result<DownloadProgressEventParams, DownloadProgressEventParamsBuilderError>
pub fn build( &self, ) -> Result<DownloadProgressEventParams, DownloadProgressEventParamsBuilderError>