pub struct SetPermissionBuilder { /* private fields */ }Expand description
Builder for SetPermission.
Implementations
Sourceimpl SetPermissionBuilder
impl SetPermissionBuilder
Sourcepub fn permission<VALUE: Into<PermissionDescriptor>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn permission<VALUE: Into<PermissionDescriptor>>( &mut self, value: VALUE, ) -> &mut Self
Descriptor of permission to override.
Sourcepub fn setting<VALUE: Into<PermissionSetting>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn setting<VALUE: Into<PermissionSetting>>( &mut self, value: VALUE, ) -> &mut Self
Setting of the permission.
Sourcepub fn origin<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn origin<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Embedding origin the permission applies to, all origins if not specified.
Sourcepub fn embedded_origin<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn embedded_origin<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
Embedded origin the permission applies to. It is ignored unless the embedding origin is present and valid. If the embedding origin is provided but the embedded origin isn’t, the embedding origin is used as the embedded origin.
Sourcepub fn browser_context_id<VALUE: Into<BrowserContextId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn browser_context_id<VALUE: Into<BrowserContextId>>( &mut self, value: VALUE, ) -> &mut Self
Context to override. When omitted, default browser context is used.
Sourcepub fn build(&self) -> Result<SetPermission, SetPermissionBuilderError>
pub fn build(&self) -> Result<SetPermission, SetPermissionBuilderError>