Skip to main content Module css Copy item path Source events AddRule Inserts a new rule with the given ruleText in a stylesheet with given styleSheetId, at the
position specified by location. AddRuleBuilder Builder for AddRule . AddRuleReturnObject Inserts a new rule with the given ruleText in a stylesheet with given styleSheetId, at the
position specified by location. AddRuleReturnObjectBuilder Builder for AddRuleReturnObject . CollectClassNames Returns all class names from specified stylesheet. CollectClassNamesBuilder Builder for CollectClassNames . CollectClassNamesReturnObject Returns all class names from specified stylesheet. CollectClassNamesReturnObjectBuilder Builder for CollectClassNamesReturnObject . ComputedStyleExtraFields ComputedStyleExtraFieldsBuilder Builder for ComputedStyleExtraFields . CreateStyleSheet Creates a new special “via-inspector” stylesheet in the frame with given frameId. CreateStyleSheetBuilder Builder for CreateStyleSheet . CreateStyleSheetReturnObject Creates a new special “via-inspector” stylesheet in the frame with given frameId. CreateStyleSheetReturnObjectBuilder Builder for CreateStyleSheetReturnObject . CssAnimationStyle CSS style coming from animations with the name of the animation. CssAnimationStyleBuilder Builder for CssAnimationStyle . CssAtRule CSS generic @rule representation. CssAtRuleBuilder Builder for CssAtRule . CssComputedStyleProperty CssComputedStylePropertyBuilder Builder for CssComputedStyleProperty . CssContainerQuery CSS container query rule descriptor. CssContainerQueryBuilder Builder for CssContainerQuery . CssFunctionConditionNode CSS function conditional block representation. CssFunctionConditionNodeBuilder Builder for CssFunctionConditionNode . CssFunctionNode Section of the body of a CSS function rule. CssFunctionNodeBuilder Builder for CssFunctionNode . CssFunctionParameter CSS function argument representation. CssFunctionParameterBuilder Builder for CssFunctionParameter . CssFunctionRule CSS function at-rule representation. CssFunctionRuleBuilder Builder for CssFunctionRule . CssKeyframeRule CSS keyframe rule representation. CssKeyframeRuleBuilder Builder for CssKeyframeRule . CssKeyframesRule CSS keyframes rule representation. CssKeyframesRuleBuilder Builder for CssKeyframesRule . CssLayer CSS Layer at-rule descriptor. CssLayerBuilder Builder for CssLayer . CssLayerData CSS Layer data. CssLayerDataBuilder Builder for CssLayerData . CssMedia CSS media rule descriptor. CssMediaBuilder Builder for CssMedia . CssPositionTryRule CSS @position-try rule representation. CssPositionTryRuleBuilder Builder for CssPositionTryRule . CssProperty CSS property declaration data. CssPropertyBuilder Builder for CssProperty . CssPropertyRegistration Representation of a custom property registration through CSS.registerProperty CssPropertyRegistrationBuilder Builder for CssPropertyRegistration . CssPropertyRule CSS property at-rule representation. CssPropertyRuleBuilder Builder for CssPropertyRule . CssRule CSS rule representation. CssRuleBuilder Builder for CssRule . CssScope CSS Scope at-rule descriptor. CssScopeBuilder Builder for CssScope . CssStartingStyle CSS Starting Style at-rule descriptor. CssStartingStyleBuilder Builder for CssStartingStyle . CssStyle CSS style representation. CssStyleBuilder Builder for CssStyle . CssStyleSheetHeader CSS stylesheet metainformation. CssStyleSheetHeaderBuilder Builder for CssStyleSheetHeader . CssSupports CSS Supports at-rule descriptor. CssSupportsBuilder Builder for CssSupports . CssTryRule CSS try rule representation. CssTryRuleBuilder Builder for CssTryRule . Disable DisableReturnObject Disables the CSS agent for the given page. Enable EnableReturnObject Enables the CSS agent for the given page. Clients should not assume that the CSS agent has been
enabled until the result of this command is received. FontFace Properties of a web font: https://www.w3.org/TR/2008/REC-CSS2-20080411/fonts.html#font-descriptions
and additional information such as platformFontFamily and fontVariationAxes. FontFaceBuilder Builder for FontFace . FontVariationAxis Information about font variation axes for variable fonts FontVariationAxisBuilder Builder for FontVariationAxis . ForcePseudoState Ensures that the given node will have specified pseudo-classes whenever its style is computed by
the browser. ForcePseudoStateBuilder Builder for ForcePseudoState . ForcePseudoStateReturnObject Ensures that the given node will have specified pseudo-classes whenever its style is computed by
the browser. ForceStartingStyle Ensures that the given node is in its starting-style state. ForceStartingStyleBuilder Builder for ForceStartingStyle . ForceStartingStyleReturnObject Ensures that the given node is in its starting-style state. GetAnimatedStylesForNode Returns the styles coming from animations & transitions
including the animation & transition styles coming from inheritance chain. GetAnimatedStylesForNodeBuilder Builder for GetAnimatedStylesForNode . GetAnimatedStylesForNodeReturnObject Returns the styles coming from animations & transitions
including the animation & transition styles coming from inheritance chain. GetAnimatedStylesForNodeReturnObjectBuilder Builder for GetAnimatedStylesForNodeReturnObject . GetBackgroundColors GetBackgroundColorsBuilder Builder for GetBackgroundColors . GetBackgroundColorsReturnObject GetBackgroundColorsReturnObjectBuilder Builder for GetBackgroundColorsReturnObject . GetComputedStyleForNode Returns the computed style for a DOM node identified by nodeId. GetComputedStyleForNodeBuilder Builder for GetComputedStyleForNode . GetComputedStyleForNodeReturnObject Returns the computed style for a DOM node identified by nodeId. GetComputedStyleForNodeReturnObjectBuilder Builder for GetComputedStyleForNodeReturnObject . GetEnvironmentVariables GetEnvironmentVariablesReturnObject Returns the values of the default UA-defined environment variables used in env() GetEnvironmentVariablesReturnObjectBuilder Builder for GetEnvironmentVariablesReturnObject . GetInlineStylesForNode Returns the styles defined inline (explicitly in the “style” attribute and implicitly, using DOM
attributes) for a DOM node identified by nodeId. GetInlineStylesForNodeBuilder Builder for GetInlineStylesForNode . GetInlineStylesForNodeReturnObject Returns the styles defined inline (explicitly in the “style” attribute and implicitly, using DOM
attributes) for a DOM node identified by nodeId. GetInlineStylesForNodeReturnObjectBuilder Builder for GetInlineStylesForNodeReturnObject . GetLayersForNode Returns all layers parsed by the rendering engine for the tree scope of a node.
Given a DOM element identified by nodeId, getLayersForNode returns the root
layer for the nearest ancestor document or shadow root. The layer root contains
the full layer tree for the tree scope and their ordering. GetLayersForNodeBuilder Builder for GetLayersForNode . GetLayersForNodeReturnObject Returns all layers parsed by the rendering engine for the tree scope of a node.
Given a DOM element identified by nodeId, getLayersForNode returns the root
layer for the nearest ancestor document or shadow root. The layer root contains
the full layer tree for the tree scope and their ordering. GetLayersForNodeReturnObjectBuilder Builder for GetLayersForNodeReturnObject . GetLocationForSelector Given a CSS selector text and a style sheet ID, getLocationForSelector
returns an array of locations of the CSS selector in the style sheet. GetLocationForSelectorBuilder Builder for GetLocationForSelector . GetLocationForSelectorReturnObject Given a CSS selector text and a style sheet ID, getLocationForSelector
returns an array of locations of the CSS selector in the style sheet. GetLocationForSelectorReturnObjectBuilder Builder for GetLocationForSelectorReturnObject . GetLonghandProperties GetLonghandPropertiesBuilder Builder for GetLonghandProperties . GetLonghandPropertiesReturnObject GetLonghandPropertiesReturnObjectBuilder Builder for GetLonghandPropertiesReturnObject . GetMatchedStylesForNode Returns requested styles for a DOM node identified by nodeId. GetMatchedStylesForNodeBuilder Builder for GetMatchedStylesForNode . GetMatchedStylesForNodeReturnObject Returns requested styles for a DOM node identified by nodeId. GetMatchedStylesForNodeReturnObjectBuilder Builder for GetMatchedStylesForNodeReturnObject . GetMediaQueries GetMediaQueriesReturnObject Returns all media queries parsed by the rendering engine. GetMediaQueriesReturnObjectBuilder Builder for GetMediaQueriesReturnObject . GetPlatformFontsForNode Requests information about platform fonts which we used to render child TextNodes in the given
node. GetPlatformFontsForNodeBuilder Builder for GetPlatformFontsForNode . GetPlatformFontsForNodeReturnObject Requests information about platform fonts which we used to render child TextNodes in the given
node. GetPlatformFontsForNodeReturnObjectBuilder Builder for GetPlatformFontsForNodeReturnObject . GetStyleSheetText Returns the current textual content for a stylesheet. GetStyleSheetTextBuilder Builder for GetStyleSheetText . GetStyleSheetTextReturnObject Returns the current textual content for a stylesheet. GetStyleSheetTextReturnObjectBuilder Builder for GetStyleSheetTextReturnObject . InheritedAnimatedStyleEntry Inherited CSS style collection for animated styles from ancestor node. InheritedAnimatedStyleEntryBuilder Builder for InheritedAnimatedStyleEntry . InheritedPseudoElementMatches Inherited pseudo element matches from pseudos of an ancestor node. InheritedPseudoElementMatchesBuilder Builder for InheritedPseudoElementMatches . InheritedStyleEntry Inherited CSS rule collection from ancestor node. InheritedStyleEntryBuilder Builder for InheritedStyleEntry . MediaQuery Media query descriptor. MediaQueryBuilder Builder for MediaQuery . MediaQueryExpression Media query expression descriptor. MediaQueryExpressionBuilder Builder for MediaQueryExpression . PlatformFontUsage Information about amount of glyphs that were rendered with given font. PlatformFontUsageBuilder Builder for PlatformFontUsage . PseudoElementMatches CSS rule collection for a single pseudo style. PseudoElementMatchesBuilder Builder for PseudoElementMatches . ResolveValues Resolve the specified values in the context of the provided element.
For example, a value of ‘1em’ is evaluated according to the computed
‘font-size’ of the element and a value ‘calc(1px + 2px)’ will be
resolved to ‘3px’.
If the propertyName was specified the values are resolved as if
they were property’s declaration. If a value cannot be parsed according
to the provided property syntax, the value is parsed using combined
syntax as if null propertyName was provided. If the value cannot be
resolved even then, return the provided value without any changes.
Note: this function currently does not resolve CSS random() function,
it returns unmodified random() function parts.` ResolveValuesBuilder Builder for ResolveValues . ResolveValuesReturnObject Resolve the specified values in the context of the provided element.
For example, a value of ‘1em’ is evaluated according to the computed
‘font-size’ of the element and a value ‘calc(1px + 2px)’ will be
resolved to ‘3px’.
If the propertyName was specified the values are resolved as if
they were property’s declaration. If a value cannot be parsed according
to the provided property syntax, the value is parsed using combined
syntax as if null propertyName was provided. If the value cannot be
resolved even then, return the provided value without any changes.
Note: this function currently does not resolve CSS random() function,
it returns unmodified random() function parts.` ResolveValuesReturnObjectBuilder Builder for ResolveValuesReturnObject . RuleMatch Match data for a CSS rule. RuleMatchBuilder Builder for RuleMatch . RuleUsage CSS coverage information. RuleUsageBuilder Builder for RuleUsage . SelectorList Selector list data. SelectorListBuilder Builder for SelectorList . SetContainerQueryText Modifies the expression of a container query. SetContainerQueryTextBuilder Builder for SetContainerQueryText . SetContainerQueryTextReturnObject Modifies the expression of a container query. SetContainerQueryTextReturnObjectBuilder Builder for SetContainerQueryTextReturnObject . SetEffectivePropertyValueForNode Find a rule with the given active property for the given node and set the new value for this
property SetEffectivePropertyValueForNodeBuilder Builder for SetEffectivePropertyValueForNode . SetEffectivePropertyValueForNodeReturnObject Find a rule with the given active property for the given node and set the new value for this
property SetKeyframeKey Modifies the keyframe rule key text. SetKeyframeKeyBuilder Builder for SetKeyframeKey . SetKeyframeKeyReturnObject Modifies the keyframe rule key text. SetKeyframeKeyReturnObjectBuilder Builder for SetKeyframeKeyReturnObject . SetLocalFontsEnabled Enables/disables rendering of local CSS fonts (enabled by default). SetLocalFontsEnabledBuilder Builder for SetLocalFontsEnabled . SetLocalFontsEnabledReturnObject Enables/disables rendering of local CSS fonts (enabled by default). SetMediaText Modifies the rule selector. SetMediaTextBuilder Builder for SetMediaText . SetMediaTextReturnObject Modifies the rule selector. SetMediaTextReturnObjectBuilder Builder for SetMediaTextReturnObject . SetPropertyRulePropertyName Modifies the property rule property name. SetPropertyRulePropertyNameBuilder Builder for SetPropertyRulePropertyName . SetPropertyRulePropertyNameReturnObject Modifies the property rule property name. SetPropertyRulePropertyNameReturnObjectBuilder Builder for SetPropertyRulePropertyNameReturnObject . SetRuleSelector Modifies the rule selector. SetRuleSelectorBuilder Builder for SetRuleSelector . SetRuleSelectorReturnObject Modifies the rule selector. SetRuleSelectorReturnObjectBuilder Builder for SetRuleSelectorReturnObject . SetScopeText Modifies the expression of a scope at-rule. SetScopeTextBuilder Builder for SetScopeText . SetScopeTextReturnObject Modifies the expression of a scope at-rule. SetScopeTextReturnObjectBuilder Builder for SetScopeTextReturnObject . SetStyleSheetText Sets the new stylesheet text. SetStyleSheetTextBuilder Builder for SetStyleSheetText . SetStyleSheetTextReturnObject Sets the new stylesheet text. SetStyleSheetTextReturnObjectBuilder Builder for SetStyleSheetTextReturnObject . SetStyleTexts Applies specified style edits one after another in the given order. SetStyleTextsBuilder Builder for SetStyleTexts . SetStyleTextsReturnObject Applies specified style edits one after another in the given order. SetStyleTextsReturnObjectBuilder Builder for SetStyleTextsReturnObject . SetSupportsText Modifies the expression of a supports at-rule. SetSupportsTextBuilder Builder for SetSupportsText . SetSupportsTextReturnObject Modifies the expression of a supports at-rule. SetSupportsTextReturnObjectBuilder Builder for SetSupportsTextReturnObject . ShorthandEntry ShorthandEntryBuilder Builder for ShorthandEntry . SourceRange Text range within a resource. All numbers are zero-based. SourceRangeBuilder Builder for SourceRange . Specificity Specificity:
https://drafts.csswg.org/selectors/#specificity-rules SpecificityBuilder Builder for Specificity . StartRuleUsageTracking StartRuleUsageTrackingReturnObject Enables the selector recording. StopRuleUsageTracking StopRuleUsageTrackingReturnObject Stop tracking rule usage and return the list of rules that were used since last call to
takeCoverageDelta (or since start of coverage instrumentation). StopRuleUsageTrackingReturnObjectBuilder Builder for StopRuleUsageTrackingReturnObject . StyleDeclarationEdit A descriptor of operation to mutate style declaration text. StyleDeclarationEditBuilder Builder for StyleDeclarationEdit . TakeComputedStyleUpdates TakeComputedStyleUpdatesReturnObject Polls the next batch of computed style updates. TakeComputedStyleUpdatesReturnObjectBuilder Builder for TakeComputedStyleUpdatesReturnObject . TakeCoverageDelta TakeCoverageDeltaReturnObject Obtain list of rules that became used since last call to this method (or since start of coverage
instrumentation). TakeCoverageDeltaReturnObjectBuilder Builder for TakeCoverageDeltaReturnObject . TrackComputedStyleUpdates Starts tracking the given computed styles for updates. The specified array of properties
replaces the one previously specified. Pass empty array to disable tracking.
Use takeComputedStyleUpdates to retrieve the list of nodes that had properties modified.
The changes to computed style properties are only tracked for nodes pushed to the front-end
by the DOM agent. If no changes to the tracked properties occur after the node has been pushed
to the front-end, no updates will be issued for the node. TrackComputedStyleUpdatesBuilder Builder for TrackComputedStyleUpdates . TrackComputedStyleUpdatesForNode Starts tracking the given node for the computed style updates
and whenever the computed style is updated for node, it queues
a computedStyleUpdated event with throttling.
There can only be 1 node tracked for computed style updates
so passing a new node id removes tracking from the previous node.
Pass undefined to disable tracking. TrackComputedStyleUpdatesForNodeBuilder Builder for TrackComputedStyleUpdatesForNode . TrackComputedStyleUpdatesForNodeReturnObject Starts tracking the given node for the computed style updates
and whenever the computed style is updated for node, it queues
a computedStyleUpdated event with throttling.
There can only be 1 node tracked for computed style updates
so passing a new node id removes tracking from the previous node.
Pass undefined to disable tracking. TrackComputedStyleUpdatesReturnObject Starts tracking the given computed styles for updates. The specified array of properties
replaces the one previously specified. Pass empty array to disable tracking.
Use takeComputedStyleUpdates to retrieve the list of nodes that had properties modified.
The changes to computed style properties are only tracked for nodes pushed to the front-end
by the DOM agent. If no changes to the tracked properties occur after the node has been pushed
to the front-end, no updates will be issued for the node. Value Data for a simple selector (these are delimited by commas in a selector list). ValueBuilder Builder for Value . AddRuleBuilderError Error type for AddRuleBuilder AddRuleReturnObjectBuilderError Error type for AddRuleReturnObjectBuilder CollectClassNamesBuilderError Error type for CollectClassNamesBuilder CollectClassNamesReturnObjectBuilderError Error type for CollectClassNamesReturnObjectBuilder ComputedStyleExtraFieldsBuilderError Error type for ComputedStyleExtraFieldsBuilder CreateStyleSheetBuilderError Error type for CreateStyleSheetBuilder CreateStyleSheetReturnObjectBuilderError Error type for CreateStyleSheetReturnObjectBuilder CssAnimationStyleBuilderError Error type for CssAnimationStyleBuilder CssAtRuleBuilderError Error type for CssAtRuleBuilder CssAtRuleSubsection CssAtRuleType CssComputedStylePropertyBuilderError Error type for CssComputedStylePropertyBuilder CssContainerQueryBuilderError Error type for CssContainerQueryBuilder CssFunctionConditionNodeBuilderError Error type for CssFunctionConditionNodeBuilder CssFunctionNodeBuilderError Error type for CssFunctionNodeBuilder CssFunctionParameterBuilderError Error type for CssFunctionParameterBuilder CssFunctionRuleBuilderError Error type for CssFunctionRuleBuilder CssKeyframeRuleBuilderError Error type for CssKeyframeRuleBuilder CssKeyframesRuleBuilderError Error type for CssKeyframesRuleBuilder CssLayerBuilderError Error type for CssLayerBuilder CssLayerDataBuilderError Error type for CssLayerDataBuilder CssMediaBuilderError Error type for CssMediaBuilder CssMediaSource CssPositionTryRuleBuilderError Error type for CssPositionTryRuleBuilder CssPropertyBuilderError Error type for CssPropertyBuilder CssPropertyRegistrationBuilderError Error type for CssPropertyRegistrationBuilder CssPropertyRuleBuilderError Error type for CssPropertyRuleBuilder CssRuleBuilderError Error type for CssRuleBuilder CssRuleType CssScopeBuilderError Error type for CssScopeBuilder CssStartingStyleBuilderError Error type for CssStartingStyleBuilder CssStyleBuilderError Error type for CssStyleBuilder CssStyleSheetHeaderBuilderError Error type for CssStyleSheetHeaderBuilder CssSupportsBuilderError Error type for CssSupportsBuilder CssTryRuleBuilderError Error type for CssTryRuleBuilder FontFaceBuilderError Error type for FontFaceBuilder FontVariationAxisBuilderError Error type for FontVariationAxisBuilder ForcePseudoStateBuilderError Error type for ForcePseudoStateBuilder ForceStartingStyleBuilderError Error type for ForceStartingStyleBuilder GetAnimatedStylesForNodeBuilderError Error type for GetAnimatedStylesForNodeBuilder GetAnimatedStylesForNodeReturnObjectBuilderError Error type for GetAnimatedStylesForNodeReturnObjectBuilder GetBackgroundColorsBuilderError Error type for GetBackgroundColorsBuilder GetBackgroundColorsReturnObjectBuilderError Error type for GetBackgroundColorsReturnObjectBuilder GetComputedStyleForNodeBuilderError Error type for GetComputedStyleForNodeBuilder GetComputedStyleForNodeReturnObjectBuilderError Error type for GetComputedStyleForNodeReturnObjectBuilder GetEnvironmentVariablesReturnObjectBuilderError Error type for GetEnvironmentVariablesReturnObjectBuilder GetInlineStylesForNodeBuilderError Error type for GetInlineStylesForNodeBuilder GetInlineStylesForNodeReturnObjectBuilderError Error type for GetInlineStylesForNodeReturnObjectBuilder GetLayersForNodeBuilderError Error type for GetLayersForNodeBuilder GetLayersForNodeReturnObjectBuilderError Error type for GetLayersForNodeReturnObjectBuilder GetLocationForSelectorBuilderError Error type for GetLocationForSelectorBuilder GetLocationForSelectorReturnObjectBuilderError Error type for GetLocationForSelectorReturnObjectBuilder GetLonghandPropertiesBuilderError Error type for GetLonghandPropertiesBuilder GetLonghandPropertiesReturnObjectBuilderError Error type for GetLonghandPropertiesReturnObjectBuilder GetMatchedStylesForNodeBuilderError Error type for GetMatchedStylesForNodeBuilder GetMatchedStylesForNodeReturnObjectBuilderError Error type for GetMatchedStylesForNodeReturnObjectBuilder GetMediaQueriesReturnObjectBuilderError Error type for GetMediaQueriesReturnObjectBuilder GetPlatformFontsForNodeBuilderError Error type for GetPlatformFontsForNodeBuilder GetPlatformFontsForNodeReturnObjectBuilderError Error type for GetPlatformFontsForNodeReturnObjectBuilder GetStyleSheetTextBuilderError Error type for GetStyleSheetTextBuilder GetStyleSheetTextReturnObjectBuilderError Error type for GetStyleSheetTextReturnObjectBuilder InheritedAnimatedStyleEntryBuilderError Error type for InheritedAnimatedStyleEntryBuilder InheritedPseudoElementMatchesBuilderError Error type for InheritedPseudoElementMatchesBuilder InheritedStyleEntryBuilderError Error type for InheritedStyleEntryBuilder MediaQueryBuilderError Error type for MediaQueryBuilder MediaQueryExpressionBuilderError Error type for MediaQueryExpressionBuilder PlatformFontUsageBuilderError Error type for PlatformFontUsageBuilder PseudoElementMatchesBuilderError Error type for PseudoElementMatchesBuilder ResolveValuesBuilderError Error type for ResolveValuesBuilder ResolveValuesReturnObjectBuilderError Error type for ResolveValuesReturnObjectBuilder RuleMatchBuilderError Error type for RuleMatchBuilder RuleUsageBuilderError Error type for RuleUsageBuilder SelectorListBuilderError Error type for SelectorListBuilder SetContainerQueryTextBuilderError Error type for SetContainerQueryTextBuilder SetContainerQueryTextReturnObjectBuilderError Error type for SetContainerQueryTextReturnObjectBuilder SetEffectivePropertyValueForNodeBuilderError Error type for SetEffectivePropertyValueForNodeBuilder SetKeyframeKeyBuilderError Error type for SetKeyframeKeyBuilder SetKeyframeKeyReturnObjectBuilderError Error type for SetKeyframeKeyReturnObjectBuilder SetLocalFontsEnabledBuilderError Error type for SetLocalFontsEnabledBuilder SetMediaTextBuilderError Error type for SetMediaTextBuilder SetMediaTextReturnObjectBuilderError Error type for SetMediaTextReturnObjectBuilder SetPropertyRulePropertyNameBuilderError Error type for SetPropertyRulePropertyNameBuilder SetPropertyRulePropertyNameReturnObjectBuilderError Error type for SetPropertyRulePropertyNameReturnObjectBuilder SetRuleSelectorBuilderError Error type for SetRuleSelectorBuilder SetRuleSelectorReturnObjectBuilderError Error type for SetRuleSelectorReturnObjectBuilder SetScopeTextBuilderError Error type for SetScopeTextBuilder SetScopeTextReturnObjectBuilderError Error type for SetScopeTextReturnObjectBuilder SetStyleSheetTextBuilderError Error type for SetStyleSheetTextBuilder SetStyleSheetTextReturnObjectBuilderError Error type for SetStyleSheetTextReturnObjectBuilder SetStyleTextsBuilderError Error type for SetStyleTextsBuilder SetStyleTextsReturnObjectBuilderError Error type for SetStyleTextsReturnObjectBuilder SetSupportsTextBuilderError Error type for SetSupportsTextBuilder SetSupportsTextReturnObjectBuilderError Error type for SetSupportsTextReturnObjectBuilder ShorthandEntryBuilderError Error type for ShorthandEntryBuilder SourceRangeBuilderError Error type for SourceRangeBuilder SpecificityBuilderError Error type for SpecificityBuilder StopRuleUsageTrackingReturnObjectBuilderError Error type for StopRuleUsageTrackingReturnObjectBuilder StyleDeclarationEditBuilderError Error type for StyleDeclarationEditBuilder StyleSheetOrigin TakeComputedStyleUpdatesReturnObjectBuilderError Error type for TakeComputedStyleUpdatesReturnObjectBuilder TakeCoverageDeltaReturnObjectBuilderError Error type for TakeCoverageDeltaReturnObjectBuilder TrackComputedStyleUpdatesBuilderError Error type for TrackComputedStyleUpdatesBuilder TrackComputedStyleUpdatesForNodeBuilderError Error type for TrackComputedStyleUpdatesForNodeBuilder ValueBuilderError Error type for ValueBuilder