pub struct AddRuleBuilder { /* private fields */ }Expand description
Builder for AddRule.
Implementations
Sourceimpl AddRuleBuilder
impl AddRuleBuilder
Sourcepub fn style_sheet_id<VALUE: Into<StyleSheetId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn style_sheet_id<VALUE: Into<StyleSheetId>>( &mut self, value: VALUE, ) -> &mut Self
The css style sheet identifier where a new rule should be inserted.
Sourcepub fn rule_text<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn rule_text<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The text of a new rule.
Sourcepub fn location<VALUE: Into<SourceRange>>(&mut self, value: VALUE) -> &mut Self
pub fn location<VALUE: Into<SourceRange>>(&mut self, value: VALUE) -> &mut Self
Text position of a new rule in the target style sheet.
Sourcepub fn node_for_property_syntax_validation<VALUE: Into<NodeId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn node_for_property_syntax_validation<VALUE: Into<NodeId>>( &mut self, value: VALUE, ) -> &mut Self
NodeId for the DOM node in whose context custom property declarations for registered properties should be validated. If omitted, declarations in the new rule text can only be validated statically, which may produce incorrect results if the declaration contains a var() for example.