pub struct CssRuleBuilder { /* private fields */ }Expand description
Builder for CssRule.
Implementations
Sourceimpl CssRuleBuilder
impl CssRuleBuilder
Sourcepub fn style_sheet_id<VALUE: Into<StyleSheetId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn style_sheet_id<VALUE: Into<StyleSheetId>>( &mut self, value: VALUE, ) -> &mut Self
The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from.
Sourcepub fn selector_list<VALUE: Into<SelectorList>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn selector_list<VALUE: Into<SelectorList>>( &mut self, value: VALUE, ) -> &mut Self
Rule selector data.
Sourcepub fn nesting_selectors<VALUE: Into<Vec<String>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn nesting_selectors<VALUE: Into<Vec<String>>>( &mut self, value: VALUE, ) -> &mut Self
Array of selectors from ancestor style rules, sorted by distance from the current rule.
Sourcepub fn origin<VALUE: Into<StyleSheetOrigin>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn origin<VALUE: Into<StyleSheetOrigin>>( &mut self, value: VALUE, ) -> &mut Self
Parent stylesheet’s origin.
Sourcepub fn style<VALUE: Into<CssStyle>>(&mut self, value: VALUE) -> &mut Self
pub fn style<VALUE: Into<CssStyle>>(&mut self, value: VALUE) -> &mut Self
Associated style declaration.
Sourcepub fn origin_tree_scope_node_id<VALUE: Into<BackendNodeId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn origin_tree_scope_node_id<VALUE: Into<BackendNodeId>>( &mut self, value: VALUE, ) -> &mut Self
The BackendNodeId of the DOM node that constitutes the origin tree scope of this rule.
Sourcepub fn media<VALUE: Into<Vec<CssMedia>>>(&mut self, value: VALUE) -> &mut Self
pub fn media<VALUE: Into<Vec<CssMedia>>>(&mut self, value: VALUE) -> &mut Self
Media list array (for rules involving media queries). The array enumerates media queries starting with the innermost one, going outwards.
Sourcepub fn container_queries<VALUE: Into<Vec<CssContainerQuery>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn container_queries<VALUE: Into<Vec<CssContainerQuery>>>( &mut self, value: VALUE, ) -> &mut Self
Container query list array (for rules involving container queries). The array enumerates container queries starting with the innermost one, going outwards.
Sourcepub fn supports<VALUE: Into<Vec<CssSupports>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn supports<VALUE: Into<Vec<CssSupports>>>( &mut self, value: VALUE, ) -> &mut Self
@supports CSS at-rule array. The array enumerates @supports at-rules starting with the innermost one, going outwards.
Sourcepub fn layers<VALUE: Into<Vec<CssLayer>>>(&mut self, value: VALUE) -> &mut Self
pub fn layers<VALUE: Into<Vec<CssLayer>>>(&mut self, value: VALUE) -> &mut Self
Cascade layer array. Contains the layer hierarchy that this rule belongs to starting with the innermost layer and going outwards.
Sourcepub fn scopes<VALUE: Into<Vec<CssScope>>>(&mut self, value: VALUE) -> &mut Self
pub fn scopes<VALUE: Into<Vec<CssScope>>>(&mut self, value: VALUE) -> &mut Self
@scope CSS at-rule array. The array enumerates @scope at-rules starting with the innermost one, going outwards.
Sourcepub fn rule_types<VALUE: Into<Vec<CssRuleType>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn rule_types<VALUE: Into<Vec<CssRuleType>>>( &mut self, value: VALUE, ) -> &mut Self
The array keeps the types of ancestor CSSRules from the innermost going outwards.
Sourcepub fn starting_styles<VALUE: Into<Vec<CssStartingStyle>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn starting_styles<VALUE: Into<Vec<CssStartingStyle>>>( &mut self, value: VALUE, ) -> &mut Self
@starting-style CSS at-rule array. The array enumerates @starting-style at-rules starting with the innermost one, going outwards.