pub struct GetMatchedStylesForNodeReturnObjectBuilder { /* private fields */ }Expand description
Builder for GetMatchedStylesForNodeReturnObject.
Implementations
Sourceimpl GetMatchedStylesForNodeReturnObjectBuilder
impl GetMatchedStylesForNodeReturnObjectBuilder
Sourcepub fn inline_style(&mut self, value: Option<CssStyle>) -> &mut Self
pub fn inline_style(&mut self, value: Option<CssStyle>) -> &mut Self
Inline style for the specified DOM node.
Sourcepub fn attributes_style(&mut self, value: Option<CssStyle>) -> &mut Self
pub fn attributes_style(&mut self, value: Option<CssStyle>) -> &mut Self
Attribute-defined element style (e.g. resulting from “width=20 height=100%”).
Sourcepub fn matched_css_rules(&mut self, value: Option<Vec<RuleMatch>>) -> &mut Self
pub fn matched_css_rules(&mut self, value: Option<Vec<RuleMatch>>) -> &mut Self
CSS rules matching this node, from all applicable stylesheets.
Sourcepub fn pseudo_elements(
&mut self,
value: Option<Vec<PseudoElementMatches>>,
) -> &mut Self
pub fn pseudo_elements( &mut self, value: Option<Vec<PseudoElementMatches>>, ) -> &mut Self
Pseudo style matches for this node.
Sourcepub fn inherited(
&mut self,
value: Option<Vec<InheritedStyleEntry>>,
) -> &mut Self
pub fn inherited( &mut self, value: Option<Vec<InheritedStyleEntry>>, ) -> &mut Self
A chain of inherited styles (from the immediate node parent up to the DOM tree root).
Sourcepub fn inherited_pseudo_elements(
&mut self,
value: Option<Vec<InheritedPseudoElementMatches>>,
) -> &mut Self
pub fn inherited_pseudo_elements( &mut self, value: Option<Vec<InheritedPseudoElementMatches>>, ) -> &mut Self
A chain of inherited pseudo element styles (from the immediate node parent up to the DOM tree root).
Sourcepub fn css_keyframes_rules(
&mut self,
value: Option<Vec<CssKeyframesRule>>,
) -> &mut Self
pub fn css_keyframes_rules( &mut self, value: Option<Vec<CssKeyframesRule>>, ) -> &mut Self
A list of CSS keyframed animations matching this node.
Sourcepub fn css_position_try_rules(
&mut self,
value: Option<Vec<CssPositionTryRule>>,
) -> &mut Self
pub fn css_position_try_rules( &mut self, value: Option<Vec<CssPositionTryRule>>, ) -> &mut Self
A list of CSS @position-try rules matching this node, based on the position-try-fallbacks property.
Sourcepub fn active_position_fallback_index(
&mut self,
value: Option<JsUInt>,
) -> &mut Self
pub fn active_position_fallback_index( &mut self, value: Option<JsUInt>, ) -> &mut Self
Index of the active fallback in the applied position-try-fallback property, will not be set if there is no active position-try fallback.
Sourcepub fn css_property_rules(
&mut self,
value: Option<Vec<CssPropertyRule>>,
) -> &mut Self
pub fn css_property_rules( &mut self, value: Option<Vec<CssPropertyRule>>, ) -> &mut Self
A list of CSS at-property rules matching this node.
Sourcepub fn css_property_registrations(
&mut self,
value: Option<Vec<CssPropertyRegistration>>,
) -> &mut Self
pub fn css_property_registrations( &mut self, value: Option<Vec<CssPropertyRegistration>>, ) -> &mut Self
A list of CSS property registrations matching this node.
Sourcepub fn css_at_rules(&mut self, value: Option<Vec<CssAtRule>>) -> &mut Self
pub fn css_at_rules(&mut self, value: Option<Vec<CssAtRule>>) -> &mut Self
A list of simple @rules matching this node or its pseudo-elements.
Sourcepub fn parent_layout_node_id(&mut self, value: Option<NodeId>) -> &mut Self
pub fn parent_layout_node_id(&mut self, value: Option<NodeId>) -> &mut Self
Id of the first parent element that does not have display: contents.
Sourcepub fn css_function_rules(
&mut self,
value: Option<Vec<CssFunctionRule>>,
) -> &mut Self
pub fn css_function_rules( &mut self, value: Option<Vec<CssFunctionRule>>, ) -> &mut Self
A list of CSS at-function rules referenced by styles of this node.
Sourcepub fn build(
&self,
) -> Result<GetMatchedStylesForNodeReturnObject, GetMatchedStylesForNodeReturnObjectBuilderError>
pub fn build( &self, ) -> Result<GetMatchedStylesForNodeReturnObject, GetMatchedStylesForNodeReturnObjectBuilderError>
Builds a new GetMatchedStylesForNodeReturnObject.
Errors
If a required field has not been initialized.