pub struct SpecificityBuilder { /* private fields */ }Expand description
Builder for Specificity.
Implementations
Sourceimpl SpecificityBuilder
impl SpecificityBuilder
Sourcepub fn a<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn a<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The a component, which represents the number of ID selectors.
Sourcepub fn b<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn b<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The b component, which represents the number of class selectors, attributes selectors, and pseudo-classes.
Sourcepub fn c<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn c<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The c component, which represents the number of type selectors and pseudo-elements.
Sourcepub fn build(&self) -> Result<Specificity, SpecificityBuilderError>
pub fn build(&self) -> Result<Specificity, SpecificityBuilderError>