pub struct ScriptParsedEventParamsBuilder { /* private fields */ }Expand description
Builder for ScriptParsedEventParams.
Implementations
Sourceimpl ScriptParsedEventParamsBuilder
impl ScriptParsedEventParamsBuilder
Sourcepub fn start_line(&mut self, value: JsUInt) -> &mut Self
pub fn start_line(&mut self, value: JsUInt) -> &mut Self
Line offset of the script within the resource with given URL (for script tags).
Sourcepub fn start_column(&mut self, value: JsUInt) -> &mut Self
pub fn start_column(&mut self, value: JsUInt) -> &mut Self
Column offset of the script within the resource with given URL.
Sourcepub fn end_column(&mut self, value: JsUInt) -> &mut Self
pub fn end_column(&mut self, value: JsUInt) -> &mut Self
Length of the last line of the script.
Sourcepub fn execution_context_id(&mut self, value: ExecutionContextId) -> &mut Self
pub fn execution_context_id(&mut self, value: ExecutionContextId) -> &mut Self
Specifies script creation context.
Sourcepub fn build_id(&mut self, value: String) -> &mut Self
pub fn build_id(&mut self, value: String) -> &mut Self
For Wasm modules, the content of the build_id custom section. For JavaScript the debugId magic comment.
Sourcepub fn execution_context_aux_data(&mut self, value: Option<Json>) -> &mut Self
pub fn execution_context_aux_data(&mut self, value: Option<Json>) -> &mut Self
Embedder-specific auxiliary data likely matching {isDefault: boolean, type: ‘default’|‘isolated’|‘worker’, frameId: string}
Sourcepub fn is_live_edit(&mut self, value: Option<bool>) -> &mut Self
pub fn is_live_edit(&mut self, value: Option<bool>) -> &mut Self
True, if this script is generated as a result of the live edit operation.
Sourcepub fn source_map_url(&mut self, value: Option<String>) -> &mut Self
pub fn source_map_url(&mut self, value: Option<String>) -> &mut Self
URL of source map associated with script (if any).
Sourcepub fn has_source_url(&mut self, value: Option<bool>) -> &mut Self
pub fn has_source_url(&mut self, value: Option<bool>) -> &mut Self
True, if this script has sourceURL.
Sourcepub fn is_module(&mut self, value: Option<bool>) -> &mut Self
pub fn is_module(&mut self, value: Option<bool>) -> &mut Self
True, if this script is ES6 module.
Sourcepub fn stack_trace(&mut self, value: Option<StackTrace>) -> &mut Self
pub fn stack_trace(&mut self, value: Option<StackTrace>) -> &mut Self
JavaScript top stack frame of where the script parsed event was triggered if available.
Sourcepub fn code_offset(&mut self, value: Option<JsUInt>) -> &mut Self
pub fn code_offset(&mut self, value: Option<JsUInt>) -> &mut Self
If the scriptLanguage is WebAssembly, the code section offset in the module.
Sourcepub fn script_language(&mut self, value: Option<ScriptLanguage>) -> &mut Self
pub fn script_language(&mut self, value: Option<ScriptLanguage>) -> &mut Self
The language of the script.
Sourcepub fn debug_symbols(&mut self, value: Option<DebugSymbols>) -> &mut Self
pub fn debug_symbols(&mut self, value: Option<DebugSymbols>) -> &mut Self
If the scriptLanguage is WebAssembly, the source of debug symbols for the module.
Sourcepub fn embedder_name(&mut self, value: Option<String>) -> &mut Self
pub fn embedder_name(&mut self, value: Option<String>) -> &mut Self
The name the embedder supplied for this script.
Sourcepub fn resolved_breakpoints(
&mut self,
value: Option<Vec<ResolvedBreakpoint>>,
) -> &mut Self
pub fn resolved_breakpoints( &mut self, value: Option<Vec<ResolvedBreakpoint>>, ) -> &mut Self
The list of set breakpoints in this script if calls to setBreakpointByUrl
matches this script’s URL or hash. Clients that use this list can ignore the
breakpointResolved event. They are equivalent.
Sourcepub fn build(
&self,
) -> Result<ScriptParsedEventParams, ScriptParsedEventParamsBuilderError>
pub fn build( &self, ) -> Result<ScriptParsedEventParams, ScriptParsedEventParamsBuilderError>