pub struct SetBlackboxedRangesReturnObject(pub Option<Value>);Expand description
Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. Positions array contains positions where blackbox state is changed. First interval isn’t blackboxed. Array should be sorted.
Tuple Fields
0: Option<Value>Trait Implementations
Sourceimpl Clone for SetBlackboxedRangesReturnObject
impl Clone for SetBlackboxedRangesReturnObject
Sourcefn clone(&self) -> SetBlackboxedRangesReturnObject
fn clone(&self) -> SetBlackboxedRangesReturnObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SetBlackboxedRangesReturnObject
impl<'de> Deserialize<'de> for SetBlackboxedRangesReturnObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SetBlackboxedRangesReturnObject
impl PartialEq for SetBlackboxedRangesReturnObject
Sourcefn eq(&self, other: &SetBlackboxedRangesReturnObject) -> bool
fn eq(&self, other: &SetBlackboxedRangesReturnObject) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SetBlackboxedRangesReturnObject