pub struct ScrollIntoViewIfNeededBuilder { /* private fields */ }Expand description
Builder for ScrollIntoViewIfNeeded.
Implementations
Sourceimpl ScrollIntoViewIfNeededBuilder
impl ScrollIntoViewIfNeededBuilder
Sourcepub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
pub fn node_id<VALUE: Into<NodeId>>(&mut self, value: VALUE) -> &mut Self
Identifier of the node.
Sourcepub fn backend_node_id<VALUE: Into<BackendNodeId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn backend_node_id<VALUE: Into<BackendNodeId>>( &mut self, value: VALUE, ) -> &mut Self
Identifier of the backend node.
Sourcepub fn object_id<VALUE: Into<RemoteObjectId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn object_id<VALUE: Into<RemoteObjectId>>( &mut self, value: VALUE, ) -> &mut Self
JavaScript object id of the node wrapper.
Sourcepub fn rect<VALUE: Into<Rect>>(&mut self, value: VALUE) -> &mut Self
pub fn rect<VALUE: Into<Rect>>(&mut self, value: VALUE) -> &mut Self
The rect to be scrolled into view, relative to the node’s border box, in CSS pixels. When omitted, center of the node will be used, similar to Element.scrollIntoView.
Sourcepub fn build(
&self,
) -> Result<ScrollIntoViewIfNeeded, ScrollIntoViewIfNeededBuilderError>
pub fn build( &self, ) -> Result<ScrollIntoViewIfNeeded, ScrollIntoViewIfNeededBuilderError>