pub struct LayoutTreeSnapshotBuilder { /* private fields */ }Expand description
Builder for LayoutTreeSnapshot.
Implementations
Sourceimpl LayoutTreeSnapshotBuilder
impl LayoutTreeSnapshotBuilder
Sourcepub fn node_index<VALUE: Into<Vec<JsUInt>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn node_index<VALUE: Into<Vec<JsUInt>>>( &mut self, value: VALUE, ) -> &mut Self
Index of the corresponding node in the NodeTreeSnapshot array returned by captureSnapshot.
Sourcepub fn styles<VALUE: Into<Vec<ArrayOfStrings>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn styles<VALUE: Into<Vec<ArrayOfStrings>>>( &mut self, value: VALUE, ) -> &mut Self
Array of indexes specifying computed style strings, filtered according to the computedStyles parameter passed to captureSnapshot.
Sourcepub fn bounds<VALUE: Into<Vec<Rectangle>>>(&mut self, value: VALUE) -> &mut Self
pub fn bounds<VALUE: Into<Vec<Rectangle>>>(&mut self, value: VALUE) -> &mut Self
The absolute position bounding box.
Sourcepub fn text<VALUE: Into<Vec<StringIndex>>>(&mut self, value: VALUE) -> &mut Self
pub fn text<VALUE: Into<Vec<StringIndex>>>(&mut self, value: VALUE) -> &mut Self
Contents of the LayoutText, if any.
Sourcepub fn stacking_contexts<VALUE: Into<RareBooleanData>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn stacking_contexts<VALUE: Into<RareBooleanData>>( &mut self, value: VALUE, ) -> &mut Self
Stacking context information.
Sourcepub fn paint_orders<VALUE: Into<Vec<JsUInt>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn paint_orders<VALUE: Into<Vec<JsUInt>>>( &mut self, value: VALUE, ) -> &mut Self
Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in captureSnapshot was true.
Sourcepub fn offset_rects<VALUE: Into<Vec<Rectangle>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn offset_rects<VALUE: Into<Vec<Rectangle>>>( &mut self, value: VALUE, ) -> &mut Self
The offset rect of nodes. Only available when includeDOMRects is set to true
Sourcepub fn scroll_rects<VALUE: Into<Vec<Rectangle>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn scroll_rects<VALUE: Into<Vec<Rectangle>>>( &mut self, value: VALUE, ) -> &mut Self
The scroll rect of nodes. Only available when includeDOMRects is set to true
Sourcepub fn client_rects<VALUE: Into<Vec<Rectangle>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn client_rects<VALUE: Into<Vec<Rectangle>>>( &mut self, value: VALUE, ) -> &mut Self
The client rect of nodes. Only available when includeDOMRects is set to true
Sourcepub fn blended_background_colors<VALUE: Into<Vec<StringIndex>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn blended_background_colors<VALUE: Into<Vec<StringIndex>>>( &mut self, value: VALUE, ) -> &mut Self
The list of background colors that are blended with colors of overlapping elements.
Sourcepub fn text_color_opacities<VALUE: Into<Vec<JsFloat>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn text_color_opacities<VALUE: Into<Vec<JsFloat>>>( &mut self, value: VALUE, ) -> &mut Self
The list of computed text opacities.
Sourcepub fn build(
&self,
) -> Result<LayoutTreeSnapshot, LayoutTreeSnapshotBuilderError>
pub fn build( &self, ) -> Result<LayoutTreeSnapshot, LayoutTreeSnapshotBuilderError>