pub struct EnableBuilder { /* private fields */ }Expand description
Builder for Enable.
Implementations
Sourceimpl EnableBuilder
impl EnableBuilder
Sourcepub fn patterns<VALUE: Into<Vec<RequestPattern>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn patterns<VALUE: Into<Vec<RequestPattern>>>( &mut self, value: VALUE, ) -> &mut Self
If specified, only requests matching any of these patterns will produce fetchRequested event and will be paused until clients response. If not set, all requests will be affected.
Sourcepub fn handle_auth_requests<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn handle_auth_requests<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
If true, authRequired events will be issued and requests will be paused expecting a call to continueWithAuth.