Modules
Structs
- Cancel
Dragging - Cancel
Dragging Return Object - Cancels any active dragging in the page.
- Dispatch
Drag Event - Dispatches a drag event into the page.
- Dispatch
Drag Event Builder - Builder for
DispatchDragEvent. - Dispatch
Drag Event Return Object - Dispatches a drag event into the page.
- Dispatch
KeyEvent - Dispatches a key event to the page.
- Dispatch
KeyEvent Builder - Builder for
DispatchKeyEvent. - Dispatch
KeyEvent Return Object - Dispatches a key event to the page.
- Dispatch
Mouse Event - Dispatches a mouse event to the page.
- Dispatch
Mouse Event Builder - Builder for
DispatchMouseEvent. - Dispatch
Mouse Event Return Object - Dispatches a mouse event to the page.
- Dispatch
Touch Event - Dispatches a touch event to the page.
- Dispatch
Touch Event Builder - Builder for
DispatchTouchEvent. - Dispatch
Touch Event Return Object - Dispatches a touch event to the page.
- Drag
Data - Drag
Data Builder - Builder for
DragData. - Drag
Data Item - Drag
Data Item Builder - Builder for
DragDataItem. - Emulate
Touch From Mouse Event - Emulates touch event from the mouse event parameters.
- Emulate
Touch From Mouse Event Builder - Builder for
EmulateTouchFromMouseEvent. - Emulate
Touch From Mouse Event Return Object - Emulates touch event from the mouse event parameters.
- ImeSet
Composition - This method sets the current candidate text for IME. Use imeCommitComposition to commit the final text. Use imeSetComposition with empty string as text to cancel composition.
- ImeSet
Composition Builder - Builder for
ImeSetComposition. - ImeSet
Composition Return Object - This method sets the current candidate text for IME. Use imeCommitComposition to commit the final text. Use imeSetComposition with empty string as text to cancel composition.
- Insert
Text - This method emulates inserting text that doesn’t come from a key press, for example an emoji keyboard or an IME.
- Insert
Text Builder - Builder for
InsertText. - Insert
Text Return Object - This method emulates inserting text that doesn’t come from a key press, for example an emoji keyboard or an IME.
- SetIgnore
Input Events - Ignores input events (useful while auditing page).
- SetIgnore
Input Events Builder - Builder for
SetIgnoreInputEvents. - SetIgnore
Input Events Return Object - Ignores input events (useful while auditing page).
- SetIntercept
Drags - Prevents default drag and drop behavior and instead emits
Input.dragInterceptedevents. Drag and drop behavior can be directly controlled viaInput.dispatchDragEvent. - SetIntercept
Drags Builder - Builder for
SetInterceptDrags. - SetIntercept
Drags Return Object - Prevents default drag and drop behavior and instead emits
Input.dragInterceptedevents. Drag and drop behavior can be directly controlled viaInput.dispatchDragEvent. - Synthesize
Pinch Gesture - Synthesizes a pinch gesture over a time period by issuing appropriate touch events.
- Synthesize
Pinch Gesture Builder - Builder for
SynthesizePinchGesture. - Synthesize
Pinch Gesture Return Object - Synthesizes a pinch gesture over a time period by issuing appropriate touch events.
- Synthesize
Scroll Gesture - Synthesizes a scroll gesture over a time period by issuing appropriate touch events.
- Synthesize
Scroll Gesture Builder - Builder for
SynthesizeScrollGesture. - Synthesize
Scroll Gesture Return Object - Synthesizes a scroll gesture over a time period by issuing appropriate touch events.
- Synthesize
TapGesture - Synthesizes a tap gesture over a time period by issuing appropriate touch events.
- Synthesize
TapGesture Builder - Builder for
SynthesizeTapGesture. - Synthesize
TapGesture Return Object - Synthesizes a tap gesture over a time period by issuing appropriate touch events.
- Touch
Point - Touch
Point Builder - Builder for
TouchPoint.
Enums
- Dispatch
Drag Event Builder Error - Error type for DispatchDragEventBuilder
- Dispatch
Drag Event Type Option - Dispatch
KeyEvent Builder Error - Error type for DispatchKeyEventBuilder
- Dispatch
KeyEvent Type Option - Dispatch
Mouse Event Builder Error - Error type for DispatchMouseEventBuilder
- Dispatch
Mouse Event Pointer Type Option - Dispatch
Mouse Event Type Option - Dispatch
Touch Event Builder Error - Error type for DispatchTouchEventBuilder
- Dispatch
Touch Event Type Option - Drag
Data Builder Error - Error type for DragDataBuilder
- Drag
Data Item Builder Error - Error type for DragDataItemBuilder
- Emulate
Touch From Mouse Event Builder Error - Error type for EmulateTouchFromMouseEventBuilder
- Emulate
Touch From Mouse Event Type Option - Gesture
Source Type - ImeSet
Composition Builder Error - Error type for ImeSetCompositionBuilder
- Insert
Text Builder Error - Error type for InsertTextBuilder
- Mouse
Button - SetIgnore
Input Events Builder Error - Error type for SetIgnoreInputEventsBuilder
- SetIntercept
Drags Builder Error - Error type for SetInterceptDragsBuilder
- Synthesize
Pinch Gesture Builder Error - Error type for SynthesizePinchGestureBuilder
- Synthesize
Scroll Gesture Builder Error - Error type for SynthesizeScrollGestureBuilder
- Synthesize
TapGesture Builder Error - Error type for SynthesizeTapGestureBuilder
- Touch
Point Builder Error - Error type for TouchPointBuilder