pub struct DispatchDragEventBuilder { /* private fields */ }Expand description
Builder for DispatchDragEvent.
Implementations
Sourceimpl DispatchDragEventBuilder
impl DispatchDragEventBuilder
Sourcepub fn type<VALUE: Into<DispatchDragEventTypeOption>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn type<VALUE: Into<DispatchDragEventTypeOption>>( &mut self, value: VALUE, ) -> &mut Self
Type of the drag event.
Sourcepub fn x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
X coordinate of the event relative to the main frame’s viewport in CSS pixels.
Sourcepub fn y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.
pub fn data<VALUE: Into<DragData>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn modifiers<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn modifiers<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0).
Sourcepub fn build(&self) -> Result<DispatchDragEvent, DispatchDragEventBuilderError>
pub fn build(&self) -> Result<DispatchDragEvent, DispatchDragEventBuilderError>