pub struct SynthesizeScrollGestureBuilder { /* private fields */ }Expand description
Builder for SynthesizeScrollGesture.
Implementations
Sourceimpl SynthesizeScrollGestureBuilder
impl SynthesizeScrollGestureBuilder
Sourcepub fn x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn x<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
X coordinate of the start of the gesture in CSS pixels.
Sourcepub fn y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn y<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Y coordinate of the start of the gesture in CSS pixels.
Sourcepub fn x_distance<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn x_distance<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
The distance to scroll along the X axis (positive to scroll left).
Sourcepub fn y_distance<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn y_distance<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
The distance to scroll along the Y axis (positive to scroll up).
Sourcepub fn x_overscroll<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn x_overscroll<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
The number of additional pixels to scroll back along the X axis, in addition to the given distance.
Sourcepub fn y_overscroll<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn y_overscroll<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
The number of additional pixels to scroll back along the Y axis, in addition to the given distance.
Sourcepub fn prevent_fling<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn prevent_fling<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Prevent fling (default: true).
Sourcepub fn speed<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn speed<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Swipe speed in pixels per second (default: 800).
Sourcepub fn gesture_source_type<VALUE: Into<GestureSourceType>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn gesture_source_type<VALUE: Into<GestureSourceType>>( &mut self, value: VALUE, ) -> &mut Self
Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).
Sourcepub fn repeat_count<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn repeat_count<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
The number of times to repeat the gesture (default: 0).
Sourcepub fn repeat_delay_ms<VALUE: Into<JsUInt>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn repeat_delay_ms<VALUE: Into<JsUInt>>( &mut self, value: VALUE, ) -> &mut Self
The number of milliseconds delay between each repeat. (default: 250).
Sourcepub fn interaction_marker_name<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn interaction_marker_name<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
The name of the interaction markers to generate, if not empty (default: “”).
Sourcepub fn build(
&self,
) -> Result<SynthesizeScrollGesture, SynthesizeScrollGestureBuilderError>
pub fn build( &self, ) -> Result<SynthesizeScrollGesture, SynthesizeScrollGestureBuilderError>