pub struct ReadBuilder { /* private fields */ }Expand description
Builder for Read.
Implementations
Sourceimpl ReadBuilder
impl ReadBuilder
Sourcepub fn handle<VALUE: Into<StreamHandle>>(&mut self, value: VALUE) -> &mut Self
pub fn handle<VALUE: Into<StreamHandle>>(&mut self, value: VALUE) -> &mut Self
Handle of the stream to read.
Sourcepub fn offset<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn offset<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Seek to the specified offset before reading (if not specified, proceed with offset following the last read). Some types of streams may only support sequential reads.