Modules
Structs
- Clear
- Clear
Return Object - Clears the log.
- Disable
- Disable
Return Object - Disables log domain, prevents further log entries from being reported to the client.
- Enable
- Enable
Return Object - Enables log domain, sends the entries collected so far to the client by means of the
entryAddednotification. - LogEntry
- Log entry.
- LogEntry
Builder - Builder for
LogEntry. - Start
Violations Report - start violation reporting.
- Start
Violations Report Builder - Builder for
StartViolationsReport. - Start
Violations Report Return Object - start violation reporting.
- Stop
Violations Report - Stop
Violations Report Return Object - Stop violation reporting.
- Violation
Setting - Violation configuration setting.
- Violation
Setting Builder - Builder for
ViolationSetting.
Enums
- LogEntry
Builder Error - Error type for LogEntryBuilder
- LogEntry
Category - LogEntry
Level - LogEntry
Source - Start
Violations Report Builder Error - Error type for StartViolationsReportBuilder
- Violation
Setting Builder Error - Error type for ViolationSettingBuilder
- Violation
Setting Name