Modules
Structs
- DomCounter
- DOM object counter data.
- DomCounter
Builder - Builder for
DomCounter. - Forcibly
Purge Java Script Memory - Forcibly
Purge Java Script Memory Return Object - Simulate OomIntervention by purging V8 memory.
- GetAll
Time Sampling Profile - GetAll
Time Sampling Profile Return Object - Retrieve native memory allocations profile collected since renderer process startup.
- GetAll
Time Sampling Profile Return Object Builder - Builder for
GetAllTimeSamplingProfileReturnObject. - GetBrowser
Sampling Profile - GetBrowser
Sampling Profile Return Object - Retrieve native memory allocations profile collected since browser process startup.
- GetBrowser
Sampling Profile Return Object Builder - Builder for
GetBrowserSamplingProfileReturnObject. - GetDOM
Counters - GetDOM
Counters ForLeak Detection - GetDOM
Counters ForLeak Detection Return Object - Retruns DOM object counters after preparing renderer for leak detection.
- GetDOM
Counters ForLeak Detection Return Object Builder - Builder for
GetDOMCountersForLeakDetectionReturnObject. - GetDOM
Counters Return Object - Retruns current DOM object counters.
- GetDOM
Counters Return Object Builder - Builder for
GetDOMCountersReturnObject. - GetSampling
Profile - GetSampling
Profile Return Object - Retrieve native memory allocations profile collected since last
startSamplingcall. - GetSampling
Profile Return Object Builder - Builder for
GetSamplingProfileReturnObject. - Module
- Executable module information
- Module
Builder - Builder for
Module. - Prepare
ForLeak Detection - Prepare
ForLeak Detection Return Object - Prepares for leak detection by terminating workers, stopping spellcheckers, dropping non-essential internal caches, running garbage collections, etc.
- Sampling
Profile - Array of heap profile samples.
- Sampling
Profile Builder - Builder for
SamplingProfile. - Sampling
Profile Node - Heap profile sample.
- Sampling
Profile Node Builder - Builder for
SamplingProfileNode. - SetPressure
Notifications Suppressed - Enable/disable suppressing memory pressure notifications in all processes.
- SetPressure
Notifications Suppressed Builder - Builder for
SetPressureNotificationsSuppressed. - SetPressure
Notifications Suppressed Return Object - Enable/disable suppressing memory pressure notifications in all processes.
- Simulate
Pressure Notification - Simulate a memory pressure notification in all processes.
- Simulate
Pressure Notification Builder - Builder for
SimulatePressureNotification. - Simulate
Pressure Notification Return Object - Simulate a memory pressure notification in all processes.
- Start
Sampling - Start collecting native memory profile.
- Start
Sampling Builder - Builder for
StartSampling. - Start
Sampling Return Object - Start collecting native memory profile.
- Stop
Sampling - Stop
Sampling Return Object - Stop collecting native memory profile.
Enums
- DomCounter
Builder Error - Error type for DomCounterBuilder
- GetAll
Time Sampling Profile Return Object Builder Error - Error type for GetAllTimeSamplingProfileReturnObjectBuilder
- GetBrowser
Sampling Profile Return Object Builder Error - Error type for GetBrowserSamplingProfileReturnObjectBuilder
- GetDOM
Counters ForLeak Detection Return Object Builder Error - Error type for GetDOMCountersForLeakDetectionReturnObjectBuilder
- GetDOM
Counters Return Object Builder Error - Error type for GetDOMCountersReturnObjectBuilder
- GetSampling
Profile Return Object Builder Error - Error type for GetSamplingProfileReturnObjectBuilder
- Module
Builder Error - Error type for ModuleBuilder
- Pressure
Level - Sampling
Profile Builder Error - Error type for SamplingProfileBuilder
- Sampling
Profile Node Builder Error - Error type for SamplingProfileNodeBuilder
- SetPressure
Notifications Suppressed Builder Error - Error type for SetPressureNotificationsSuppressedBuilder
- Simulate
Pressure Notification Builder Error - Error type for SimulatePressureNotificationBuilder
- Start
Sampling Builder Error - Error type for StartSamplingBuilder