pub struct RequestWillBeSentEventParamsBuilder { /* private fields */ }Expand description
Builder for RequestWillBeSentEventParams.
Implementations
Sourceimpl RequestWillBeSentEventParamsBuilder
impl RequestWillBeSentEventParamsBuilder
Sourcepub fn request_id(&mut self, value: RequestId) -> &mut Self
pub fn request_id(&mut self, value: RequestId) -> &mut Self
Request identifier.
Sourcepub fn loader_id(&mut self, value: LoaderId) -> &mut Self
pub fn loader_id(&mut self, value: LoaderId) -> &mut Self
Loader identifier. Empty string if the request is fetched from worker.
Sourcepub fn document_url(&mut self, value: String) -> &mut Self
pub fn document_url(&mut self, value: String) -> &mut Self
URL of the document this request is loaded for.
Sourcepub fn timestamp(&mut self, value: MonotonicTime) -> &mut Self
pub fn timestamp(&mut self, value: MonotonicTime) -> &mut Self
Timestamp.
Sourcepub fn wall_time(&mut self, value: TimeSinceEpoch) -> &mut Self
pub fn wall_time(&mut self, value: TimeSinceEpoch) -> &mut Self
Timestamp.
Sourcepub fn redirect_has_extra_info(&mut self, value: bool) -> &mut Self
pub fn redirect_has_extra_info(&mut self, value: bool) -> &mut Self
In the case that redirectResponse is populated, this flag indicates whether requestWillBeSentExtraInfo and responseReceivedExtraInfo events will be or were emitted for the request which was just redirected.
Sourcepub fn redirect_response(&mut self, value: Option<Response>) -> &mut Self
pub fn redirect_response(&mut self, value: Option<Response>) -> &mut Self
Redirect response data.
Sourcepub fn type(&mut self, value: Option<ResourceType>) -> &mut Self
pub fn type(&mut self, value: Option<ResourceType>) -> &mut Self
Type of this resource.
Sourcepub fn has_user_gesture(&mut self, value: Option<bool>) -> &mut Self
pub fn has_user_gesture(&mut self, value: Option<bool>) -> &mut Self
Whether the request is initiated by a user gesture. Defaults to false.
Sourcepub fn render_blocking_behavior(
&mut self,
value: Option<RenderBlockingBehavior>,
) -> &mut Self
pub fn render_blocking_behavior( &mut self, value: Option<RenderBlockingBehavior>, ) -> &mut Self
The render blocking behavior of the request.
Sourcepub fn build(
&self,
) -> Result<RequestWillBeSentEventParams, RequestWillBeSentEventParamsBuilderError>
pub fn build( &self, ) -> Result<RequestWillBeSentEventParams, RequestWillBeSentEventParamsBuilderError>