pub struct AssociatedCookieBuilder { /* private fields */ }Expand description
Builder for AssociatedCookie.
Implementations
Sourceimpl AssociatedCookieBuilder
impl AssociatedCookieBuilder
The cookie object representing the cookie which was not sent.
Sourcepub fn blocked_reasons<VALUE: Into<Vec<CookieBlockedReason>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn blocked_reasons<VALUE: Into<Vec<CookieBlockedReason>>>( &mut self, value: VALUE, ) -> &mut Self
The reason(s) the cookie was blocked. If empty means the cookie is included.
Sourcepub fn exemption_reason<VALUE: Into<CookieExemptionReason>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn exemption_reason<VALUE: Into<CookieExemptionReason>>( &mut self, value: VALUE, ) -> &mut Self
The reason the cookie should have been blocked by 3PCD but is exempted. A cookie could only have at most one exemption reason.
Sourcepub fn build(&self) -> Result<AssociatedCookie, AssociatedCookieBuilderError>
pub fn build(&self) -> Result<AssociatedCookie, AssociatedCookieBuilderError>