pub struct ContinueInterceptedRequestBuilder { /* private fields */ }Expand description
Builder for ContinueInterceptedRequest.
Implementations
Sourceimpl ContinueInterceptedRequestBuilder
impl ContinueInterceptedRequestBuilder
pub fn interception_id<VALUE: Into<InterceptionId>>( &mut self, value: VALUE, ) -> &mut Self
Sourcepub fn error_reason<VALUE: Into<ErrorReason>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn error_reason<VALUE: Into<ErrorReason>>( &mut self, value: VALUE, ) -> &mut Self
If set this causes the request to fail with the given reason. Passing Aborted for requests
marked with isNavigationRequest also cancels the navigation. Must not be set in response
to an authChallenge.
Sourcepub fn raw_response<VALUE: Into<Vec<u8>>>(&mut self, value: VALUE) -> &mut Self
pub fn raw_response<VALUE: Into<Vec<u8>>>(&mut self, value: VALUE) -> &mut Self
If set the requests completes using with the provided base64 encoded raw response, including HTTP status line and headers etc… Must not be set in response to an authChallenge.
Sourcepub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
If set the request url will be modified in a way that’s not observable by page. Must not be set in response to an authChallenge.
Sourcepub fn method<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn method<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
If set this allows the request method to be overridden. Must not be set in response to an authChallenge.
Sourcepub fn post_data<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn post_data<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
If set this allows postData to be set. Must not be set in response to an authChallenge.
Sourcepub fn headers<VALUE: Into<Headers>>(&mut self, value: VALUE) -> &mut Self
pub fn headers<VALUE: Into<Headers>>(&mut self, value: VALUE) -> &mut Self
If set this allows the request headers to be changed. Must not be set in response to an authChallenge.
Sourcepub fn auth_challenge_response<VALUE: Into<AuthChallengeResponse>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn auth_challenge_response<VALUE: Into<AuthChallengeResponse>>( &mut self, value: VALUE, ) -> &mut Self
Response to a requestIntercepted with an authChallenge. Must not be set otherwise.
Sourcepub fn build(
&self,
) -> Result<ContinueInterceptedRequest, ContinueInterceptedRequestBuilderError>
pub fn build( &self, ) -> Result<ContinueInterceptedRequest, ContinueInterceptedRequestBuilderError>