pub struct EmulateNetworkConditions {
pub offline: bool,
pub latency: JsFloat,
pub download_throughput: JsFloat,
pub upload_throughput: JsFloat,
pub connection_type: Option<ConnectionType>,
pub packet_loss: Option<JsFloat>,
pub packet_queue_length: Option<JsUInt>,
pub packet_reordering: Option<bool>,
}👎Deprecated
Activates emulation of network conditions. This command is deprecated in favor of the emulateNetworkConditionsByRule and overrideNetworkState commands, which can be used together to the same effect.
Fields
offline: bool👎Deprecated
True to emulate internet disconnection.
latency: JsFloat👎Deprecated
Minimum latency from request sent to response headers received (ms).
download_throughput: JsFloat👎Deprecated
Maximal aggregated download throughput (bytes/sec). -1 disables download throttling.
upload_throughput: JsFloat👎Deprecated
Maximal aggregated upload throughput (bytes/sec). -1 disables upload throttling.
connection_type: Option<ConnectionType>👎Deprecated
Connection type if known.
packet_loss: Option<JsFloat>👎Deprecated
WebRTC packet loss (percent, 0-100). 0 disables packet loss emulation, 100 drops all the packets.
packet_queue_length: Option<JsUInt>👎Deprecated
WebRTC packet queue length (packet). 0 removes any queue length limitations.
packet_reordering: Option<bool>👎Deprecated
WebRTC packetReordering feature.