pub struct EmulateNetworkConditionsReturnObject(pub Option<Value>);๐Deprecated
Activates emulation of network conditions. This command is deprecated in favor of the emulateNetworkConditionsByRule and overrideNetworkState commands, which can be used together to the same effect.
Tuple Fields
0: Option<Value>๐Deprecated