pub struct GetCookiesBuilder { /* private fields */ }Expand description
Builder for GetCookies.
Implementations
Sourceimpl GetCookiesBuilder
impl GetCookiesBuilder
Sourcepub fn urls<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
pub fn urls<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
The list of URLs for which applicable cookies will be fetched. If not specified, it’s assumed to be set to the list containing the URLs of the page and all of its subframes.
Sourcepub fn build(&self) -> Result<GetCookies, GetCookiesBuilderError>
pub fn build(&self) -> Result<GetCookies, GetCookiesBuilderError>