pub struct ReportingApiReportBuilder { /* private fields */ }Expand description
Builder for ReportingApiReport.
Implementations
Sourceimpl ReportingApiReportBuilder
impl ReportingApiReportBuilder
pub fn id<VALUE: Into<ReportId>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn initiator_url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn initiator_url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The URL of the document that triggered the report.
Sourcepub fn destination<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn destination<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The name of the endpoint group that should be used to deliver the report.
Sourcepub fn type<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn type<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The type of the report (specifies the set of data that is contained in the report body).
Sourcepub fn timestamp<VALUE: Into<TimeSinceEpoch>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn timestamp<VALUE: Into<TimeSinceEpoch>>( &mut self, value: VALUE, ) -> &mut Self
When the report was generated.
Sourcepub fn depth<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn depth<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
How many uploads deep the related request was.
Sourcepub fn completed_attempts<VALUE: Into<JsUInt>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn completed_attempts<VALUE: Into<JsUInt>>( &mut self, value: VALUE, ) -> &mut Self
The number of delivery attempts made so far, not including an active attempt.
pub fn body<VALUE: Into<Json>>(&mut self, value: VALUE) -> &mut Self
pub fn status<VALUE: Into<ReportStatus>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn build(
&self,
) -> Result<ReportingApiReport, ReportingApiReportBuilderError>
pub fn build( &self, ) -> Result<ReportingApiReport, ReportingApiReportBuilderError>