pub struct ResponseBuilder { /* private fields */ }Expand description
Builder for Response.
Implementations
Sourceimpl ResponseBuilder
impl ResponseBuilder
Sourcepub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Response URL. This URL can be different from CachedResource.url in case of redirect.
Sourcepub fn status<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn status<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
HTTP response status code.
Sourcepub fn status_text<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn status_text<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
HTTP response status text.
Sourcepub fn headers<VALUE: Into<Headers>>(&mut self, value: VALUE) -> &mut Self
pub fn headers<VALUE: Into<Headers>>(&mut self, value: VALUE) -> &mut Self
HTTP response headers.
Sourcepub fn headers_text<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn headers_text<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
HTTP response headers text. This has been replaced by the headers in Network.responseReceivedExtraInfo.
Sourcepub fn mime_type<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn mime_type<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Resource mimeType as determined by the browser.
Sourcepub fn charset<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn charset<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Resource charset as determined by the browser (if applicable).
Sourcepub fn request_headers<VALUE: Into<Headers>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn request_headers<VALUE: Into<Headers>>( &mut self, value: VALUE, ) -> &mut Self
Refined HTTP request headers that were actually transmitted over the network.
Sourcepub fn request_headers_text<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn request_headers_text<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
HTTP request headers text. This has been replaced by the headers in Network.requestWillBeSentExtraInfo.
Sourcepub fn connection_reused<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn connection_reused<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Specifies whether physical connection was actually reused for this request.
Sourcepub fn connection_id<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn connection_id<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
Physical connection id that was actually used for this request.
Sourcepub fn remote_ip_address<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn remote_ip_address<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
Remote IP address.
Sourcepub fn remote_port<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn remote_port<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Remote port.
Sourcepub fn from_disk_cache<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn from_disk_cache<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Specifies that the request was served from the disk cache.
Sourcepub fn from_service_worker<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn from_service_worker<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Specifies that the request was served from the ServiceWorker.
Sourcepub fn from_prefetch_cache<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn from_prefetch_cache<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Specifies that the request was served from the prefetch cache.
Sourcepub fn from_early_hints<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn from_early_hints<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Specifies that the request was served from the prefetch cache.
Sourcepub fn service_worker_router_info<VALUE: Into<ServiceWorkerRouterInfo>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn service_worker_router_info<VALUE: Into<ServiceWorkerRouterInfo>>( &mut self, value: VALUE, ) -> &mut Self
Information about how ServiceWorker Static Router API was used. If this
field is set with matchedSourceType field, a matching rule is found.
If this field is set without matchedSource, no matching rule is found.
Otherwise, the API is not used.
Sourcepub fn encoded_data_length<VALUE: Into<JsFloat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn encoded_data_length<VALUE: Into<JsFloat>>( &mut self, value: VALUE, ) -> &mut Self
Total number of bytes received for this request so far.
Sourcepub fn timing<VALUE: Into<ResourceTiming>>(&mut self, value: VALUE) -> &mut Self
pub fn timing<VALUE: Into<ResourceTiming>>(&mut self, value: VALUE) -> &mut Self
Timing information for the given request.
Sourcepub fn service_worker_response_source<VALUE: Into<ServiceWorkerResponseSource>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn service_worker_response_source<VALUE: Into<ServiceWorkerResponseSource>>( &mut self, value: VALUE, ) -> &mut Self
Response source of response from ServiceWorker.
Sourcepub fn response_time<VALUE: Into<TimeSinceEpoch>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn response_time<VALUE: Into<TimeSinceEpoch>>( &mut self, value: VALUE, ) -> &mut Self
The time at which the returned response was generated.
Sourcepub fn cache_storage_cache_name<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn cache_storage_cache_name<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
Cache Storage Cache Name.
Sourcepub fn protocol<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn protocol<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Protocol used to fetch this request.
Sourcepub fn alternate_protocol_usage<VALUE: Into<AlternateProtocolUsage>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn alternate_protocol_usage<VALUE: Into<AlternateProtocolUsage>>( &mut self, value: VALUE, ) -> &mut Self
The reason why Chrome uses a specific transport protocol for HTTP semantics.
Sourcepub fn security_state<VALUE: Into<SecurityState>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn security_state<VALUE: Into<SecurityState>>( &mut self, value: VALUE, ) -> &mut Self
Security state of the request resource.
Sourcepub fn security_details<VALUE: Into<SecurityDetails>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn security_details<VALUE: Into<SecurityDetails>>( &mut self, value: VALUE, ) -> &mut Self
Security details for the request.