pub struct JavascriptDialogOpeningEventParamsBuilder { /* private fields */ }Expand description
Builder for JavascriptDialogOpeningEventParams.
Implementations
Sourceimpl JavascriptDialogOpeningEventParamsBuilder
impl JavascriptDialogOpeningEventParamsBuilder
Sourcepub fn message(&mut self, value: String) -> &mut Self
pub fn message(&mut self, value: String) -> &mut Self
Message that will be displayed by the dialog.
Sourcepub fn type(&mut self, value: DialogType) -> &mut Self
pub fn type(&mut self, value: DialogType) -> &mut Self
Dialog type.
Sourcepub fn has_browser_handler(&mut self, value: bool) -> &mut Self
pub fn has_browser_handler(&mut self, value: bool) -> &mut Self
True iff browser is capable showing or acting on the given dialog. When browser has no dialog handler for given target, calling alert while Page domain is engaged will stall the page execution. Execution can be resumed via calling Page.handleJavaScriptDialog.
Sourcepub fn default_prompt(&mut self, value: Option<String>) -> &mut Self
pub fn default_prompt(&mut self, value: Option<String>) -> &mut Self
Default dialog prompt.
Sourcepub fn build(
&self,
) -> Result<JavascriptDialogOpeningEventParams, JavascriptDialogOpeningEventParamsBuilderError>
pub fn build( &self, ) -> Result<JavascriptDialogOpeningEventParams, JavascriptDialogOpeningEventParamsBuilderError>
Builds a new JavascriptDialogOpeningEventParams.
Errors
If a required field has not been initialized.