pub struct FrameBuilder { /* private fields */ }Expand description
Builder for Frame.
Implementations
Sourceimpl FrameBuilder
impl FrameBuilder
Sourcepub fn parent_id<VALUE: Into<FrameId>>(&mut self, value: VALUE) -> &mut Self
pub fn parent_id<VALUE: Into<FrameId>>(&mut self, value: VALUE) -> &mut Self
Parent frame identifier.
Sourcepub fn loader_id<VALUE: Into<LoaderId>>(&mut self, value: VALUE) -> &mut Self
pub fn loader_id<VALUE: Into<LoaderId>>(&mut self, value: VALUE) -> &mut Self
Identifier of the loader associated with this frame.
Sourcepub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Frame’s name as specified in the tag.
Sourcepub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Frame document’s URL without fragment.
Sourcepub fn url_fragment<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn url_fragment<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Frame document’s URL fragment including the ‘#’.
Sourcepub fn domain_and_registry<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn domain_and_registry<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
Frame document’s registered domain, taking the public suffixes list into account. Extracted from the Frame’s url. Example URLs: http://www.google.com/file.html -> “google.com” http://a.b.co.uk/file.html -> “b.co.uk”
Sourcepub fn security_origin<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn security_origin<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
Frame document’s security origin.
Sourcepub fn security_origin_details<VALUE: Into<SecurityOriginDetails>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn security_origin_details<VALUE: Into<SecurityOriginDetails>>( &mut self, value: VALUE, ) -> &mut Self
Additional details about the frame document’s security origin.
Sourcepub fn mime_type<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn mime_type<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Frame document’s mimeType as determined by the browser.
Sourcepub fn unreachable_url<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn unreachable_url<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
If the frame failed to load, this contains the URL that could not be loaded. Note that unlike url above, this URL may contain a fragment.
Sourcepub fn ad_frame_status<VALUE: Into<AdFrameStatus>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn ad_frame_status<VALUE: Into<AdFrameStatus>>( &mut self, value: VALUE, ) -> &mut Self
Indicates whether this frame was tagged as an ad and why.
Sourcepub fn secure_context_type<VALUE: Into<SecureContextType>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn secure_context_type<VALUE: Into<SecureContextType>>( &mut self, value: VALUE, ) -> &mut Self
Indicates whether the main document is a secure context and explains why that is the case.
Sourcepub fn cross_origin_isolated_context_type<VALUE: Into<CrossOriginIsolatedContextType>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn cross_origin_isolated_context_type<VALUE: Into<CrossOriginIsolatedContextType>>( &mut self, value: VALUE, ) -> &mut Self
Indicates whether this is a cross origin isolated context.
Sourcepub fn gated_api_features<VALUE: Into<Vec<GatedApiFeatures>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn gated_api_features<VALUE: Into<Vec<GatedApiFeatures>>>( &mut self, value: VALUE, ) -> &mut Self
Indicated which gated APIs / features are available.