pub struct GetAdScriptAncestryReturnObjectBuilder { /* private fields */ }Expand description
Builder for GetAdScriptAncestryReturnObject.
Implementations
Sourceimpl GetAdScriptAncestryReturnObjectBuilder
impl GetAdScriptAncestryReturnObjectBuilder
Sourcepub fn ad_script_ancestry(
&mut self,
value: Option<AdScriptAncestry>,
) -> &mut Self
pub fn ad_script_ancestry( &mut self, value: Option<AdScriptAncestry>, ) -> &mut Self
The ancestry chain of ad script identifiers leading to this frame’s creation, along with the root script’s filterlist rule. The ancestry chain is ordered from the most immediate script (in the frame creation stack) to more distant ancestors (that created the immediately preceding script). Only sent if frame is labelled as an ad and ids are available.
Sourcepub fn build(
&self,
) -> Result<GetAdScriptAncestryReturnObject, GetAdScriptAncestryReturnObjectBuilderError>
pub fn build( &self, ) -> Result<GetAdScriptAncestryReturnObject, GetAdScriptAncestryReturnObjectBuilderError>