pub struct GetAppManifest {
pub manifest_id: Option<String>,
}Expand description
Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.
Fields
manifest_id: Option<String>Trait Implementations
Sourceimpl Clone for GetAppManifest
impl Clone for GetAppManifest
Sourcefn clone(&self) -> GetAppManifest
fn clone(&self) -> GetAppManifest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetAppManifest
impl Debug for GetAppManifest
Sourceimpl<'de> Deserialize<'de> for GetAppManifest
impl<'de> Deserialize<'de> for GetAppManifest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Method for GetAppManifest
impl Method for GetAppManifest
const NAME: &'static str = "Page.getAppManifest"
type ReturnObject = GetAppManifestReturnObject
fn to_method_call(self, call_id: CallId) -> MethodCall<Self>where
Self: Sized,
Sourceimpl PartialEq for GetAppManifest
impl PartialEq for GetAppManifest
Sourceimpl Serialize for GetAppManifest
impl Serialize for GetAppManifest
impl StructuralPartialEq for GetAppManifest