pub struct GetAppManifestReturnObject {
pub url: String,
pub errors: Vec<AppManifestError>,
pub data: Option<String>,
pub parsed: Option<AppManifestParsedProperties>,
pub manifest: WebAppManifest,
}Expand description
Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.
Fields
url: StringManifest location.
errors: Vec<AppManifestError>data: Option<String>Manifest content.
parsed: Option<AppManifestParsedProperties>👎Deprecated
Parsed manifest properties. Deprecated, use manifest instead.
manifest: WebAppManifestTrait Implementations
Sourceimpl Clone for GetAppManifestReturnObject
impl Clone for GetAppManifestReturnObject
Sourcefn clone(&self) -> GetAppManifestReturnObject
fn clone(&self) -> GetAppManifestReturnObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetAppManifestReturnObject
impl Debug for GetAppManifestReturnObject
Sourceimpl<'de> Deserialize<'de> for GetAppManifestReturnObject
impl<'de> Deserialize<'de> for GetAppManifestReturnObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for GetAppManifestReturnObject