Modules
Structs
- Disable
- Disable
Return Object - Enable
- Enable
Return Object - Preloading
Attempt Key - A key that identifies a preloading attempt.
- Preloading
Attempt KeyBuilder - Builder for
PreloadingAttemptKey. - Preloading
Attempt Source - Lists sources for a preloading attempt, specifically the ids of rule sets that had a speculation rule that triggered the attempt, and the BackendNodeIds of <a href> or <area href> elements that triggered the attempt (in the case of attempts triggered by a document rule). It is possible for multiple rule sets and links to trigger a single attempt.
- Preloading
Attempt Source Builder - Builder for
PreloadingAttemptSource. - Prerender
Mismatched Headers - Information of headers to be displayed when the header mismatch occurred.
- Prerender
Mismatched Headers Builder - Builder for
PrerenderMismatchedHeaders. - RuleSet
- Corresponds to SpeculationRuleSet
- Rule
SetBuilder - Builder for
RuleSet.
Enums
- Prefetch
Status - Preloading
Attempt KeyBuilder Error - Error type for PreloadingAttemptKeyBuilder
- Preloading
Attempt Source Builder Error - Error type for PreloadingAttemptSourceBuilder
- Preloading
Status - Prerender
Final Status - Prerender
Mismatched Headers Builder Error - Error type for PrerenderMismatchedHeadersBuilder
- Rule
SetBuilder Error - Error type for RuleSetBuilder
- Rule
SetError Type - Speculation
Action - Speculation
Target Hint