pub struct ChangeAppUserSettingsBuilder { /* private fields */ }Expand description
Builder for ChangeAppUserSettings.
Implementations
Sourceimpl ChangeAppUserSettingsBuilder
impl ChangeAppUserSettingsBuilder
pub fn manifest_id<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn link_capturing<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn link_capturing<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If user allows the links clicked on by the user in the app’s scope, or
extended scope if the manifest has scope extensions and the flags
DesktopPWAsLinkCapturingWithScopeExtensions and
WebAppEnableScopeExtensions are enabled.
Note, the API does not support resetting the linkCapturing to the initial value, uninstalling and installing the web app again will reset it.
TODO(crbug.com/339453269): Setting this value on ChromeOS is not supported yet.
pub fn display_mode<VALUE: Into<DisplayMode>>( &mut self, value: VALUE, ) -> &mut Self
Sourcepub fn build(
&self,
) -> Result<ChangeAppUserSettings, ChangeAppUserSettingsBuilderError>
pub fn build( &self, ) -> Result<ChangeAppUserSettings, ChangeAppUserSettingsBuilderError>