pub struct AddBindingReturnObject(pub Option<Value>);Expand description
If executionContextId is empty, adds binding with the given name on the global objects of all inspected contexts, including those created later, bindings survive reloads. Binding function takes exactly one argument, this argument should be string, in case of any other input, function throws an exception. Each binding function call produces Runtime.bindingCalled notification.
Tuple Fields
0: Option<Value>Trait Implementations
Sourceimpl Clone for AddBindingReturnObject
impl Clone for AddBindingReturnObject
Sourcefn clone(&self) -> AddBindingReturnObject
fn clone(&self) -> AddBindingReturnObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddBindingReturnObject
impl Debug for AddBindingReturnObject
Sourceimpl<'de> Deserialize<'de> for AddBindingReturnObject
impl<'de> Deserialize<'de> for AddBindingReturnObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AddBindingReturnObject
impl PartialEq for AddBindingReturnObject
Sourceimpl Serialize for AddBindingReturnObject
impl Serialize for AddBindingReturnObject
impl StructuralPartialEq for AddBindingReturnObject