pub struct RunScriptBuilder { /* private fields */ }Expand description
Builder for RunScript.
Implementations
Sourceimpl RunScriptBuilder
impl RunScriptBuilder
Sourcepub fn script_id<VALUE: Into<ScriptId>>(&mut self, value: VALUE) -> &mut Self
pub fn script_id<VALUE: Into<ScriptId>>(&mut self, value: VALUE) -> &mut Self
Id of the script to run.
Sourcepub fn execution_context_id<VALUE: Into<ExecutionContextId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn execution_context_id<VALUE: Into<ExecutionContextId>>( &mut self, value: VALUE, ) -> &mut Self
Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page.
Sourcepub fn object_group<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn object_group<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Symbolic group name that can be used to release multiple objects.
Sourcepub fn silent<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn silent<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
In silent mode exceptions thrown during evaluation are not reported and do not pause
execution. Overrides setPauseOnException state.
Sourcepub fn include_command_line_api<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn include_command_line_api<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Determines whether Command Line API should be available during the evaluation.
Sourcepub fn return_by_value<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn return_by_value<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether the result is expected to be a JSON object which should be sent by value.
Sourcepub fn generate_preview<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn generate_preview<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether preview should be generated for the result.
Sourcepub fn await_promise<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn await_promise<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether execution should await for resulting value and return once awaited promise is
resolved.