pub struct CertificateSecurityStateBuilder { /* private fields */ }Expand description
Builder for CertificateSecurityState.
Implementations
Sourceimpl CertificateSecurityStateBuilder
impl CertificateSecurityStateBuilder
Sourcepub fn protocol<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn protocol<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Protocol name (e.g. “TLS 1.2” or “QUIC”).
Sourcepub fn key_exchange<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn key_exchange<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Key Exchange used by the connection, or the empty string if not applicable.
Sourcepub fn key_exchange_group<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn key_exchange_group<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
(EC)DH group used by the connection, if applicable.
Sourcepub fn mac<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn mac<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
TLS MAC. Note that AEAD ciphers do not have separate MACs.
Sourcepub fn certificate<VALUE: Into<Vec<String>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn certificate<VALUE: Into<Vec<String>>>( &mut self, value: VALUE, ) -> &mut Self
Page certificate.
Sourcepub fn subject_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn subject_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Certificate subject name.
Sourcepub fn issuer<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn issuer<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Name of the issuing CA.
Sourcepub fn valid_from<VALUE: Into<TimeSinceEpoch>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn valid_from<VALUE: Into<TimeSinceEpoch>>( &mut self, value: VALUE, ) -> &mut Self
Certificate valid from date.
Sourcepub fn valid_to<VALUE: Into<TimeSinceEpoch>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn valid_to<VALUE: Into<TimeSinceEpoch>>( &mut self, value: VALUE, ) -> &mut Self
Certificate valid to (expiration) date
Sourcepub fn certificate_network_error<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn certificate_network_error<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
The highest priority network error code, if the certificate has an error.
Sourcepub fn certificate_has_weak_signature<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn certificate_has_weak_signature<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
True if the certificate uses a weak signature algorithm.
Sourcepub fn certificate_has_sha_1_signature<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn certificate_has_sha_1_signature<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
True if the certificate has a SHA1 signature in the chain.
Sourcepub fn modern_ssl<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn modern_ssl<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
True if modern SSL
Sourcepub fn obsolete_ssl_protocol<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn obsolete_ssl_protocol<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
True if the connection is using an obsolete SSL protocol.
Sourcepub fn obsolete_ssl_key_exchange<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn obsolete_ssl_key_exchange<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
True if the connection is using an obsolete SSL key exchange.
Sourcepub fn obsolete_ssl_cipher<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn obsolete_ssl_cipher<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
True if the connection is using an obsolete SSL cipher.
Sourcepub fn obsolete_ssl_signature<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn obsolete_ssl_signature<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
True if the connection is using an obsolete SSL signature.
Sourcepub fn build(
&self,
) -> Result<CertificateSecurityState, CertificateSecurityStateBuilderError>
pub fn build( &self, ) -> Result<CertificateSecurityState, CertificateSecurityStateBuilderError>