pub struct OverrideQuotaForOriginBuilder { /* private fields */ }Expand description
Builder for OverrideQuotaForOrigin.
Implementations
Sourceimpl OverrideQuotaForOriginBuilder
impl OverrideQuotaForOriginBuilder
Sourcepub fn quota_size<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
pub fn quota_size<VALUE: Into<JsFloat>>(&mut self, value: VALUE) -> &mut Self
The quota size (in bytes) to override the original quota with. If this is called multiple times, the overridden quota will be equal to the quotaSize provided in the final call. If this is called without specifying a quotaSize, the quota will be reset to the default value for the specified origin. If this is called multiple times with different origins, the override will be maintained for each origin until it is disabled (called without a quotaSize).
Sourcepub fn build(
&self,
) -> Result<OverrideQuotaForOrigin, OverrideQuotaForOriginBuilderError>
pub fn build( &self, ) -> Result<OverrideQuotaForOrigin, OverrideQuotaForOriginBuilderError>