pub struct SharedStorageAccessParamsBuilder { /* private fields */ }Expand description
Builder for SharedStorageAccessParams.
Implementations
Sourcepub fn script_source_url<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn script_source_url<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
Spec of the module script URL. Present only for SharedStorageAccessMethods: addModule and createWorklet.
Sourcepub fn data_origin<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn data_origin<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
String denoting “context-origin”, “script-origin”, or a custom origin to be used as the worklet’s data origin. Present only for SharedStorageAccessMethod: createWorklet.
Sourcepub fn operation_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn operation_name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Name of the registered operation to be run. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn operation_id<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn operation_id<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
ID of the operation call. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn keep_alive<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn keep_alive<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether or not to keep the worket alive for future run or selectURL calls. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn private_aggregation_config<VALUE: Into<SharedStoragePrivateAggregationConfig>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn private_aggregation_config<VALUE: Into<SharedStoragePrivateAggregationConfig>>( &mut self, value: VALUE, ) -> &mut Self
Configures the private aggregation options. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn serialized_data<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn serialized_data<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
The operation’s serialized data in bytes (converted to a string). Present only for SharedStorageAccessMethods: run and selectURL. TODO(crbug.com/401011862): Consider updating this parameter to binary.
Sourcepub fn urls_with_metadata<VALUE: Into<Vec<SharedStorageUrlWithMetadata>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn urls_with_metadata<VALUE: Into<Vec<SharedStorageUrlWithMetadata>>>( &mut self, value: VALUE, ) -> &mut Self
Array of candidate URLs’ specs, along with any associated metadata. Present only for SharedStorageAccessMethod: selectURL.
Sourcepub fn urn_uuid<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn urn_uuid<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Spec of the URN:UUID generated for a selectURL call. Present only for SharedStorageAccessMethod: selectURL.
Sourcepub fn key<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn key<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Key for a specific entry in an origin’s shared storage. Present only for SharedStorageAccessMethods: set, append, delete, and get.
Sourcepub fn value<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn value<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Value for a specific entry in an origin’s shared storage. Present only for SharedStorageAccessMethods: set and append.
Sourcepub fn ignore_if_present<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn ignore_if_present<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Whether or not to set an entry for a key if that key is already present. Present only for SharedStorageAccessMethod: set.
Sourcepub fn worklet_ordinal<VALUE: Into<JsUInt>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn worklet_ordinal<VALUE: Into<JsUInt>>( &mut self, value: VALUE, ) -> &mut Self
A number denoting the (0-based) order of the worklet’s creation relative to all other shared storage worklets created by documents using the current storage partition. Present only for SharedStorageAccessMethods: addModule, createWorklet.
Sourcepub fn worklet_target_id<VALUE: Into<TargetId>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn worklet_target_id<VALUE: Into<TargetId>>( &mut self, value: VALUE, ) -> &mut Self
Hex representation of the DevTools token used as the TargetID for the associated shared storage worklet. Present only for SharedStorageAccessMethods: addModule, createWorklet, run, selectURL, and any other SharedStorageAccessMethod when the SharedStorageAccessScope is sharedStorageWorklet.
Sourcepub fn with_lock<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn with_lock<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Name of the lock to be acquired, if present. Optionally present only for SharedStorageAccessMethods: batchUpdate, set, append, delete, and clear.
Sourcepub fn batch_update_id<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn batch_update_id<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
If the method has been called as part of a batchUpdate, then this number identifies the batch to which it belongs. Optionally present only for SharedStorageAccessMethods: batchUpdate (required), set, append, delete, and clear.
Sourcepub fn batch_size<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
pub fn batch_size<VALUE: Into<JsUInt>>(&mut self, value: VALUE) -> &mut Self
Number of modifier methods sent in batch. Present only for SharedStorageAccessMethod: batchUpdate.
Sourcepub fn build(
&self,
) -> Result<SharedStorageAccessParams, SharedStorageAccessParamsBuilderError>
pub fn build( &self, ) -> Result<SharedStorageAccessParams, SharedStorageAccessParamsBuilderError>