pub struct VirtualAuthenticatorOptionsBuilder { /* private fields */ }Expand description
Builder for VirtualAuthenticatorOptions.
Implementations
Sourceimpl VirtualAuthenticatorOptionsBuilder
impl VirtualAuthenticatorOptionsBuilder
pub fn protocol<VALUE: Into<AuthenticatorProtocol>>( &mut self, value: VALUE, ) -> &mut Self
Sourcepub fn ctap_2_version<VALUE: Into<Ctap2Version>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn ctap_2_version<VALUE: Into<Ctap2Version>>( &mut self, value: VALUE, ) -> &mut Self
Defaults to ctap2_0. Ignored if |protocol| == u2f.
pub fn transport<VALUE: Into<AuthenticatorTransport>>( &mut self, value: VALUE, ) -> &mut Self
Sourcepub fn has_resident_key<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn has_resident_key<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Defaults to false.
Sourcepub fn has_user_verification<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn has_user_verification<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Defaults to false.
Sourcepub fn has_large_blob<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn has_large_blob<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If set to true, the authenticator will support the largeBlob extension. https://w3c.github.io/webauthn#largeBlob Defaults to false.
Sourcepub fn has_cred_blob<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn has_cred_blob<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If set to true, the authenticator will support the credBlob extension. https://fidoalliance.org/specs/fido-v2.1-rd-20201208/fido-client-to-authenticator-protocol-v2.1-rd-20201208.html#sctn-credBlob-extension Defaults to false.
Sourcepub fn has_min_pin_length<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn has_min_pin_length<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
If set to true, the authenticator will support the minPinLength extension. https://fidoalliance.org/specs/fido-v2.1-ps-20210615/fido-client-to-authenticator-protocol-v2.1-ps-20210615.html#sctn-minpinlength-extension Defaults to false.
Sourcepub fn has_prf<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn has_prf<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If set to true, the authenticator will support the prf extension. https://w3c.github.io/webauthn/#prf-extension Defaults to false.
Sourcepub fn automatic_presence_simulation<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn automatic_presence_simulation<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
If set to true, tests of user presence will succeed immediately. Otherwise, they will not be resolved. Defaults to true.
Sourcepub fn is_user_verified<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn is_user_verified<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Sets whether User Verification succeeds or fails for an authenticator. Defaults to false.
Sourcepub fn default_backup_eligibility<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn default_backup_eligibility<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Credentials created by this authenticator will have the backup eligibility (BE) flag set to this value. Defaults to false. https://w3c.github.io/webauthn/#sctn-credential-backup
Sourcepub fn default_backup_state<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn default_backup_state<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Credentials created by this authenticator will have the backup state (BS) flag set to this value. Defaults to false. https://w3c.github.io/webauthn/#sctn-credential-backup
Sourcepub fn build(
&self,
) -> Result<VirtualAuthenticatorOptions, VirtualAuthenticatorOptionsBuilderError>
pub fn build( &self, ) -> Result<VirtualAuthenticatorOptions, VirtualAuthenticatorOptionsBuilderError>